""" Cisco_IOS_XR_ifmgr_cfg 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ifmgr package configuration.

This module contains definitions
for the following management objects\:
  global\-interface\-configuration\: Global scoped configuration
    for interfaces
  interface\-configurations\: interface configurations

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class InterfaceModeEnum(Enum):
    """
    InterfaceModeEnum

    Interface mode enum

    .. data:: default = 0

    	Default Interface Mode

    .. data:: point_to_point = 1

    	Point-to-Point Interface Mode

    .. data:: multipoint = 2

    	Multipoint Interface Mode

    .. data:: l2_transport = 3

    	L2 Transport Interface Mode

    """

    default = Enum.YLeaf(0, "default")

    point_to_point = Enum.YLeaf(1, "point-to-point")

    multipoint = Enum.YLeaf(2, "multipoint")

    l2_transport = Enum.YLeaf(3, "l2-transport")


class LinkStatusEnum(Enum):
    """
    LinkStatusEnum

    Link status enum

    .. data:: default = 0

    	Display link status messages for physical links

    .. data:: disable = 1

    	Disable link status messages

    .. data:: software_interfaces = 2

    	Display link status messages for all interfaces

    """

    default = Enum.YLeaf(0, "default")

    disable = Enum.YLeaf(1, "disable")

    software_interfaces = Enum.YLeaf(2, "software-interfaces")


class SecondaryAdminStateEnum(Enum):
    """
    SecondaryAdminStateEnum

    Secondary admin state enum

    .. data:: normal = 0

    	Normal Mode

    .. data:: maintenance = 1

    	Maintenance Mode

    """

    normal = Enum.YLeaf(0, "normal")

    maintenance = Enum.YLeaf(1, "maintenance")



class GlobalInterfaceConfiguration(Entity):
    """
    Global scoped configuration for interfaces
    
    .. attribute:: link_status
    
    	Enable or disable link\-status messages
    	**type**\:   :py:class:`LinkStatusEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.LinkStatusEnum>`
    
    	**default value**\: default
    
    

    """

    _prefix = 'ifmgr-cfg'
    _revision = '2015-07-30'

    def __init__(self):
        super(GlobalInterfaceConfiguration, self).__init__()
        self._top_entity = None

        self.yang_name = "global-interface-configuration"
        self.yang_parent_name = "Cisco-IOS-XR-ifmgr-cfg"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {}
        self._child_list_classes = {}

        self.link_status = YLeaf(YType.enumeration, "link-status")
        self._segment_path = lambda: "Cisco-IOS-XR-ifmgr-cfg:global-interface-configuration"

    def __setattr__(self, name, value):
        self._perform_setattr(GlobalInterfaceConfiguration, ['link_status'], name, value)

    def clone_ptr(self):
        self._top_entity = GlobalInterfaceConfiguration()
        return self._top_entity

class InterfaceConfigurations(Entity):
    """
    interface configurations
    
    .. attribute:: interface_configuration
    
    	The configuration for an interface
    	**type**\: list of    :py:class:`InterfaceConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration>`
    
    

    """

    _prefix = 'ifmgr-cfg'
    _revision = '2015-07-30'

    def __init__(self):
        super(InterfaceConfigurations, self).__init__()
        self._top_entity = None

        self.yang_name = "interface-configurations"
        self.yang_parent_name = "Cisco-IOS-XR-ifmgr-cfg"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {}
        self._child_list_classes = {"interface-configuration" : ("interface_configuration", InterfaceConfigurations.InterfaceConfiguration)}

        self.interface_configuration = YList(self)
        self._segment_path = lambda: "Cisco-IOS-XR-ifmgr-cfg:interface-configurations"

    def __setattr__(self, name, value):
        self._perform_setattr(InterfaceConfigurations, [], name, value)


    class InterfaceConfiguration(Entity):
        """
        The configuration for an interface
        
        .. attribute:: active  <key>
        
        	Whether the interface is active or preconfigured
        	**type**\:  str
        
        	**pattern:** (act)\|(pre)
        
        .. attribute:: interface_name  <key>
        
        	The name of the interface
        	**type**\:  str
        
        	**pattern:** [a\-zA\-Z0\-9./\-]+
        
        .. attribute:: aaa_table
        
        	AAA configuration
        	**type**\:   :py:class:`AaaTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.AaaTable>`
        
        .. attribute:: afs
        
        	Per\-address\-family and topology configuration
        	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Afs>`
        
        .. attribute:: atm
        
        	ATM Configuration
        	**type**\:   :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm>`
        
        .. attribute:: bandwidth
        
        	The bandwidth of the interface in kbps
        	**type**\:  int
        
        	**range:** 0..4294967295
        
        	**units**\: kbit/s
        
        .. attribute:: bfd
        
        	BFD over bundle members configuration
        	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd>`
        
        .. attribute:: bundle
        
        	Generic per\-bundle configuration
        	**type**\:   :py:class:`Bundle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle>`
        
        .. attribute:: bundle_member
        
        	Generic per\-member configuration
        	**type**\:   :py:class:`BundleMember <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.BundleMember>`
        
        .. attribute:: bvi
        
        	BVI attributes
        	**type**\:   :py:class:`Bvi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bvi>`
        
        .. attribute:: carrier_delay
        
        	Set the carrier transition delay on an interface in msecs
        	**type**\:   :py:class:`CarrierDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CarrierDelay>`
        
        .. attribute:: cdp
        
        	Interface specific CDP configuration
        	**type**\:   :py:class:`Cdp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Cdp>`
        
        .. attribute:: cisco_ios_xr_freqsync_cfg_frequency_synchronization
        
        	Frequency Synchronization interface configuration
        	**type**\:   :py:class:`CiscoIOSXRFreqsyncCfgFrequencySynchronization <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization>`
        
        .. attribute:: cisco_ios_xr_ncs4k_freqsync_cfg_frequency_synchronization
        
        	Frequency Synchronization interface configuration
        	**type**\:   :py:class:`CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIOSXRPppMaCfgPpp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaCfgPpp>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_fsm_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIOSXRPppMaFsmCfgPpp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaFsmCfgPpp>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_ipcp_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIOSXRPppMaIpcpCfgPpp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIOSXRPppMaIpcpiwCfgPpp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpiwCfgPpp>`
        
        .. attribute:: cisco_ios_xr_ppp_ma_lcp_cfg_ppp
        
        	Interface PPP configuration data
        	**type**\:   :py:class:`CiscoIOSXRPppMaLcpCfgPpp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp>`
        
        .. attribute:: dagrs
        
        	Direct\-Attached Gateway Redundancy configuration
        	**type**\:   :py:class:`Dagrs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs>`
        
        .. attribute:: dampening
        
        	Whether this interface's state changes are dampened or not
        	**type**\:   :py:class:`Dampening <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dampening>`
        
        .. attribute:: description
        
        	The description of this interface
        	**type**\:  str
        
        .. attribute:: dot1x_interface
        
        	Interface Specific Dot1x Configuration
        	**type**\:   :py:class:`Dot1XInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dot1XInterface>`
        
        .. attribute:: dwdm
        
        	DWDM port controller configuration
        	**type**\:   :py:class:`Dwdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm>`
        
        .. attribute:: encapsulation
        
        	The encapsulation on the interface
        	**type**\:   :py:class:`Encapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Encapsulation>`
        
        .. attribute:: es_packet_filter
        
        	ES Packet Filtering configuration for the interface
        	**type**\:   :py:class:`EsPacketFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter>`
        
        .. attribute:: ethernet
        
        	Ether specific interface configuration
        	**type**\:   :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet>`
        
        .. attribute:: ethernet_bng
        
        	Ethernet Infra BNG specific configuration
        	**type**\:   :py:class:`EthernetBng <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetBng>`
        
        .. attribute:: ethernet_control
        
        	EthernetControl
        	**type**\:   :py:class:`EthernetControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetControl>`
        
        .. attribute:: ethernet_features
        
        	Ethernet Features Configuration
        	**type**\:   :py:class:`EthernetFeatures <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures>`
        
        .. attribute:: ethernet_service
        
        	Ethernet service configuration
        	**type**\:   :py:class:`EthernetService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetService>`
        
        .. attribute:: fast_shutdown
        
        	Enable Fast Shutdown for this interface
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: interface_mode_non_physical
        
        	The mode in which an interface is running. The existence of this object causes the creation of the software subinterface
        	**type**\:   :py:class:`InterfaceModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceModeEnum>`
        
        	**default value**\: default
        
        .. attribute:: interface_virtual
        
        	The mode in which an interface is running. The existence of this object causes the creation of the software virtual/subinterface
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: ipv4_network
        
        	Interface IPv4 Network configuration data
        	**type**\:   :py:class:`Ipv4Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network>`
        
        .. attribute:: ipv4_network_forwarding
        
        	Interface IPv4 Network configuration data also used for forwarding
        	**type**\:   :py:class:`Ipv4NetworkForwarding <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding>`
        
        .. attribute:: ipv4_packet_filter
        
        	IPv4 Packet Filtering configuration for the interface
        	**type**\:   :py:class:`Ipv4PacketFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter>`
        
        .. attribute:: ipv4arp
        
        	Configure Address Resolution Protocol
        	**type**\:   :py:class:`Ipv4Arp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp>`
        
        .. attribute:: ipv6_neighbor
        
        	IPv6 interface neighbor or neighbor discovery configuration
        	**type**\:   :py:class:`Ipv6Neighbor <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor>`
        
        .. attribute:: ipv6_network
        
        	Interface IPv6 Network configuration data
        	**type**\:   :py:class:`Ipv6Network <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network>`
        
        .. attribute:: ipv6_packet_filter
        
        	IPv6 Packet Filtering configuration for the interface
        	**type**\:   :py:class:`Ipv6PacketFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter>`
        
        .. attribute:: l2_transport
        
        	Interface Layer 2 Transport service configuration data
        	**type**\:   :py:class:`L2Transport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport>`
        
        .. attribute:: lacp
        
        	Link Aggregation Control Protocol per\-interface configuration (for bundle or member)
        	**type**\:   :py:class:`Lacp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lacp>`
        
        .. attribute:: laser_squelch
        
        	Configure Laser\-Squelch
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: link_status
        
        	Enable interface and line\-protocol state change alarms
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: lldp
        
        	Disable LLDP TX or RX
        	**type**\:   :py:class:`Lldp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lldp>`
        
        	**presence node**\: True
        
        .. attribute:: loopbacks
        
        	Configure Extended loopback (diagnostics)
        	**type**\:   :py:class:`Loopbacks <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Loopbacks>`
        
        .. attribute:: mac_accounting
        
        	MAC Accounting Configuration
        	**type**\:   :py:class:`MacAccounting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MacAccounting>`
        
        .. attribute:: mac_addr
        
        	Set the Mac address on an interface
        	**type**\:  str
        
        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
        
        .. attribute:: macsec
        
        	MACSec service for an interface
        	**type**\:   :py:class:`Macsec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Macsec>`
        
        .. attribute:: maintenance_embargo
        
        	configure maintenance embargo flag on the given interface
        	**type**\:  bool
        
        .. attribute:: mlacp
        
        	Multi\-chassis LACP configuration
        	**type**\:   :py:class:`Mlacp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mlacp>`
        
        .. attribute:: mpls
        
        	MPLS configuration under an interface
        	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mpls>`
        
        .. attribute:: mte_tunnel_attributes
        
        	MPLS P2MP tunnel attributes
        	**type**\:   :py:class:`MteTunnelAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes>`
        
        .. attribute:: mtus
        
        	The MTU configuration for the interface
        	**type**\:   :py:class:`Mtus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mtus>`
        
        .. attribute:: net_flow
        
        	Interface netflow configuration
        	**type**\:   :py:class:`NetFlow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow>`
        
        .. attribute:: nv_satellite_access
        
        	nV Satellite Access Link Configuration
        	**type**\:   :py:class:`NvSatelliteAccess <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess>`
        
        .. attribute:: nv_satellite_fabric_link
        
        	nV Satellite Fabric Link Configuration
        	**type**\:   :py:class:`NvSatelliteFabricLink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink>`
        
        .. attribute:: nv_satellite_fabric_network
        
        	Complex Network connection to one or more Satellites
        	**type**\:   :py:class:`NvSatelliteFabricNetwork <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork>`
        
        .. attribute:: nve
        
        	NVE operational data
        	**type**\:   :py:class:`Nve <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve>`
        
        .. attribute:: optics
        
        	Optics controller configuration
        	**type**\:   :py:class:`Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics>`
        
        .. attribute:: otu
        
        	OTU port controller configuration
        	**type**\:   :py:class:`Otu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu>`
        
        .. attribute:: pbr
        
        	Interface PBR configuration
        	**type**\:   :py:class:`Pbr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Pbr>`
        
        .. attribute:: perf_mon_disable
        
        	Configure Performance Monitoring 
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: performance_management
        
        	Configure pm parameters
        	**type**\:   :py:class:`PerformanceManagement <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement>`
        
        .. attribute:: portmode
        
        	Configure through port\-mode
        	**type**\:   :py:class:`Portmode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Portmode>`
        
        .. attribute:: pppoe
        
        	Interface PPPoE configuration data
        	**type**\:   :py:class:`Pppoe <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Pppoe>`
        
        .. attribute:: pseudowire_ether
        
        	PW\-Ether attributes
        	**type**\:   :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PseudowireEther>`
        
        .. attribute:: pseudowire_iw
        
        	PW\-IW attributes
        	**type**\:   :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PseudowireIw>`
        
        .. attribute:: ptp
        
        	Precision Time Protocol interface configuration
        	**type**\:   :py:class:`Ptp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp>`
        
        .. attribute:: qos
        
        	Interface QOS configuration
        	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos>`
        
        .. attribute:: secondary_admin_state
        
        	The secondary admin state of the interface
        	**type**\:   :py:class:`SecondaryAdminStateEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.SecondaryAdminStateEnum>`
        
        .. attribute:: service_policies
        
        	Interface control subscriber policy configuration
        	**type**\:   :py:class:`ServicePolicies <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.ServicePolicies>`
        
        .. attribute:: shutdown
        
        	The existence of this configuration indicates the interface is shut down
        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
        
        .. attribute:: span_monitor_sessions
        
        	Monitor Session container for this source interface
        	**type**\:   :py:class:`SpanMonitorSessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions>`
        
        .. attribute:: ssrp_session
        
        	SSRP Config
        	**type**\:   :py:class:`SsrpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SsrpSession>`
        
        .. attribute:: statistics
        
        	Per\-interface statistics configuration
        	**type**\:   :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Statistics>`
        
        .. attribute:: subscriber
        
        	Subscribers on interface
        	**type**\:   :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber>`
        
        .. attribute:: track_name
        
        	Track Name
        	**type**\:  str
        
        	**length:** 1..32
        
        .. attribute:: transport_profile_tunnel
        
        	MPLS\-TP tunnel attributes
        	**type**\:   :py:class:`TransportProfileTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel>`
        
        .. attribute:: tunnel_ip
        
        	IP over GRE encapsulation
        	**type**\:   :py:class:`TunnelIp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp>`
        
        .. attribute:: tunnel_te_attributes
        
        	MPLS tunnel attributes
        	**type**\:   :py:class:`TunnelTeAttributes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes>`
        
        .. attribute:: vlan_sub_configuration
        
        	IEEE 802.1Q VLAN subinterface configuration
        	**type**\:   :py:class:`VlanSubConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration>`
        
        .. attribute:: vlan_trunk_configuration
        
        	IEEE 802.1Q VLAN trunk interface configuration
        	**type**\:   :py:class:`VlanTrunkConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration>`
        
        .. attribute:: vrf
        
        	Assign the interface to a VRF
        	**type**\:  str
        
        	**length:** 1..32
        
        .. attribute:: wanphy
        
        	WANPHY port controller configuration
        	**type**\:   :py:class:`Wanphy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Wanphy>`
        
        

        """

        _prefix = 'ifmgr-cfg'
        _revision = '2015-07-30'

        def __init__(self):
            super(InterfaceConfigurations.InterfaceConfiguration, self).__init__()

            self.yang_name = "interface-configuration"
            self.yang_parent_name = "interface-configurations"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"aaa-table" : ("aaa_table", InterfaceConfigurations.InterfaceConfiguration.AaaTable), "afs" : ("afs", InterfaceConfigurations.InterfaceConfiguration.Afs), "atm" : ("atm", InterfaceConfigurations.InterfaceConfiguration.Atm), "bfd" : ("bfd", InterfaceConfigurations.InterfaceConfiguration.Bfd), "bundle" : ("bundle", InterfaceConfigurations.InterfaceConfiguration.Bundle), "bundle-member" : ("bundle_member", InterfaceConfigurations.InterfaceConfiguration.BundleMember), "bvi" : ("bvi", InterfaceConfigurations.InterfaceConfiguration.Bvi), "carrier-delay" : ("carrier_delay", InterfaceConfigurations.InterfaceConfiguration.CarrierDelay), "cdp" : ("cdp", InterfaceConfigurations.InterfaceConfiguration.Cdp), "Cisco-IOS-XR-freqsync-cfg_frequency-synchronization" : ("cisco_ios_xr_freqsync_cfg_frequency_synchronization", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization), "Cisco-IOS-XR-ncs4k-freqsync-cfg_frequency-synchronization" : ("cisco_ios_xr_ncs4k_freqsync_cfg_frequency_synchronization", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization), "Cisco-IOS-XR-ppp-ma-cfg_ppp" : ("cisco_ios_xr_ppp_ma_cfg_ppp", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaCfgPpp), "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp" : ("cisco_ios_xr_ppp_ma_fsm_cfg_ppp", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaFsmCfgPpp), "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp" : ("cisco_ios_xr_ppp_ma_ipcp_cfg_ppp", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp), "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp" : ("cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpiwCfgPpp), "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp" : ("cisco_ios_xr_ppp_ma_lcp_cfg_ppp", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp), "dagrs" : ("dagrs", InterfaceConfigurations.InterfaceConfiguration.Dagrs), "dampening" : ("dampening", InterfaceConfigurations.InterfaceConfiguration.Dampening), "dot1x-interface" : ("dot1x_interface", InterfaceConfigurations.InterfaceConfiguration.Dot1XInterface), "dwdm" : ("dwdm", InterfaceConfigurations.InterfaceConfiguration.Dwdm), "encapsulation" : ("encapsulation", InterfaceConfigurations.InterfaceConfiguration.Encapsulation), "es-packet-filter" : ("es_packet_filter", InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter), "ethernet" : ("ethernet", InterfaceConfigurations.InterfaceConfiguration.Ethernet), "ethernet-bng" : ("ethernet_bng", InterfaceConfigurations.InterfaceConfiguration.EthernetBng), "ethernet-control" : ("ethernet_control", InterfaceConfigurations.InterfaceConfiguration.EthernetControl), "ethernet-features" : ("ethernet_features", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures), "ethernet-service" : ("ethernet_service", InterfaceConfigurations.InterfaceConfiguration.EthernetService), "ipv4-network" : ("ipv4_network", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network), "ipv4-network-forwarding" : ("ipv4_network_forwarding", InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding), "ipv4-packet-filter" : ("ipv4_packet_filter", InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter), "ipv4arp" : ("ipv4arp", InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp), "ipv6-neighbor" : ("ipv6_neighbor", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor), "ipv6-network" : ("ipv6_network", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network), "ipv6-packet-filter" : ("ipv6_packet_filter", InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter), "l2-transport" : ("l2_transport", InterfaceConfigurations.InterfaceConfiguration.L2Transport), "lacp" : ("lacp", InterfaceConfigurations.InterfaceConfiguration.Lacp), "lldp" : ("lldp", InterfaceConfigurations.InterfaceConfiguration.Lldp), "loopbacks" : ("loopbacks", InterfaceConfigurations.InterfaceConfiguration.Loopbacks), "mac-accounting" : ("mac_accounting", InterfaceConfigurations.InterfaceConfiguration.MacAccounting), "macsec" : ("macsec", InterfaceConfigurations.InterfaceConfiguration.Macsec), "mlacp" : ("mlacp", InterfaceConfigurations.InterfaceConfiguration.Mlacp), "mpls" : ("mpls", InterfaceConfigurations.InterfaceConfiguration.Mpls), "mte-tunnel-attributes" : ("mte_tunnel_attributes", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes), "mtus" : ("mtus", InterfaceConfigurations.InterfaceConfiguration.Mtus), "net-flow" : ("net_flow", InterfaceConfigurations.InterfaceConfiguration.NetFlow), "nv-satellite-access" : ("nv_satellite_access", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess), "nv-satellite-fabric-link" : ("nv_satellite_fabric_link", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink), "nv-satellite-fabric-network" : ("nv_satellite_fabric_network", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork), "nve" : ("nve", InterfaceConfigurations.InterfaceConfiguration.Nve), "optics" : ("optics", InterfaceConfigurations.InterfaceConfiguration.Optics), "otu" : ("otu", InterfaceConfigurations.InterfaceConfiguration.Otu), "pbr" : ("pbr", InterfaceConfigurations.InterfaceConfiguration.Pbr), "performance-management" : ("performance_management", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement), "portmode" : ("portmode", InterfaceConfigurations.InterfaceConfiguration.Portmode), "pppoe" : ("pppoe", InterfaceConfigurations.InterfaceConfiguration.Pppoe), "pseudowire-ether" : ("pseudowire_ether", InterfaceConfigurations.InterfaceConfiguration.PseudowireEther), "pseudowire-iw" : ("pseudowire_iw", InterfaceConfigurations.InterfaceConfiguration.PseudowireIw), "ptp" : ("ptp", InterfaceConfigurations.InterfaceConfiguration.Ptp), "qos" : ("qos", InterfaceConfigurations.InterfaceConfiguration.Qos), "service-policies" : ("service_policies", InterfaceConfigurations.InterfaceConfiguration.ServicePolicies), "span-monitor-sessions" : ("span_monitor_sessions", InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions), "ssrp-session" : ("ssrp_session", InterfaceConfigurations.InterfaceConfiguration.SsrpSession), "statistics" : ("statistics", InterfaceConfigurations.InterfaceConfiguration.Statistics), "subscriber" : ("subscriber", InterfaceConfigurations.InterfaceConfiguration.Subscriber), "transport-profile-tunnel" : ("transport_profile_tunnel", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel), "tunnel-ip" : ("tunnel_ip", InterfaceConfigurations.InterfaceConfiguration.TunnelIp), "tunnel-te-attributes" : ("tunnel_te_attributes", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes), "vlan-sub-configuration" : ("vlan_sub_configuration", InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration), "vlan-trunk-configuration" : ("vlan_trunk_configuration", InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration), "wanphy" : ("wanphy", InterfaceConfigurations.InterfaceConfiguration.Wanphy)}
            self._child_list_classes = {}

            self.active = YLeaf(YType.str, "active")

            self.interface_name = YLeaf(YType.str, "interface-name")

            self.bandwidth = YLeaf(YType.uint32, "bandwidth")

            self.description = YLeaf(YType.str, "description")

            self.fast_shutdown = YLeaf(YType.empty, "Cisco-IOS-XR-mdrv-lib-cfg:fast-shutdown")

            self.interface_mode_non_physical = YLeaf(YType.enumeration, "interface-mode-non-physical")

            self.interface_virtual = YLeaf(YType.empty, "interface-virtual")

            self.laser_squelch = YLeaf(YType.empty, "Cisco-IOS-XR-drivers-icpe-ethernet-cfg:laser-squelch")

            self.link_status = YLeaf(YType.empty, "link-status")

            self.mac_addr = YLeaf(YType.str, "Cisco-IOS-XR-mdrv-lib-cfg:mac-addr")

            self.maintenance_embargo = YLeaf(YType.boolean, "Cisco-IOS-XR-dwdm-ui-cfg:maintenance-embargo")

            self.perf_mon_disable = YLeaf(YType.empty, "Cisco-IOS-XR-drivers-icpe-ethernet-cfg:perf-mon-disable")

            self.secondary_admin_state = YLeaf(YType.enumeration, "secondary-admin-state")

            self.shutdown = YLeaf(YType.empty, "shutdown")

            self.track_name = YLeaf(YType.str, "Cisco-IOS-XR-manageability-object-tracking-cfg:track-name")

            self.vrf = YLeaf(YType.str, "Cisco-IOS-XR-infra-rsi-cfg:vrf")

            self.aaa_table = InterfaceConfigurations.InterfaceConfiguration.AaaTable()
            self.aaa_table.parent = self
            self._children_name_map["aaa_table"] = "aaa-table"
            self._children_yang_names.add("aaa-table")

            self.afs = InterfaceConfigurations.InterfaceConfiguration.Afs()
            self.afs.parent = self
            self._children_name_map["afs"] = "afs"
            self._children_yang_names.add("afs")

            self.atm = InterfaceConfigurations.InterfaceConfiguration.Atm()
            self.atm.parent = self
            self._children_name_map["atm"] = "atm"
            self._children_yang_names.add("atm")

            self.bfd = InterfaceConfigurations.InterfaceConfiguration.Bfd()
            self.bfd.parent = self
            self._children_name_map["bfd"] = "bfd"
            self._children_yang_names.add("bfd")

            self.bundle = InterfaceConfigurations.InterfaceConfiguration.Bundle()
            self.bundle.parent = self
            self._children_name_map["bundle"] = "bundle"
            self._children_yang_names.add("bundle")

            self.bundle_member = InterfaceConfigurations.InterfaceConfiguration.BundleMember()
            self.bundle_member.parent = self
            self._children_name_map["bundle_member"] = "bundle-member"
            self._children_yang_names.add("bundle-member")

            self.bvi = InterfaceConfigurations.InterfaceConfiguration.Bvi()
            self.bvi.parent = self
            self._children_name_map["bvi"] = "bvi"
            self._children_yang_names.add("bvi")

            self.carrier_delay = InterfaceConfigurations.InterfaceConfiguration.CarrierDelay()
            self.carrier_delay.parent = self
            self._children_name_map["carrier_delay"] = "carrier-delay"
            self._children_yang_names.add("carrier-delay")

            self.cdp = InterfaceConfigurations.InterfaceConfiguration.Cdp()
            self.cdp.parent = self
            self._children_name_map["cdp"] = "cdp"
            self._children_yang_names.add("cdp")

            self.cisco_ios_xr_freqsync_cfg_frequency_synchronization = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization()
            self.cisco_ios_xr_freqsync_cfg_frequency_synchronization.parent = self
            self._children_name_map["cisco_ios_xr_freqsync_cfg_frequency_synchronization"] = "Cisco-IOS-XR-freqsync-cfg_frequency-synchronization"
            self._children_yang_names.add("Cisco-IOS-XR-freqsync-cfg_frequency-synchronization")

            self.cisco_ios_xr_ncs4k_freqsync_cfg_frequency_synchronization = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization()
            self.cisco_ios_xr_ncs4k_freqsync_cfg_frequency_synchronization.parent = self
            self._children_name_map["cisco_ios_xr_ncs4k_freqsync_cfg_frequency_synchronization"] = "Cisco-IOS-XR-ncs4k-freqsync-cfg_frequency-synchronization"
            self._children_yang_names.add("Cisco-IOS-XR-ncs4k-freqsync-cfg_frequency-synchronization")

            self.cisco_ios_xr_ppp_ma_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaCfgPpp()
            self.cisco_ios_xr_ppp_ma_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-cfg_ppp")

            self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaFsmCfgPpp()
            self.cisco_ios_xr_ppp_ma_fsm_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_fsm_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp")

            self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp()
            self.cisco_ios_xr_ppp_ma_ipcp_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_ipcp_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp")

            self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpiwCfgPpp()
            self.cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_ipcpiw_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp")

            self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp()
            self.cisco_ios_xr_ppp_ma_lcp_cfg_ppp.parent = self
            self._children_name_map["cisco_ios_xr_ppp_ma_lcp_cfg_ppp"] = "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"
            self._children_yang_names.add("Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp")

            self.dagrs = InterfaceConfigurations.InterfaceConfiguration.Dagrs()
            self.dagrs.parent = self
            self._children_name_map["dagrs"] = "dagrs"
            self._children_yang_names.add("dagrs")

            self.dampening = InterfaceConfigurations.InterfaceConfiguration.Dampening()
            self.dampening.parent = self
            self._children_name_map["dampening"] = "dampening"
            self._children_yang_names.add("dampening")

            self.dot1x_interface = InterfaceConfigurations.InterfaceConfiguration.Dot1XInterface()
            self.dot1x_interface.parent = self
            self._children_name_map["dot1x_interface"] = "dot1x-interface"
            self._children_yang_names.add("dot1x-interface")

            self.dwdm = InterfaceConfigurations.InterfaceConfiguration.Dwdm()
            self.dwdm.parent = self
            self._children_name_map["dwdm"] = "dwdm"
            self._children_yang_names.add("dwdm")

            self.encapsulation = InterfaceConfigurations.InterfaceConfiguration.Encapsulation()
            self.encapsulation.parent = self
            self._children_name_map["encapsulation"] = "encapsulation"
            self._children_yang_names.add("encapsulation")

            self.es_packet_filter = InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter()
            self.es_packet_filter.parent = self
            self._children_name_map["es_packet_filter"] = "es-packet-filter"
            self._children_yang_names.add("es-packet-filter")

            self.ethernet = InterfaceConfigurations.InterfaceConfiguration.Ethernet()
            self.ethernet.parent = self
            self._children_name_map["ethernet"] = "ethernet"
            self._children_yang_names.add("ethernet")

            self.ethernet_bng = InterfaceConfigurations.InterfaceConfiguration.EthernetBng()
            self.ethernet_bng.parent = self
            self._children_name_map["ethernet_bng"] = "ethernet-bng"
            self._children_yang_names.add("ethernet-bng")

            self.ethernet_control = InterfaceConfigurations.InterfaceConfiguration.EthernetControl()
            self.ethernet_control.parent = self
            self._children_name_map["ethernet_control"] = "ethernet-control"
            self._children_yang_names.add("ethernet-control")

            self.ethernet_features = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures()
            self.ethernet_features.parent = self
            self._children_name_map["ethernet_features"] = "ethernet-features"
            self._children_yang_names.add("ethernet-features")

            self.ethernet_service = InterfaceConfigurations.InterfaceConfiguration.EthernetService()
            self.ethernet_service.parent = self
            self._children_name_map["ethernet_service"] = "ethernet-service"
            self._children_yang_names.add("ethernet-service")

            self.ipv4_network = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network()
            self.ipv4_network.parent = self
            self._children_name_map["ipv4_network"] = "ipv4-network"
            self._children_yang_names.add("ipv4-network")

            self.ipv4_network_forwarding = InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding()
            self.ipv4_network_forwarding.parent = self
            self._children_name_map["ipv4_network_forwarding"] = "ipv4-network-forwarding"
            self._children_yang_names.add("ipv4-network-forwarding")

            self.ipv4_packet_filter = InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter()
            self.ipv4_packet_filter.parent = self
            self._children_name_map["ipv4_packet_filter"] = "ipv4-packet-filter"
            self._children_yang_names.add("ipv4-packet-filter")

            self.ipv4arp = InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp()
            self.ipv4arp.parent = self
            self._children_name_map["ipv4arp"] = "ipv4arp"
            self._children_yang_names.add("ipv4arp")

            self.ipv6_neighbor = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor()
            self.ipv6_neighbor.parent = self
            self._children_name_map["ipv6_neighbor"] = "ipv6-neighbor"
            self._children_yang_names.add("ipv6-neighbor")

            self.ipv6_network = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network()
            self.ipv6_network.parent = self
            self._children_name_map["ipv6_network"] = "ipv6-network"
            self._children_yang_names.add("ipv6-network")

            self.ipv6_packet_filter = InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter()
            self.ipv6_packet_filter.parent = self
            self._children_name_map["ipv6_packet_filter"] = "ipv6-packet-filter"
            self._children_yang_names.add("ipv6-packet-filter")

            self.l2_transport = InterfaceConfigurations.InterfaceConfiguration.L2Transport()
            self.l2_transport.parent = self
            self._children_name_map["l2_transport"] = "l2-transport"
            self._children_yang_names.add("l2-transport")

            self.lacp = InterfaceConfigurations.InterfaceConfiguration.Lacp()
            self.lacp.parent = self
            self._children_name_map["lacp"] = "lacp"
            self._children_yang_names.add("lacp")

            self.lldp = None
            self._children_name_map["lldp"] = "lldp"
            self._children_yang_names.add("lldp")

            self.loopbacks = InterfaceConfigurations.InterfaceConfiguration.Loopbacks()
            self.loopbacks.parent = self
            self._children_name_map["loopbacks"] = "loopbacks"
            self._children_yang_names.add("loopbacks")

            self.mac_accounting = InterfaceConfigurations.InterfaceConfiguration.MacAccounting()
            self.mac_accounting.parent = self
            self._children_name_map["mac_accounting"] = "mac-accounting"
            self._children_yang_names.add("mac-accounting")

            self.macsec = InterfaceConfigurations.InterfaceConfiguration.Macsec()
            self.macsec.parent = self
            self._children_name_map["macsec"] = "macsec"
            self._children_yang_names.add("macsec")

            self.mlacp = InterfaceConfigurations.InterfaceConfiguration.Mlacp()
            self.mlacp.parent = self
            self._children_name_map["mlacp"] = "mlacp"
            self._children_yang_names.add("mlacp")

            self.mpls = InterfaceConfigurations.InterfaceConfiguration.Mpls()
            self.mpls.parent = self
            self._children_name_map["mpls"] = "mpls"
            self._children_yang_names.add("mpls")

            self.mte_tunnel_attributes = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes()
            self.mte_tunnel_attributes.parent = self
            self._children_name_map["mte_tunnel_attributes"] = "mte-tunnel-attributes"
            self._children_yang_names.add("mte-tunnel-attributes")

            self.mtus = InterfaceConfigurations.InterfaceConfiguration.Mtus()
            self.mtus.parent = self
            self._children_name_map["mtus"] = "mtus"
            self._children_yang_names.add("mtus")

            self.net_flow = InterfaceConfigurations.InterfaceConfiguration.NetFlow()
            self.net_flow.parent = self
            self._children_name_map["net_flow"] = "net-flow"
            self._children_yang_names.add("net-flow")

            self.nv_satellite_access = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess()
            self.nv_satellite_access.parent = self
            self._children_name_map["nv_satellite_access"] = "nv-satellite-access"
            self._children_yang_names.add("nv-satellite-access")

            self.nv_satellite_fabric_link = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink()
            self.nv_satellite_fabric_link.parent = self
            self._children_name_map["nv_satellite_fabric_link"] = "nv-satellite-fabric-link"
            self._children_yang_names.add("nv-satellite-fabric-link")

            self.nv_satellite_fabric_network = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork()
            self.nv_satellite_fabric_network.parent = self
            self._children_name_map["nv_satellite_fabric_network"] = "nv-satellite-fabric-network"
            self._children_yang_names.add("nv-satellite-fabric-network")

            self.nve = InterfaceConfigurations.InterfaceConfiguration.Nve()
            self.nve.parent = self
            self._children_name_map["nve"] = "nve"
            self._children_yang_names.add("nve")

            self.optics = InterfaceConfigurations.InterfaceConfiguration.Optics()
            self.optics.parent = self
            self._children_name_map["optics"] = "optics"
            self._children_yang_names.add("optics")

            self.otu = InterfaceConfigurations.InterfaceConfiguration.Otu()
            self.otu.parent = self
            self._children_name_map["otu"] = "otu"
            self._children_yang_names.add("otu")

            self.pbr = InterfaceConfigurations.InterfaceConfiguration.Pbr()
            self.pbr.parent = self
            self._children_name_map["pbr"] = "pbr"
            self._children_yang_names.add("pbr")

            self.performance_management = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement()
            self.performance_management.parent = self
            self._children_name_map["performance_management"] = "performance-management"
            self._children_yang_names.add("performance-management")

            self.portmode = InterfaceConfigurations.InterfaceConfiguration.Portmode()
            self.portmode.parent = self
            self._children_name_map["portmode"] = "portmode"
            self._children_yang_names.add("portmode")

            self.pppoe = InterfaceConfigurations.InterfaceConfiguration.Pppoe()
            self.pppoe.parent = self
            self._children_name_map["pppoe"] = "pppoe"
            self._children_yang_names.add("pppoe")

            self.pseudowire_ether = InterfaceConfigurations.InterfaceConfiguration.PseudowireEther()
            self.pseudowire_ether.parent = self
            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"
            self._children_yang_names.add("pseudowire-ether")

            self.pseudowire_iw = InterfaceConfigurations.InterfaceConfiguration.PseudowireIw()
            self.pseudowire_iw.parent = self
            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
            self._children_yang_names.add("pseudowire-iw")

            self.ptp = InterfaceConfigurations.InterfaceConfiguration.Ptp()
            self.ptp.parent = self
            self._children_name_map["ptp"] = "ptp"
            self._children_yang_names.add("ptp")

            self.qos = InterfaceConfigurations.InterfaceConfiguration.Qos()
            self.qos.parent = self
            self._children_name_map["qos"] = "qos"
            self._children_yang_names.add("qos")

            self.service_policies = InterfaceConfigurations.InterfaceConfiguration.ServicePolicies()
            self.service_policies.parent = self
            self._children_name_map["service_policies"] = "service-policies"
            self._children_yang_names.add("service-policies")

            self.span_monitor_sessions = InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions()
            self.span_monitor_sessions.parent = self
            self._children_name_map["span_monitor_sessions"] = "span-monitor-sessions"
            self._children_yang_names.add("span-monitor-sessions")

            self.ssrp_session = InterfaceConfigurations.InterfaceConfiguration.SsrpSession()
            self.ssrp_session.parent = self
            self._children_name_map["ssrp_session"] = "ssrp-session"
            self._children_yang_names.add("ssrp-session")

            self.statistics = InterfaceConfigurations.InterfaceConfiguration.Statistics()
            self.statistics.parent = self
            self._children_name_map["statistics"] = "statistics"
            self._children_yang_names.add("statistics")

            self.subscriber = InterfaceConfigurations.InterfaceConfiguration.Subscriber()
            self.subscriber.parent = self
            self._children_name_map["subscriber"] = "subscriber"
            self._children_yang_names.add("subscriber")

            self.transport_profile_tunnel = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel()
            self.transport_profile_tunnel.parent = self
            self._children_name_map["transport_profile_tunnel"] = "transport-profile-tunnel"
            self._children_yang_names.add("transport-profile-tunnel")

            self.tunnel_ip = InterfaceConfigurations.InterfaceConfiguration.TunnelIp()
            self.tunnel_ip.parent = self
            self._children_name_map["tunnel_ip"] = "tunnel-ip"
            self._children_yang_names.add("tunnel-ip")

            self.tunnel_te_attributes = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes()
            self.tunnel_te_attributes.parent = self
            self._children_name_map["tunnel_te_attributes"] = "tunnel-te-attributes"
            self._children_yang_names.add("tunnel-te-attributes")

            self.vlan_sub_configuration = InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration()
            self.vlan_sub_configuration.parent = self
            self._children_name_map["vlan_sub_configuration"] = "vlan-sub-configuration"
            self._children_yang_names.add("vlan-sub-configuration")

            self.vlan_trunk_configuration = InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration()
            self.vlan_trunk_configuration.parent = self
            self._children_name_map["vlan_trunk_configuration"] = "vlan-trunk-configuration"
            self._children_yang_names.add("vlan-trunk-configuration")

            self.wanphy = InterfaceConfigurations.InterfaceConfiguration.Wanphy()
            self.wanphy.parent = self
            self._children_name_map["wanphy"] = "wanphy"
            self._children_yang_names.add("wanphy")
            self._segment_path = lambda: "interface-configuration" + "[active='" + self.active.get() + "']" + "[interface-name='" + self.interface_name.get() + "']"
            self._absolute_path = lambda: "Cisco-IOS-XR-ifmgr-cfg:interface-configurations/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration, ['active', 'interface_name', 'bandwidth', 'description', 'fast_shutdown', 'interface_mode_non_physical', 'interface_virtual', 'laser_squelch', 'link_status', 'mac_addr', 'maintenance_embargo', 'perf_mon_disable', 'secondary_admin_state', 'shutdown', 'track_name', 'vrf'], name, value)


        class AaaTable(Entity):
            """
            AAA configuration
            
            .. attribute:: radius
            
            	AAA radius configuration
            	**type**\:   :py:class:`Radius <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius>`
            
            

            """

            _prefix = 'aaa-aaacore-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.AaaTable, self).__init__()

                self.yang_name = "aaa-table"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"radius" : ("radius", InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius)}
                self._child_list_classes = {}

                self.radius = InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius()
                self.radius.parent = self
                self._children_name_map["radius"] = "radius"
                self._children_yang_names.add("radius")
                self._segment_path = lambda: "Cisco-IOS-XR-aaa-aaacore-cfg:aaa-table"


            class Radius(Entity):
                """
                AAA radius configuration
                
                .. attribute:: attribute
                
                	AAA radius attribute
                	**type**\:   :py:class:`Attribute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute>`
                
                

                """

                _prefix = 'aaa-aaacore-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius, self).__init__()

                    self.yang_name = "radius"
                    self.yang_parent_name = "aaa-table"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"attribute" : ("attribute", InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute)}
                    self._child_list_classes = {}

                    self.attribute = InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute()
                    self.attribute.parent = self
                    self._children_name_map["attribute"] = "attribute"
                    self._children_yang_names.add("attribute")
                    self._segment_path = lambda: "radius"


                class Attribute(Entity):
                    """
                    AAA radius attribute
                    
                    .. attribute:: nas_port_type
                    
                    	AAA nas\-port\-type attribute
                    	**type**\:   :py:class:`NasPortValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_aaa_aaacore_cfg.NasPortValue>`
                    
                    

                    """

                    _prefix = 'aaa-aaacore-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute, self).__init__()

                        self.yang_name = "attribute"
                        self.yang_parent_name = "radius"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nas_port_type = YLeaf(YType.enumeration, "nas-port-type")
                        self._segment_path = lambda: "attribute"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.AaaTable.Radius.Attribute, ['nas_port_type'], name, value)


        class Afs(Entity):
            """
            Per\-address\-family and topology configuration
            
            .. attribute:: af
            
            	The presence of this object enables the givenaddress\-family and topology on the interface
            	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Afs.Af>`
            
            .. attribute:: af_topology_name
            
            	The presence of this object enables the givenaddress\-family and topology on the interface
            	**type**\: list of    :py:class:`AfTopologyName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Afs.AfTopologyName>`
            
            

            """

            _prefix = 'infra-rsi-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Afs, self).__init__()

                self.yang_name = "afs"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {"af" : ("af", InterfaceConfigurations.InterfaceConfiguration.Afs.Af), "af-topology-name" : ("af_topology_name", InterfaceConfigurations.InterfaceConfiguration.Afs.AfTopologyName)}

                self.af = YList(self)
                self.af_topology_name = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XR-infra-rsi-cfg:afs"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Afs, [], name, value)


            class Af(Entity):
                """
                The presence of this object enables the
                givenaddress\-family and topology on the
                interface.
                
                .. attribute:: af_name  <key>
                
                	Address\-family
                	**type**\:   :py:class:`VrfAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_infra_rsi_cfg.VrfAddressFamily>`
                
                .. attribute:: saf_name  <key>
                
                	Sub\-address\-family
                	**type**\:   :py:class:`VrfSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_infra_rsi_cfg.VrfSubAddressFamily>`
                
                

                """

                _prefix = 'infra-rsi-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Afs.Af, self).__init__()

                    self.yang_name = "af"
                    self.yang_parent_name = "afs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.af_name = YLeaf(YType.enumeration, "af-name")

                    self.saf_name = YLeaf(YType.enumeration, "saf-name")
                    self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']" + "[saf-name='" + self.saf_name.get() + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Afs.Af, ['af_name', 'saf_name'], name, value)


            class AfTopologyName(Entity):
                """
                The presence of this object enables the
                givenaddress\-family and topology on the
                interface.
                
                .. attribute:: topology_name  <key>
                
                	Topology name
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: af_name  <key>
                
                	Address\-family
                	**type**\:   :py:class:`VrfAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_infra_rsi_cfg.VrfAddressFamily>`
                
                .. attribute:: saf_name  <key>
                
                	Sub\-address\-family
                	**type**\:   :py:class:`VrfSubAddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_infra_rsi_cfg.VrfSubAddressFamily>`
                
                

                """

                _prefix = 'infra-rsi-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Afs.AfTopologyName, self).__init__()

                    self.yang_name = "af-topology-name"
                    self.yang_parent_name = "afs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.topology_name = YLeaf(YType.str, "topology-name")

                    self.af_name = YLeaf(YType.enumeration, "af-name")

                    self.saf_name = YLeaf(YType.enumeration, "saf-name")
                    self._segment_path = lambda: "af-topology-name" + "[topology-name='" + self.topology_name.get() + "']" + "[af-name='" + self.af_name.get() + "']" + "[saf-name='" + self.saf_name.get() + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Afs.AfTopologyName, ['topology_name', 'af_name', 'saf_name'], name, value)


        class Atm(Entity):
            """
            ATM Configuration
            
            .. attribute:: max_vpi_bits
            
            	Support 12\-bits VPI cell format
            	**type**\:   :py:class:`AtmVpiBitsMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_vcm_cfg.AtmVpiBitsMode>`
            
            .. attribute:: maximum_cell_packing_timers
            
            	Configure maximum cell\-packing timers.  All parameters are mandatory
            	**type**\:   :py:class:`MaximumCellPackingTimers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.MaximumCellPackingTimers>`
            
            	**presence node**\: True
            
            .. attribute:: pvcs
            
            	PVC Configuration
            	**type**\:   :py:class:`Pvcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs>`
            
            .. attribute:: pvps
            
            	PVP Configuration
            	**type**\:   :py:class:`Pvps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps>`
            
            .. attribute:: vc_class
            
            	Name of the VC class
            	**type**\:  str
            
            	**length:** 1..30
            
            .. attribute:: vp_tunnels
            
            	VP tunnel configuration
            	**type**\:   :py:class:`VpTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels>`
            
            

            """

            _prefix = 'atm-vcm-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Atm, self).__init__()

                self.yang_name = "atm"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"maximum-cell-packing-timers" : ("maximum_cell_packing_timers", InterfaceConfigurations.InterfaceConfiguration.Atm.MaximumCellPackingTimers), "pvcs" : ("pvcs", InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs), "pvps" : ("pvps", InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps), "vp-tunnels" : ("vp_tunnels", InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels)}
                self._child_list_classes = {}

                self.max_vpi_bits = YLeaf(YType.enumeration, "max-vpi-bits")

                self.vc_class = YLeaf(YType.str, "vc-class")

                self.maximum_cell_packing_timers = None
                self._children_name_map["maximum_cell_packing_timers"] = "maximum-cell-packing-timers"
                self._children_yang_names.add("maximum-cell-packing-timers")

                self.pvcs = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs()
                self.pvcs.parent = self
                self._children_name_map["pvcs"] = "pvcs"
                self._children_yang_names.add("pvcs")

                self.pvps = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps()
                self.pvps.parent = self
                self._children_name_map["pvps"] = "pvps"
                self._children_yang_names.add("pvps")

                self.vp_tunnels = InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels()
                self.vp_tunnels.parent = self
                self._children_name_map["vp_tunnels"] = "vp-tunnels"
                self._children_yang_names.add("vp-tunnels")
                self._segment_path = lambda: "Cisco-IOS-XR-atm-vcm-cfg:atm"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm, ['max_vpi_bits', 'vc_class'], name, value)


            class MaximumCellPackingTimers(Entity):
                """
                Configure maximum cell\-packing timers.  All
                parameters are mandatory.
                
                .. attribute:: cell_packing_timer1
                
                	Cell\-packing timer1 (micro seconds)
                	**type**\:  int
                
                	**range:** 50..4095
                
                	**mandatory**\: True
                
                .. attribute:: cell_packing_timer2
                
                	Cell\-packing timer2 (micro seconds)
                	**type**\:  int
                
                	**range:** 50..4095
                
                	**mandatory**\: True
                
                .. attribute:: cell_packing_timer3
                
                	Cell\-packing timer3 (micro seconds)
                	**type**\:  int
                
                	**range:** 50..4095
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.MaximumCellPackingTimers, self).__init__()

                    self.yang_name = "maximum-cell-packing-timers"
                    self.yang_parent_name = "atm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.cell_packing_timer1 = YLeaf(YType.uint32, "cell-packing-timer1")

                    self.cell_packing_timer2 = YLeaf(YType.uint32, "cell-packing-timer2")

                    self.cell_packing_timer3 = YLeaf(YType.uint32, "cell-packing-timer3")
                    self._segment_path = lambda: "maximum-cell-packing-timers"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.MaximumCellPackingTimers, ['cell_packing_timer1', 'cell_packing_timer2', 'cell_packing_timer3'], name, value)


            class Pvcs(Entity):
                """
                PVC Configuration
                
                .. attribute:: pvc
                
                	Configuration particular PVC
                	**type**\: list of    :py:class:`Pvc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc>`
                
                

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs, self).__init__()

                    self.yang_name = "pvcs"
                    self.yang_parent_name = "atm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"pvc" : ("pvc", InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc)}

                    self.pvc = YList(self)
                    self._segment_path = lambda: "pvcs"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs, [], name, value)


                class Pvc(Entity):
                    """
                    Configuration particular PVC
                    
                    .. attribute:: vpi  <key>
                    
                    	VPI value
                    	**type**\:  int
                    
                    	**range:** 0..4095
                    
                    .. attribute:: vci  <key>
                    
                    	VCI value
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    .. attribute:: pv_ctype  <key>
                    
                    	PVC type
                    	**type**\:   :py:class:`AtmPvcData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmPvcData>`
                    
                    .. attribute:: cell_packing
                    
                    	Configure cell\-packing parameters.  All parameters are mandatory
                    	**type**\:   :py:class:`CellPacking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.CellPacking>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: enable
                    
                    	Create the PVC
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: encapsulation
                    
                    	Configure encapsulation
                    	**type**\:   :py:class:`AtmPvcEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmPvcEncapsulation>`
                    
                    .. attribute:: oam_emulation
                    
                    	L2VPN OAM emulation
                    	**type**\:   :py:class:`OamEmulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation>`
                    
                    .. attribute:: oam_segment_endpoint
                    
                    	Enable L2VPN PVC OAM segment endpoint
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: shape
                    
                    	Configure traffic shaping parameters
                    	**type**\:   :py:class:`Shape <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape>`
                    
                    .. attribute:: test_mode
                    
                    	Configure the PVC test mode
                    	**type**\:   :py:class:`AtmPvcTestMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_vcm_cfg.AtmPvcTestMode>`
                    
                    .. attribute:: vc_class
                    
                    	Name of the VC class
                    	**type**\:  str
                    
                    	**length:** 1..30
                    
                    

                    """

                    _prefix = 'atm-vcm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc, self).__init__()

                        self.yang_name = "pvc"
                        self.yang_parent_name = "pvcs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"cell-packing" : ("cell_packing", InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.CellPacking), "oam-emulation" : ("oam_emulation", InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation), "shape" : ("shape", InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape)}
                        self._child_list_classes = {}

                        self.vpi = YLeaf(YType.uint32, "vpi")

                        self.vci = YLeaf(YType.uint32, "vci")

                        self.pv_ctype = YLeaf(YType.enumeration, "pv-ctype")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.encapsulation = YLeaf(YType.enumeration, "encapsulation")

                        self.oam_segment_endpoint = YLeaf(YType.empty, "oam-segment-endpoint")

                        self.test_mode = YLeaf(YType.enumeration, "test-mode")

                        self.vc_class = YLeaf(YType.str, "vc-class")

                        self.cell_packing = None
                        self._children_name_map["cell_packing"] = "cell-packing"
                        self._children_yang_names.add("cell-packing")

                        self.oam_emulation = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation()
                        self.oam_emulation.parent = self
                        self._children_name_map["oam_emulation"] = "oam-emulation"
                        self._children_yang_names.add("oam-emulation")

                        self.shape = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"
                        self._children_yang_names.add("shape")
                        self._segment_path = lambda: "pvc" + "[vpi='" + self.vpi.get() + "']" + "[vci='" + self.vci.get() + "']" + "[pv-ctype='" + self.pv_ctype.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc, ['vpi', 'vci', 'pv_ctype', 'enable', 'encapsulation', 'oam_segment_endpoint', 'test_mode', 'vc_class'], name, value)


                    class CellPacking(Entity):
                        """
                        Configure cell\-packing parameters.  All
                        parameters are mandatory.
                        
                        .. attribute:: cell_packing_timer_id
                        
                        	Which cell packing timer to use
                        	**type**\:  int
                        
                        	**range:** 1..3
                        
                        	**mandatory**\: True
                        
                        .. attribute:: maximum_cells_packed
                        
                        	Maximum number of cells to be packed in a packet
                        	**type**\:  int
                        
                        	**range:** 2..255
                        
                        	**mandatory**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.CellPacking, self).__init__()

                            self.yang_name = "cell-packing"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.cell_packing_timer_id = YLeaf(YType.uint32, "cell-packing-timer-id")

                            self.maximum_cells_packed = YLeaf(YType.uint32, "maximum-cells-packed")
                            self._segment_path = lambda: "cell-packing"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.CellPacking, ['cell_packing_timer_id', 'maximum_cells_packed'], name, value)


                    class OamEmulation(Entity):
                        """
                        L2VPN OAM emulation
                        
                        .. attribute:: ais_transmit_rate
                        
                        	AIS cell transmit rate (1 per x seconds)
                        	**type**\:  int
                        
                        	**range:** 0..60
                        
                        .. attribute:: enable
                        
                        	Enable OAM emulation
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation, self).__init__()

                            self.yang_name = "oam-emulation"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.ais_transmit_rate = YLeaf(YType.uint32, "ais-transmit-rate")

                            self.enable = YLeaf(YType.empty, "enable")
                            self._segment_path = lambda: "oam-emulation"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.OamEmulation, ['ais_transmit_rate', 'enable'], name, value)


                    class Shape(Entity):
                        """
                        Configure traffic shaping parameters
                        
                        .. attribute:: burst_size
                        
                        	Burst size in cells
                        	**type**\:  int
                        
                        	**range:** 1..8192
                        
                        .. attribute:: peak_cell_rate
                        
                        	Peak cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: sustained_cell_rate
                        
                        	Sustained cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: type
                        
                        	Traffic shaping type
                        	**type**\:   :py:class:`AtmPvcShaping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmPvcShaping>`
                        
                        

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "pvc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.burst_size = YLeaf(YType.uint32, "burst-size")

                            self.peak_cell_rate = YLeaf(YType.uint32, "peak-cell-rate")

                            self.sustained_cell_rate = YLeaf(YType.uint32, "sustained-cell-rate")

                            self.type = YLeaf(YType.enumeration, "type")
                            self._segment_path = lambda: "shape"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvcs.Pvc.Shape, ['burst_size', 'peak_cell_rate', 'sustained_cell_rate', 'type'], name, value)


            class Pvps(Entity):
                """
                PVP Configuration
                
                .. attribute:: pvp
                
                	Configuration of particular PVP
                	**type**\: list of    :py:class:`Pvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp>`
                
                

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps, self).__init__()

                    self.yang_name = "pvps"
                    self.yang_parent_name = "atm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"pvp" : ("pvp", InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp)}

                    self.pvp = YList(self)
                    self._segment_path = lambda: "pvps"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps, [], name, value)


                class Pvp(Entity):
                    """
                    Configuration of particular PVP
                    
                    .. attribute:: vpi  <key>
                    
                    	VPI value
                    	**type**\:  int
                    
                    	**range:** 0..4095
                    
                    .. attribute:: cell_packing
                    
                    	Configure cell\-packing parameters.  All parameters are mandatory
                    	**type**\:   :py:class:`CellPacking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.CellPacking>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: enable
                    
                    	Create the PVP
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: oam_segment_endpoint
                    
                    	Enable L2VPN PVP OAM segment endpoint
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: shape
                    
                    	Configure traffic shaping parameters
                    	**type**\:   :py:class:`Shape <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape>`
                    
                    .. attribute:: test_mode
                    
                    	Configure the PVP test mode
                    	**type**\:   :py:class:`AtmPvpTestMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_vcm_cfg.AtmPvpTestMode>`
                    
                    

                    """

                    _prefix = 'atm-vcm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp, self).__init__()

                        self.yang_name = "pvp"
                        self.yang_parent_name = "pvps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"cell-packing" : ("cell_packing", InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.CellPacking), "shape" : ("shape", InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape)}
                        self._child_list_classes = {}

                        self.vpi = YLeaf(YType.uint32, "vpi")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.oam_segment_endpoint = YLeaf(YType.empty, "oam-segment-endpoint")

                        self.test_mode = YLeaf(YType.enumeration, "test-mode")

                        self.cell_packing = None
                        self._children_name_map["cell_packing"] = "cell-packing"
                        self._children_yang_names.add("cell-packing")

                        self.shape = InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"
                        self._children_yang_names.add("shape")
                        self._segment_path = lambda: "pvp" + "[vpi='" + self.vpi.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp, ['vpi', 'enable', 'oam_segment_endpoint', 'test_mode'], name, value)


                    class CellPacking(Entity):
                        """
                        Configure cell\-packing parameters.  All
                        parameters are mandatory.
                        
                        .. attribute:: cell_packing_timer_id
                        
                        	Which cell packing timer to use
                        	**type**\:  int
                        
                        	**range:** 1..3
                        
                        	**mandatory**\: True
                        
                        .. attribute:: maximum_cells_packed
                        
                        	Maximum number of cells to be packed in a packet
                        	**type**\:  int
                        
                        	**range:** 2..255
                        
                        	**mandatory**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.CellPacking, self).__init__()

                            self.yang_name = "cell-packing"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.cell_packing_timer_id = YLeaf(YType.uint32, "cell-packing-timer-id")

                            self.maximum_cells_packed = YLeaf(YType.uint32, "maximum-cells-packed")
                            self._segment_path = lambda: "cell-packing"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.CellPacking, ['cell_packing_timer_id', 'maximum_cells_packed'], name, value)


                    class Shape(Entity):
                        """
                        Configure traffic shaping parameters
                        
                        .. attribute:: burst_size
                        
                        	Burst size in cells
                        	**type**\:  int
                        
                        	**range:** 1..8192
                        
                        .. attribute:: peak_cell_rate
                        
                        	Peak cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: sustained_cell_rate
                        
                        	Sustained cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: type
                        
                        	Traffic shaping type
                        	**type**\:   :py:class:`AtmPvcShaping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmPvcShaping>`
                        
                        

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "pvp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.burst_size = YLeaf(YType.uint32, "burst-size")

                            self.peak_cell_rate = YLeaf(YType.uint32, "peak-cell-rate")

                            self.sustained_cell_rate = YLeaf(YType.uint32, "sustained-cell-rate")

                            self.type = YLeaf(YType.enumeration, "type")
                            self._segment_path = lambda: "shape"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.Pvps.Pvp.Shape, ['burst_size', 'peak_cell_rate', 'sustained_cell_rate', 'type'], name, value)


            class VpTunnels(Entity):
                """
                VP tunnel configuration
                
                .. attribute:: vp_tunnel
                
                	Configure a VP tunnel on this interface
                	**type**\: list of    :py:class:`VpTunnel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel>`
                
                

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels, self).__init__()

                    self.yang_name = "vp-tunnels"
                    self.yang_parent_name = "atm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"vp-tunnel" : ("vp_tunnel", InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel)}

                    self.vp_tunnel = YList(self)
                    self._segment_path = lambda: "vp-tunnels"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels, [], name, value)


                class VpTunnel(Entity):
                    """
                    Configure a VP tunnel on this interface
                    
                    .. attribute:: vpi  <key>
                    
                    	VPI value
                    	**type**\:  int
                    
                    	**range:** 0..4095
                    
                    .. attribute:: disable_f4oam
                    
                    	Disable F4 OAM configuration
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	Create the VP Tunnel
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable_hierarchical_shaping
                    
                    	Enable Hierarchical Shaping configuration
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: shape
                    
                    	Configure Traffic shaping parameters
                    	**type**\:   :py:class:`Shape <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape>`
                    
                    

                    """

                    _prefix = 'atm-vcm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel, self).__init__()

                        self.yang_name = "vp-tunnel"
                        self.yang_parent_name = "vp-tunnels"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"shape" : ("shape", InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape)}
                        self._child_list_classes = {}

                        self.vpi = YLeaf(YType.uint32, "vpi")

                        self.disable_f4oam = YLeaf(YType.empty, "disable-f4oam")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.enable_hierarchical_shaping = YLeaf(YType.empty, "enable-hierarchical-shaping")

                        self.shape = InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape()
                        self.shape.parent = self
                        self._children_name_map["shape"] = "shape"
                        self._children_yang_names.add("shape")
                        self._segment_path = lambda: "vp-tunnel" + "[vpi='" + self.vpi.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel, ['vpi', 'disable_f4oam', 'enable', 'enable_hierarchical_shaping'], name, value)


                    class Shape(Entity):
                        """
                        Configure Traffic shaping parameters
                        
                        .. attribute:: burst_size
                        
                        	Burst size in cells
                        	**type**\:  int
                        
                        	**range:** 1..8192
                        
                        .. attribute:: peak_cell_rate
                        
                        	Peak cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: sustained_cell_rate
                        
                        	Sustained cell rate (kbps)
                        	**type**\:  int
                        
                        	**range:** 8..622080
                        
                        .. attribute:: type
                        
                        	Traffic shaping type
                        	**type**\:   :py:class:`AtmVpShaping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_atm_common_datatypes.AtmVpShaping>`
                        
                        

                        """

                        _prefix = 'atm-vcm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape, self).__init__()

                            self.yang_name = "shape"
                            self.yang_parent_name = "vp-tunnel"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.burst_size = YLeaf(YType.uint32, "burst-size")

                            self.peak_cell_rate = YLeaf(YType.uint32, "peak-cell-rate")

                            self.sustained_cell_rate = YLeaf(YType.uint32, "sustained-cell-rate")

                            self.type = YLeaf(YType.enumeration, "type")
                            self._segment_path = lambda: "shape"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Atm.VpTunnels.VpTunnel.Shape, ['burst_size', 'peak_cell_rate', 'sustained_cell_rate', 'type'], name, value)


        class Bfd(Entity):
            """
            BFD over bundle members configuration
            
            .. attribute:: address_family
            
            	Configuration of BFDoBM for all address families
            	**type**\:   :py:class:`AddressFamily <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily>`
            
            .. attribute:: mode
            
            	Configuration of BFDoBM mode [cisco\|ietf]
            	**type**\:   :py:class:`BfdMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BfdMode>`
            
            	**default value**\: no-cfg
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Bfd, self).__init__()

                self.yang_name = "bfd"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"address-family" : ("address_family", InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily)}
                self._child_list_classes = {}

                self.mode = YLeaf(YType.enumeration, "mode")

                self.address_family = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily()
                self.address_family.parent = self
                self._children_name_map["address_family"] = "address-family"
                self._children_yang_names.add("address-family")
                self._segment_path = lambda: "Cisco-IOS-XR-bundlemgr-cfg:bfd"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bfd, ['mode'], name, value)


            class AddressFamily(Entity):
                """
                Configuration of BFDoBM for all address
                families
                
                .. attribute:: ipv4
                
                	Configuration of BFDoBM for IPv4 address family
                	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4>`
                
                .. attribute:: ipv6
                
                	Configuration of BFDoBM for IPv6 address family
                	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6>`
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily, self).__init__()

                    self.yang_name = "address-family"
                    self.yang_parent_name = "bfd"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"ipv4" : ("ipv4", InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4), "ipv6" : ("ipv6", InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6)}
                    self._child_list_classes = {}

                    self.ipv4 = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._children_yang_names.add("ipv4")

                    self.ipv6 = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._children_yang_names.add("ipv6")
                    self._segment_path = lambda: "address-family"


                class Ipv4(Entity):
                    """
                    Configuration of BFDoBM for IPv4 address
                    family
                    
                    .. attribute:: destination_address
                    
                    	Destination address for BFD sessions created by bundlemgr
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection multiplier for BFD sessions created by bundlemgr
                    	**type**\:  int
                    
                    	**range:** 2..50
                    
                    .. attribute:: echo
                    
                    	Container for Echo min\-multiplier
                    	**type**\:   :py:class:`Echo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo>`
                    
                    .. attribute:: fast_detect
                    
                    	Configure to enable BFD over bundle members
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: interval
                    
                    	Hello interval for BFD sessions created by bundlemgr
                    	**type**\:  int
                    
                    	**range:** 3..30000
                    
                    .. attribute:: timers
                    
                    	Timers associated with BFDoBM
                    	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers>`
                    
                    

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"echo" : ("echo", InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo), "timers" : ("timers", InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers)}
                        self._child_list_classes = {}

                        self.destination_address = YLeaf(YType.str, "destination-address")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.fast_detect = YLeaf(YType.empty, "fast-detect")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.echo = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo()
                        self.echo.parent = self
                        self._children_name_map["echo"] = "echo"
                        self._children_yang_names.add("echo")

                        self.timers = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"
                        self._children_yang_names.add("timers")
                        self._segment_path = lambda: "ipv4"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4, ['destination_address', 'detection_multiplier', 'fast_detect', 'interval'], name, value)


                    class Echo(Entity):
                        """
                        Container for Echo min\-multiplier
                        
                        .. attribute:: min_interval
                        
                        	Configure echo min\-interval for bundle interface
                        	**type**\:  int
                        
                        	**range:** 15..2000
                        
                        

                        """

                        _prefix = 'bundlemgr-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo, self).__init__()

                            self.yang_name = "echo"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.min_interval = YLeaf(YType.uint32, "min-interval")
                            self._segment_path = lambda: "echo"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Echo, ['min_interval'], name, value)


                    class Timers(Entity):
                        """
                        Timers associated with BFDoBM
                        
                        .. attribute:: nbor_unconfig_timer
                        
                        	Timer associated with aggressiveness on BFD session peer being unconfigured
                        	**type**\:  int
                        
                        	**range:** 60..3600
                        
                        .. attribute:: start_timer
                        
                        	Timer associated with aggressiveness on BFD session creation
                        	**type**\:  int
                        
                        	**range:** 60..3600
                        
                        

                        """

                        _prefix = 'bundlemgr-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.nbor_unconfig_timer = YLeaf(YType.uint32, "nbor-unconfig-timer")

                            self.start_timer = YLeaf(YType.uint32, "start-timer")
                            self._segment_path = lambda: "timers"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv4.Timers, ['nbor_unconfig_timer', 'start_timer'], name, value)


                class Ipv6(Entity):
                    """
                    Configuration of BFDoBM for IPv6 address
                    family
                    
                    .. attribute:: ipv6_destination_address
                    
                    	IPv6 Destination address for BFD sessions created by bundlemgr
                    	**type**\:  str
                    
                    .. attribute:: ipv6_detection_multiplier
                    
                    	IPv6 Detection multiplier for BFD sessions created by bundlemgr
                    	**type**\:  int
                    
                    	**range:** 2..50
                    
                    .. attribute:: ipv6_fast_detect
                    
                    	Configure to enable BFD over bundle members
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: ipv6_interval
                    
                    	IPV6 Hello interval for BFD sessions created by bundlemgr
                    	**type**\:  int
                    
                    	**range:** 3..30000
                    
                    .. attribute:: ipv6_timers
                    
                    	Timers associated with BFDoBM
                    	**type**\:   :py:class:`Ipv6Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers>`
                    
                    

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "address-family"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"ipv6-timers" : ("ipv6_timers", InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers)}
                        self._child_list_classes = {}

                        self.ipv6_destination_address = YLeaf(YType.str, "ipv6-destination-address")

                        self.ipv6_detection_multiplier = YLeaf(YType.uint32, "ipv6-detection-multiplier")

                        self.ipv6_fast_detect = YLeaf(YType.empty, "ipv6-fast-detect")

                        self.ipv6_interval = YLeaf(YType.uint32, "ipv6-interval")

                        self.ipv6_timers = InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers()
                        self.ipv6_timers.parent = self
                        self._children_name_map["ipv6_timers"] = "ipv6-timers"
                        self._children_yang_names.add("ipv6-timers")
                        self._segment_path = lambda: "ipv6"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6, ['ipv6_destination_address', 'ipv6_detection_multiplier', 'ipv6_fast_detect', 'ipv6_interval'], name, value)


                    class Ipv6Timers(Entity):
                        """
                        Timers associated with BFDoBM
                        
                        .. attribute:: ipv6_nbor_unconfig_timer
                        
                        	IPv6 Timer associated with aggressiveness on BFD session peer being unconfigured
                        	**type**\:  int
                        
                        	**range:** 60..3600
                        
                        .. attribute:: ipv6_start_timer
                        
                        	IPv6 Timer associated with aggressiveness on BFD session creation
                        	**type**\:  int
                        
                        	**range:** 60..3600
                        
                        

                        """

                        _prefix = 'bundlemgr-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers, self).__init__()

                            self.yang_name = "ipv6-timers"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.ipv6_nbor_unconfig_timer = YLeaf(YType.uint32, "ipv6-nbor-unconfig-timer")

                            self.ipv6_start_timer = YLeaf(YType.uint32, "ipv6-start-timer")
                            self._segment_path = lambda: "ipv6-timers"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bfd.AddressFamily.Ipv6.Ipv6Timers, ['ipv6_nbor_unconfig_timer', 'ipv6_start_timer'], name, value)


        class Bundle(Entity):
            """
            Generic per\-bundle configuration
            
            .. attribute:: bundle_load_balancing
            
            	Load\-balance configuration
            	**type**\:   :py:class:`BundleLoadBalancing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing>`
            
            .. attribute:: lacp_delay
            
            	Set the lacp\-delay timeout for members of this bundle
            	**type**\:  int
            
            	**range:** 1000..15000
            
            .. attribute:: maximum_active
            
            	Set a limit on the number of links that can be active
            	**type**\:   :py:class:`MaximumActive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive>`
            
            .. attribute:: minimum_active
            
            	Minimum criteria for a bundle to be active
            	**type**\:   :py:class:`MinimumActive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive>`
            
            .. attribute:: shutdown
            
            	Deactivate all member links (down to Standby state)
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: wait_while
            
            	Set the wait\-while timeout for members of this bundle
            	**type**\:  int
            
            	**range:** 0..2000
            
            	**default value**\: 2000
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Bundle, self).__init__()

                self.yang_name = "bundle"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"bundle-load-balancing" : ("bundle_load_balancing", InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing), "maximum-active" : ("maximum_active", InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive), "minimum-active" : ("minimum_active", InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive)}
                self._child_list_classes = {}

                self.lacp_delay = YLeaf(YType.uint32, "lacp-delay")

                self.shutdown = YLeaf(YType.empty, "shutdown")

                self.wait_while = YLeaf(YType.uint32, "wait-while")

                self.bundle_load_balancing = InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing()
                self.bundle_load_balancing.parent = self
                self._children_name_map["bundle_load_balancing"] = "bundle-load-balancing"
                self._children_yang_names.add("bundle-load-balancing")

                self.maximum_active = InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive()
                self.maximum_active.parent = self
                self._children_name_map["maximum_active"] = "maximum-active"
                self._children_yang_names.add("maximum-active")

                self.minimum_active = InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive()
                self.minimum_active.parent = self
                self._children_name_map["minimum_active"] = "minimum-active"
                self._children_yang_names.add("minimum-active")
                self._segment_path = lambda: "Cisco-IOS-XR-bundlemgr-cfg:bundle"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bundle, ['lacp_delay', 'shutdown', 'wait_while'], name, value)


            class BundleLoadBalancing(Entity):
                """
                Load\-balance configuration
                
                .. attribute:: hash_function
                
                	Enable loadbalancing on this Bundle / EFP
                	**type**\:   :py:class:`HashFunction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing.HashFunction>`
                
                	**presence node**\: True
                
                .. attribute:: localize_links
                
                	Set thresholds for forwarding bundle traffic within a rack
                	**type**\:  int
                
                	**range:** 1..64
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing, self).__init__()

                    self.yang_name = "bundle-load-balancing"
                    self.yang_parent_name = "bundle"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"hash-function" : ("hash_function", InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing.HashFunction)}
                    self._child_list_classes = {}

                    self.localize_links = YLeaf(YType.uint32, "localize-links")

                    self.hash_function = None
                    self._children_name_map["hash_function"] = "hash-function"
                    self._children_yang_names.add("hash-function")
                    self._segment_path = lambda: "bundle-load-balancing"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing, ['localize_links'], name, value)


                class HashFunction(Entity):
                    """
                    Enable loadbalancing on this Bundle / EFP
                    
                    .. attribute:: hash_type
                    
                    	The specified hash function to use
                    	**type**\:   :py:class:`BundleLoadBalance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleLoadBalance>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: hash_value
                    
                    	The loadbalance hash value selected. For non\-EFP Value methods, this value must be set to 1
                    	**type**\:  int
                    
                    	**range:** 1..64
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing.HashFunction, self).__init__()

                        self.yang_name = "hash-function"
                        self.yang_parent_name = "bundle-load-balancing"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.hash_type = YLeaf(YType.enumeration, "hash-type")

                        self.hash_value = YLeaf(YType.uint32, "hash-value")
                        self._segment_path = lambda: "hash-function"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bundle.BundleLoadBalancing.HashFunction, ['hash_type', 'hash_value'], name, value)


            class MaximumActive(Entity):
                """
                Set a limit on the number of links that can be
                active
                
                .. attribute:: links
                
                	Maximum number of active links in a bundle
                	**type**\:   :py:class:`Links <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive.Links>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive, self).__init__()

                    self.yang_name = "maximum-active"
                    self.yang_parent_name = "bundle"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"links" : ("links", InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive.Links)}
                    self._child_list_classes = {}

                    self.links = None
                    self._children_name_map["links"] = "links"
                    self._children_yang_names.add("links")
                    self._segment_path = lambda: "maximum-active"


                class Links(Entity):
                    """
                    Maximum number of active links in a bundle
                    
                    .. attribute:: links
                    
                    	Number of active links
                    	**type**\:  int
                    
                    	**range:** 1..64
                    
                    	**mandatory**\: True
                    
                    .. attribute:: max_active_links_mode
                    
                    	Maximum active links mode
                    	**type**\:   :py:class:`BundleMaximumActiveLinksMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleMaximumActiveLinksMode>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive.Links, self).__init__()

                        self.yang_name = "links"
                        self.yang_parent_name = "maximum-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.links = YLeaf(YType.uint32, "links")

                        self.max_active_links_mode = YLeaf(YType.enumeration, "max-active-links-mode")
                        self._segment_path = lambda: "links"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bundle.MaximumActive.Links, ['links', 'max_active_links_mode'], name, value)


            class MinimumActive(Entity):
                """
                Minimum criteria for a bundle to be active
                
                .. attribute:: bandwidth
                
                	Bandwidth (in kbps) needed to bring up a bundle
                	**type**\:   :py:class:`Bandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive.Bandwidth>`
                
                	**presence node**\: True
                
                .. attribute:: links
                
                	Number of active links needed to bring up a bundle
                	**type**\:  int
                
                	**range:** 1..64
                
                	**default value**\: 1
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive, self).__init__()

                    self.yang_name = "minimum-active"
                    self.yang_parent_name = "bundle"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"bandwidth" : ("bandwidth", InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive.Bandwidth)}
                    self._child_list_classes = {}

                    self.links = YLeaf(YType.uint32, "links")

                    self.bandwidth = None
                    self._children_name_map["bandwidth"] = "bandwidth"
                    self._children_yang_names.add("bandwidth")
                    self._segment_path = lambda: "minimum-active"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive, ['links'], name, value)


                class Bandwidth(Entity):
                    """
                    Bandwidth (in kbps) needed to bring up a
                    bundle
                    
                    .. attribute:: bandwidth
                    
                    	Bandwidth
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    	**mandatory**\: True
                    
                    .. attribute:: min_bandwidth_range
                    
                    	Minimum Bandwidth Range
                    	**type**\:   :py:class:`BundleMinimumBandwidthRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleMinimumBandwidthRange>`
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'bundlemgr-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive.Bandwidth, self).__init__()

                        self.yang_name = "bandwidth"
                        self.yang_parent_name = "minimum-active"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                        self.min_bandwidth_range = YLeaf(YType.enumeration, "min-bandwidth-range")
                        self._segment_path = lambda: "bandwidth"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bundle.MinimumActive.Bandwidth, ['bandwidth', 'min_bandwidth_range'], name, value)


        class BundleMember(Entity):
            """
            Generic per\-member configuration
            
            .. attribute:: id
            
            	Add the port to an aggregated interface
            	**type**\:   :py:class:`Id <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id>`
            
            .. attribute:: port_priority
            
            	Priority for this port. Lower value is higher priority
            	**type**\:  int
            
            	**range:** 1..65535
            
            	**default value**\: 32768
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.BundleMember, self).__init__()

                self.yang_name = "bundle-member"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"id" : ("id", InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id)}
                self._child_list_classes = {}

                self.port_priority = YLeaf(YType.uint16, "port-priority")

                self.id = InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id()
                self.id.parent = self
                self._children_name_map["id"] = "id"
                self._children_yang_names.add("id")
                self._segment_path = lambda: "Cisco-IOS-XR-bundlemgr-cfg:bundle-member"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.BundleMember, ['port_priority'], name, value)


            class Id(Entity):
                """
                Add the port to an aggregated interface.
                
                .. attribute:: bundle_id
                
                	Identifier of the bundle to add the port to
                	**type**\:  int
                
                	**range:** 1..65535
                
                .. attribute:: port_activity
                
                	Port Activity
                	**type**\:   :py:class:`BundlePortActivity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundlePortActivity>`
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id, self).__init__()

                    self.yang_name = "id"
                    self.yang_parent_name = "bundle-member"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bundle_id = YLeaf(YType.uint32, "bundle-id")

                    self.port_activity = YLeaf(YType.enumeration, "port-activity")
                    self._segment_path = lambda: "id"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.BundleMember.Id, ['bundle_id', 'port_activity'], name, value)


        class Bvi(Entity):
            """
            BVI attributes
            
            .. attribute:: host_routing
            
            	Enable host\-routing on this BVI
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'l2vpn-cfg'
            _revision = '2017-06-26'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Bvi, self).__init__()

                self.yang_name = "bvi"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.host_routing = YLeaf(YType.empty, "host-routing")
                self._segment_path = lambda: "Cisco-IOS-XR-l2vpn-cfg:bvi"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Bvi, ['host_routing'], name, value)


        class CarrierDelay(Entity):
            """
            Set the carrier transition delay on an interface
            in msecs
            
            .. attribute:: carrier_delay_down
            
            	Carrier Delay down in msecs, must be set to 0
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: carrier_delay_up
            
            	Carrier Delay (up) in msecs
            	**type**\:  int
            
            	**range:** 1..65535
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CarrierDelay, self).__init__()

                self.yang_name = "carrier-delay"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.carrier_delay_down = YLeaf(YType.uint32, "carrier-delay-down")

                self.carrier_delay_up = YLeaf(YType.uint32, "carrier-delay-up")
                self._segment_path = lambda: "Cisco-IOS-XR-l2-eth-infra-cfg:carrier-delay"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CarrierDelay, ['carrier_delay_down', 'carrier_delay_up'], name, value)


        class Cdp(Entity):
            """
            Interface specific CDP configuration
            
            .. attribute:: enable
            
            	Enable or disable CDP on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'cdp-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Cdp, self).__init__()

                self.yang_name = "cdp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.enable = YLeaf(YType.empty, "enable")
                self._segment_path = lambda: "Cisco-IOS-XR-cdp-cfg:cdp"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Cdp, ['enable'], name, value)


        class CiscoIOSXRFreqsyncCfgFrequencySynchronization(Entity):
            """
            Frequency Synchronization interface
            configuration
            
            .. attribute:: enable
            
            	Enable Frequency Synchronization
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: input_quality_level
            
            	Set the input quality level
            	**type**\:   :py:class:`InputQualityLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.InputQualityLevel>`
            
            .. attribute:: output_quality_level
            
            	Set the output quality level
            	**type**\:   :py:class:`OutputQualityLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.OutputQualityLevel>`
            
            .. attribute:: priority
            
            	Set the priority of this source
            	**type**\:  int
            
            	**range:** 1..254
            
            	**default value**\: 100
            
            .. attribute:: selection_input
            
            	Assign this source as a selection input
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ssm_disable
            
            	Disable SSM on this source
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: time_of_day_priority
            
            	Set the time\-of\-day priority of this source
            	**type**\:  int
            
            	**range:** 1..254
            
            	**default value**\: 100
            
            .. attribute:: wait_to_restore_time
            
            	Set the wait\-to\-restore time for this source
            	**type**\:  int
            
            	**range:** 0..12
            
            	**default value**\: 5
            
            

            """

            _prefix = 'freqsync-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization, self).__init__()

                self.yang_name = "Cisco-IOS-XR-freqsync-cfg_frequency-synchronization"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"input-quality-level" : ("input_quality_level", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.InputQualityLevel), "output-quality-level" : ("output_quality_level", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.OutputQualityLevel)}
                self._child_list_classes = {}

                self.enable = YLeaf(YType.empty, "enable")

                self.priority = YLeaf(YType.uint32, "priority")

                self.selection_input = YLeaf(YType.empty, "selection-input")

                self.ssm_disable = YLeaf(YType.empty, "ssm-disable")

                self.time_of_day_priority = YLeaf(YType.uint32, "time-of-day-priority")

                self.wait_to_restore_time = YLeaf(YType.uint32, "wait-to-restore-time")

                self.input_quality_level = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.InputQualityLevel()
                self.input_quality_level.parent = self
                self._children_name_map["input_quality_level"] = "input-quality-level"
                self._children_yang_names.add("input-quality-level")

                self.output_quality_level = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.OutputQualityLevel()
                self.output_quality_level.parent = self
                self._children_name_map["output_quality_level"] = "output-quality-level"
                self._children_yang_names.add("output-quality-level")
                self._segment_path = lambda: "Cisco-IOS-XR-freqsync-cfg:Cisco-IOS-XR-freqsync-cfg_frequency-synchronization"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization, ['enable', 'priority', 'selection_input', 'ssm_disable', 'time_of_day_priority', 'wait_to_restore_time'], name, value)


            class InputQualityLevel(Entity):
                """
                Set the input quality level
                
                .. attribute:: exact_quality_level_value
                
                	Exact quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: max_quality_level_value
                
                	Maximum quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: min_quality_level_value
                
                	Minimum quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: quality_level_option
                
                	Quality level option
                	**type**\:   :py:class:`FsyncQlOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlOption>`
                
                

                """

                _prefix = 'freqsync-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.InputQualityLevel, self).__init__()

                    self.yang_name = "input-quality-level"
                    self.yang_parent_name = "Cisco-IOS-XR-freqsync-cfg_frequency-synchronization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.exact_quality_level_value = YLeaf(YType.enumeration, "exact-quality-level-value")

                    self.max_quality_level_value = YLeaf(YType.enumeration, "max-quality-level-value")

                    self.min_quality_level_value = YLeaf(YType.enumeration, "min-quality-level-value")

                    self.quality_level_option = YLeaf(YType.enumeration, "quality-level-option")
                    self._segment_path = lambda: "input-quality-level"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.InputQualityLevel, ['exact_quality_level_value', 'max_quality_level_value', 'min_quality_level_value', 'quality_level_option'], name, value)


            class OutputQualityLevel(Entity):
                """
                Set the output quality level
                
                .. attribute:: exact_quality_level_value
                
                	Exact quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: max_quality_level_value
                
                	Maximum quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: min_quality_level_value
                
                	Minimum quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: quality_level_option
                
                	Quality level option
                	**type**\:   :py:class:`FsyncQlOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlOption>`
                
                

                """

                _prefix = 'freqsync-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.OutputQualityLevel, self).__init__()

                    self.yang_name = "output-quality-level"
                    self.yang_parent_name = "Cisco-IOS-XR-freqsync-cfg_frequency-synchronization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.exact_quality_level_value = YLeaf(YType.enumeration, "exact-quality-level-value")

                    self.max_quality_level_value = YLeaf(YType.enumeration, "max-quality-level-value")

                    self.min_quality_level_value = YLeaf(YType.enumeration, "min-quality-level-value")

                    self.quality_level_option = YLeaf(YType.enumeration, "quality-level-option")
                    self._segment_path = lambda: "output-quality-level"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRFreqsyncCfgFrequencySynchronization.OutputQualityLevel, ['exact_quality_level_value', 'max_quality_level_value', 'min_quality_level_value', 'quality_level_option'], name, value)


        class CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization(Entity):
            """
            Frequency Synchronization interface
            configuration
            
            .. attribute:: enable
            
            	Enable Frequency Synchronization
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: input_quality_level
            
            	Set the input quality level
            	**type**\:   :py:class:`InputQualityLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.InputQualityLevel>`
            
            .. attribute:: output_quality_level
            
            	Set the output quality level
            	**type**\:   :py:class:`OutputQualityLevel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.OutputQualityLevel>`
            
            .. attribute:: priority
            
            	Set the priority of this source
            	**type**\:  int
            
            	**range:** 1..254
            
            	**default value**\: 100
            
            .. attribute:: selection_input
            
            	Assign this source as a selection input
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ssm_disable
            
            	Disable SSM on this source
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: time_of_day_priority
            
            	Set the time\-of\-day priority of this source
            	**type**\:  int
            
            	**range:** 1..254
            
            	**default value**\: 100
            
            .. attribute:: wait_to_restore_time
            
            	Set the wait\-to\-restore time for this source
            	**type**\:  int
            
            	**range:** 0..12
            
            	**default value**\: 5
            
            

            """

            _prefix = 'ncs4k-freqsync-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ncs4k-freqsync-cfg_frequency-synchronization"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"input-quality-level" : ("input_quality_level", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.InputQualityLevel), "output-quality-level" : ("output_quality_level", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.OutputQualityLevel)}
                self._child_list_classes = {}

                self.enable = YLeaf(YType.empty, "enable")

                self.priority = YLeaf(YType.uint32, "priority")

                self.selection_input = YLeaf(YType.empty, "selection-input")

                self.ssm_disable = YLeaf(YType.empty, "ssm-disable")

                self.time_of_day_priority = YLeaf(YType.uint32, "time-of-day-priority")

                self.wait_to_restore_time = YLeaf(YType.uint32, "wait-to-restore-time")

                self.input_quality_level = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.InputQualityLevel()
                self.input_quality_level.parent = self
                self._children_name_map["input_quality_level"] = "input-quality-level"
                self._children_yang_names.add("input-quality-level")

                self.output_quality_level = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.OutputQualityLevel()
                self.output_quality_level.parent = self
                self._children_name_map["output_quality_level"] = "output-quality-level"
                self._children_yang_names.add("output-quality-level")
                self._segment_path = lambda: "Cisco-IOS-XR-ncs4k-freqsync-cfg:Cisco-IOS-XR-ncs4k-freqsync-cfg_frequency-synchronization"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization, ['enable', 'priority', 'selection_input', 'ssm_disable', 'time_of_day_priority', 'wait_to_restore_time'], name, value)


            class InputQualityLevel(Entity):
                """
                Set the input quality level
                
                .. attribute:: exact_quality_level_value
                
                	Exact quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: max_quality_level_value
                
                	Maximum quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: min_quality_level_value
                
                	Minimum quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: quality_level_option
                
                	Quality level option
                	**type**\:   :py:class:`FsyncQlOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlOption>`
                
                

                """

                _prefix = 'ncs4k-freqsync-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.InputQualityLevel, self).__init__()

                    self.yang_name = "input-quality-level"
                    self.yang_parent_name = "Cisco-IOS-XR-ncs4k-freqsync-cfg_frequency-synchronization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.exact_quality_level_value = YLeaf(YType.enumeration, "exact-quality-level-value")

                    self.max_quality_level_value = YLeaf(YType.enumeration, "max-quality-level-value")

                    self.min_quality_level_value = YLeaf(YType.enumeration, "min-quality-level-value")

                    self.quality_level_option = YLeaf(YType.enumeration, "quality-level-option")
                    self._segment_path = lambda: "input-quality-level"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.InputQualityLevel, ['exact_quality_level_value', 'max_quality_level_value', 'min_quality_level_value', 'quality_level_option'], name, value)


            class OutputQualityLevel(Entity):
                """
                Set the output quality level
                
                .. attribute:: exact_quality_level_value
                
                	Exact quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: max_quality_level_value
                
                	Maximum quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: min_quality_level_value
                
                	Minimum quality level value
                	**type**\:   :py:class:`FsyncQlValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlValue>`
                
                .. attribute:: quality_level_option
                
                	Quality level option
                	**type**\:   :py:class:`FsyncQlOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_freqsync_datatypes.FsyncQlOption>`
                
                

                """

                _prefix = 'ncs4k-freqsync-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.OutputQualityLevel, self).__init__()

                    self.yang_name = "output-quality-level"
                    self.yang_parent_name = "Cisco-IOS-XR-ncs4k-freqsync-cfg_frequency-synchronization"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.exact_quality_level_value = YLeaf(YType.enumeration, "exact-quality-level-value")

                    self.max_quality_level_value = YLeaf(YType.enumeration, "max-quality-level-value")

                    self.min_quality_level_value = YLeaf(YType.enumeration, "min-quality-level-value")

                    self.quality_level_option = YLeaf(YType.enumeration, "quality-level-option")
                    self._segment_path = lambda: "output-quality-level"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRNcs4KFreqsyncCfgFrequencySynchronization.OutputQualityLevel, ['exact_quality_level_value', 'max_quality_level_value', 'min_quality_level_value', 'quality_level_option'], name, value)


        class CiscoIOSXRPppMaCfgPpp(Entity):
            """
            Interface PPP configuration data
            
            

            """

            _prefix = 'ppp-ma-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaCfgPpp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-cfg_ppp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}
                self._segment_path = lambda: "Cisco-IOS-XR-ppp-ma-cfg:Cisco-IOS-XR-ppp-ma-cfg_ppp"


        class CiscoIOSXRPppMaFsmCfgPpp(Entity):
            """
            Interface PPP configuration data
            
            .. attribute:: fsm
            
            	PPP FSM configuration data
            	**type**\:   :py:class:`Fsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaFsmCfgPpp.Fsm>`
            
            

            """

            _prefix = 'ppp-ma-fsm-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaFsmCfgPpp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"fsm" : ("fsm", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaFsmCfgPpp.Fsm)}
                self._child_list_classes = {}

                self.fsm = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaFsmCfgPpp.Fsm()
                self.fsm.parent = self
                self._children_name_map["fsm"] = "fsm"
                self._children_yang_names.add("fsm")
                self._segment_path = lambda: "Cisco-IOS-XR-ppp-ma-fsm-cfg:Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp"


            class Fsm(Entity):
                """
                PPP FSM configuration data
                
                .. attribute:: max_consecutive_conf_naks
                
                	This specifies the maximum number of consecutive Conf\-Naks
                	**type**\:  int
                
                	**range:** 2..10
                
                	**default value**\: 5
                
                .. attribute:: max_unacknowledged_conf_requests
                
                	This specifies the maximum number of unacknowledged Conf\-Requests
                	**type**\:  int
                
                	**range:** 4..20
                
                	**default value**\: 10
                
                .. attribute:: max_unacknowledged_term_requests
                
                	This specifies the maximum number of Term\-Requests
                	**type**\:  int
                
                	**range:** 2..10
                
                	**default value**\: 2
                
                .. attribute:: retry_timeout
                
                	This specifies the maximum time to wait for a response during PPP negotiation
                	**type**\:  int
                
                	**range:** 1..10
                
                	**default value**\: 3
                
                

                """

                _prefix = 'ppp-ma-fsm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaFsmCfgPpp.Fsm, self).__init__()

                    self.yang_name = "fsm"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-fsm-cfg_ppp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.max_consecutive_conf_naks = YLeaf(YType.uint32, "max-consecutive-conf-naks")

                    self.max_unacknowledged_conf_requests = YLeaf(YType.uint32, "max-unacknowledged-conf-requests")

                    self.max_unacknowledged_term_requests = YLeaf(YType.uint32, "max-unacknowledged-term-requests")

                    self.retry_timeout = YLeaf(YType.uint32, "retry-timeout")
                    self._segment_path = lambda: "fsm"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaFsmCfgPpp.Fsm, ['max_consecutive_conf_naks', 'max_unacknowledged_conf_requests', 'max_unacknowledged_term_requests', 'retry_timeout'], name, value)


        class CiscoIOSXRPppMaIpcpCfgPpp(Entity):
            """
            Interface PPP configuration data
            
            .. attribute:: ipcp
            
            	PPP IPCP configuration data
            	**type**\:   :py:class:`Ipcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp>`
            
            

            """

            _prefix = 'ppp-ma-ipcp-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"ipcp" : ("ipcp", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp)}
                self._child_list_classes = {}

                self.ipcp = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp()
                self.ipcp.parent = self
                self._children_name_map["ipcp"] = "ipcp"
                self._children_yang_names.add("ipcp")
                self._segment_path = lambda: "Cisco-IOS-XR-ppp-ma-ipcp-cfg:Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp"


            class Ipcp(Entity):
                """
                PPP IPCP configuration data
                
                .. attribute:: dns
                
                	IPCP DNS parameters
                	**type**\:   :py:class:`Dns <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.Dns>`
                
                .. attribute:: neighbor_route_disable
                
                	Disable Neighbor Route installation
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: peer_address
                
                	IPCP address parameters
                	**type**\:   :py:class:`PeerAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.PeerAddress>`
                
                

                """

                _prefix = 'ppp-ma-ipcp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp, self).__init__()

                    self.yang_name = "ipcp"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-ipcp-cfg_ppp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"dns" : ("dns", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.Dns), "peer-address" : ("peer_address", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.PeerAddress)}
                    self._child_list_classes = {}

                    self.neighbor_route_disable = YLeaf(YType.empty, "neighbor-route-disable")

                    self.dns = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.Dns()
                    self.dns.parent = self
                    self._children_name_map["dns"] = "dns"
                    self._children_yang_names.add("dns")

                    self.peer_address = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.PeerAddress()
                    self.peer_address.parent = self
                    self._children_name_map["peer_address"] = "peer-address"
                    self._children_yang_names.add("peer-address")
                    self._segment_path = lambda: "ipcp"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp, ['neighbor_route_disable'], name, value)


                class Dns(Entity):
                    """
                    IPCP DNS parameters
                    
                    .. attribute:: dns_addresses
                    
                    	Specify DNS address(es) to provide
                    	**type**\:   :py:class:`DnsAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.Dns.DnsAddresses>`
                    
                    

                    """

                    _prefix = 'ppp-ma-ipcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.Dns, self).__init__()

                        self.yang_name = "dns"
                        self.yang_parent_name = "ipcp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"dns-addresses" : ("dns_addresses", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.Dns.DnsAddresses)}
                        self._child_list_classes = {}

                        self.dns_addresses = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.Dns.DnsAddresses()
                        self.dns_addresses.parent = self
                        self._children_name_map["dns_addresses"] = "dns-addresses"
                        self._children_yang_names.add("dns-addresses")
                        self._segment_path = lambda: "dns"


                    class DnsAddresses(Entity):
                        """
                        Specify DNS address(es) to provide
                        
                        .. attribute:: primary
                        
                        	Primary DNS IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: secondary
                        
                        	Secondary DNS IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'ppp-ma-ipcp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.Dns.DnsAddresses, self).__init__()

                            self.yang_name = "dns-addresses"
                            self.yang_parent_name = "dns"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.primary = YLeaf(YType.str, "primary")

                            self.secondary = YLeaf(YType.str, "secondary")
                            self._segment_path = lambda: "dns-addresses"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.Dns.DnsAddresses, ['primary', 'secondary'], name, value)


                class PeerAddress(Entity):
                    """
                    IPCP address parameters
                    
                    .. attribute:: default
                    
                    	Specify an IP address to assign to peers through IPCP
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ppp-ma-ipcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.PeerAddress, self).__init__()

                        self.yang_name = "peer-address"
                        self.yang_parent_name = "ipcp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.default = YLeaf(YType.str, "default")
                        self._segment_path = lambda: "peer-address"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpCfgPpp.Ipcp.PeerAddress, ['default'], name, value)


        class CiscoIOSXRPppMaIpcpiwCfgPpp(Entity):
            """
            Interface PPP configuration data
            
            .. attribute:: ipcpiw
            
            	PPP IPCPIW configuration data
            	**type**\:   :py:class:`Ipcpiw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpiwCfgPpp.Ipcpiw>`
            
            

            """

            _prefix = 'ppp-ma-ipcpiw-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpiwCfgPpp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"ipcpiw" : ("ipcpiw", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpiwCfgPpp.Ipcpiw)}
                self._child_list_classes = {}

                self.ipcpiw = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpiwCfgPpp.Ipcpiw()
                self.ipcpiw.parent = self
                self._children_name_map["ipcpiw"] = "ipcpiw"
                self._children_yang_names.add("ipcpiw")
                self._segment_path = lambda: "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg:Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp"


            class Ipcpiw(Entity):
                """
                PPP IPCPIW configuration data
                
                .. attribute:: proxy_address
                
                	Specify an IP address to publish to peers through IPCPIW
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ppp-ma-ipcpiw-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpiwCfgPpp.Ipcpiw, self).__init__()

                    self.yang_name = "ipcpiw"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-ipcpiw-cfg_ppp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.proxy_address = YLeaf(YType.str, "proxy-address")
                    self._segment_path = lambda: "ipcpiw"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaIpcpiwCfgPpp.Ipcpiw, ['proxy_address'], name, value)


        class CiscoIOSXRPppMaLcpCfgPpp(Entity):
            """
            Interface PPP configuration data
            
            .. attribute:: lcp
            
            	PPP LCP configuration data
            	**type**\:   :py:class:`Lcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp>`
            
            .. attribute:: mcmp
            
            	PPP Multiclass Multilink parameters
            	**type**\:   :py:class:`Mcmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp>`
            
            

            """

            _prefix = 'ppp-ma-lcp-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp, self).__init__()

                self.yang_name = "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"lcp" : ("lcp", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp), "mcmp" : ("mcmp", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp)}
                self._child_list_classes = {}

                self.lcp = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp()
                self.lcp.parent = self
                self._children_name_map["lcp"] = "lcp"
                self._children_yang_names.add("lcp")

                self.mcmp = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp()
                self.mcmp.parent = self
                self._children_name_map["mcmp"] = "mcmp"
                self._children_yang_names.add("mcmp")
                self._segment_path = lambda: "Cisco-IOS-XR-ppp-ma-lcp-cfg:Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"


            class Lcp(Entity):
                """
                PPP LCP configuration data
                
                .. attribute:: authentication
                
                	PPP authentication parameters
                	**type**\:   :py:class:`Authentication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication>`
                
                .. attribute:: chap
                
                	Challenge Handshake Authentication Protocol (CHAP) configuration data
                	**type**\:   :py:class:`Chap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Chap>`
                
                .. attribute:: loop_back
                
                	Loopback configuration
                	**type**\:   :py:class:`LoopBack <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.LoopBack>`
                
                .. attribute:: ms_chap
                
                	Microsoft Challenge Handshake Authentication Protocol (MS\-CHAP) configuration data
                	**type**\:   :py:class:`MsChap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.MsChap>`
                
                .. attribute:: multilink
                
                	Multilink configuration
                	**type**\:   :py:class:`Multilink <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Multilink>`
                
                .. attribute:: pap
                
                	Password Authentication Protocol (PAP) configuration data
                	**type**\:   :py:class:`Pap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap>`
                
                .. attribute:: service_type
                
                	This specifies whether to allow multiple authentication failures and, if so, how many
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ppp-ma-lcp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp, self).__init__()

                    self.yang_name = "lcp"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"authentication" : ("authentication", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication), "chap" : ("chap", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Chap), "loop-back" : ("loop_back", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.LoopBack), "ms-chap" : ("ms_chap", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.MsChap), "multilink" : ("multilink", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Multilink), "pap" : ("pap", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap)}
                    self._child_list_classes = {}

                    self.service_type = YLeaf(YType.int32, "service-type")

                    self.authentication = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication()
                    self.authentication.parent = self
                    self._children_name_map["authentication"] = "authentication"
                    self._children_yang_names.add("authentication")

                    self.chap = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Chap()
                    self.chap.parent = self
                    self._children_name_map["chap"] = "chap"
                    self._children_yang_names.add("chap")

                    self.loop_back = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.LoopBack()
                    self.loop_back.parent = self
                    self._children_name_map["loop_back"] = "loop-back"
                    self._children_yang_names.add("loop-back")

                    self.ms_chap = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.MsChap()
                    self.ms_chap.parent = self
                    self._children_name_map["ms_chap"] = "ms-chap"
                    self._children_yang_names.add("ms-chap")

                    self.multilink = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Multilink()
                    self.multilink.parent = self
                    self._children_name_map["multilink"] = "multilink"
                    self._children_yang_names.add("multilink")

                    self.pap = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap()
                    self.pap.parent = self
                    self._children_name_map["pap"] = "pap"
                    self._children_yang_names.add("pap")
                    self._segment_path = lambda: "lcp"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp, ['service_type'], name, value)


                class Authentication(Entity):
                    """
                    PPP authentication parameters
                    
                    .. attribute:: max_authentication_failures
                    
                    	This specifies whether to allow multiple authentication failures and, if so, how many
                    	**type**\:  int
                    
                    	**range:** 0..10
                    
                    .. attribute:: method
                    
                    	This specifies the PPP link authentication method
                    	**type**\:   :py:class:`Method <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication.Method>`
                    
                    .. attribute:: timeout
                    
                    	Maximum time to wait for an authentication response
                    	**type**\:  int
                    
                    	**range:** 3..30
                    
                    	**default value**\: 10
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication, self).__init__()

                        self.yang_name = "authentication"
                        self.yang_parent_name = "lcp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"method" : ("method", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication.Method)}
                        self._child_list_classes = {}

                        self.max_authentication_failures = YLeaf(YType.uint32, "max-authentication-failures")

                        self.timeout = YLeaf(YType.uint32, "timeout")

                        self.method = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication.Method()
                        self.method.parent = self
                        self._children_name_map["method"] = "method"
                        self._children_yang_names.add("method")
                        self._segment_path = lambda: "authentication"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication, ['max_authentication_failures', 'timeout'], name, value)


                    class Method(Entity):
                        """
                        This specifies the PPP link authentication
                        method
                        
                        .. attribute:: method
                        
                        	Select between one and three authentication methods in order of preference
                        	**type**\:  list of   :py:class:`PppAuthenticationMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ppp_ma_lcp_cfg.PppAuthenticationMethod>`
                        
                        .. attribute:: name
                        
                        	Use an authentication list with this name
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ppp-ma-lcp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication.Method, self).__init__()

                            self.yang_name = "method"
                            self.yang_parent_name = "authentication"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.method = YLeafList(YType.enumeration, "method")

                            self.name = YLeaf(YType.str, "name")
                            self._segment_path = lambda: "method"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Authentication.Method, ['method', 'name'], name, value)


                class Chap(Entity):
                    """
                    Challenge Handshake Authentication Protocol
                    (CHAP) configuration data
                    
                    .. attribute:: host_name
                    
                    	This specifies the CHAP hostname
                    	**type**\:  str
                    
                    .. attribute:: password
                    
                    	This specifies the default CHAP password
                    	**type**\:  str
                    
                    	**pattern:** (!.+)\|([^!].+)
                    
                    .. attribute:: refuse
                    
                    	This specifies whether to refuse to authenticate using CHAP
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Chap, self).__init__()

                        self.yang_name = "chap"
                        self.yang_parent_name = "lcp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.host_name = YLeaf(YType.str, "host-name")

                        self.password = YLeaf(YType.str, "password")

                        self.refuse = YLeaf(YType.empty, "refuse")
                        self._segment_path = lambda: "chap"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Chap, ['host_name', 'password', 'refuse'], name, value)


                class LoopBack(Entity):
                    """
                    Loopback configuration
                    
                    .. attribute:: ignore
                    
                    	Allow magic numbers to be equal
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.LoopBack, self).__init__()

                        self.yang_name = "loop-back"
                        self.yang_parent_name = "lcp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.ignore = YLeaf(YType.empty, "ignore")
                        self._segment_path = lambda: "loop-back"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.LoopBack, ['ignore'], name, value)


                class MsChap(Entity):
                    """
                    Microsoft Challenge Handshake Authentication
                    Protocol (MS\-CHAP) configuration data
                    
                    .. attribute:: host_name
                    
                    	This specifies the MS\-CHAP hostname
                    	**type**\:  str
                    
                    .. attribute:: password
                    
                    	This specifies the default MS\-CHAP password
                    	**type**\:  str
                    
                    	**pattern:** (!.+)\|([^!].+)
                    
                    .. attribute:: refuse
                    
                    	This specifies whether to refuse to authenticate using MS\-CHAP
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.MsChap, self).__init__()

                        self.yang_name = "ms-chap"
                        self.yang_parent_name = "lcp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.host_name = YLeaf(YType.str, "host-name")

                        self.password = YLeaf(YType.str, "password")

                        self.refuse = YLeaf(YType.empty, "refuse")
                        self._segment_path = lambda: "ms-chap"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.MsChap, ['host_name', 'password', 'refuse'], name, value)


                class Multilink(Entity):
                    """
                    Multilink configuration
                    
                    .. attribute:: minimum_active
                    
                    	Minimum criteria for the linestate of a Multilink PPPinterface to be brought up
                    	**type**\:   :py:class:`MinimumActive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Multilink.MinimumActive>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Multilink, self).__init__()

                        self.yang_name = "multilink"
                        self.yang_parent_name = "lcp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"minimum-active" : ("minimum_active", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Multilink.MinimumActive)}
                        self._child_list_classes = {}

                        self.minimum_active = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Multilink.MinimumActive()
                        self.minimum_active.parent = self
                        self._children_name_map["minimum_active"] = "minimum-active"
                        self._children_yang_names.add("minimum-active")
                        self._segment_path = lambda: "multilink"


                    class MinimumActive(Entity):
                        """
                        Minimum criteria for the linestate of a
                        Multilink PPPinterface to be brought up
                        
                        .. attribute:: links
                        
                        	Number of active links needed to bring up an MP interface
                        	**type**\:  int
                        
                        	**range:** 1..65535
                        
                        	**default value**\: 1
                        
                        

                        """

                        _prefix = 'ppp-ma-lcp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Multilink.MinimumActive, self).__init__()

                            self.yang_name = "minimum-active"
                            self.yang_parent_name = "multilink"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.links = YLeaf(YType.uint32, "links")
                            self._segment_path = lambda: "minimum-active"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Multilink.MinimumActive, ['links'], name, value)


                class Pap(Entity):
                    """
                    Password Authentication Protocol (PAP)
                    configuration data
                    
                    .. attribute:: refuse
                    
                    	This specifies whether to refuse to authenticate using PAP
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: send_user_info
                    
                    	This specifies the outbound PAP username and password
                    	**type**\:   :py:class:`SendUserInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap.SendUserInfo>`
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap, self).__init__()

                        self.yang_name = "pap"
                        self.yang_parent_name = "lcp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"send-user-info" : ("send_user_info", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap.SendUserInfo)}
                        self._child_list_classes = {}

                        self.refuse = YLeaf(YType.empty, "refuse")

                        self.send_user_info = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap.SendUserInfo()
                        self.send_user_info.parent = self
                        self._children_name_map["send_user_info"] = "send-user-info"
                        self._children_yang_names.add("send-user-info")
                        self._segment_path = lambda: "pap"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap, ['refuse'], name, value)


                    class SendUserInfo(Entity):
                        """
                        This specifies the outbound PAP username and
                        password
                        
                        .. attribute:: password
                        
                        	Outbound PAP password
                        	**type**\:  str
                        
                        	**pattern:** (!.+)\|([^!].+)
                        
                        .. attribute:: username
                        
                        	Outbound PAP username
                        	**type**\:  str
                        
                        

                        """

                        _prefix = 'ppp-ma-lcp-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap.SendUserInfo, self).__init__()

                            self.yang_name = "send-user-info"
                            self.yang_parent_name = "pap"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.password = YLeaf(YType.str, "password")

                            self.username = YLeaf(YType.str, "username")
                            self._segment_path = lambda: "send-user-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Lcp.Pap.SendUserInfo, ['password', 'username'], name, value)


            class Mcmp(Entity):
                """
                PPP Multiclass Multilink parameters
                
                .. attribute:: enable
                
                	This specifies that MCMP is enabled on this interface
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: local
                
                	This specifies the MCMP options for the local host
                	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp.Local>`
                
                .. attribute:: remote
                
                	This specifies the MCMP options for the peer
                	**type**\:  int
                
                	**range:** 1..16
                
                	**default value**\: 2
                
                

                """

                _prefix = 'ppp-ma-lcp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp, self).__init__()

                    self.yang_name = "mcmp"
                    self.yang_parent_name = "Cisco-IOS-XR-ppp-ma-lcp-cfg_ppp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"local" : ("local", InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp.Local)}
                    self._child_list_classes = {}

                    self.enable = YLeaf(YType.empty, "enable")

                    self.remote = YLeaf(YType.uint32, "remote")

                    self.local = InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp.Local()
                    self.local.parent = self
                    self._children_name_map["local"] = "local"
                    self._children_yang_names.add("local")
                    self._segment_path = lambda: "mcmp"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp, ['enable', 'remote'], name, value)


                class Local(Entity):
                    """
                    This specifies the MCMP options for the local
                    host
                    
                    .. attribute:: initial
                    
                    	Local Initial #classes
                    	**type**\:  int
                    
                    	**range:** 1..16
                    
                    	**default value**\: 2
                    
                    .. attribute:: maximum
                    
                    	Local Maximum #classes
                    	**type**\:  int
                    
                    	**range:** 1..16
                    
                    	**default value**\: 4
                    
                    

                    """

                    _prefix = 'ppp-ma-lcp-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp.Local, self).__init__()

                        self.yang_name = "local"
                        self.yang_parent_name = "mcmp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.initial = YLeaf(YType.uint32, "initial")

                        self.maximum = YLeaf(YType.uint32, "maximum")
                        self._segment_path = lambda: "local"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.CiscoIOSXRPppMaLcpCfgPpp.Mcmp.Local, ['initial', 'maximum'], name, value)


        class Dagrs(Entity):
            """
            Direct\-Attached Gateway Redundancy configuration
            
            .. attribute:: dagr
            
            	The DAGR entry being configured
            	**type**\: list of    :py:class:`Dagr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr>`
            
            

            """

            _prefix = 'ipv4-arp-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Dagrs, self).__init__()

                self.yang_name = "dagrs"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {"dagr" : ("dagr", InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr)}

                self.dagr = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XR-ipv4-arp-cfg:dagrs"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dagrs, [], name, value)


            class Dagr(Entity):
                """
                The DAGR entry being configured
                
                .. attribute:: ip_addr  <key>
                
                	DAGR Peer IPv4 address
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: enter
                
                	DAGR Group Enter item
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sub
                
                	DAGR Submode configuration
                	**type**\:   :py:class:`Sub <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub>`
                
                

                """

                _prefix = 'ipv4-arp-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr, self).__init__()

                    self.yang_name = "dagr"
                    self.yang_parent_name = "dagrs"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"sub" : ("sub", InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub)}
                    self._child_list_classes = {}

                    self.ip_addr = YLeaf(YType.str, "ip-addr")

                    self.enter = YLeaf(YType.empty, "enter")

                    self.sub = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub()
                    self.sub.parent = self
                    self._children_name_map["sub"] = "sub"
                    self._children_yang_names.add("sub")
                    self._segment_path = lambda: "dagr" + "[ip-addr='" + self.ip_addr.get() + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr, ['ip_addr', 'enter'], name, value)


                class Sub(Entity):
                    """
                    DAGR Submode configuration
                    
                    .. attribute:: distance
                    
                    	Set Route Distance
                    	**type**\:   :py:class:`Distance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance>`
                    
                    .. attribute:: metric
                    
                    	Set Route Metric
                    	**type**\:   :py:class:`Metric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric>`
                    
                    .. attribute:: priority_timeout
                    
                    	Priority Timeout value
                    	**type**\:  int
                    
                    	**range:** 1..10000
                    
                    	**default value**\: 20
                    
                    .. attribute:: timers
                    
                    	Set Query Timers
                    	**type**\:   :py:class:`Timers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers>`
                    
                    

                    """

                    _prefix = 'ipv4-arp-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub, self).__init__()

                        self.yang_name = "sub"
                        self.yang_parent_name = "dagr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"distance" : ("distance", InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance), "metric" : ("metric", InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric), "timers" : ("timers", InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers)}
                        self._child_list_classes = {}

                        self.priority_timeout = YLeaf(YType.uint32, "priority-timeout")

                        self.distance = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance()
                        self.distance.parent = self
                        self._children_name_map["distance"] = "distance"
                        self._children_yang_names.add("distance")

                        self.metric = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"
                        self._children_yang_names.add("metric")

                        self.timers = InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers()
                        self.timers.parent = self
                        self._children_name_map["timers"] = "timers"
                        self._children_yang_names.add("timers")
                        self._segment_path = lambda: "sub"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub, ['priority_timeout'], name, value)


                    class Distance(Entity):
                        """
                        Set Route Distance
                        
                        .. attribute:: dist_norm
                        
                        	Normal Route Distance
                        	**type**\:  int
                        
                        	**range:** 0..256
                        
                        	**default value**\: 150
                        
                        .. attribute:: dist_prio
                        
                        	Priority Route Distance
                        	**type**\:  int
                        
                        	**range:** 0..256
                        
                        	**default value**\: 5
                        
                        

                        """

                        _prefix = 'ipv4-arp-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance, self).__init__()

                            self.yang_name = "distance"
                            self.yang_parent_name = "sub"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.dist_norm = YLeaf(YType.uint32, "dist-norm")

                            self.dist_prio = YLeaf(YType.uint32, "dist-prio")
                            self._segment_path = lambda: "distance"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Distance, ['dist_norm', 'dist_prio'], name, value)


                    class Metric(Entity):
                        """
                        Set Route Metric
                        
                        .. attribute:: metric_norm
                        
                        	Normal Route Metric
                        	**type**\:  int
                        
                        	**range:** 0..256
                        
                        	**default value**\: 100
                        
                        .. attribute:: metric_prio
                        
                        	Priority Route Metric
                        	**type**\:  int
                        
                        	**range:** 0..256
                        
                        	**default value**\: 90
                        
                        

                        """

                        _prefix = 'ipv4-arp-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "sub"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.metric_norm = YLeaf(YType.uint32, "metric-norm")

                            self.metric_prio = YLeaf(YType.uint32, "metric-prio")
                            self._segment_path = lambda: "metric"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Metric, ['metric_norm', 'metric_prio'], name, value)


                    class Timers(Entity):
                        """
                        Set Query Timers
                        
                        .. attribute:: query_time
                        
                        	Query Timeout
                        	**type**\:  int
                        
                        	**range:** 1..10000
                        
                        	**default value**\: 1
                        
                        .. attribute:: sby_time
                        
                        	Standby Query Timeout
                        	**type**\:  int
                        
                        	**range:** 1..10000
                        
                        	**default value**\: 20
                        
                        

                        """

                        _prefix = 'ipv4-arp-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers, self).__init__()

                            self.yang_name = "timers"
                            self.yang_parent_name = "sub"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.query_time = YLeaf(YType.uint32, "query-time")

                            self.sby_time = YLeaf(YType.uint32, "sby-time")
                            self._segment_path = lambda: "timers"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dagrs.Dagr.Sub.Timers, ['query_time', 'sby_time'], name, value)


        class Dampening(Entity):
            """
            Whether this interface's state changes are
            dampened or not
            
            .. attribute:: args
            
            	Dampening Arguments
            	**type**\:   :py:class:`Args <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dampening.Args>`
            
            .. attribute:: half_life
            
            	Decay half life (in minutes)
            	**type**\:  int
            
            	**range:** 1..45
            
            	**units**\: minute
            
            .. attribute:: restart_penalty
            
            	Restart penalty
            	**type**\:  int
            
            	**range:** 0..20000
            
            .. attribute:: reuse_threshold
            
            	Reuse threshold
            	**type**\:  int
            
            	**range:** 1..20000
            
            .. attribute:: suppress_threshold
            
            	Suppress threshold
            	**type**\:  int
            
            	**range:** 1..20000
            
            .. attribute:: suppress_time
            
            	Max suppress time (in minutes)
            	**type**\:  int
            
            	**range:** 1..255
            
            	**units**\: minute
            
            

            """

            _prefix = 'ifmgr-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Dampening, self).__init__()

                self.yang_name = "dampening"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.args = YLeaf(YType.enumeration, "args")

                self.half_life = YLeaf(YType.uint32, "half-life")

                self.restart_penalty = YLeaf(YType.uint32, "restart-penalty")

                self.reuse_threshold = YLeaf(YType.uint32, "reuse-threshold")

                self.suppress_threshold = YLeaf(YType.uint32, "suppress-threshold")

                self.suppress_time = YLeaf(YType.uint32, "suppress-time")
                self._segment_path = lambda: "dampening"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dampening, ['args', 'half_life', 'restart_penalty', 'reuse_threshold', 'suppress_threshold', 'suppress_time'], name, value)

            class Args(Enum):
                """
                Args

                Dampening Arguments

                .. data:: default_values = 0

                	Default values

                .. data:: specify_half_life = 1

                	Half Life Specified

                .. data:: specify_all = 4

                	All Arguments except Restart Penalty

                	Specified

                .. data:: specify_rp = 5

                	All Arguments Specified

                """

                default_values = Enum.YLeaf(0, "default-values")

                specify_half_life = Enum.YLeaf(1, "specify-half-life")

                specify_all = Enum.YLeaf(4, "specify-all")

                specify_rp = Enum.YLeaf(5, "specify-rp")



        class Dot1XInterface(Entity):
            """
            Interface Specific Dot1x Configuration
            
            .. attribute:: dot1x_profile
            
            	Name of Dot1x profile
            	**type**\:  str
            
            

            """

            _prefix = 'dot1x-if-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Dot1XInterface, self).__init__()

                self.yang_name = "dot1x-interface"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.dot1x_profile = YLeaf(YType.str, "dot1x-profile")
                self._segment_path = lambda: "Cisco-IOS-XR-dot1x-if-cfg:dot1x-interface"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dot1XInterface, ['dot1x_profile'], name, value)


        class Dwdm(Entity):
            """
            DWDM port controller configuration
            
            .. attribute:: enable_vtxp
            
            	Disable or Enable VTXP configuration
            	**type**\:  bool
            
            .. attribute:: g709
            
            	Configure G709 parameters
            	**type**\:   :py:class:`G709 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709>`
            
            .. attribute:: laser
            
            	Configure laser off/on
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: loopback
            
            	Configure loopback mode 
            	**type**\:   :py:class:`DwdmLoopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.DwdmLoopback>`
            
            	**default value**\: none
            
            .. attribute:: network_connection_id
            
            	Configure network connection id
            	**type**\:  str
            
            	**length:** 1..64
            
            .. attribute:: network_port_id
            
            	Configure network port id
            	**type**\:  str
            
            	**length:** 1..64
            
            .. attribute:: network_srlgs
            
            	Configure Network srlgs
            	**type**\:   :py:class:`NetworkSrlgs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs>`
            
            .. attribute:: rx_threshold
            
            	Select power level (in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** \-350..50
            
            .. attribute:: transmit_power
            
            	Select power level (in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** \-190..10
            
            .. attribute:: transport_admin_state
            
            	Configure transport admin state
            	**type**\:   :py:class:`DwdmAdminState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.DwdmAdminState>`
            
            	**default value**\: out-of-service
            
            .. attribute:: wavelength
            
            	Configure transponder wavelength
            	**type**\:   :py:class:`Wavelength <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.Wavelength>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'dwdm-ui-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm, self).__init__()

                self.yang_name = "dwdm"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"g709" : ("g709", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709), "network-srlgs" : ("network_srlgs", InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs), "wavelength" : ("wavelength", InterfaceConfigurations.InterfaceConfiguration.Dwdm.Wavelength)}
                self._child_list_classes = {}

                self.enable_vtxp = YLeaf(YType.boolean, "enable-vtxp")

                self.laser = YLeaf(YType.empty, "laser")

                self.loopback = YLeaf(YType.enumeration, "loopback")

                self.network_connection_id = YLeaf(YType.str, "network-connection-id")

                self.network_port_id = YLeaf(YType.str, "network-port-id")

                self.rx_threshold = YLeaf(YType.int32, "rx-threshold")

                self.transmit_power = YLeaf(YType.int32, "transmit-power")

                self.transport_admin_state = YLeaf(YType.enumeration, "transport-admin-state")

                self.g709 = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709()
                self.g709.parent = self
                self._children_name_map["g709"] = "g709"
                self._children_yang_names.add("g709")

                self.network_srlgs = InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs()
                self.network_srlgs.parent = self
                self._children_name_map["network_srlgs"] = "network-srlgs"
                self._children_yang_names.add("network-srlgs")

                self.wavelength = None
                self._children_name_map["wavelength"] = "wavelength"
                self._children_yang_names.add("wavelength")
                self._segment_path = lambda: "Cisco-IOS-XR-dwdm-ui-cfg:dwdm"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm, ['enable_vtxp', 'laser', 'loopback', 'network_connection_id', 'network_port_id', 'rx_threshold', 'transmit_power', 'transport_admin_state'], name, value)


            class G709(Entity):
                """
                Configure G709 parameters
                
                .. attribute:: bdi_to_gais
                
                	Enable GAIS insertion
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: enable
                
                	Disable or Enable g709 framing
                	**type**\:  bool
                
                .. attribute:: fec
                
                	Configure FEC mode
                	**type**\:   :py:class:`Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Fec>`
                
                	**presence node**\: True
                
                .. attribute:: framing
                
                	Over clocking mode for client signal bw compatibility
                	**type**\:   :py:class:`Framing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.Framing>`
                
                .. attribute:: odu
                
                	Configure ODU parameters
                	**type**\:   :py:class:`Odu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu>`
                
                .. attribute:: otu
                
                	Configure OTU parameters
                	**type**\:   :py:class:`Otu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu>`
                
                .. attribute:: prbs
                
                	Configure PRBS mode and pattern
                	**type**\:   :py:class:`Prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Prbs>`
                
                	**presence node**\: True
                
                .. attribute:: proactive
                
                	Enable proactive protectioni Graceful or Default mode
                	**type**\:   :py:class:`Proactive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.Proactive>`
                
                .. attribute:: proactive_logging_file
                
                	Configure proactive protection log file
                	**type**\:  str
                
                	**length:** 1..128
                
                .. attribute:: tim_to_gais
                
                	Configure Trace Identifier Mismatch alarm consequence
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: tti_processing
                
                	Configure Trail Trace Identifier  processing
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'dwdm-ui-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709, self).__init__()

                    self.yang_name = "g709"
                    self.yang_parent_name = "dwdm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"fec" : ("fec", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Fec), "odu" : ("odu", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu), "otu" : ("otu", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu), "prbs" : ("prbs", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Prbs)}
                    self._child_list_classes = {}

                    self.bdi_to_gais = YLeaf(YType.empty, "bdi-to-gais")

                    self.enable = YLeaf(YType.boolean, "enable")

                    self.framing = YLeaf(YType.enumeration, "framing")

                    self.proactive = YLeaf(YType.enumeration, "proactive")

                    self.proactive_logging_file = YLeaf(YType.str, "proactive-logging-file")

                    self.tim_to_gais = YLeaf(YType.empty, "tim-to-gais")

                    self.tti_processing = YLeaf(YType.empty, "tti-processing")

                    self.fec = None
                    self._children_name_map["fec"] = "fec"
                    self._children_yang_names.add("fec")

                    self.odu = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu()
                    self.odu.parent = self
                    self._children_name_map["odu"] = "odu"
                    self._children_yang_names.add("odu")

                    self.otu = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu()
                    self.otu.parent = self
                    self._children_name_map["otu"] = "otu"
                    self._children_yang_names.add("otu")

                    self.prbs = None
                    self._children_name_map["prbs"] = "prbs"
                    self._children_yang_names.add("prbs")
                    self._segment_path = lambda: "g709"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709, ['bdi_to_gais', 'enable', 'framing', 'proactive', 'proactive_logging_file', 'tim_to_gais', 'tti_processing'], name, value)


                class Fec(Entity):
                    """
                    Configure FEC mode
                    
                    .. attribute:: efec_mode
                    
                    	Enhanced FECMode to use i.4, i.7, Other FECMode to use None
                    	**type**\:   :py:class:`Efec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.Efec>`
                    
                    	**default value**\: none
                    
                    .. attribute:: fec_mode
                    
                    	None, Standard, Enhanced, High\-Gain, Long\-Haul, Ci\-BCH
                    	**type**\:   :py:class:`Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.Fec>`
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Fec, self).__init__()

                        self.yang_name = "fec"
                        self.yang_parent_name = "g709"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.efec_mode = YLeaf(YType.enumeration, "efec-mode")

                        self.fec_mode = YLeaf(YType.enumeration, "fec-mode")
                        self._segment_path = lambda: "fec"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Fec, ['efec_mode', 'fec_mode'], name, value)


                class Odu(Entity):
                    """
                    Configure ODU parameters
                    
                    .. attribute:: odu_expected_tti
                    
                    	Configure ODU Expected TTI value
                    	**type**\:   :py:class:`OduExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti>`
                    
                    .. attribute:: odu_reports
                    
                    	Configure ODU alarm reporting
                    	**type**\:   :py:class:`OduReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports>`
                    
                    .. attribute:: odu_thresholds
                    
                    	Configure ODU threshold value
                    	**type**\:   :py:class:`OduThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds>`
                    
                    .. attribute:: odu_tx_tti
                    
                    	Configure ODU TTI value
                    	**type**\:   :py:class:`OduTxTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti>`
                    
                    

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu, self).__init__()

                        self.yang_name = "odu"
                        self.yang_parent_name = "g709"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"odu-expected-tti" : ("odu_expected_tti", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti), "odu-reports" : ("odu_reports", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports), "odu-thresholds" : ("odu_thresholds", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds), "odu-tx-tti" : ("odu_tx_tti", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti)}
                        self._child_list_classes = {}

                        self.odu_expected_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti()
                        self.odu_expected_tti.parent = self
                        self._children_name_map["odu_expected_tti"] = "odu-expected-tti"
                        self._children_yang_names.add("odu-expected-tti")

                        self.odu_reports = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports()
                        self.odu_reports.parent = self
                        self._children_name_map["odu_reports"] = "odu-reports"
                        self._children_yang_names.add("odu-reports")

                        self.odu_thresholds = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds()
                        self.odu_thresholds.parent = self
                        self._children_name_map["odu_thresholds"] = "odu-thresholds"
                        self._children_yang_names.add("odu-thresholds")

                        self.odu_tx_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti()
                        self.odu_tx_tti.parent = self
                        self._children_name_map["odu_tx_tti"] = "odu-tx-tti"
                        self._children_yang_names.add("odu-tx-tti")
                        self._segment_path = lambda: "odu"


                    class OduExpectedTti(Entity):
                        """
                        Configure ODU Expected TTI value
                        
                        .. attribute:: ascii_string
                        
                        	ASCII text (Max 64 characters)
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: hex_string
                        
                        	Hex nibbles (Max 128\- The string length should be an even number)
                        	**type**\:  str
                        
                        	**length:** 1..128
                        
                        .. attribute:: string_type
                        
                        	TTI string type (ascii or hex format)
                        	**type**\:   :py:class:`ExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.ExpectedTti>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti, self).__init__()

                            self.yang_name = "odu-expected-tti"
                            self.yang_parent_name = "odu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.ascii_string = YLeaf(YType.str, "ascii-string")

                            self.hex_string = YLeaf(YType.str, "hex-string")

                            self.string_type = YLeaf(YType.enumeration, "string-type")
                            self._segment_path = lambda: "odu-expected-tti"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduExpectedTti, ['ascii_string', 'hex_string', 'string_type'], name, value)


                    class OduReports(Entity):
                        """
                        Configure ODU alarm reporting
                        
                        .. attribute:: odu_report
                        
                        	none
                        	**type**\: list of    :py:class:`OduReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports.OduReport>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports, self).__init__()

                            self.yang_name = "odu-reports"
                            self.yang_parent_name = "odu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"odu-report" : ("odu_report", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports.OduReport)}

                            self.odu_report = YList(self)
                            self._segment_path = lambda: "odu-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports, [], name, value)


                        class OduReport(Entity):
                            """
                            none
                            
                            .. attribute:: alarm  <key>
                            
                            	ODU alarm type
                            	**type**\:   :py:class:`OduAlarm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.OduAlarm>`
                            
                            

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports.OduReport, self).__init__()

                                self.yang_name = "odu-report"
                                self.yang_parent_name = "odu-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.alarm = YLeaf(YType.enumeration, "alarm")
                                self._segment_path = lambda: "odu-report" + "[alarm='" + self.alarm.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduReports.OduReport, ['alarm'], name, value)


                    class OduThresholds(Entity):
                        """
                        Configure ODU threshold value
                        
                        .. attribute:: odu_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`OduThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds.OduThreshold>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds, self).__init__()

                            self.yang_name = "odu-thresholds"
                            self.yang_parent_name = "odu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"odu-threshold" : ("odu_threshold", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds.OduThreshold)}

                            self.odu_threshold = YList(self)
                            self._segment_path = lambda: "odu-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds, [], name, value)


                        class OduThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: threshold  <key>
                            
                            	ODU Threshold type
                            	**type**\:   :py:class:`OduThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.OduThreshold>`
                            
                            .. attribute:: threshold_value
                            
                            	Bit error rate (10 to the minus n)
                            	**type**\:  int
                            
                            	**range:** 1..9
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds.OduThreshold, self).__init__()

                                self.yang_name = "odu-threshold"
                                self.yang_parent_name = "odu-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.threshold = YLeaf(YType.enumeration, "threshold")

                                self.threshold_value = YLeaf(YType.uint32, "threshold-value")
                                self._segment_path = lambda: "odu-threshold" + "[threshold='" + self.threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduThresholds.OduThreshold, ['threshold', 'threshold_value'], name, value)


                    class OduTxTti(Entity):
                        """
                        Configure ODU TTI value
                        
                        .. attribute:: ascii_string
                        
                        	ASCII text (Max 64 characters)
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: hex_string
                        
                        	Hex nibbles (Max 128\- The string length should be an even number)
                        	**type**\:  str
                        
                        	**length:** 1..128
                        
                        .. attribute:: string_type
                        
                        	TTI string type (ascii or hex format)
                        	**type**\:   :py:class:`TxTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.TxTti>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti, self).__init__()

                            self.yang_name = "odu-tx-tti"
                            self.yang_parent_name = "odu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.ascii_string = YLeaf(YType.str, "ascii-string")

                            self.hex_string = YLeaf(YType.str, "hex-string")

                            self.string_type = YLeaf(YType.enumeration, "string-type")
                            self._segment_path = lambda: "odu-tx-tti"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Odu.OduTxTti, ['ascii_string', 'hex_string', 'string_type'], name, value)


                class Otu(Entity):
                    """
                    Configure OTU parameters
                    
                    .. attribute:: frr
                    
                    	Configure FRR thresholds and Window for trigger and revert
                    	**type**\:   :py:class:`Frr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr>`
                    
                    .. attribute:: otu_expected_tti
                    
                    	Configure OTU Expected TTI value
                    	**type**\:   :py:class:`OtuExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti>`
                    
                    .. attribute:: otu_reports
                    
                    	Configure OTU alarm reporting
                    	**type**\:   :py:class:`OtuReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports>`
                    
                    .. attribute:: otu_thresholds
                    
                    	Configure OTU threshold value
                    	**type**\:   :py:class:`OtuThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds>`
                    
                    .. attribute:: otu_tx_tti
                    
                    	Configure OTU TTI value
                    	**type**\:   :py:class:`OtuTxTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti>`
                    
                    

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu, self).__init__()

                        self.yang_name = "otu"
                        self.yang_parent_name = "g709"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"frr" : ("frr", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr), "otu-expected-tti" : ("otu_expected_tti", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti), "otu-reports" : ("otu_reports", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports), "otu-thresholds" : ("otu_thresholds", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds), "otu-tx-tti" : ("otu_tx_tti", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti)}
                        self._child_list_classes = {}

                        self.frr = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr()
                        self.frr.parent = self
                        self._children_name_map["frr"] = "frr"
                        self._children_yang_names.add("frr")

                        self.otu_expected_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti()
                        self.otu_expected_tti.parent = self
                        self._children_name_map["otu_expected_tti"] = "otu-expected-tti"
                        self._children_yang_names.add("otu-expected-tti")

                        self.otu_reports = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports()
                        self.otu_reports.parent = self
                        self._children_name_map["otu_reports"] = "otu-reports"
                        self._children_yang_names.add("otu-reports")

                        self.otu_thresholds = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds()
                        self.otu_thresholds.parent = self
                        self._children_name_map["otu_thresholds"] = "otu-thresholds"
                        self._children_yang_names.add("otu-thresholds")

                        self.otu_tx_tti = InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti()
                        self.otu_tx_tti.parent = self
                        self._children_name_map["otu_tx_tti"] = "otu-tx-tti"
                        self._children_yang_names.add("otu-tx-tti")
                        self._segment_path = lambda: "otu"


                    class Frr(Entity):
                        """
                        Configure FRR thresholds and Window for
                        trigger and revert
                        
                        .. attribute:: revert_threshold
                        
                        	Configure proactive protection revert threshold
                        	**type**\:   :py:class:`RevertThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertThreshold>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: revert_window
                        
                        	Configure FRR revert window
                        	**type**\:   :py:class:`RevertWindow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertWindow>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: trigger_threshold
                        
                        	Configure proactive protection trigger threshold
                        	**type**\:   :py:class:`TriggerThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerThreshold>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: trigger_window
                        
                        	Configure FRR trigger window
                        	**type**\:   :py:class:`TriggerWindow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerWindow>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr, self).__init__()

                            self.yang_name = "frr"
                            self.yang_parent_name = "otu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"revert-threshold" : ("revert_threshold", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertThreshold), "revert-window" : ("revert_window", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertWindow), "trigger-threshold" : ("trigger_threshold", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerThreshold), "trigger-window" : ("trigger_window", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerWindow)}
                            self._child_list_classes = {}

                            self.revert_threshold = None
                            self._children_name_map["revert_threshold"] = "revert-threshold"
                            self._children_yang_names.add("revert-threshold")

                            self.revert_window = None
                            self._children_name_map["revert_window"] = "revert-window"
                            self._children_yang_names.add("revert-window")

                            self.trigger_threshold = None
                            self._children_name_map["trigger_threshold"] = "trigger-threshold"
                            self._children_yang_names.add("trigger-threshold")

                            self.trigger_window = None
                            self._children_name_map["trigger_window"] = "trigger-window"
                            self._children_yang_names.add("trigger-window")
                            self._segment_path = lambda: "frr"


                        class RevertThreshold(Entity):
                            """
                            Configure proactive protection revert
                            threshold
                            
                            .. attribute:: ber_base
                            
                            	Bit error rate base (x of xE\-y)
                            	**type**\:  int
                            
                            	**range:** 1..9
                            
                            	**mandatory**\: True
                            
                            .. attribute:: ber_power
                            
                            	Bit error rate power (y of xE\-y)
                            	**type**\:  int
                            
                            	**range:** 3..10
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertThreshold, self).__init__()

                                self.yang_name = "revert-threshold"
                                self.yang_parent_name = "frr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.ber_base = YLeaf(YType.uint32, "ber-base")

                                self.ber_power = YLeaf(YType.uint32, "ber-power")
                                self._segment_path = lambda: "revert-threshold"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertThreshold, ['ber_base', 'ber_power'], name, value)


                        class RevertWindow(Entity):
                            """
                            Configure FRR revert window
                            
                            .. attribute:: dummy
                            
                            	Just a Dummy for window for FRR revert in MS
                            	**type**\:  int
                            
                            	**range:** 0..2
                            
                            .. attribute:: window
                            
                            	Integration window for FRR revert in MS
                            	**type**\:  int
                            
                            	**range:** 500..100000
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertWindow, self).__init__()

                                self.yang_name = "revert-window"
                                self.yang_parent_name = "frr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.dummy = YLeaf(YType.uint32, "dummy")

                                self.window = YLeaf(YType.uint32, "window")
                                self._segment_path = lambda: "revert-window"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.RevertWindow, ['dummy', 'window'], name, value)


                        class TriggerThreshold(Entity):
                            """
                            Configure proactive protection trigger
                            threshold
                            
                            .. attribute:: ber_base
                            
                            	Bit error rate base (x of xE\-y)
                            	**type**\:  int
                            
                            	**range:** 1..9
                            
                            	**mandatory**\: True
                            
                            .. attribute:: ber_power
                            
                            	Bit error rate power (y of xE\-y)
                            	**type**\:  int
                            
                            	**range:** 2..9
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerThreshold, self).__init__()

                                self.yang_name = "trigger-threshold"
                                self.yang_parent_name = "frr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.ber_base = YLeaf(YType.uint32, "ber-base")

                                self.ber_power = YLeaf(YType.uint32, "ber-power")
                                self._segment_path = lambda: "trigger-threshold"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerThreshold, ['ber_base', 'ber_power'], name, value)


                        class TriggerWindow(Entity):
                            """
                            Configure FRR trigger window
                            
                            .. attribute:: dummy
                            
                            	Just a Dummy for window for FRR revert in MS
                            	**type**\:  int
                            
                            	**range:** 0..2
                            
                            .. attribute:: window
                            
                            	Integration window for FRR trigger in MS
                            	**type**\:  int
                            
                            	**range:** 10..10000
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerWindow, self).__init__()

                                self.yang_name = "trigger-window"
                                self.yang_parent_name = "frr"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.dummy = YLeaf(YType.uint32, "dummy")

                                self.window = YLeaf(YType.uint32, "window")
                                self._segment_path = lambda: "trigger-window"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.Frr.TriggerWindow, ['dummy', 'window'], name, value)


                    class OtuExpectedTti(Entity):
                        """
                        Configure OTU Expected TTI value
                        
                        .. attribute:: ascii_string
                        
                        	ASCII text (Max 64 characters)
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: hex_string
                        
                        	Hex nibbles (Max 128\- The string length should be an even number)
                        	**type**\:  str
                        
                        	**length:** 1..128
                        
                        .. attribute:: string_type
                        
                        	TTI string type (ascii or hex format)
                        	**type**\:   :py:class:`ExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.ExpectedTti>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti, self).__init__()

                            self.yang_name = "otu-expected-tti"
                            self.yang_parent_name = "otu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.ascii_string = YLeaf(YType.str, "ascii-string")

                            self.hex_string = YLeaf(YType.str, "hex-string")

                            self.string_type = YLeaf(YType.enumeration, "string-type")
                            self._segment_path = lambda: "otu-expected-tti"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuExpectedTti, ['ascii_string', 'hex_string', 'string_type'], name, value)


                    class OtuReports(Entity):
                        """
                        Configure OTU alarm reporting
                        
                        .. attribute:: otu_report
                        
                        	none
                        	**type**\: list of    :py:class:`OtuReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports.OtuReport>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports, self).__init__()

                            self.yang_name = "otu-reports"
                            self.yang_parent_name = "otu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"otu-report" : ("otu_report", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports.OtuReport)}

                            self.otu_report = YList(self)
                            self._segment_path = lambda: "otu-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports, [], name, value)


                        class OtuReport(Entity):
                            """
                            none
                            
                            .. attribute:: alarm  <key>
                            
                            	OTU alarm type
                            	**type**\:   :py:class:`OtuAlarm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.OtuAlarm>`
                            
                            

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports.OtuReport, self).__init__()

                                self.yang_name = "otu-report"
                                self.yang_parent_name = "otu-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.alarm = YLeaf(YType.enumeration, "alarm")
                                self._segment_path = lambda: "otu-report" + "[alarm='" + self.alarm.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuReports.OtuReport, ['alarm'], name, value)


                    class OtuThresholds(Entity):
                        """
                        Configure OTU threshold value
                        
                        .. attribute:: otu_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`OtuThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds.OtuThreshold>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds, self).__init__()

                            self.yang_name = "otu-thresholds"
                            self.yang_parent_name = "otu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"otu-threshold" : ("otu_threshold", InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds.OtuThreshold)}

                            self.otu_threshold = YList(self)
                            self._segment_path = lambda: "otu-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds, [], name, value)


                        class OtuThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: threshold  <key>
                            
                            	OTU Threshold type
                            	**type**\:   :py:class:`OtuThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.OtuThreshold>`
                            
                            .. attribute:: threshold_value
                            
                            	Bit error rate (10 to the minus n)
                            	**type**\:  int
                            
                            	**range:** 1..9
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'dwdm-ui-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds.OtuThreshold, self).__init__()

                                self.yang_name = "otu-threshold"
                                self.yang_parent_name = "otu-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.threshold = YLeaf(YType.enumeration, "threshold")

                                self.threshold_value = YLeaf(YType.uint32, "threshold-value")
                                self._segment_path = lambda: "otu-threshold" + "[threshold='" + self.threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuThresholds.OtuThreshold, ['threshold', 'threshold_value'], name, value)


                    class OtuTxTti(Entity):
                        """
                        Configure OTU TTI value
                        
                        .. attribute:: ascii_string
                        
                        	ASCII text (Max 64 characters)
                        	**type**\:  str
                        
                        	**length:** 1..64
                        
                        .. attribute:: hex_string
                        
                        	Hex nibbles (Max 128\- The string length should be an even number)
                        	**type**\:  str
                        
                        	**length:** 1..128
                        
                        .. attribute:: string_type
                        
                        	TTI string type (ascii or hex format)
                        	**type**\:   :py:class:`TxTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.TxTti>`
                        
                        

                        """

                        _prefix = 'dwdm-ui-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti, self).__init__()

                            self.yang_name = "otu-tx-tti"
                            self.yang_parent_name = "otu"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.ascii_string = YLeaf(YType.str, "ascii-string")

                            self.hex_string = YLeaf(YType.str, "hex-string")

                            self.string_type = YLeaf(YType.enumeration, "string-type")
                            self._segment_path = lambda: "otu-tx-tti"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Otu.OtuTxTti, ['ascii_string', 'hex_string', 'string_type'], name, value)


                class Prbs(Entity):
                    """
                    Configure PRBS mode and pattern
                    
                    .. attribute:: prbs_mode
                    
                    	Enable PRBS with mode
                    	**type**\:   :py:class:`PrbsMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.PrbsMode>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: prbs_pattern
                    
                    	Enable prbs test with pattern
                    	**type**\:   :py:class:`PrbsPattern <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.PrbsPattern>`
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Prbs, self).__init__()

                        self.yang_name = "prbs"
                        self.yang_parent_name = "g709"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.prbs_mode = YLeaf(YType.enumeration, "prbs-mode")

                        self.prbs_pattern = YLeaf(YType.enumeration, "prbs-pattern")
                        self._segment_path = lambda: "prbs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.G709.Prbs, ['prbs_mode', 'prbs_pattern'], name, value)


            class NetworkSrlgs(Entity):
                """
                Configure Network srlgs
                
                .. attribute:: network_srlg
                
                	Configure network srlg sets
                	**type**\: list of    :py:class:`NetworkSrlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs.NetworkSrlg>`
                
                

                """

                _prefix = 'dwdm-ui-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs, self).__init__()

                    self.yang_name = "network-srlgs"
                    self.yang_parent_name = "dwdm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"network-srlg" : ("network_srlg", InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs.NetworkSrlg)}

                    self.network_srlg = YList(self)
                    self._segment_path = lambda: "network-srlgs"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs, [], name, value)


                class NetworkSrlg(Entity):
                    """
                    Configure network srlg sets
                    
                    .. attribute:: set_id  <key>
                    
                    	Set index
                    	**type**\:  int
                    
                    	**range:** 1..17
                    
                    .. attribute:: srlg1
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg2
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg3
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg4
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg5
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg6
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    

                    """

                    _prefix = 'dwdm-ui-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs.NetworkSrlg, self).__init__()

                        self.yang_name = "network-srlg"
                        self.yang_parent_name = "network-srlgs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.set_id = YLeaf(YType.uint32, "set-id")

                        self.srlg1 = YLeaf(YType.uint32, "srlg1")

                        self.srlg2 = YLeaf(YType.uint32, "srlg2")

                        self.srlg3 = YLeaf(YType.uint32, "srlg3")

                        self.srlg4 = YLeaf(YType.uint32, "srlg4")

                        self.srlg5 = YLeaf(YType.uint32, "srlg5")

                        self.srlg6 = YLeaf(YType.uint32, "srlg6")
                        self._segment_path = lambda: "network-srlg" + "[set-id='" + self.set_id.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.NetworkSrlgs.NetworkSrlg, ['set_id', 'srlg1', 'srlg2', 'srlg3', 'srlg4', 'srlg5', 'srlg6'], name, value)


            class Wavelength(Entity):
                """
                Configure transponder wavelength
                
                .. attribute:: prog_frequency
                
                	Enter Frequency Data in THz
                	**type**\:  str
                
                	**length:** 1..128
                
                .. attribute:: wave_channel
                
                	Select a ITU channel number,channel range for C\-band\: 1~82,L\-band\:106~185,spacing\:50GHZ or 100MHz
                	**type**\:  int
                
                	**range:** 1..1568362
                
                	**mandatory**\: True
                
                .. attribute:: wave_channel_number
                
                	Wave Channel Number
                	**type**\:   :py:class:`WaveChannelNum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_dwdm_ui_cfg.WaveChannelNum>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'dwdm-ui-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Dwdm.Wavelength, self).__init__()

                    self.yang_name = "wavelength"
                    self.yang_parent_name = "dwdm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.prog_frequency = YLeaf(YType.str, "prog-frequency")

                    self.wave_channel = YLeaf(YType.uint32, "wave-channel")

                    self.wave_channel_number = YLeaf(YType.enumeration, "wave-channel-number")
                    self._segment_path = lambda: "wavelength"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Dwdm.Wavelength, ['prog_frequency', 'wave_channel', 'wave_channel_number'], name, value)


        class Encapsulation(Entity):
            """
            The encapsulation on the interface
            
            .. attribute:: capsulation_options
            
            	The options for this capsulation, usually '0'
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: encapsulation
            
            	The encapsulation \- e.g. hdlc, ppp
            	**type**\:  str
            
            

            """

            _prefix = 'ifmgr-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Encapsulation, self).__init__()

                self.yang_name = "encapsulation"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.capsulation_options = YLeaf(YType.int32, "capsulation-options")

                self.encapsulation = YLeaf(YType.str, "encapsulation")
                self._segment_path = lambda: "encapsulation"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Encapsulation, ['capsulation_options', 'encapsulation'], name, value)


        class EsPacketFilter(Entity):
            """
            ES Packet Filtering configuration for the
            interface
            
            .. attribute:: inbound
            
            	Name of filter to be applied to inbound packets
            	**type**\:  str
            
            	**length:** 1..65
            
            .. attribute:: outbound
            
            	Name of filter to be applied to outbound packets
            	**type**\:  str
            
            	**length:** 1..65
            
            

            """

            _prefix = 'ip-pfilter-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter, self).__init__()

                self.yang_name = "es-packet-filter"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.inbound = YLeaf(YType.str, "inbound")

                self.outbound = YLeaf(YType.str, "outbound")
                self._segment_path = lambda: "Cisco-IOS-XR-ip-pfilter-cfg:es-packet-filter"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EsPacketFilter, ['inbound', 'outbound'], name, value)


        class Ethernet(Entity):
            """
            Ether specific interface configuration
            
            .. attribute:: auto_negotiation
            
            	Link auto\-negotiation
            	**type**\:   :py:class:`EthernetAutoNegotiation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetAutoNegotiation>`
            
            .. attribute:: carrier_delay
            
            	Set the carrier transition delay on an interface in msecs
            	**type**\:   :py:class:`CarrierDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay>`
            
            .. attribute:: duplex
            
            	Configure duplex operational mode
            	**type**\:   :py:class:`EthernetDuplex <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetDuplex>`
            
            .. attribute:: flow_control
            
            	Configure flow\-control mode
            	**type**\:   :py:class:`EthernetFlowCtrl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetFlowCtrl>`
            
            .. attribute:: forward_error_correction
            
            	Forward Error Correction
            	**type**\:   :py:class:`EthernetFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetFec>`
            
            .. attribute:: inter_packet_gap
            
            	Inter\-packet gap
            	**type**\:   :py:class:`EthernetIpg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetIpg>`
            
            .. attribute:: loopback
            
            	Configure loopback mode
            	**type**\:   :py:class:`EthernetLoopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetLoopback>`
            
            .. attribute:: optical_power_degrade
            
            	Optical power degrade handling options
            	**type**\:   :py:class:`OpticalPowerDegrade <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade>`
            
            .. attribute:: priority_flow_control
            
            	Configure priority flow\-control mode
            	**type**\:   :py:class:`EthernetPfc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetPfc>`
            
            .. attribute:: signal_degrade_bit_error_rate
            
            	Signal Degrade Bit Error Rate handling options
            	**type**\:   :py:class:`SignalDegradeBitErrorRate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate>`
            
            .. attribute:: signal_fail_bit_error_rate
            
            	Signal Fail Bit Error Rate handling options
            	**type**\:   :py:class:`SignalFailBitErrorRate <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate>`
            
            .. attribute:: speed
            
            	Set the ethernet speed on an interface
            	**type**\:   :py:class:`EthernetSpeed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_media_eth_cfg.EthernetSpeed>`
            
            

            """

            _prefix = 'drivers-media-eth-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ethernet, self).__init__()

                self.yang_name = "ethernet"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"carrier-delay" : ("carrier_delay", InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay), "optical-power-degrade" : ("optical_power_degrade", InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade), "signal-degrade-bit-error-rate" : ("signal_degrade_bit_error_rate", InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate), "signal-fail-bit-error-rate" : ("signal_fail_bit_error_rate", InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate)}
                self._child_list_classes = {}

                self.auto_negotiation = YLeaf(YType.enumeration, "auto-negotiation")

                self.duplex = YLeaf(YType.enumeration, "duplex")

                self.flow_control = YLeaf(YType.enumeration, "flow-control")

                self.forward_error_correction = YLeaf(YType.enumeration, "forward-error-correction")

                self.inter_packet_gap = YLeaf(YType.enumeration, "inter-packet-gap")

                self.loopback = YLeaf(YType.enumeration, "loopback")

                self.priority_flow_control = YLeaf(YType.enumeration, "priority-flow-control")

                self.speed = YLeaf(YType.enumeration, "speed")

                self.carrier_delay = InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay()
                self.carrier_delay.parent = self
                self._children_name_map["carrier_delay"] = "carrier-delay"
                self._children_yang_names.add("carrier-delay")

                self.optical_power_degrade = InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade()
                self.optical_power_degrade.parent = self
                self._children_name_map["optical_power_degrade"] = "optical-power-degrade"
                self._children_yang_names.add("optical-power-degrade")

                self.signal_degrade_bit_error_rate = InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate()
                self.signal_degrade_bit_error_rate.parent = self
                self._children_name_map["signal_degrade_bit_error_rate"] = "signal-degrade-bit-error-rate"
                self._children_yang_names.add("signal-degrade-bit-error-rate")

                self.signal_fail_bit_error_rate = InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate()
                self.signal_fail_bit_error_rate.parent = self
                self._children_name_map["signal_fail_bit_error_rate"] = "signal-fail-bit-error-rate"
                self._children_yang_names.add("signal-fail-bit-error-rate")
                self._segment_path = lambda: "Cisco-IOS-XR-drivers-media-eth-cfg:ethernet"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ethernet, ['auto_negotiation', 'duplex', 'flow_control', 'forward_error_correction', 'inter_packet_gap', 'loopback', 'priority_flow_control', 'speed'], name, value)


            class CarrierDelay(Entity):
                """
                Set the carrier transition delay on an
                interface in msecs
                
                .. attribute:: carrier_delay_down
                
                	Carrier Delay (down) in msecs
                	**type**\:  int
                
                	**range:** 0..2147483647
                
                .. attribute:: carrier_delay_up
                
                	Carrier Delay (up) in msecs
                	**type**\:  int
                
                	**range:** 0..2147483647
                
                

                """

                _prefix = 'drivers-media-eth-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay, self).__init__()

                    self.yang_name = "carrier-delay"
                    self.yang_parent_name = "ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.carrier_delay_down = YLeaf(YType.uint32, "carrier-delay-down")

                    self.carrier_delay_up = YLeaf(YType.uint32, "carrier-delay-up")
                    self._segment_path = lambda: "carrier-delay"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ethernet.CarrierDelay, ['carrier_delay_down', 'carrier_delay_up'], name, value)


            class OpticalPowerDegrade(Entity):
                """
                Optical power degrade handling options
                
                .. attribute:: rx_alarm_threshold
                
                	Set the value of the received optical power degrade alarm threshold on an interface
                	**type**\:  int
                
                	**range:** \-300..50
                
                

                """

                _prefix = 'drivers-media-eth-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade, self).__init__()

                    self.yang_name = "optical-power-degrade"
                    self.yang_parent_name = "ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.rx_alarm_threshold = YLeaf(YType.int32, "rx-alarm-threshold")
                    self._segment_path = lambda: "optical-power-degrade"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ethernet.OpticalPowerDegrade, ['rx_alarm_threshold'], name, value)


            class SignalDegradeBitErrorRate(Entity):
                """
                Signal Degrade Bit Error Rate handling options
                
                .. attribute:: signal_degrade_report
                
                	Generate an alarm whenever the SD\-BER threshold is crossed for this interface
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: signal_degrade_threshold
                
                	Set the Signal Degrade bit error rate threshold on an interface to a value of 10e\-x, where x is the value passed in here
                	**type**\:  int
                
                	**range:** 3..12
                
                	**default value**\: 6
                
                

                """

                _prefix = 'drivers-media-eth-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate, self).__init__()

                    self.yang_name = "signal-degrade-bit-error-rate"
                    self.yang_parent_name = "ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.signal_degrade_report = YLeaf(YType.empty, "signal-degrade-report")

                    self.signal_degrade_threshold = YLeaf(YType.uint32, "signal-degrade-threshold")
                    self._segment_path = lambda: "signal-degrade-bit-error-rate"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalDegradeBitErrorRate, ['signal_degrade_report', 'signal_degrade_threshold'], name, value)


            class SignalFailBitErrorRate(Entity):
                """
                Signal Fail Bit Error Rate handling options
                
                .. attribute:: signal_fail_report_disable
                
                	Disable generation of an alarm whenever the SF\-BER threshold is crossed for this interface
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: signal_fail_threshold
                
                	Set the Signal Fail bit error rate threshold on an interface to a value of 10e\-x, where x is the value passed in here
                	**type**\:  int
                
                	**range:** 4..12
                
                	**default value**\: 4
                
                .. attribute:: signal_remote_fault
                
                	Signal a remote fault to the peer device whenever the link is taken down due to crossing the SF\-BER threshold
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'drivers-media-eth-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate, self).__init__()

                    self.yang_name = "signal-fail-bit-error-rate"
                    self.yang_parent_name = "ethernet"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.signal_fail_report_disable = YLeaf(YType.empty, "signal-fail-report-disable")

                    self.signal_fail_threshold = YLeaf(YType.uint32, "signal-fail-threshold")

                    self.signal_remote_fault = YLeaf(YType.empty, "signal-remote-fault")
                    self._segment_path = lambda: "signal-fail-bit-error-rate"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ethernet.SignalFailBitErrorRate, ['signal_fail_report_disable', 'signal_fail_threshold', 'signal_remote_fault'], name, value)


        class EthernetBng(Entity):
            """
            Ethernet Infra BNG specific configuration
            
            .. attribute:: ambiguous_encapsulation
            
            	L3 Ambiguous encapsulation
            	**type**\:   :py:class:`AmbiguousEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetBng.AmbiguousEncapsulation>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EthernetBng, self).__init__()

                self.yang_name = "ethernet-bng"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"ambiguous-encapsulation" : ("ambiguous_encapsulation", InterfaceConfigurations.InterfaceConfiguration.EthernetBng.AmbiguousEncapsulation)}
                self._child_list_classes = {}

                self.ambiguous_encapsulation = None
                self._children_name_map["ambiguous_encapsulation"] = "ambiguous-encapsulation"
                self._children_yang_names.add("ambiguous-encapsulation")
                self._segment_path = lambda: "Cisco-IOS-XR-l2-eth-infra-cfg:ethernet-bng"


            class AmbiguousEncapsulation(Entity):
                """
                L3 Ambiguous encapsulation
                
                .. attribute:: additional_range1_high
                
                	High value of first additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range1_low
                
                	Low value of first additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range2_high
                
                	High value of second additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range2_low
                
                	Low value of second additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range3_high
                
                	High value of third additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range3_low
                
                	Low value of third additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range4_high
                
                	High value of forth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range4_low
                
                	Low value of forth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range5_high
                
                	High value of fifth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range5_low
                
                	Low value of fifth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range6_high
                
                	High value of sixth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range6_low
                
                	Low value of sixth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range7_high
                
                	High value of seventh additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range7_low
                
                	Low value of seventh additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range8_high
                
                	High value of eighth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range8_low
                
                	Low value of eighth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: exact
                
                	Only match packets with no more tags than explicitly matched
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ingress_destination_mac
                
                	Destination MAC address to match on egress
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: ingress_source_mac
                
                	Source MAC address to match on ingress
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: inner_class_of_service
                
                	Value to match against Class Of Service bits for inner tag
                	**type**\:  int
                
                	**range:** 0..7
                
                .. attribute:: inner_range1_high
                
                	High value of first range for inner tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: inner_range1_low
                
                	Low value of first range for inner tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrAny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrAny>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..4096
                
                
                ----
                .. attribute:: inner_tag_type
                
                	Type of tag for inner match (if present)
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                .. attribute:: outer_class_of_service
                
                	Value to match against Class Of Service bits for outer tag
                	**type**\:  int
                
                	**range:** 0..7
                
                .. attribute:: outer_range1_high
                
                	High value of first range for outer tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrNative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrNative>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65535
                
                
                ----
                .. attribute:: outer_range1_low
                
                	Low value of first range for outer tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrAny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrAny>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..4096
                
                
                ----
                .. attribute:: outer_tag_type
                
                	Whether to match all unmatched packets, untagged packets or tagged packets, and if matching tagged packets, the outer tag type to match
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                	**mandatory**\: True
                
                .. attribute:: payload_ethertype_match
                
                	Which payload ethertype values to match
                	**type**\:   :py:class:`EthertypeMatch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.EthertypeMatch>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetBng.AmbiguousEncapsulation, self).__init__()

                    self.yang_name = "ambiguous-encapsulation"
                    self.yang_parent_name = "ethernet-bng"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.additional_range1_high = YLeaf(YType.uint32, "additional-range1-high")

                    self.additional_range1_low = YLeaf(YType.str, "additional-range1-low")

                    self.additional_range2_high = YLeaf(YType.uint32, "additional-range2-high")

                    self.additional_range2_low = YLeaf(YType.str, "additional-range2-low")

                    self.additional_range3_high = YLeaf(YType.uint32, "additional-range3-high")

                    self.additional_range3_low = YLeaf(YType.str, "additional-range3-low")

                    self.additional_range4_high = YLeaf(YType.uint32, "additional-range4-high")

                    self.additional_range4_low = YLeaf(YType.str, "additional-range4-low")

                    self.additional_range5_high = YLeaf(YType.uint32, "additional-range5-high")

                    self.additional_range5_low = YLeaf(YType.str, "additional-range5-low")

                    self.additional_range6_high = YLeaf(YType.uint32, "additional-range6-high")

                    self.additional_range6_low = YLeaf(YType.str, "additional-range6-low")

                    self.additional_range7_high = YLeaf(YType.uint32, "additional-range7-high")

                    self.additional_range7_low = YLeaf(YType.str, "additional-range7-low")

                    self.additional_range8_high = YLeaf(YType.uint32, "additional-range8-high")

                    self.additional_range8_low = YLeaf(YType.str, "additional-range8-low")

                    self.exact = YLeaf(YType.empty, "exact")

                    self.ingress_destination_mac = YLeaf(YType.str, "ingress-destination-mac")

                    self.ingress_source_mac = YLeaf(YType.str, "ingress-source-mac")

                    self.inner_class_of_service = YLeaf(YType.uint32, "inner-class-of-service")

                    self.inner_range1_high = YLeaf(YType.uint32, "inner-range1-high")

                    self.inner_range1_low = YLeaf(YType.str, "inner-range1-low")

                    self.inner_tag_type = YLeaf(YType.enumeration, "inner-tag-type")

                    self.outer_class_of_service = YLeaf(YType.uint32, "outer-class-of-service")

                    self.outer_range1_high = YLeaf(YType.str, "outer-range1-high")

                    self.outer_range1_low = YLeaf(YType.str, "outer-range1-low")

                    self.outer_tag_type = YLeaf(YType.enumeration, "outer-tag-type")

                    self.payload_ethertype_match = YLeaf(YType.enumeration, "payload-ethertype-match")
                    self._segment_path = lambda: "ambiguous-encapsulation"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetBng.AmbiguousEncapsulation, ['additional_range1_high', 'additional_range1_low', 'additional_range2_high', 'additional_range2_low', 'additional_range3_high', 'additional_range3_low', 'additional_range4_high', 'additional_range4_low', 'additional_range5_high', 'additional_range5_low', 'additional_range6_high', 'additional_range6_low', 'additional_range7_high', 'additional_range7_low', 'additional_range8_high', 'additional_range8_low', 'exact', 'ingress_destination_mac', 'ingress_source_mac', 'inner_class_of_service', 'inner_range1_high', 'inner_range1_low', 'inner_tag_type', 'outer_class_of_service', 'outer_range1_high', 'outer_range1_low', 'outer_tag_type', 'payload_ethertype_match'], name, value)


        class EthernetControl(Entity):
            """
            EthernetControl
            
            .. attribute:: small_frame_padding
            
            	Enable small frame padding on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: transceiver
            
            	Transceiver
            	**type**\:   :py:class:`Transceiver <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver>`
            
            .. attribute:: transport_mode
            
            	Set the transport mode on an interface
            	**type**\:   :py:class:`EtherCtrlTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_asr9k_lc_ethctrl_cfg.EtherCtrlTransportMode>`
            
            

            """

            _prefix = 'asr9k-lc-ethctrl-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl, self).__init__()

                self.yang_name = "ethernet-control"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"transceiver" : ("transceiver", InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver)}
                self._child_list_classes = {}

                self.small_frame_padding = YLeaf(YType.empty, "small-frame-padding")

                self.transport_mode = YLeaf(YType.enumeration, "transport-mode")

                self.transceiver = InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver()
                self.transceiver.parent = self
                self._children_name_map["transceiver"] = "transceiver"
                self._children_yang_names.add("transceiver")
                self._segment_path = lambda: "Cisco-IOS-XR-asr9k-lc-ethctrl-cfg:ethernet-control"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetControl, ['small_frame_padding', 'transport_mode'], name, value)


            class Transceiver(Entity):
                """
                Transceiver
                
                .. attribute:: permit
                
                	Permit
                	**type**\:   :py:class:`Permit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit>`
                
                

                """

                _prefix = 'asr9k-lc-ethctrl-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver, self).__init__()

                    self.yang_name = "transceiver"
                    self.yang_parent_name = "ethernet-control"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"permit" : ("permit", InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit)}
                    self._child_list_classes = {}

                    self.permit = InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit()
                    self.permit.parent = self
                    self._children_name_map["permit"] = "permit"
                    self._children_yang_names.add("permit")
                    self._segment_path = lambda: "transceiver"


                class Permit(Entity):
                    """
                    Permit
                    
                    .. attribute:: pid
                    
                    	Permit pluggable PID (Product ID) all
                    	**type**\:   :py:class:`PermitPluggablePid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_asr9k_lc_ethctrl_cfg.PermitPluggablePid>`
                    
                    .. attribute:: type
                    
                    	Permit pluggable type all
                    	**type**\:   :py:class:`PermitPluggable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_asr9k_lc_ethctrl_cfg.PermitPluggable>`
                    
                    

                    """

                    _prefix = 'asr9k-lc-ethctrl-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit, self).__init__()

                        self.yang_name = "permit"
                        self.yang_parent_name = "transceiver"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.pid = YLeaf(YType.enumeration, "pid")

                        self.type = YLeaf(YType.enumeration, "type")
                        self._segment_path = lambda: "permit"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetControl.Transceiver.Permit, ['pid', 'type'], name, value)


        class EthernetFeatures(Entity):
            """
            Ethernet Features Configuration
            
            .. attribute:: cfm
            
            	CFM interface configuration
            	**type**\:   :py:class:`Cfm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm>`
            
            .. attribute:: ether_link_oam
            
            	Ethernet Link OAM Interface Configuration
            	**type**\:   :py:class:`EtherLinkOam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam>`
            
            .. attribute:: ether_link_oam_enable
            
            	Enable Ethernet Link OAM on the interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: filtering
            
            	Ingress Ethernet frame filtering
            	**type**\:   :py:class:`Filtering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_cfg.Filtering>`
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures, self).__init__()

                self.yang_name = "ethernet-features"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"cfm" : ("cfm", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm), "ether-link-oam" : ("ether_link_oam", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam)}
                self._child_list_classes = {}

                self.ether_link_oam_enable = YLeaf(YType.empty, "Cisco-IOS-XR-ethernet-link-oam-cfg:ether-link-oam-enable")

                self.filtering = YLeaf(YType.enumeration, "filtering")

                self.cfm = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm()
                self.cfm.parent = self
                self._children_name_map["cfm"] = "cfm"
                self._children_yang_names.add("cfm")

                self.ether_link_oam = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam()
                self.ether_link_oam.parent = self
                self._children_name_map["ether_link_oam"] = "ether-link-oam"
                self._children_yang_names.add("ether-link-oam")
                self._segment_path = lambda: "Cisco-IOS-XR-l2-eth-infra-cfg:ethernet-features"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures, ['ether_link_oam_enable', 'filtering'], name, value)


            class Cfm(Entity):
                """
                CFM interface configuration
                
                .. attribute:: ais_up
                
                	Interface specific AIS configuration
                	**type**\:   :py:class:`AisUp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp>`
                
                .. attribute:: domains
                
                	Domain\-specific interface configuration
                	**type**\:   :py:class:`Domains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains>`
                
                

                """

                _prefix = 'ethernet-cfm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm, self).__init__()

                    self.yang_name = "cfm"
                    self.yang_parent_name = "ethernet-features"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"ais-up" : ("ais_up", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp), "domains" : ("domains", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains)}
                    self._child_list_classes = {}

                    self.ais_up = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp()
                    self.ais_up.parent = self
                    self._children_name_map["ais_up"] = "ais-up"
                    self._children_yang_names.add("ais-up")

                    self.domains = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains()
                    self.domains.parent = self
                    self._children_name_map["domains"] = "domains"
                    self._children_yang_names.add("domains")
                    self._segment_path = lambda: "Cisco-IOS-XR-ethernet-cfm-cfg:cfm"


                class AisUp(Entity):
                    """
                    Interface specific AIS configuration
                    
                    .. attribute:: transmission
                    
                    	AIS transmission configuration
                    	**type**\:   :py:class:`Transmission <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp.Transmission>`
                    
                    	**presence node**\: True
                    
                    

                    """

                    _prefix = 'ethernet-cfm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp, self).__init__()

                        self.yang_name = "ais-up"
                        self.yang_parent_name = "cfm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"transmission" : ("transmission", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp.Transmission)}
                        self._child_list_classes = {}

                        self.transmission = None
                        self._children_name_map["transmission"] = "transmission"
                        self._children_yang_names.add("transmission")
                        self._segment_path = lambda: "ais-up"


                    class Transmission(Entity):
                        """
                        AIS transmission configuration
                        
                        .. attribute:: ais_interval
                        
                        	AIS Interval
                        	**type**\:   :py:class:`CfmAisInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_cfm_datatypes.CfmAisInterval>`
                        
                        .. attribute:: cos
                        
                        	Class of Service bits
                        	**type**\:  int
                        
                        	**range:** 0..7
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ethernet-cfm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp.Transmission, self).__init__()

                            self.yang_name = "transmission"
                            self.yang_parent_name = "ais-up"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.ais_interval = YLeaf(YType.enumeration, "ais-interval")

                            self.cos = YLeaf(YType.uint32, "cos")
                            self._segment_path = lambda: "transmission"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.AisUp.Transmission, ['ais_interval', 'cos'], name, value)


                class Domains(Entity):
                    """
                    Domain\-specific interface configuration
                    
                    .. attribute:: domain
                    
                    	Configuration for a particular Maintenance Domain
                    	**type**\: list of    :py:class:`Domain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain>`
                    
                    

                    """

                    _prefix = 'ethernet-cfm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains, self).__init__()

                        self.yang_name = "domains"
                        self.yang_parent_name = "cfm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"domain" : ("domain", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain)}

                        self.domain = YList(self)
                        self._segment_path = lambda: "domains"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains, [], name, value)


                    class Domain(Entity):
                        """
                        Configuration for a particular Maintenance
                        Domain
                        
                        .. attribute:: domain  <key>
                        
                        	Maintenance Domain
                        	**type**\:  str
                        
                        	**length:** 1..79
                        
                        .. attribute:: mep
                        
                        	MEP Configuration
                        	**type**\:   :py:class:`Mep <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep>`
                        
                        

                        """

                        _prefix = 'ethernet-cfm-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain, self).__init__()

                            self.yang_name = "domain"
                            self.yang_parent_name = "domains"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"mep" : ("mep", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep)}
                            self._child_list_classes = {}

                            self.domain = YLeaf(YType.str, "domain")

                            self.mep = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep()
                            self.mep.parent = self
                            self._children_name_map["mep"] = "mep"
                            self._children_yang_names.add("mep")
                            self._segment_path = lambda: "domain" + "[domain='" + self.domain.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain, ['domain'], name, value)


                        class Mep(Entity):
                            """
                            MEP Configuration
                            
                            .. attribute:: cos
                            
                            	The Class of Service bits for this MEP
                            	**type**\:  int
                            
                            	**range:** 0..7
                            
                            .. attribute:: loss_measurement_counters
                            
                            	Loss\-measurement specific configuration
                            	**type**\:   :py:class:`LossMeasurementCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.LossMeasurementCounters>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: mep_properties
                            
                            	Properties for this MEP
                            	**type**\:   :py:class:`MepProperties <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.MepProperties>`
                            
                            	**presence node**\: True
                            
                            .. attribute:: sla_profile_target_mep_ids
                            
                            	SLA specific configuration
                            	**type**\:   :py:class:`SlaProfileTargetMepIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds>`
                            
                            

                            """

                            _prefix = 'ethernet-cfm-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep, self).__init__()

                                self.yang_name = "mep"
                                self.yang_parent_name = "domain"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"loss-measurement-counters" : ("loss_measurement_counters", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.LossMeasurementCounters), "mep-properties" : ("mep_properties", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.MepProperties), "sla-profile-target-mep-ids" : ("sla_profile_target_mep_ids", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds)}
                                self._child_list_classes = {}

                                self.cos = YLeaf(YType.uint32, "cos")

                                self.loss_measurement_counters = None
                                self._children_name_map["loss_measurement_counters"] = "loss-measurement-counters"
                                self._children_yang_names.add("loss-measurement-counters")

                                self.mep_properties = None
                                self._children_name_map["mep_properties"] = "mep-properties"
                                self._children_yang_names.add("mep-properties")

                                self.sla_profile_target_mep_ids = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds()
                                self.sla_profile_target_mep_ids.parent = self
                                self._children_name_map["sla_profile_target_mep_ids"] = "sla-profile-target-mep-ids"
                                self._children_yang_names.add("sla-profile-target-mep-ids")
                                self._segment_path = lambda: "mep"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep, ['cos'], name, value)


                            class LossMeasurementCounters(Entity):
                                """
                                Loss\-measurement specific configuration
                                
                                .. attribute:: cfg_type
                                
                                	Aggregate, List, or Range
                                	**type**\:   :py:class:`CfmLmCountersCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_cfm_cfg.CfmLmCountersCfg>`
                                
                                	**mandatory**\: True
                                
                                .. attribute:: cos0
                                
                                	CoS bits for per\-CoS counters \- start of range or list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos1
                                
                                	CoS bits for per\-CoS counters \- end of range or list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos2
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos3
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos4
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos5
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos6
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                .. attribute:: cos7
                                
                                	CoS bits for per\-CoS counters \- list item
                                	**type**\:  int
                                
                                	**range:** 0..7
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ethernet-cfm-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.LossMeasurementCounters, self).__init__()

                                    self.yang_name = "loss-measurement-counters"
                                    self.yang_parent_name = "mep"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}
                                    self.is_presence_container = True

                                    self.cfg_type = YLeaf(YType.enumeration, "cfg-type")

                                    self.cos0 = YLeaf(YType.uint32, "cos0")

                                    self.cos1 = YLeaf(YType.uint32, "cos1")

                                    self.cos2 = YLeaf(YType.uint32, "cos2")

                                    self.cos3 = YLeaf(YType.uint32, "cos3")

                                    self.cos4 = YLeaf(YType.uint32, "cos4")

                                    self.cos5 = YLeaf(YType.uint32, "cos5")

                                    self.cos6 = YLeaf(YType.uint32, "cos6")

                                    self.cos7 = YLeaf(YType.uint32, "cos7")
                                    self._segment_path = lambda: "loss-measurement-counters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.LossMeasurementCounters, ['cfg_type', 'cos0', 'cos1', 'cos2', 'cos3', 'cos4', 'cos5', 'cos6', 'cos7'], name, value)


                            class MepProperties(Entity):
                                """
                                Properties for this MEP
                                
                                .. attribute:: mep_id
                                
                                	MEP ID
                                	**type**\:  int
                                
                                	**range:** 1..8191
                                
                                	**mandatory**\: True
                                
                                .. attribute:: service
                                
                                	Service (Maintenance Association)
                                	**type**\:  str
                                
                                	**length:** 1..79
                                
                                	**mandatory**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'ethernet-cfm-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.MepProperties, self).__init__()

                                    self.yang_name = "mep-properties"
                                    self.yang_parent_name = "mep"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}
                                    self.is_presence_container = True

                                    self.mep_id = YLeaf(YType.uint32, "mep-id")

                                    self.service = YLeaf(YType.str, "service")
                                    self._segment_path = lambda: "mep-properties"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.MepProperties, ['mep_id', 'service'], name, value)


                            class SlaProfileTargetMepIds(Entity):
                                """
                                SLA specific configuration
                                
                                .. attribute:: sla_profile_target_mac_address
                                
                                	Configuration for a particular SLA operation
                                	**type**\: list of    :py:class:`SlaProfileTargetMacAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMacAddress>`
                                
                                .. attribute:: sla_profile_target_mep_id
                                
                                	Configuration for a particular SLA operation
                                	**type**\: list of    :py:class:`SlaProfileTargetMepId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMepId>`
                                
                                

                                """

                                _prefix = 'ethernet-cfm-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds, self).__init__()

                                    self.yang_name = "sla-profile-target-mep-ids"
                                    self.yang_parent_name = "mep"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"sla-profile-target-mac-address" : ("sla_profile_target_mac_address", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMacAddress), "sla-profile-target-mep-id" : ("sla_profile_target_mep_id", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMepId)}

                                    self.sla_profile_target_mac_address = YList(self)
                                    self.sla_profile_target_mep_id = YList(self)
                                    self._segment_path = lambda: "sla-profile-target-mep-ids"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds, [], name, value)


                                class SlaProfileTargetMacAddress(Entity):
                                    """
                                    Configuration for a particular SLA
                                    operation
                                    
                                    .. attribute:: profile  <key>
                                    
                                    	SLA profile name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: target_mac_address  <key>
                                    
                                    	Target MAC address
                                    	**type**\:  str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    

                                    """

                                    _prefix = 'ethernet-cfm-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMacAddress, self).__init__()

                                        self.yang_name = "sla-profile-target-mac-address"
                                        self.yang_parent_name = "sla-profile-target-mep-ids"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.profile = YLeaf(YType.str, "profile")

                                        self.target_mac_address = YLeaf(YType.str, "target-mac-address")
                                        self._segment_path = lambda: "sla-profile-target-mac-address" + "[profile='" + self.profile.get() + "']" + "[target-mac-address='" + self.target_mac_address.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMacAddress, ['profile', 'target_mac_address'], name, value)


                                class SlaProfileTargetMepId(Entity):
                                    """
                                    Configuration for a particular SLA
                                    operation
                                    
                                    .. attribute:: profile  <key>
                                    
                                    	SLA profile name
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: target_mep_id  <key>
                                    
                                    	Target MEP\-ID
                                    	**type**\:  int
                                    
                                    	**range:** 1..8191
                                    
                                    

                                    """

                                    _prefix = 'ethernet-cfm-cfg'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMepId, self).__init__()

                                        self.yang_name = "sla-profile-target-mep-id"
                                        self.yang_parent_name = "sla-profile-target-mep-ids"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.profile = YLeaf(YType.str, "profile")

                                        self.target_mep_id = YLeaf(YType.uint32, "target-mep-id")
                                        self._segment_path = lambda: "sla-profile-target-mep-id" + "[profile='" + self.profile.get() + "']" + "[target-mep-id='" + self.target_mep_id.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.Cfm.Domains.Domain.Mep.SlaProfileTargetMepIds.SlaProfileTargetMepId, ['profile', 'target_mep_id'], name, value)


            class EtherLinkOam(Entity):
                """
                Ethernet Link OAM Interface Configuration
                
                .. attribute:: action
                
                	Configure action parameters
                	**type**\:   :py:class:`Action <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action>`
                
                .. attribute:: hello_interval
                
                	Possible Ethernet Link OAM hello intervals
                	**type**\:   :py:class:`EtherLinkOamHelloIntervalEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamHelloIntervalEnum>`
                
                .. attribute:: link_monitoring
                
                	Configure link monitor parameters
                	**type**\:   :py:class:`LinkMonitoring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring>`
                
                .. attribute:: mib_retrieval
                
                	Enable or disable MIB retrieval
                	**type**\:  bool
                
                .. attribute:: mode
                
                	Possible Ethernet Link OAM modes
                	**type**\:   :py:class:`EtherLinkOamModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamModeEnum>`
                
                .. attribute:: profile_name
                
                	Set the profile to use on the interface
                	**type**\:  str
                
                .. attribute:: remote_loopback
                
                	Enable or disable remote loopback
                	**type**\:  bool
                
                .. attribute:: require_remote
                
                	Configure remote requirement parameters
                	**type**\:   :py:class:`RequireRemote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote>`
                
                .. attribute:: timeout
                
                	Connection timeout period in number of lost heartbeats
                	**type**\:  int
                
                	**range:** 2..30
                
                .. attribute:: udlf
                
                	Enable or disable uni\-directional link\-fault detection
                	**type**\:  bool
                
                

                """

                _prefix = 'ethernet-link-oam-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam, self).__init__()

                    self.yang_name = "ether-link-oam"
                    self.yang_parent_name = "ethernet-features"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"action" : ("action", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action), "link-monitoring" : ("link_monitoring", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring), "require-remote" : ("require_remote", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote)}
                    self._child_list_classes = {}

                    self.hello_interval = YLeaf(YType.enumeration, "hello-interval")

                    self.mib_retrieval = YLeaf(YType.boolean, "mib-retrieval")

                    self.mode = YLeaf(YType.enumeration, "mode")

                    self.profile_name = YLeaf(YType.str, "profile-name")

                    self.remote_loopback = YLeaf(YType.boolean, "remote-loopback")

                    self.timeout = YLeaf(YType.uint32, "timeout")

                    self.udlf = YLeaf(YType.boolean, "udlf")

                    self.action = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action()
                    self.action.parent = self
                    self._children_name_map["action"] = "action"
                    self._children_yang_names.add("action")

                    self.link_monitoring = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring()
                    self.link_monitoring.parent = self
                    self._children_name_map["link_monitoring"] = "link-monitoring"
                    self._children_yang_names.add("link-monitoring")

                    self.require_remote = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote()
                    self.require_remote.parent = self
                    self._children_name_map["require_remote"] = "require-remote"
                    self._children_yang_names.add("require-remote")
                    self._segment_path = lambda: "Cisco-IOS-XR-ethernet-link-oam-cfg:ether-link-oam"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam, ['hello_interval', 'mib_retrieval', 'mode', 'profile_name', 'remote_loopback', 'timeout', 'udlf'], name, value)


                class Action(Entity):
                    """
                    Configure action parameters
                    
                    .. attribute:: capabilities_conflict
                    
                    	Action to perform when a capabilities conflict occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    .. attribute:: critical_event
                    
                    	Action to perform when a critical event occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnum>`
                    
                    .. attribute:: discovery_timeout
                    
                    	Action to perform when discovery timeout occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    .. attribute:: dying_gasp
                    
                    	Action to perform when a dying gasp occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnum>`
                    
                    .. attribute:: high_threshold
                    
                    	Action to perform when a high\-threshold event occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnum>`
                    
                    .. attribute:: link_fault
                    
                    	Action to perform when a link fault occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    .. attribute:: remote_loopback
                    
                    	Action to perform when remote loopback is entered or exited
                    	**type**\:   :py:class:`EtherLinkOamEventActionPrimEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionPrimEnum>`
                    
                    .. attribute:: session_down
                    
                    	Action to perform when a session comes down
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    .. attribute:: session_up
                    
                    	Action to perform when a session comes up
                    	**type**\:   :py:class:`EtherLinkOamEventActionPrimEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionPrimEnum>`
                    
                    .. attribute:: wiring_conflict
                    
                    	Action to perform when a wiring conflict occurs
                    	**type**\:   :py:class:`EtherLinkOamEventActionEnumEfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamEventActionEnumEfd>`
                    
                    

                    """

                    _prefix = 'ethernet-link-oam-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action, self).__init__()

                        self.yang_name = "action"
                        self.yang_parent_name = "ether-link-oam"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.capabilities_conflict = YLeaf(YType.enumeration, "capabilities-conflict")

                        self.critical_event = YLeaf(YType.enumeration, "critical-event")

                        self.discovery_timeout = YLeaf(YType.enumeration, "discovery-timeout")

                        self.dying_gasp = YLeaf(YType.enumeration, "dying-gasp")

                        self.high_threshold = YLeaf(YType.enumeration, "high-threshold")

                        self.link_fault = YLeaf(YType.enumeration, "link-fault")

                        self.remote_loopback = YLeaf(YType.enumeration, "remote-loopback")

                        self.session_down = YLeaf(YType.enumeration, "session-down")

                        self.session_up = YLeaf(YType.enumeration, "session-up")

                        self.wiring_conflict = YLeaf(YType.enumeration, "wiring-conflict")
                        self._segment_path = lambda: "action"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.Action, ['capabilities_conflict', 'critical_event', 'discovery_timeout', 'dying_gasp', 'high_threshold', 'link_fault', 'remote_loopback', 'session_down', 'session_up', 'wiring_conflict'], name, value)


                class LinkMonitoring(Entity):
                    """
                    Configure link monitor parameters
                    
                    .. attribute:: frame
                    
                    	Frame event configuration
                    	**type**\:   :py:class:`Frame <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame>`
                    
                    .. attribute:: frame_period
                    
                    	Frame\-period event configuration
                    	**type**\:   :py:class:`FramePeriod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod>`
                    
                    .. attribute:: frame_seconds
                    
                    	Frame\-seconds event configuration
                    	**type**\:   :py:class:`FrameSeconds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds>`
                    
                    .. attribute:: monitoring
                    
                    	Enable or disable monitoring
                    	**type**\:  bool
                    
                    .. attribute:: symbol_period
                    
                    	Symbol\-period event configuration
                    	**type**\:   :py:class:`SymbolPeriod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod>`
                    
                    

                    """

                    _prefix = 'ethernet-link-oam-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring, self).__init__()

                        self.yang_name = "link-monitoring"
                        self.yang_parent_name = "ether-link-oam"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"frame" : ("frame", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame), "frame-period" : ("frame_period", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod), "frame-seconds" : ("frame_seconds", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds), "symbol-period" : ("symbol_period", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod)}
                        self._child_list_classes = {}

                        self.monitoring = YLeaf(YType.boolean, "monitoring")

                        self.frame = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame()
                        self.frame.parent = self
                        self._children_name_map["frame"] = "frame"
                        self._children_yang_names.add("frame")

                        self.frame_period = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod()
                        self.frame_period.parent = self
                        self._children_name_map["frame_period"] = "frame-period"
                        self._children_yang_names.add("frame-period")

                        self.frame_seconds = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds()
                        self.frame_seconds.parent = self
                        self._children_name_map["frame_seconds"] = "frame-seconds"
                        self._children_yang_names.add("frame-seconds")

                        self.symbol_period = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod()
                        self.symbol_period.parent = self
                        self._children_name_map["symbol_period"] = "symbol-period"
                        self._children_yang_names.add("symbol-period")
                        self._segment_path = lambda: "link-monitoring"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring, ['monitoring'], name, value)


                    class Frame(Entity):
                        """
                        Frame event configuration
                        
                        .. attribute:: threshold
                        
                        	Threshold configuration for frame events
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold>`
                        
                        .. attribute:: window
                        
                        	Window size configuration for frame events
                        	**type**\:  int
                        
                        	**range:** 1000..60000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 1000
                        
                        

                        """

                        _prefix = 'ethernet-link-oam-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame, self).__init__()

                            self.yang_name = "frame"
                            self.yang_parent_name = "link-monitoring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"threshold" : ("threshold", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold)}
                            self._child_list_classes = {}

                            self.window = YLeaf(YType.uint32, "window")

                            self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"
                            self._children_yang_names.add("threshold")
                            self._segment_path = lambda: "frame"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame, ['window'], name, value)


                        class Threshold(Entity):
                            """
                            Threshold configuration for frame events
                            
                            .. attribute:: multiplier_high
                            
                            	The multiplier to use for the high threshold (treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            .. attribute:: multiplier_low
                            
                            	The multiplier to use for the low threshold (treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: threshold_high
                            
                            	The high threshold for frame events
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: threshold_low
                            
                            	The low threshold for frame events
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**default value**\: 1
                            
                            

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "frame"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.multiplier_high = YLeaf(YType.enumeration, "multiplier-high")

                                self.multiplier_low = YLeaf(YType.enumeration, "multiplier-low")

                                self.threshold_high = YLeaf(YType.uint32, "threshold-high")

                                self.threshold_low = YLeaf(YType.uint32, "threshold-low")
                                self._segment_path = lambda: "threshold"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.Frame.Threshold, ['multiplier_high', 'multiplier_low', 'threshold_high', 'threshold_low'], name, value)


                    class FramePeriod(Entity):
                        """
                        Frame\-period event configuration
                        
                        .. attribute:: threshold
                        
                        	Threshold configuration for frame\-period events
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold>`
                        
                        .. attribute:: window
                        
                        	Window size configuration for frame\-period events
                        	**type**\:   :py:class:`Window <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Window>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ethernet-link-oam-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod, self).__init__()

                            self.yang_name = "frame-period"
                            self.yang_parent_name = "link-monitoring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"threshold" : ("threshold", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold), "window" : ("window", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Window)}
                            self._child_list_classes = {}

                            self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"
                            self._children_yang_names.add("threshold")

                            self.window = None
                            self._children_name_map["window"] = "window"
                            self._children_yang_names.add("window")
                            self._segment_path = lambda: "frame-period"


                        class Threshold(Entity):
                            """
                            Threshold configuration for frame\-period
                            events
                            
                            .. attribute:: multiplier_high
                            
                            	The multiplier to use for the high threshold (only valid if 'Units' is Frames and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            .. attribute:: multiplier_low
                            
                            	The multiplier to use for the low threshold (only valid if 'Units' is Frames and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: threshold_high
                            
                            	The high threshold for frame\-period events
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: threshold_low
                            
                            	The low threshold for frame\-period events
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**default value**\: 1
                            
                            .. attribute:: units
                            
                            	The units to use for these thresholds
                            	**type**\:   :py:class:`EtherLinkOamThresholdUnitsFramesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdUnitsFramesEnum>`
                            
                            	**default value**\: ppm
                            
                            

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "frame-period"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.multiplier_high = YLeaf(YType.enumeration, "multiplier-high")

                                self.multiplier_low = YLeaf(YType.enumeration, "multiplier-low")

                                self.threshold_high = YLeaf(YType.uint32, "threshold-high")

                                self.threshold_low = YLeaf(YType.uint32, "threshold-low")

                                self.units = YLeaf(YType.enumeration, "units")
                                self._segment_path = lambda: "threshold"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Threshold, ['multiplier_high', 'multiplier_low', 'threshold_high', 'threshold_low', 'units'], name, value)


                        class Window(Entity):
                            """
                            Window size configuration for frame\-period
                            events
                            
                            .. attribute:: multiplier
                            
                            	The multiplier to use for this window (only valid if 'Units' is Frames and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: units
                            
                            	The units to use for this window
                            	**type**\:   :py:class:`EtherLinkOamWindowUnitsFramesEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamWindowUnitsFramesEnum>`
                            
                            	**mandatory**\: True
                            
                            .. attribute:: window
                            
                            	Size of the frame\-period window
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Window, self).__init__()

                                self.yang_name = "window"
                                self.yang_parent_name = "frame-period"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.multiplier = YLeaf(YType.enumeration, "multiplier")

                                self.units = YLeaf(YType.enumeration, "units")

                                self.window = YLeaf(YType.uint32, "window")
                                self._segment_path = lambda: "window"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FramePeriod.Window, ['multiplier', 'units', 'window'], name, value)


                    class FrameSeconds(Entity):
                        """
                        Frame\-seconds event configuration
                        
                        .. attribute:: threshold
                        
                        	Threshold configuration for frame\-seconds events
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold>`
                        
                        .. attribute:: window
                        
                        	Window size configuration for frame\-seconds events
                        	**type**\:  int
                        
                        	**range:** 10000..900000
                        
                        	**units**\: millisecond
                        
                        	**default value**\: 60000
                        
                        

                        """

                        _prefix = 'ethernet-link-oam-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds, self).__init__()

                            self.yang_name = "frame-seconds"
                            self.yang_parent_name = "link-monitoring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"threshold" : ("threshold", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold)}
                            self._child_list_classes = {}

                            self.window = YLeaf(YType.uint32, "window")

                            self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"
                            self._children_yang_names.add("threshold")
                            self._segment_path = lambda: "frame-seconds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds, ['window'], name, value)


                        class Threshold(Entity):
                            """
                            Threshold configuration for frame\-seconds
                            events
                            
                            .. attribute:: threshold_high
                            
                            	The high threshold for frame\-seconds events
                            	**type**\:  int
                            
                            	**range:** 1..900
                            
                            	**units**\: second
                            
                            .. attribute:: threshold_low
                            
                            	The low threshold for frame\-seconds events
                            	**type**\:  int
                            
                            	**range:** 1..900
                            
                            	**units**\: second
                            
                            	**default value**\: 1
                            
                            

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "frame-seconds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.threshold_high = YLeaf(YType.uint32, "threshold-high")

                                self.threshold_low = YLeaf(YType.uint32, "threshold-low")
                                self._segment_path = lambda: "threshold"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.FrameSeconds.Threshold, ['threshold_high', 'threshold_low'], name, value)


                    class SymbolPeriod(Entity):
                        """
                        Symbol\-period event configuration
                        
                        .. attribute:: threshold
                        
                        	Threshold configuration for symbol\-period events
                        	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold>`
                        
                        .. attribute:: window
                        
                        	Window size configuration for symbol\-period events
                        	**type**\:   :py:class:`Window <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Window>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ethernet-link-oam-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod, self).__init__()

                            self.yang_name = "symbol-period"
                            self.yang_parent_name = "link-monitoring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"threshold" : ("threshold", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold), "window" : ("window", InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Window)}
                            self._child_list_classes = {}

                            self.threshold = InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold()
                            self.threshold.parent = self
                            self._children_name_map["threshold"] = "threshold"
                            self._children_yang_names.add("threshold")

                            self.window = None
                            self._children_name_map["window"] = "window"
                            self._children_yang_names.add("window")
                            self._segment_path = lambda: "symbol-period"


                        class Threshold(Entity):
                            """
                            Threshold configuration for symbol\-period
                            events
                            
                            .. attribute:: multiplier_high
                            
                            	The multiplier to use for the high threshold (only valid if 'Units' is Symbols and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            .. attribute:: multiplier_low
                            
                            	The multiplier to use for the low threshold (only valid if 'Units' is Symbols and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: threshold_high
                            
                            	The high threshold for symbol\-period
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: threshold_low
                            
                            	The low threshold for symbol\-period
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**default value**\: 1
                            
                            .. attribute:: units
                            
                            	The units to use for these thresholds
                            	**type**\:   :py:class:`EtherLinkOamThresholdUnitsSymbolsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdUnitsSymbolsEnum>`
                            
                            	**default value**\: symbols
                            
                            

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold, self).__init__()

                                self.yang_name = "threshold"
                                self.yang_parent_name = "symbol-period"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.multiplier_high = YLeaf(YType.enumeration, "multiplier-high")

                                self.multiplier_low = YLeaf(YType.enumeration, "multiplier-low")

                                self.threshold_high = YLeaf(YType.uint32, "threshold-high")

                                self.threshold_low = YLeaf(YType.uint32, "threshold-low")

                                self.units = YLeaf(YType.enumeration, "units")
                                self._segment_path = lambda: "threshold"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Threshold, ['multiplier_high', 'multiplier_low', 'threshold_high', 'threshold_low', 'units'], name, value)


                        class Window(Entity):
                            """
                            Window size configuration for symbol\-period
                            events
                            
                            .. attribute:: multiplier
                            
                            	The multiplier to use for this window (only valid if 'Units' is Symbols and treated as 1 if unspecified)
                            	**type**\:   :py:class:`EtherLinkOamThresholdWindowMultiplierEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamThresholdWindowMultiplierEnum>`
                            
                            	**default value**\: none
                            
                            .. attribute:: units
                            
                            	Units to use for this window
                            	**type**\:   :py:class:`EtherLinkOamWindowUnitsSymbolsEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamWindowUnitsSymbolsEnum>`
                            
                            	**mandatory**\: True
                            
                            .. attribute:: window
                            
                            	Size of the symbol\-period window
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ethernet-link-oam-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Window, self).__init__()

                                self.yang_name = "window"
                                self.yang_parent_name = "symbol-period"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.multiplier = YLeaf(YType.enumeration, "multiplier")

                                self.units = YLeaf(YType.enumeration, "units")

                                self.window = YLeaf(YType.uint32, "window")
                                self._segment_path = lambda: "window"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.LinkMonitoring.SymbolPeriod.Window, ['multiplier', 'units', 'window'], name, value)


                class RequireRemote(Entity):
                    """
                    Configure remote requirement parameters
                    
                    .. attribute:: link_monitoring
                    
                    	Enable or disable link monitoring peer requirement
                    	**type**\:  bool
                    
                    .. attribute:: mib_retrieval
                    
                    	Enable or disable MIB retrieval peer requirement
                    	**type**\:  bool
                    
                    .. attribute:: mode
                    
                    	Possible required peer modes
                    	**type**\:   :py:class:`EtherLinkOamRequireModeEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_link_oam_cfg.EtherLinkOamRequireModeEnum>`
                    
                    .. attribute:: remote_loopback
                    
                    	Enable or disable remote loopback peer requirement
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ethernet-link-oam-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote, self).__init__()

                        self.yang_name = "require-remote"
                        self.yang_parent_name = "ether-link-oam"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.link_monitoring = YLeaf(YType.boolean, "link-monitoring")

                        self.mib_retrieval = YLeaf(YType.boolean, "mib-retrieval")

                        self.mode = YLeaf(YType.enumeration, "mode")

                        self.remote_loopback = YLeaf(YType.boolean, "remote-loopback")
                        self._segment_path = lambda: "require-remote"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetFeatures.EtherLinkOam.RequireRemote, ['link_monitoring', 'mib_retrieval', 'mode', 'remote_loopback'], name, value)


        class EthernetService(Entity):
            """
            Ethernet service configuration
            
            .. attribute:: encapsulation
            
            	The encapsulation of this Ethernet service
            	**type**\:   :py:class:`Encapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetService.Encapsulation>`
            
            	**presence node**\: True
            
            .. attribute:: local_traffic_default_encapsulation
            
            	The default encapsulation to be used for locally\-sourced packets
            	**type**\:   :py:class:`LocalTrafficDefaultEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetService.LocalTrafficDefaultEncapsulation>`
            
            	**presence node**\: True
            
            .. attribute:: rewrite
            
            	The rewrite operation for the Ethernet service
            	**type**\:   :py:class:`Rewrite <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.EthernetService.Rewrite>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.EthernetService, self).__init__()

                self.yang_name = "ethernet-service"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"encapsulation" : ("encapsulation", InterfaceConfigurations.InterfaceConfiguration.EthernetService.Encapsulation), "local-traffic-default-encapsulation" : ("local_traffic_default_encapsulation", InterfaceConfigurations.InterfaceConfiguration.EthernetService.LocalTrafficDefaultEncapsulation), "rewrite" : ("rewrite", InterfaceConfigurations.InterfaceConfiguration.EthernetService.Rewrite)}
                self._child_list_classes = {}

                self.encapsulation = None
                self._children_name_map["encapsulation"] = "encapsulation"
                self._children_yang_names.add("encapsulation")

                self.local_traffic_default_encapsulation = None
                self._children_name_map["local_traffic_default_encapsulation"] = "local-traffic-default-encapsulation"
                self._children_yang_names.add("local-traffic-default-encapsulation")

                self.rewrite = None
                self._children_name_map["rewrite"] = "rewrite"
                self._children_yang_names.add("rewrite")
                self._segment_path = lambda: "Cisco-IOS-XR-l2-eth-infra-cfg:ethernet-service"


            class Encapsulation(Entity):
                """
                The encapsulation of this Ethernet service
                
                .. attribute:: additional_range1_high
                
                	High value of first additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range1_low
                
                	Low value of first additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range2_high
                
                	High value of second additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range2_low
                
                	Low value of second additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range3_high
                
                	High value of third additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range3_low
                
                	Low value of third additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range4_high
                
                	High value of forth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range4_low
                
                	Low value of forth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range5_high
                
                	High value of fifth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range5_low
                
                	Low value of fifth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range6_high
                
                	High value of sixth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range6_low
                
                	Low value of sixth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range7_high
                
                	High value of seventh additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range7_low
                
                	Low value of seventh additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: additional_range8_high
                
                	High value of eighth additional range for tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: additional_range8_low
                
                	Low value of eighth additional range for tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrCvp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrCvp>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65534
                
                
                ----
                .. attribute:: exact
                
                	Only match packets with no more tags than explicitly matched
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ingress_destination_mac
                
                	Destination MAC address to match on egress
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: ingress_source_mac
                
                	Source MAC address to match on ingress
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: inner_class_of_service
                
                	Value to match against Class Of Service bits for inner tag
                	**type**\:  int
                
                	**range:** 0..7
                
                .. attribute:: inner_range1_high
                
                	High value of first range for inner tag match
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: inner_range1_low
                
                	Low value of first range for inner tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrAny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrAny>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..4096
                
                
                ----
                .. attribute:: inner_tag_type
                
                	Type of tag for inner match (if present)
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                .. attribute:: outer_class_of_service
                
                	Value to match against Class Of Service bits for outer tag
                	**type**\:  int
                
                	**range:** 0..7
                
                .. attribute:: outer_range1_high
                
                	High value of first range for outer tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrNative <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrNative>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..65535
                
                
                ----
                .. attribute:: outer_range1_low
                
                	Low value of first range for outer tag match
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrAny <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrAny>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 1..4096
                
                
                ----
                .. attribute:: outer_tag_type
                
                	Whether to match all unmatched packets, untagged packets or tagged packets, and if matching tagged packets, the outer tag type to match
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                	**mandatory**\: True
                
                .. attribute:: payload_ethertype_match
                
                	Which payload ethertype values to match
                	**type**\:   :py:class:`EthertypeMatch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.EthertypeMatch>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Encapsulation, self).__init__()

                    self.yang_name = "encapsulation"
                    self.yang_parent_name = "ethernet-service"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.additional_range1_high = YLeaf(YType.uint32, "additional-range1-high")

                    self.additional_range1_low = YLeaf(YType.str, "additional-range1-low")

                    self.additional_range2_high = YLeaf(YType.uint32, "additional-range2-high")

                    self.additional_range2_low = YLeaf(YType.str, "additional-range2-low")

                    self.additional_range3_high = YLeaf(YType.uint32, "additional-range3-high")

                    self.additional_range3_low = YLeaf(YType.str, "additional-range3-low")

                    self.additional_range4_high = YLeaf(YType.uint32, "additional-range4-high")

                    self.additional_range4_low = YLeaf(YType.str, "additional-range4-low")

                    self.additional_range5_high = YLeaf(YType.uint32, "additional-range5-high")

                    self.additional_range5_low = YLeaf(YType.str, "additional-range5-low")

                    self.additional_range6_high = YLeaf(YType.uint32, "additional-range6-high")

                    self.additional_range6_low = YLeaf(YType.str, "additional-range6-low")

                    self.additional_range7_high = YLeaf(YType.uint32, "additional-range7-high")

                    self.additional_range7_low = YLeaf(YType.str, "additional-range7-low")

                    self.additional_range8_high = YLeaf(YType.uint32, "additional-range8-high")

                    self.additional_range8_low = YLeaf(YType.str, "additional-range8-low")

                    self.exact = YLeaf(YType.empty, "exact")

                    self.ingress_destination_mac = YLeaf(YType.str, "ingress-destination-mac")

                    self.ingress_source_mac = YLeaf(YType.str, "ingress-source-mac")

                    self.inner_class_of_service = YLeaf(YType.uint32, "inner-class-of-service")

                    self.inner_range1_high = YLeaf(YType.uint32, "inner-range1-high")

                    self.inner_range1_low = YLeaf(YType.str, "inner-range1-low")

                    self.inner_tag_type = YLeaf(YType.enumeration, "inner-tag-type")

                    self.outer_class_of_service = YLeaf(YType.uint32, "outer-class-of-service")

                    self.outer_range1_high = YLeaf(YType.str, "outer-range1-high")

                    self.outer_range1_low = YLeaf(YType.str, "outer-range1-low")

                    self.outer_tag_type = YLeaf(YType.enumeration, "outer-tag-type")

                    self.payload_ethertype_match = YLeaf(YType.enumeration, "payload-ethertype-match")
                    self._segment_path = lambda: "encapsulation"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Encapsulation, ['additional_range1_high', 'additional_range1_low', 'additional_range2_high', 'additional_range2_low', 'additional_range3_high', 'additional_range3_low', 'additional_range4_high', 'additional_range4_low', 'additional_range5_high', 'additional_range5_low', 'additional_range6_high', 'additional_range6_low', 'additional_range7_high', 'additional_range7_low', 'additional_range8_high', 'additional_range8_low', 'exact', 'ingress_destination_mac', 'ingress_source_mac', 'inner_class_of_service', 'inner_range1_high', 'inner_range1_low', 'inner_tag_type', 'outer_class_of_service', 'outer_range1_high', 'outer_range1_low', 'outer_tag_type', 'payload_ethertype_match'], name, value)


            class LocalTrafficDefaultEncapsulation(Entity):
                """
                The default encapsulation to be used for
                locally\-sourced packets
                
                .. attribute:: inner_vlan_id
                
                	Optional VLAN Id for inner Dot1Q tag
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: outer_tag_type
                
                	Type of outer tag
                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Vlan>`
                
                	**mandatory**\: True
                
                .. attribute:: outer_vlan_id
                
                	VLAN id for outer tag
                	**type**\:  int
                
                	**range:** 1..4094
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.LocalTrafficDefaultEncapsulation, self).__init__()

                    self.yang_name = "local-traffic-default-encapsulation"
                    self.yang_parent_name = "ethernet-service"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.inner_vlan_id = YLeaf(YType.uint32, "inner-vlan-id")

                    self.outer_tag_type = YLeaf(YType.enumeration, "outer-tag-type")

                    self.outer_vlan_id = YLeaf(YType.uint32, "outer-vlan-id")
                    self._segment_path = lambda: "local-traffic-default-encapsulation"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetService.LocalTrafficDefaultEncapsulation, ['inner_vlan_id', 'outer_tag_type', 'outer_vlan_id'], name, value)


            class Rewrite(Entity):
                """
                The rewrite operation for the Ethernet service
                
                .. attribute:: inner_tag_type
                
                	Type of innermost tag to be pushed
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                .. attribute:: inner_tag_value
                
                	VLAN Id of innermost tag to be pushed
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: outer_tag_type
                
                	Type of outermost tag to be pushed
                	**type**\:   :py:class:`Match <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Match>`
                
                .. attribute:: outer_tag_value
                
                	VLAN Id of outermost tag to be pushed
                	**type**\:  int
                
                	**range:** 1..4094
                
                .. attribute:: rewrite_type
                
                	The type of rewrite to perform
                	**type**\:   :py:class:`Rewrite <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Rewrite>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Rewrite, self).__init__()

                    self.yang_name = "rewrite"
                    self.yang_parent_name = "ethernet-service"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.inner_tag_type = YLeaf(YType.enumeration, "inner-tag-type")

                    self.inner_tag_value = YLeaf(YType.uint32, "inner-tag-value")

                    self.outer_tag_type = YLeaf(YType.enumeration, "outer-tag-type")

                    self.outer_tag_value = YLeaf(YType.uint32, "outer-tag-value")

                    self.rewrite_type = YLeaf(YType.enumeration, "rewrite-type")
                    self._segment_path = lambda: "rewrite"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.EthernetService.Rewrite, ['inner_tag_type', 'inner_tag_value', 'outer_tag_type', 'outer_tag_value', 'rewrite_type'], name, value)


        class Ipv4Arp(Entity):
            """
            Configure Address Resolution Protocol
            
            .. attribute:: gratuitous_ignore
            
            	Ignore the receipt of Gratuitous ARP packets on the interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: learning_disable
            
            	Disable the dynamic learning of ARP entries on the interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: learning_local
            
            	Enable the dynamic learning of ARP entries(for local subnet) on the interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: learning_solicited
            
            	ARP learning solicited configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: local_proxy_arp
            
            	Local Proxy ARP configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: proxy_arp
            
            	Proxy ARP configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: purge_delay
            
            	Time to delay purging arp entries when the interface goes down
            	**type**\:  int
            
            	**range:** 1..65535
            
            .. attribute:: timeout
            
            	Number of seconds for ARP cache timeout
            	**type**\:  int
            
            	**range:** 30..2144448000
            
            	**units**\: second
            
            

            """

            _prefix = 'ipv4-arp-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp, self).__init__()

                self.yang_name = "ipv4arp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.gratuitous_ignore = YLeaf(YType.empty, "gratuitous-ignore")

                self.learning_disable = YLeaf(YType.empty, "learning-disable")

                self.learning_local = YLeaf(YType.empty, "learning-local")

                self.learning_solicited = YLeaf(YType.empty, "learning-solicited")

                self.local_proxy_arp = YLeaf(YType.empty, "local-proxy-arp")

                self.proxy_arp = YLeaf(YType.empty, "proxy-arp")

                self.purge_delay = YLeaf(YType.uint32, "purge-delay")

                self.timeout = YLeaf(YType.uint32, "timeout")
                self._segment_path = lambda: "Cisco-IOS-XR-ipv4-arp-cfg:ipv4arp"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Arp, ['gratuitous_ignore', 'learning_disable', 'learning_local', 'learning_solicited', 'local_proxy_arp', 'proxy_arp', 'purge_delay', 'timeout'], name, value)


        class Ipv4Network(Entity):
            """
            Interface IPv4 Network configuration data
            
            .. attribute:: addresses
            
            	Set the IP address of an interface
            	**type**\:   :py:class:`Addresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses>`
            
            .. attribute:: bgp
            
            	Interface ipv4 bgp configuration
            	**type**\:   :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp>`
            
            .. attribute:: bgp_pa
            
            	Interface ipv4 bgp configuration
            	**type**\:   :py:class:`BgpPa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa>`
            
            .. attribute:: forwarding_enable
            
            	IPv4 forwarding to get enabled on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: helper_addresses
            
            	The set of IP destination addresses for UDP broadcasts
            	**type**\:   :py:class:`HelperAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses>`
            
            .. attribute:: icmp_mask_reply
            
            	The flag for enabling sending of ICMP mask reply messages
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: mtu
            
            	The IP Maximum Transmission Unit
            	**type**\:  int
            
            	**range:** 68..65535
            
            .. attribute:: point_to_point
            
            	Enable point\-to\-point handling for this interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: tcp_mss_adjust_enable
            
            	Enable TCP MSS Adjust on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ttl_propagate_disable
            
            	Disable TTL propagate on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: verify
            
            	Enable Verify handling for this interface
            	**type**\:   :py:class:`Verify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify>`
            
            

            """

            _prefix = 'ipv4-io-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network, self).__init__()

                self.yang_name = "ipv4-network"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"addresses" : ("addresses", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses), "bgp" : ("bgp", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp), "bgp-pa" : ("bgp_pa", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa), "helper-addresses" : ("helper_addresses", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses), "verify" : ("verify", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify)}
                self._child_list_classes = {}

                self.forwarding_enable = YLeaf(YType.empty, "forwarding-enable")

                self.icmp_mask_reply = YLeaf(YType.empty, "icmp-mask-reply")

                self.mtu = YLeaf(YType.uint32, "mtu")

                self.point_to_point = YLeaf(YType.empty, "point-to-point")

                self.tcp_mss_adjust_enable = YLeaf(YType.empty, "tcp-mss-adjust-enable")

                self.ttl_propagate_disable = YLeaf(YType.empty, "ttl-propagate-disable")

                self.addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses()
                self.addresses.parent = self
                self._children_name_map["addresses"] = "addresses"
                self._children_yang_names.add("addresses")

                self.bgp = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp()
                self.bgp.parent = self
                self._children_name_map["bgp"] = "bgp"
                self._children_yang_names.add("bgp")

                self.bgp_pa = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa()
                self.bgp_pa.parent = self
                self._children_name_map["bgp_pa"] = "bgp-pa"
                self._children_yang_names.add("bgp-pa")

                self.helper_addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses()
                self.helper_addresses.parent = self
                self._children_name_map["helper_addresses"] = "helper-addresses"
                self._children_yang_names.add("helper-addresses")

                self.verify = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify()
                self.verify.parent = self
                self._children_name_map["verify"] = "verify"
                self._children_yang_names.add("verify")
                self._segment_path = lambda: "Cisco-IOS-XR-ipv4-io-cfg:ipv4-network"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network, ['forwarding_enable', 'icmp_mask_reply', 'mtu', 'point_to_point', 'tcp_mss_adjust_enable', 'ttl_propagate_disable'], name, value)


            class Addresses(Entity):
                """
                Set the IP address of an interface
                
                .. attribute:: dhcp
                
                	IPv4 address and Mask negotiated via DHCP
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: primary
                
                	IP address and Mask
                	**type**\:   :py:class:`Primary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Primary>`
                
                	**presence node**\: True
                
                .. attribute:: secondaries
                
                	Specify a secondary address
                	**type**\:   :py:class:`Secondaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries>`
                
                .. attribute:: unnumbered
                
                	Enable IP processing without an explicit address
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses, self).__init__()

                    self.yang_name = "addresses"
                    self.yang_parent_name = "ipv4-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"primary" : ("primary", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Primary), "secondaries" : ("secondaries", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries)}
                    self._child_list_classes = {}

                    self.dhcp = YLeaf(YType.empty, "dhcp")

                    self.unnumbered = YLeaf(YType.str, "unnumbered")

                    self.primary = None
                    self._children_name_map["primary"] = "primary"
                    self._children_yang_names.add("primary")

                    self.secondaries = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries()
                    self.secondaries.parent = self
                    self._children_name_map["secondaries"] = "secondaries"
                    self._children_yang_names.add("secondaries")
                    self._segment_path = lambda: "addresses"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses, ['dhcp', 'unnumbered'], name, value)


                class Primary(Entity):
                    """
                    IP address and Mask
                    
                    .. attribute:: address
                    
                    	IP address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    .. attribute:: netmask
                    
                    	Netmask
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    .. attribute:: route_tag
                    
                    	RouteTag
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Primary, self).__init__()

                        self.yang_name = "primary"
                        self.yang_parent_name = "addresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.address = YLeaf(YType.str, "address")

                        self.netmask = YLeaf(YType.str, "netmask")

                        self.route_tag = YLeaf(YType.uint32, "route-tag")
                        self._segment_path = lambda: "primary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Primary, ['address', 'netmask', 'route_tag'], name, value)


                class Secondaries(Entity):
                    """
                    Specify a secondary address
                    
                    .. attribute:: secondary
                    
                    	IP address and Mask
                    	**type**\: list of    :py:class:`Secondary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries.Secondary>`
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries, self).__init__()

                        self.yang_name = "secondaries"
                        self.yang_parent_name = "addresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"secondary" : ("secondary", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries.Secondary)}

                        self.secondary = YList(self)
                        self._segment_path = lambda: "secondaries"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries, [], name, value)


                    class Secondary(Entity):
                        """
                        IP address and Mask
                        
                        .. attribute:: address  <key>
                        
                        	Secondary IP address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: netmask
                        
                        	Netmask
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        	**mandatory**\: True
                        
                        .. attribute:: route_tag
                        
                        	RouteTag
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        

                        """

                        _prefix = 'ipv4-io-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries.Secondary, self).__init__()

                            self.yang_name = "secondary"
                            self.yang_parent_name = "secondaries"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.netmask = YLeaf(YType.str, "netmask")

                            self.route_tag = YLeaf(YType.uint32, "route-tag")
                            self._segment_path = lambda: "secondary" + "[address='" + self.address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Addresses.Secondaries.Secondary, ['address', 'netmask', 'route_tag'], name, value)


            class Bgp(Entity):
                """
                Interface ipv4 bgp configuration
                
                .. attribute:: flow_tag
                
                	Interface ipv4 bgp policy propagation flow tag configuration
                	**type**\:   :py:class:`FlowTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag>`
                
                .. attribute:: qppb
                
                	Interface ipv4 bgp policy propagation configuration
                	**type**\:   :py:class:`Qppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb>`
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp, self).__init__()

                    self.yang_name = "bgp"
                    self.yang_parent_name = "ipv4-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"flow-tag" : ("flow_tag", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag), "qppb" : ("qppb", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb)}
                    self._child_list_classes = {}

                    self.flow_tag = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag()
                    self.flow_tag.parent = self
                    self._children_name_map["flow_tag"] = "flow-tag"
                    self._children_yang_names.add("flow-tag")

                    self.qppb = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb()
                    self.qppb.parent = self
                    self._children_name_map["qppb"] = "qppb"
                    self._children_yang_names.add("qppb")
                    self._segment_path = lambda: "bgp"


                class FlowTag(Entity):
                    """
                    Interface ipv4 bgp policy propagation flow tag
                    configuration
                    
                    .. attribute:: flow_tag_input
                    
                    	Input
                    	**type**\:   :py:class:`FlowTagInput <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput>`
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag, self).__init__()

                        self.yang_name = "flow-tag"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"flow-tag-input" : ("flow_tag_input", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput)}
                        self._child_list_classes = {}

                        self.flow_tag_input = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput()
                        self.flow_tag_input.parent = self
                        self._children_name_map["flow_tag_input"] = "flow-tag-input"
                        self._children_yang_names.add("flow-tag-input")
                        self._segment_path = lambda: "flow-tag"


                    class FlowTagInput(Entity):
                        """
                        Input
                        
                        .. attribute:: destination
                        
                        	FlowTag configuration on destination
                        	**type**\:  bool
                        
                        .. attribute:: source
                        
                        	FlowTag configuration on source
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ipv4-io-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput, self).__init__()

                            self.yang_name = "flow-tag-input"
                            self.yang_parent_name = "flow-tag"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.destination = YLeaf(YType.boolean, "destination")

                            self.source = YLeaf(YType.boolean, "source")
                            self._segment_path = lambda: "flow-tag-input"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.FlowTag.FlowTagInput, ['destination', 'source'], name, value)


                class Qppb(Entity):
                    """
                    Interface ipv4 bgp policy propagation
                    configuration
                    
                    .. attribute:: input
                    
                    	Input
                    	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input>`
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb, self).__init__()

                        self.yang_name = "qppb"
                        self.yang_parent_name = "bgp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"input" : ("input", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input)}
                        self._child_list_classes = {}

                        self.input = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._children_yang_names.add("input")
                        self._segment_path = lambda: "qppb"


                    class Input(Entity):
                        """
                        Input
                        
                        .. attribute:: destination
                        
                        	QPPB configuration on destination
                        	**type**\:   :py:class:`Ipv4InterfaceQppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4InterfaceQppb>`
                        
                        .. attribute:: source
                        
                        	QPPB configuration on source
                        	**type**\:   :py:class:`Ipv4InterfaceQppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4InterfaceQppb>`
                        
                        

                        """

                        _prefix = 'ipv4-io-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qppb"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.destination = YLeaf(YType.enumeration, "destination")

                            self.source = YLeaf(YType.enumeration, "source")
                            self._segment_path = lambda: "input"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Bgp.Qppb.Input, ['destination', 'source'], name, value)


            class BgpPa(Entity):
                """
                Interface ipv4 bgp configuration
                
                .. attribute:: input
                
                	Input
                	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input>`
                
                .. attribute:: output
                
                	Output
                	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output>`
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa, self).__init__()

                    self.yang_name = "bgp-pa"
                    self.yang_parent_name = "ipv4-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"input" : ("input", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input), "output" : ("output", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output)}
                    self._child_list_classes = {}

                    self.input = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"
                    self._children_yang_names.add("input")

                    self.output = InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._children_yang_names.add("output")
                    self._segment_path = lambda: "bgp-pa"


                class Input(Entity):
                    """
                    Input
                    
                    .. attribute:: destination_accounting
                    
                    	BGP PA configuration on destination
                    	**type**\:  bool
                    
                    .. attribute:: source_accounting
                    
                    	BGP PA configuration on source
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "bgp-pa"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.destination_accounting = YLeaf(YType.boolean, "destination-accounting")

                        self.source_accounting = YLeaf(YType.boolean, "source-accounting")
                        self._segment_path = lambda: "input"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Input, ['destination_accounting', 'source_accounting'], name, value)


                class Output(Entity):
                    """
                    Output
                    
                    .. attribute:: destination_accounting
                    
                    	BGP PA configuration on destination
                    	**type**\:  bool
                    
                    .. attribute:: source_accounting
                    
                    	BGP PA configuration on source
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "bgp-pa"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.destination_accounting = YLeaf(YType.boolean, "destination-accounting")

                        self.source_accounting = YLeaf(YType.boolean, "source-accounting")
                        self._segment_path = lambda: "output"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.BgpPa.Output, ['destination_accounting', 'source_accounting'], name, value)


            class HelperAddresses(Entity):
                """
                The set of IP destination addresses for UDP
                broadcasts
                
                .. attribute:: helper_address
                
                	An IP destination addresses for UDP broadcasts
                	**type**\: list of    :py:class:`HelperAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses.HelperAddress>`
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses, self).__init__()

                    self.yang_name = "helper-addresses"
                    self.yang_parent_name = "ipv4-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"helper-address" : ("helper_address", InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses.HelperAddress)}

                    self.helper_address = YList(self)
                    self._segment_path = lambda: "helper-addresses"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses, [], name, value)


                class HelperAddress(Entity):
                    """
                    An IP destination addresses for UDP broadcasts
                    
                    .. attribute:: address  <key>
                    
                    	IP destination address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: vrf_name  <key>
                    
                    	VRF name
                    	**type**\:  str
                    
                    	**length:** 1..32
                    
                    

                    """

                    _prefix = 'ipv4-io-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses.HelperAddress, self).__init__()

                        self.yang_name = "helper-address"
                        self.yang_parent_name = "helper-addresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.address = YLeaf(YType.str, "address")

                        self.vrf_name = YLeaf(YType.str, "vrf-name")
                        self._segment_path = lambda: "helper-address" + "[address='" + self.address.get() + "']" + "[vrf-name='" + self.vrf_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.HelperAddresses.HelperAddress, ['address', 'vrf_name'], name, value)


            class Verify(Entity):
                """
                Enable Verify handling for this interface
                
                .. attribute:: default_ping
                
                	Allow default route to match when checking source address
                	**type**\:   :py:class:`Ipv4DefaultPing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4DefaultPing>`
                
                .. attribute:: reachable
                
                	Source is reachable via any interface or interface on which packet was received
                	**type**\:   :py:class:`Ipv4Reachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4Reachable>`
                
                .. attribute:: self_ping
                
                	Allow router to ping itself (opens vulnerability in verification)
                	**type**\:   :py:class:`Ipv4SelfPing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv4_io_cfg.Ipv4SelfPing>`
                
                

                """

                _prefix = 'ipv4-io-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify, self).__init__()

                    self.yang_name = "verify"
                    self.yang_parent_name = "ipv4-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.default_ping = YLeaf(YType.enumeration, "default-ping")

                    self.reachable = YLeaf(YType.enumeration, "reachable")

                    self.self_ping = YLeaf(YType.enumeration, "self-ping")
                    self._segment_path = lambda: "verify"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4Network.Verify, ['default_ping', 'reachable', 'self_ping'], name, value)


        class Ipv4NetworkForwarding(Entity):
            """
            Interface IPv4 Network configuration data also
            used for forwarding
            
            .. attribute:: directed_broadcast
            
            	Enable forwarding of directed broadcast
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: redirects
            
            	Enable sending ICMP Redirect messages
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: unreachables
            
            	Disable sending ICMP unreachables
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'ipv4-io-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding, self).__init__()

                self.yang_name = "ipv4-network-forwarding"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.directed_broadcast = YLeaf(YType.empty, "directed-broadcast")

                self.redirects = YLeaf(YType.empty, "redirects")

                self.unreachables = YLeaf(YType.empty, "unreachables")
                self._segment_path = lambda: "Cisco-IOS-XR-ipv4-io-cfg:ipv4-network-forwarding"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4NetworkForwarding, ['directed_broadcast', 'redirects', 'unreachables'], name, value)


        class Ipv4PacketFilter(Entity):
            """
            IPv4 Packet Filtering configuration for the
            interface
            
            .. attribute:: inbound
            
            	IPv4 Packet filter to be applied to inbound packets
            	**type**\:   :py:class:`Inbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound>`
            
            .. attribute:: outbound
            
            	IPv4 Packet filter to be applied to outbound packets
            	**type**\:   :py:class:`Outbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound>`
            
            

            """

            _prefix = 'ip-pfilter-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter, self).__init__()

                self.yang_name = "ipv4-packet-filter"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"inbound" : ("inbound", InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound), "outbound" : ("outbound", InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound)}
                self._child_list_classes = {}

                self.inbound = InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound()
                self.inbound.parent = self
                self._children_name_map["inbound"] = "inbound"
                self._children_yang_names.add("inbound")

                self.outbound = InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound()
                self.outbound.parent = self
                self._children_name_map["outbound"] = "outbound"
                self._children_yang_names.add("outbound")
                self._segment_path = lambda: "Cisco-IOS-XR-ip-pfilter-cfg:ipv4-packet-filter"


            class Inbound(Entity):
                """
                IPv4 Packet filter to be applied to inbound
                packets
                
                .. attribute:: acl_name_array
                
                	Array of IPv4 Packet Filter Names to be applied to Inbound packets
                	**type**\:  list of str
                
                	**length:** 1..65
                
                .. attribute:: common_acl_name
                
                	Reserved for backward compatibility. IPv4 Packet Filter Name to be applied to Inbound packets, ACL providing HW optimization when applied on multiple interfaces. NOTE\: This parameter is mandatory if 'Name' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                .. attribute:: compression_level
                
                	The level of compression applied to the ACL on this interface. The range is 0 to 3 with default being no compression (0)
                	**type**\:  int
                
                	**range:** 0..3
                
                .. attribute:: hardware_count
                
                	True if packets hitting the ACL should be counted in the hardware.  The default is not to count them. NOTE\: HardwareCount is allowed only if Name is specified
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface_statistics
                
                	True if packets hitting the ACL should be counted in hardware per interface.The default is not to count them. NOTE\: InterfaceStatistics is allowed only if Name is specified
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: is_common_array
                
                	Array of CommonACL flags for each ACL. TRUE indicates HW optimization on multiple interfaces is provided
                	**type**\:  list of bool
                
                .. attribute:: name
                
                	Reserved for backward compatibility. IPv4 Packet Filter Name to be applied to Inbound packets NOTE\: This parameter is mandatory if 'CommonACLName' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                

                """

                _prefix = 'ip-pfilter-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound, self).__init__()

                    self.yang_name = "inbound"
                    self.yang_parent_name = "ipv4-packet-filter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.acl_name_array = YLeafList(YType.str, "acl-name-array")

                    self.common_acl_name = YLeaf(YType.str, "common-acl-name")

                    self.compression_level = YLeaf(YType.uint32, "compression-level")

                    self.hardware_count = YLeaf(YType.empty, "hardware-count")

                    self.interface_statistics = YLeaf(YType.empty, "interface-statistics")

                    self.is_common_array = YLeafList(YType.boolean, "is-common-array")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "inbound"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Inbound, ['acl_name_array', 'common_acl_name', 'compression_level', 'hardware_count', 'interface_statistics', 'is_common_array', 'name'], name, value)


            class Outbound(Entity):
                """
                IPv4 Packet filter to be applied to outbound
                packets
                
                .. attribute:: acl_name_array
                
                	Array of IPv4 Packet Filter Names to be applied to Outbound packets
                	**type**\:  list of str
                
                	**length:** 1..65
                
                .. attribute:: compression_level
                
                	The level of compression applied to the ACL on this interface. The range is 0 to 3 with default being no compression (0)
                	**type**\:  int
                
                	**range:** 0..3
                
                .. attribute:: do_not_use
                
                	Reserved.  Error if specified
                	**type**\:  str
                
                	**length:** 1..65
                
                .. attribute:: hardware_count
                
                	True if packets hitting the ACL should be counted in the hardware.  The default is not to count them
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: interface_statistics
                
                	True if packets hitting the ACL should be counted in hardware per interface.The default is not to count them
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: is_common_array
                
                	Array of CommonACL flags for each ACL. TRUE indicates HW optimization on multiple interfaces is provided
                	**type**\:  list of bool
                
                .. attribute:: name
                
                	Reserved for backward compatibility. IPv4 Packet Filter Name to be applied to Outbound packets NOTE\: This parameter is mandatory if 'CommonACLName' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                

                """

                _prefix = 'ip-pfilter-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound, self).__init__()

                    self.yang_name = "outbound"
                    self.yang_parent_name = "ipv4-packet-filter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.acl_name_array = YLeafList(YType.str, "acl-name-array")

                    self.compression_level = YLeaf(YType.uint32, "compression-level")

                    self.do_not_use = YLeaf(YType.str, "do-not-use")

                    self.hardware_count = YLeaf(YType.empty, "hardware-count")

                    self.interface_statistics = YLeaf(YType.empty, "interface-statistics")

                    self.is_common_array = YLeafList(YType.boolean, "is-common-array")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "outbound"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv4PacketFilter.Outbound, ['acl_name_array', 'compression_level', 'do_not_use', 'hardware_count', 'interface_statistics', 'is_common_array', 'name'], name, value)


        class Ipv6Neighbor(Entity):
            """
            IPv6 interface neighbor or neighbor discovery
            configuration
            
            .. attribute:: cache_limit
            
            	Set the cache limit for neighbor entries
            	**type**\:  int
            
            	**range:** 0..128000
            
            .. attribute:: dad_attempts
            
            	Set IPv6 duplicate address detection transmits
            	**type**\:  int
            
            	**range:** 0..600
            
            .. attribute:: ipv6_prefixes
            
            	Prefixes 
            	**type**\:   :py:class:`Ipv6Prefixes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes>`
            
            .. attribute:: managed_config
            
            	Host to use stateful protocol for address configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ns_interval
            
            	Set advertised NS retransmission interval in milliseconds
            	**type**\:  int
            
            	**range:** 1000..4294967295
            
            	**units**\: millisecond
            
            .. attribute:: other_config
            
            	Host to use stateful protocol for non\-address configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ra_interval
            
            	Set IPv6 Router Advertisement (RA) interval in seconds
            	**type**\:   :py:class:`RaInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaInterval>`
            
            	**presence node**\: True
            
            .. attribute:: ra_lifetime
            
            	Set IPv6 Router Advertisement (RA) lifetime in seconds
            	**type**\:  int
            
            	**range:** 0..9000
            
            	**units**\: second
            
            .. attribute:: ra_suppress
            
            	Enable suppress IPv6 router advertisement
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ra_unicast
            
            	Enable unicast IPv6 router advertisement
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ra_unspecify_hoplimit
            
            	Unspecify IPv6 Router Advertisement (RA) hop\-limit
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: radns_searches
            
            	IPv6 Router Advertisement (RA) DNS Search List
            	**type**\:   :py:class:`RadnsSearches <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches>`
            
            .. attribute:: radns_servers
            
            	IPv6 Router Advertisement (RA) DNS Servre
            	**type**\:   :py:class:`RadnsServers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers>`
            
            .. attribute:: ramtu_suppress
            
            	Enable suppress MTU in IPv6 router advertisement
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: raspecific_route_s
            
            	IPv6 Router Advertisement (RA) Specific Route
            	**type**\:   :py:class:`RaspecificRouteS <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS>`
            
            .. attribute:: reachable_time
            
            	Set advertised reachability time in milliseconds
            	**type**\:  int
            
            	**range:** 0..3600000
            
            	**units**\: millisecond
            
            .. attribute:: redirect
            
            	Enable sending of ICMP Redirect messages
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: router_preference
            
            	RA Router Preference
            	**type**\:   :py:class:`Ipv6NdRouterPref <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6NdRouterPref>`
            
            .. attribute:: srp_multicast_encapsulation
            
            	Set SRP multicast prefer encapsulation
            	**type**\:   :py:class:`Ipv6srpEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6srpEncapsulation>`
            
            .. attribute:: srp_unicast_encapsulation
            
            	Set SRP unicast prefer encapsulation
            	**type**\:   :py:class:`Ipv6srpEncapsulation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6srpEncapsulation>`
            
            

            """

            _prefix = 'ipv6-nd-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor, self).__init__()

                self.yang_name = "ipv6-neighbor"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"ipv6-prefixes" : ("ipv6_prefixes", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes), "ra-interval" : ("ra_interval", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaInterval), "radns-searches" : ("radns_searches", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches), "radns-servers" : ("radns_servers", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers), "raspecific-route-s" : ("raspecific_route_s", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS)}
                self._child_list_classes = {}

                self.cache_limit = YLeaf(YType.uint32, "cache-limit")

                self.dad_attempts = YLeaf(YType.uint32, "dad-attempts")

                self.managed_config = YLeaf(YType.empty, "managed-config")

                self.ns_interval = YLeaf(YType.uint32, "ns-interval")

                self.other_config = YLeaf(YType.empty, "other-config")

                self.ra_lifetime = YLeaf(YType.uint32, "ra-lifetime")

                self.ra_suppress = YLeaf(YType.empty, "ra-suppress")

                self.ra_unicast = YLeaf(YType.empty, "ra-unicast")

                self.ra_unspecify_hoplimit = YLeaf(YType.empty, "ra-unspecify-hoplimit")

                self.ramtu_suppress = YLeaf(YType.empty, "ramtu-suppress")

                self.reachable_time = YLeaf(YType.uint32, "reachable-time")

                self.redirect = YLeaf(YType.empty, "redirect")

                self.router_preference = YLeaf(YType.enumeration, "router-preference")

                self.srp_multicast_encapsulation = YLeaf(YType.enumeration, "srp-multicast-encapsulation")

                self.srp_unicast_encapsulation = YLeaf(YType.enumeration, "srp-unicast-encapsulation")

                self.ipv6_prefixes = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes()
                self.ipv6_prefixes.parent = self
                self._children_name_map["ipv6_prefixes"] = "ipv6-prefixes"
                self._children_yang_names.add("ipv6-prefixes")

                self.ra_interval = None
                self._children_name_map["ra_interval"] = "ra-interval"
                self._children_yang_names.add("ra-interval")

                self.radns_searches = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches()
                self.radns_searches.parent = self
                self._children_name_map["radns_searches"] = "radns-searches"
                self._children_yang_names.add("radns-searches")

                self.radns_servers = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers()
                self.radns_servers.parent = self
                self._children_name_map["radns_servers"] = "radns-servers"
                self._children_yang_names.add("radns-servers")

                self.raspecific_route_s = InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS()
                self.raspecific_route_s.parent = self
                self._children_name_map["raspecific_route_s"] = "raspecific-route-s"
                self._children_yang_names.add("raspecific-route-s")
                self._segment_path = lambda: "Cisco-IOS-XR-ipv6-nd-cfg:ipv6-neighbor"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor, ['cache_limit', 'dad_attempts', 'managed_config', 'ns_interval', 'other_config', 'ra_lifetime', 'ra_suppress', 'ra_unicast', 'ra_unspecify_hoplimit', 'ramtu_suppress', 'reachable_time', 'redirect', 'router_preference', 'srp_multicast_encapsulation', 'srp_unicast_encapsulation'], name, value)


            class Ipv6Prefixes(Entity):
                """
                Prefixes 
                
                .. attribute:: ipv6_prefix
                
                	Configure prefix with paramemters
                	**type**\: list of    :py:class:`Ipv6Prefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes.Ipv6Prefix>`
                
                

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes, self).__init__()

                    self.yang_name = "ipv6-prefixes"
                    self.yang_parent_name = "ipv6-neighbor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"ipv6-prefix" : ("ipv6_prefix", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes.Ipv6Prefix)}

                    self.ipv6_prefix = YList(self)
                    self._segment_path = lambda: "ipv6-prefixes"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes, [], name, value)


                class Ipv6Prefix(Entity):
                    """
                    Configure prefix with paramemters
                    
                    .. attribute:: prefix  <key>
                    
                    	IPv6 prefix
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: expiry_date
                    
                    	Date to expire valid lifetime
                    	**type**\:  int
                    
                    	**range:** 1..31
                    
                    .. attribute:: expiry_hour
                    
                    	Hour to expire valid lifetime
                    	**type**\:  int
                    
                    	**range:** 0..23
                    
                    .. attribute:: expiry_minute
                    
                    	Minute to expire valid lifetime
                    	**type**\:  int
                    
                    	**range:** 0..59
                    
                    .. attribute:: expiry_month
                    
                    	Month to expire valid lifetime
                    	**type**\:   :py:class:`Ipv6ndMonth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6ndMonth>`
                    
                    .. attribute:: expiry_year
                    
                    	Year to expire valid lifetime
                    	**type**\:  int
                    
                    	**range:** 2003..2035
                    
                    .. attribute:: no_advertize
                    
                    	If set, prefix will not be advertized
                    	**type**\:  bool
                    
                    .. attribute:: no_auto_config
                    
                    	If set, prefix will not be used for auto configuration
                    	**type**\:  bool
                    
                    .. attribute:: off_link
                    
                    	If set, prefix will not be used for onlink determination
                    	**type**\:  bool
                    
                    .. attribute:: pref_expiry_date
                    
                    	Date to expire preferred lifetime
                    	**type**\:  int
                    
                    	**range:** 1..31
                    
                    .. attribute:: pref_expiry_hour
                    
                    	Hour to expire preferred lifetime
                    	**type**\:  int
                    
                    	**range:** 0..23
                    
                    .. attribute:: pref_expiry_minute
                    
                    	Minute to expire preferred lifetime
                    	**type**\:  int
                    
                    	**range:** 0..59
                    
                    .. attribute:: pref_expiry_month
                    
                    	Month to expire preferred lifetime
                    	**type**\:   :py:class:`Ipv6ndMonth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6ndMonth>`
                    
                    .. attribute:: pref_expiry_year
                    
                    	Year to expire preferred lifetime
                    	**type**\:  int
                    
                    	**range:** 2003..2035
                    
                    .. attribute:: preferred_lifetime
                    
                    	Preferred Lifetime (seconds) must be <= Valid Lifetime
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: prefix_length
                    
                    	Prefix mask length
                    	**type**\:  int
                    
                    	**range:** 0..128
                    
                    	**mandatory**\: True
                    
                    .. attribute:: prefix_zone
                    
                    	Prefix zone
                    	**type**\:  str
                    
                    	**length:** 1..9
                    
                    .. attribute:: valid_lifetime
                    
                    	Valid Lifetime (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ipv6-nd-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes.Ipv6Prefix, self).__init__()

                        self.yang_name = "ipv6-prefix"
                        self.yang_parent_name = "ipv6-prefixes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.prefix = YLeaf(YType.str, "prefix")

                        self.expiry_date = YLeaf(YType.uint32, "expiry-date")

                        self.expiry_hour = YLeaf(YType.uint32, "expiry-hour")

                        self.expiry_minute = YLeaf(YType.uint32, "expiry-minute")

                        self.expiry_month = YLeaf(YType.enumeration, "expiry-month")

                        self.expiry_year = YLeaf(YType.uint32, "expiry-year")

                        self.no_advertize = YLeaf(YType.boolean, "no-advertize")

                        self.no_auto_config = YLeaf(YType.boolean, "no-auto-config")

                        self.off_link = YLeaf(YType.boolean, "off-link")

                        self.pref_expiry_date = YLeaf(YType.uint32, "pref-expiry-date")

                        self.pref_expiry_hour = YLeaf(YType.uint32, "pref-expiry-hour")

                        self.pref_expiry_minute = YLeaf(YType.uint32, "pref-expiry-minute")

                        self.pref_expiry_month = YLeaf(YType.enumeration, "pref-expiry-month")

                        self.pref_expiry_year = YLeaf(YType.uint32, "pref-expiry-year")

                        self.preferred_lifetime = YLeaf(YType.uint32, "preferred-lifetime")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                        self.prefix_zone = YLeaf(YType.str, "prefix-zone")

                        self.valid_lifetime = YLeaf(YType.uint32, "valid-lifetime")
                        self._segment_path = lambda: "ipv6-prefix" + "[prefix='" + self.prefix.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.Ipv6Prefixes.Ipv6Prefix, ['prefix', 'expiry_date', 'expiry_hour', 'expiry_minute', 'expiry_month', 'expiry_year', 'no_advertize', 'no_auto_config', 'off_link', 'pref_expiry_date', 'pref_expiry_hour', 'pref_expiry_minute', 'pref_expiry_month', 'pref_expiry_year', 'preferred_lifetime', 'prefix_length', 'prefix_zone', 'valid_lifetime'], name, value)


            class RaInterval(Entity):
                """
                Set IPv6 Router Advertisement (RA) interval in
                seconds
                
                .. attribute:: maximum
                
                	Maximum RA interval in seconds
                	**type**\:  int
                
                	**range:** 4..1800
                
                	**mandatory**\: True
                
                .. attribute:: minimum
                
                	Minimum RA interval in seconds. Must be less than 0.75 \* maximum interval
                	**type**\:  int
                
                	**range:** 3..1800
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaInterval, self).__init__()

                    self.yang_name = "ra-interval"
                    self.yang_parent_name = "ipv6-neighbor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.maximum = YLeaf(YType.uint32, "maximum")

                    self.minimum = YLeaf(YType.uint32, "minimum")
                    self._segment_path = lambda: "ra-interval"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaInterval, ['maximum', 'minimum'], name, value)


            class RadnsSearches(Entity):
                """
                IPv6 Router Advertisement (RA) DNS Search List
                
                .. attribute:: radns_search
                
                	IPv6 Router Advertisement (RA) DNS Search List
                	**type**\: list of    :py:class:`RadnsSearch <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches.RadnsSearch>`
                
                

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches, self).__init__()

                    self.yang_name = "radns-searches"
                    self.yang_parent_name = "ipv6-neighbor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"radns-search" : ("radns_search", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches.RadnsSearch)}

                    self.radns_search = YList(self)
                    self._segment_path = lambda: "radns-searches"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches, [], name, value)


                class RadnsSearch(Entity):
                    """
                    IPv6 Router Advertisement (RA) DNS Search List
                    
                    .. attribute:: dns_search_list  <key>
                    
                    	Search List
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: lifetime
                    
                    	Lifetime value in seconds
                    	**type**\:  int
                    
                    	**range:** 4..3600
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ipv6-nd-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches.RadnsSearch, self).__init__()

                        self.yang_name = "radns-search"
                        self.yang_parent_name = "radns-searches"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.dns_search_list = YLeaf(YType.str, "dns-search-list")

                        self.lifetime = YLeaf(YType.uint32, "lifetime")
                        self._segment_path = lambda: "radns-search" + "[dns-search-list='" + self.dns_search_list.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsSearches.RadnsSearch, ['dns_search_list', 'lifetime'], name, value)


            class RadnsServers(Entity):
                """
                IPv6 Router Advertisement (RA) DNS Servre
                
                .. attribute:: radns_server
                
                	IPv6 Router Advertisement (RA) DNS Servre
                	**type**\: list of    :py:class:`RadnsServer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers.RadnsServer>`
                
                

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers, self).__init__()

                    self.yang_name = "radns-servers"
                    self.yang_parent_name = "ipv6-neighbor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"radns-server" : ("radns_server", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers.RadnsServer)}

                    self.radns_server = YList(self)
                    self._segment_path = lambda: "radns-servers"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers, [], name, value)


                class RadnsServer(Entity):
                    """
                    IPv6 Router Advertisement (RA) DNS Servre
                    
                    .. attribute:: dns_server  <key>
                    
                    	IPv6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: lifetime
                    
                    	Lifetime value in seconds
                    	**type**\:  int
                    
                    	**range:** 4..3600
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ipv6-nd-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers.RadnsServer, self).__init__()

                        self.yang_name = "radns-server"
                        self.yang_parent_name = "radns-servers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.dns_server = YLeaf(YType.str, "dns-server")

                        self.lifetime = YLeaf(YType.uint32, "lifetime")
                        self._segment_path = lambda: "radns-server" + "[dns-server='" + self.dns_server.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RadnsServers.RadnsServer, ['dns_server', 'lifetime'], name, value)


            class RaspecificRouteS(Entity):
                """
                IPv6 Router Advertisement (RA) Specific Route
                
                .. attribute:: raspecific_route
                
                	IPv6 Router Advertisement (RA) Specific Route
                	**type**\: list of    :py:class:`RaspecificRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS.RaspecificRoute>`
                
                

                """

                _prefix = 'ipv6-nd-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS, self).__init__()

                    self.yang_name = "raspecific-route-s"
                    self.yang_parent_name = "ipv6-neighbor"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"raspecific-route" : ("raspecific_route", InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS.RaspecificRoute)}

                    self.raspecific_route = YList(self)
                    self._segment_path = lambda: "raspecific-route-s"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS, [], name, value)


                class RaspecificRoute(Entity):
                    """
                    IPv6 Router Advertisement (RA) Specific Route
                    
                    .. attribute:: specific_route  <key>
                    
                    	IPv6 Address
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: lifetime
                    
                    	Lifetime (seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: preference
                    
                    	Preference
                    	**type**\:   :py:class:`Ipv6NdRouterPref <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_nd_cfg.Ipv6NdRouterPref>`
                    
                    .. attribute:: prefix_length
                    
                    	Prefix mask length
                    	**type**\:  int
                    
                    	**range:** 0..128
                    
                    

                    """

                    _prefix = 'ipv6-nd-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS.RaspecificRoute, self).__init__()

                        self.yang_name = "raspecific-route"
                        self.yang_parent_name = "raspecific-route-s"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.specific_route = YLeaf(YType.str, "specific-route")

                        self.lifetime = YLeaf(YType.uint32, "lifetime")

                        self.preference = YLeaf(YType.enumeration, "preference")

                        self.prefix_length = YLeaf(YType.uint8, "prefix-length")
                        self._segment_path = lambda: "raspecific-route" + "[specific-route='" + self.specific_route.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Neighbor.RaspecificRouteS.RaspecificRoute, ['specific_route', 'lifetime', 'preference', 'prefix_length'], name, value)


        class Ipv6Network(Entity):
            """
            Interface IPv6 Network configuration data
            
            .. attribute:: addresses
            
            	Set the IPv6 address of an interface
            	**type**\:   :py:class:`Addresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses>`
            
            .. attribute:: bgp_flow_tag_policy_table
            
            	Interface ipv6 bgp policy propagation flowtag configuration
            	**type**\:   :py:class:`BgpFlowTagPolicyTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable>`
            
            .. attribute:: bgp_policy_accountings
            
            	IPv6 BGP Policy Accounting
            	**type**\:   :py:class:`BgpPolicyAccountings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings>`
            
            .. attribute:: bgp_qos_policy_propagation
            
            	Configure BGP QoS policy propagation
            	**type**\:   :py:class:`BgpQosPolicyPropagation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpQosPolicyPropagation>`
            
            	**presence node**\: True
            
            .. attribute:: mtu
            
            	MTU Setting of Interface
            	**type**\:  int
            
            	**range:** 1280..65535
            
            .. attribute:: tcp_mss_adjust_enable
            
            	Enable TCP MSS adjust on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ttl_propagate_disable
            
            	Disabled TTL propagate on an interface
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: unnumbered
            
            	Enable IPv6 processing without an explicit address
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: unreachables
            
            	Override Sending of ICMP Unreachable Messages
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: verify
            
            	IPv6 Verify Unicast Souce Reachable
            	**type**\:   :py:class:`Verify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Verify>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'ipv6-ma-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network, self).__init__()

                self.yang_name = "ipv6-network"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"addresses" : ("addresses", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses), "bgp-flow-tag-policy-table" : ("bgp_flow_tag_policy_table", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable), "bgp-policy-accountings" : ("bgp_policy_accountings", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings), "bgp-qos-policy-propagation" : ("bgp_qos_policy_propagation", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpQosPolicyPropagation), "verify" : ("verify", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Verify)}
                self._child_list_classes = {}

                self.mtu = YLeaf(YType.uint32, "mtu")

                self.tcp_mss_adjust_enable = YLeaf(YType.empty, "tcp-mss-adjust-enable")

                self.ttl_propagate_disable = YLeaf(YType.empty, "ttl-propagate-disable")

                self.unnumbered = YLeaf(YType.str, "unnumbered")

                self.unreachables = YLeaf(YType.empty, "unreachables")

                self.addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses()
                self.addresses.parent = self
                self._children_name_map["addresses"] = "addresses"
                self._children_yang_names.add("addresses")

                self.bgp_flow_tag_policy_table = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable()
                self.bgp_flow_tag_policy_table.parent = self
                self._children_name_map["bgp_flow_tag_policy_table"] = "bgp-flow-tag-policy-table"
                self._children_yang_names.add("bgp-flow-tag-policy-table")

                self.bgp_policy_accountings = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings()
                self.bgp_policy_accountings.parent = self
                self._children_name_map["bgp_policy_accountings"] = "bgp-policy-accountings"
                self._children_yang_names.add("bgp-policy-accountings")

                self.bgp_qos_policy_propagation = None
                self._children_name_map["bgp_qos_policy_propagation"] = "bgp-qos-policy-propagation"
                self._children_yang_names.add("bgp-qos-policy-propagation")

                self.verify = None
                self._children_name_map["verify"] = "verify"
                self._children_yang_names.add("verify")
                self._segment_path = lambda: "Cisco-IOS-XR-ipv6-ma-cfg:ipv6-network"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network, ['mtu', 'tcp_mss_adjust_enable', 'ttl_propagate_disable', 'unnumbered', 'unreachables'], name, value)


            class Addresses(Entity):
                """
                Set the IPv6 address of an interface
                
                .. attribute:: auto_configuration
                
                	Auto IPv6 Interface Configuration
                	**type**\:   :py:class:`AutoConfiguration <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration>`
                
                .. attribute:: eui64_addresses
                
                	EUI\-64 IPv6 address Table
                	**type**\:   :py:class:`Eui64Addresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses>`
                
                .. attribute:: link_local_address
                
                	Link local IPv6 address
                	**type**\:   :py:class:`LinkLocalAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.LinkLocalAddress>`
                
                	**presence node**\: True
                
                .. attribute:: regular_addresses
                
                	Regular IPv6 address Table
                	**type**\:   :py:class:`RegularAddresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses>`
                
                .. attribute:: segment_routings
                
                	Segment Routing Table
                	**type**\:   :py:class:`SegmentRoutings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings>`
                
                

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses, self).__init__()

                    self.yang_name = "addresses"
                    self.yang_parent_name = "ipv6-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"auto-configuration" : ("auto_configuration", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration), "eui64-addresses" : ("eui64_addresses", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses), "link-local-address" : ("link_local_address", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.LinkLocalAddress), "regular-addresses" : ("regular_addresses", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses), "segment-routings" : ("segment_routings", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings)}
                    self._child_list_classes = {}

                    self.auto_configuration = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration()
                    self.auto_configuration.parent = self
                    self._children_name_map["auto_configuration"] = "auto-configuration"
                    self._children_yang_names.add("auto-configuration")

                    self.eui64_addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses()
                    self.eui64_addresses.parent = self
                    self._children_name_map["eui64_addresses"] = "eui64-addresses"
                    self._children_yang_names.add("eui64-addresses")

                    self.link_local_address = None
                    self._children_name_map["link_local_address"] = "link-local-address"
                    self._children_yang_names.add("link-local-address")

                    self.regular_addresses = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses()
                    self.regular_addresses.parent = self
                    self._children_name_map["regular_addresses"] = "regular-addresses"
                    self._children_yang_names.add("regular-addresses")

                    self.segment_routings = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings()
                    self.segment_routings.parent = self
                    self._children_name_map["segment_routings"] = "segment-routings"
                    self._children_yang_names.add("segment-routings")
                    self._segment_path = lambda: "addresses"


                class AutoConfiguration(Entity):
                    """
                    Auto IPv6 Interface Configuration
                    
                    .. attribute:: auto_config_slaac
                    
                    	Enable slaac on Mgmt interface
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: enable
                    
                    	The flag to enable auto ipv6 interface configuration
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration, self).__init__()

                        self.yang_name = "auto-configuration"
                        self.yang_parent_name = "addresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.auto_config_slaac = YLeaf(YType.empty, "auto-config-slaac")

                        self.enable = YLeaf(YType.empty, "enable")
                        self._segment_path = lambda: "auto-configuration"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.AutoConfiguration, ['auto_config_slaac', 'enable'], name, value)


                class Eui64Addresses(Entity):
                    """
                    EUI\-64 IPv6 address Table
                    
                    .. attribute:: eui64_address
                    
                    	EUI\-64 IPv6 address
                    	**type**\: list of    :py:class:`Eui64Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses.Eui64Address>`
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses, self).__init__()

                        self.yang_name = "eui64-addresses"
                        self.yang_parent_name = "addresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"eui64-address" : ("eui64_address", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses.Eui64Address)}

                        self.eui64_address = YList(self)
                        self._segment_path = lambda: "eui64-addresses"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses, [], name, value)


                    class Eui64Address(Entity):
                        """
                        EUI\-64 IPv6 address
                        
                        .. attribute:: address  <key>
                        
                        	IPv6 address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        	**mandatory**\: True
                        
                        .. attribute:: route_tag
                        
                        	RouteTag
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: zone
                        
                        	IPv6 address zone
                        	**type**\:  str
                        
                        	**default value**\: 0
                        
                        

                        """

                        _prefix = 'ipv6-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses.Eui64Address, self).__init__()

                            self.yang_name = "eui64-address"
                            self.yang_parent_name = "eui64-addresses"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.route_tag = YLeaf(YType.uint32, "route-tag")

                            self.zone = YLeaf(YType.str, "zone")
                            self._segment_path = lambda: "eui64-address" + "[address='" + self.address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.Eui64Addresses.Eui64Address, ['address', 'prefix_length', 'route_tag', 'zone'], name, value)


                class LinkLocalAddress(Entity):
                    """
                    Link local IPv6 address
                    
                    .. attribute:: address
                    
                    	IPv6 address
                    	**type**\: one of the below types:
                    
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    
                    ----
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    
                    ----
                    .. attribute:: route_tag
                    
                    	RouteTag
                    	**type**\:  int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: zone
                    
                    	IPv6 address zone
                    	**type**\:  str
                    
                    	**default value**\: 0
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.LinkLocalAddress, self).__init__()

                        self.yang_name = "link-local-address"
                        self.yang_parent_name = "addresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.address = YLeaf(YType.str, "address")

                        self.route_tag = YLeaf(YType.uint32, "route-tag")

                        self.zone = YLeaf(YType.str, "zone")
                        self._segment_path = lambda: "link-local-address"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.LinkLocalAddress, ['address', 'route_tag', 'zone'], name, value)


                class RegularAddresses(Entity):
                    """
                    Regular IPv6 address Table
                    
                    .. attribute:: regular_address
                    
                    	Regular IPv6 address
                    	**type**\: list of    :py:class:`RegularAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses.RegularAddress>`
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses, self).__init__()

                        self.yang_name = "regular-addresses"
                        self.yang_parent_name = "addresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"regular-address" : ("regular_address", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses.RegularAddress)}

                        self.regular_address = YList(self)
                        self._segment_path = lambda: "regular-addresses"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses, [], name, value)


                    class RegularAddress(Entity):
                        """
                        Regular IPv6 address
                        
                        .. attribute:: address  <key>
                        
                        	IPv6 address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: prefix_length
                        
                        	Prefix Length
                        	**type**\:  int
                        
                        	**range:** 0..128
                        
                        	**mandatory**\: True
                        
                        .. attribute:: route_tag
                        
                        	RouteTag
                        	**type**\:  int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: zone
                        
                        	IPv6 address zone
                        	**type**\:  str
                        
                        	**default value**\: 0
                        
                        

                        """

                        _prefix = 'ipv6-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses.RegularAddress, self).__init__()

                            self.yang_name = "regular-address"
                            self.yang_parent_name = "regular-addresses"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                            self.route_tag = YLeaf(YType.uint32, "route-tag")

                            self.zone = YLeaf(YType.str, "zone")
                            self._segment_path = lambda: "regular-address" + "[address='" + self.address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.RegularAddresses.RegularAddress, ['address', 'prefix_length', 'route_tag', 'zone'], name, value)


                class SegmentRoutings(Entity):
                    """
                    Segment Routing Table
                    
                    .. attribute:: segment_routing
                    
                    	Segment Routing Submode 
                    	**type**\: list of    :py:class:`SegmentRouting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting>`
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings, self).__init__()

                        self.yang_name = "segment-routings"
                        self.yang_parent_name = "addresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"segment-routing" : ("segment_routing", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting)}

                        self.segment_routing = YList(self)
                        self._segment_path = lambda: "segment-routings"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings, [], name, value)


                    class SegmentRouting(Entity):
                        """
                        Segment Routing Submode 
                        
                        .. attribute:: address  <key>
                        
                        	IPv6 address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: enable
                        
                        	Segment Routing Submode
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: ipv6_prefix_sid
                        
                        	Prefix\-Sid for Segment Routing
                        	**type**\:   :py:class:`Ipv6PrefixSid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting.Ipv6PrefixSid>`
                        
                        	**presence node**\: True
                        
                        

                        """

                        _prefix = 'ipv6-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting, self).__init__()

                            self.yang_name = "segment-routing"
                            self.yang_parent_name = "segment-routings"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"ipv6-prefix-sid" : ("ipv6_prefix_sid", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting.Ipv6PrefixSid)}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.enable = YLeaf(YType.empty, "enable")

                            self.ipv6_prefix_sid = None
                            self._children_name_map["ipv6_prefix_sid"] = "ipv6-prefix-sid"
                            self._children_yang_names.add("ipv6-prefix-sid")
                            self._segment_path = lambda: "segment-routing" + "[address='" + self.address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting, ['address', 'enable'], name, value)


                        class Ipv6PrefixSid(Entity):
                            """
                            Prefix\-Sid for Segment Routing
                            
                            .. attribute:: prefix_length
                            
                            	Prefix Length
                            	**type**\:  int
                            
                            	**range:** 0..128
                            
                            	**mandatory**\: True
                            
                            .. attribute:: route_tag
                            
                            	RouteTag
                            	**type**\:  int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: zone
                            
                            	IPv6 address zone
                            	**type**\:  str
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ipv6-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting.Ipv6PrefixSid, self).__init__()

                                self.yang_name = "ipv6-prefix-sid"
                                self.yang_parent_name = "segment-routing"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.prefix_length = YLeaf(YType.uint32, "prefix-length")

                                self.route_tag = YLeaf(YType.uint32, "route-tag")

                                self.zone = YLeaf(YType.str, "zone")
                                self._segment_path = lambda: "ipv6-prefix-sid"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Addresses.SegmentRoutings.SegmentRouting.Ipv6PrefixSid, ['prefix_length', 'route_tag', 'zone'], name, value)


            class BgpFlowTagPolicyTable(Entity):
                """
                Interface ipv6 bgp policy propagation flowtag
                configuration
                
                .. attribute:: bgp_flow_tag_policy
                
                	Input
                	**type**\:   :py:class:`BgpFlowTagPolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy>`
                
                

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable, self).__init__()

                    self.yang_name = "bgp-flow-tag-policy-table"
                    self.yang_parent_name = "ipv6-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"bgp-flow-tag-policy" : ("bgp_flow_tag_policy", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy)}
                    self._child_list_classes = {}

                    self.bgp_flow_tag_policy = InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy()
                    self.bgp_flow_tag_policy.parent = self
                    self._children_name_map["bgp_flow_tag_policy"] = "bgp-flow-tag-policy"
                    self._children_yang_names.add("bgp-flow-tag-policy")
                    self._segment_path = lambda: "bgp-flow-tag-policy-table"


                class BgpFlowTagPolicy(Entity):
                    """
                    Input
                    
                    .. attribute:: destination
                    
                    	Flow Tag configuration on destination
                    	**type**\:  bool
                    
                    .. attribute:: source
                    
                    	Flow Tag configuration on source
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy, self).__init__()

                        self.yang_name = "bgp-flow-tag-policy"
                        self.yang_parent_name = "bgp-flow-tag-policy-table"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.destination = YLeaf(YType.boolean, "destination")

                        self.source = YLeaf(YType.boolean, "source")
                        self._segment_path = lambda: "bgp-flow-tag-policy"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpFlowTagPolicyTable.BgpFlowTagPolicy, ['destination', 'source'], name, value)


            class BgpPolicyAccountings(Entity):
                """
                IPv6 BGP Policy Accounting
                
                .. attribute:: bgp_policy_accounting
                
                	Accounting input or output
                	**type**\: list of    :py:class:`BgpPolicyAccounting <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings.BgpPolicyAccounting>`
                
                

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings, self).__init__()

                    self.yang_name = "bgp-policy-accountings"
                    self.yang_parent_name = "ipv6-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"bgp-policy-accounting" : ("bgp_policy_accounting", InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings.BgpPolicyAccounting)}

                    self.bgp_policy_accounting = YList(self)
                    self._segment_path = lambda: "bgp-policy-accountings"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings, [], name, value)


                class BgpPolicyAccounting(Entity):
                    """
                    Accounting input or output
                    
                    .. attribute:: direction  <key>
                    
                    	Accouting on input or output
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: destination_accounting
                    
                    	Accounting on Destination IP Address
                    	**type**\:  bool
                    
                    	**mandatory**\: True
                    
                    .. attribute:: source_accounting
                    
                    	Accounting on Source IP Address
                    	**type**\:  bool
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'ipv6-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings.BgpPolicyAccounting, self).__init__()

                        self.yang_name = "bgp-policy-accounting"
                        self.yang_parent_name = "bgp-policy-accountings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.direction = YLeaf(YType.str, "direction")

                        self.destination_accounting = YLeaf(YType.boolean, "destination-accounting")

                        self.source_accounting = YLeaf(YType.boolean, "source-accounting")
                        self._segment_path = lambda: "bgp-policy-accounting" + "[direction='" + self.direction.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpPolicyAccountings.BgpPolicyAccounting, ['direction', 'destination_accounting', 'source_accounting'], name, value)


            class BgpQosPolicyPropagation(Entity):
                """
                Configure BGP QoS policy propagation
                
                .. attribute:: destination
                
                	QPPB configuration on destination
                	**type**\:   :py:class:`Ipv6Qppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6Qppb>`
                
                	**mandatory**\: True
                
                .. attribute:: source
                
                	QPPB configuration on source
                	**type**\:   :py:class:`Ipv6Qppb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6Qppb>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpQosPolicyPropagation, self).__init__()

                    self.yang_name = "bgp-qos-policy-propagation"
                    self.yang_parent_name = "ipv6-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.destination = YLeaf(YType.enumeration, "destination")

                    self.source = YLeaf(YType.enumeration, "source")
                    self._segment_path = lambda: "bgp-qos-policy-propagation"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.BgpQosPolicyPropagation, ['destination', 'source'], name, value)


            class Verify(Entity):
                """
                IPv6 Verify Unicast Souce Reachable
                
                .. attribute:: default_ping
                
                	Allow Default Route
                	**type**\:   :py:class:`Ipv6DefaultPing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6DefaultPing>`
                
                	**mandatory**\: True
                
                .. attribute:: reachable
                
                	Source Reachable Interface
                	**type**\:   :py:class:`Ipv6Reachable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6Reachable>`
                
                	**mandatory**\: True
                
                .. attribute:: self_ping
                
                	Allow Self Ping
                	**type**\:   :py:class:`Ipv6SelfPing <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ipv6_ma_cfg.Ipv6SelfPing>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'ipv6-ma-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Verify, self).__init__()

                    self.yang_name = "verify"
                    self.yang_parent_name = "ipv6-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.default_ping = YLeaf(YType.enumeration, "default-ping")

                    self.reachable = YLeaf(YType.enumeration, "reachable")

                    self.self_ping = YLeaf(YType.enumeration, "self-ping")
                    self._segment_path = lambda: "verify"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6Network.Verify, ['default_ping', 'reachable', 'self_ping'], name, value)


        class Ipv6PacketFilter(Entity):
            """
            IPv6 Packet Filtering configuration for the
            interface
            
            .. attribute:: inbound
            
            	IPv6 Packet filter to be applied to inbound packets
            	**type**\:   :py:class:`Inbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound>`
            
            .. attribute:: outbound
            
            	IPv6 Packet filter to be applied to outbound packets
            	**type**\:   :py:class:`Outbound <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound>`
            
            

            """

            _prefix = 'ip-pfilter-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter, self).__init__()

                self.yang_name = "ipv6-packet-filter"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"inbound" : ("inbound", InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound), "outbound" : ("outbound", InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound)}
                self._child_list_classes = {}

                self.inbound = InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound()
                self.inbound.parent = self
                self._children_name_map["inbound"] = "inbound"
                self._children_yang_names.add("inbound")

                self.outbound = InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound()
                self.outbound.parent = self
                self._children_name_map["outbound"] = "outbound"
                self._children_yang_names.add("outbound")
                self._segment_path = lambda: "Cisco-IOS-XR-ip-pfilter-cfg:ipv6-packet-filter"


            class Inbound(Entity):
                """
                IPv6 Packet filter to be applied to inbound
                packets
                
                .. attribute:: acl_name_array
                
                	Array of IPv6 Packet Filter Names to be applied to Inbound packets
                	**type**\:  list of str
                
                	**length:** 1..65
                
                .. attribute:: common_acl_name
                
                	Reserved for backward compatibility. IPv6 Packet Filter Name to be applied to Inbound packets, ACL providing HW optimization when applied on multiple interfaces. NOTE\: This parameter is mandatory if 'Name' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                .. attribute:: compression_level
                
                	The level of compression applied to the ACL on this interface. The range is 0 to 3 with default being no compression (0)
                	**type**\:  int
                
                	**range:** 0..3
                
                .. attribute:: interface_statistics
                
                	True if packets hitting the ACL should be counted in hardware per interface.The default is not to count them. NOTE\: InterfaceStatistics is allowed only if Name is specified
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: is_common_array
                
                	Array of CommonACL flags for each ACL. TRUE indicates HW optimization on multiple interfaces is provided
                	**type**\:  list of bool
                
                .. attribute:: name
                
                	Reserved for backward compatibility. IPv6 Packet Filter Name to be applied to Inbound  NOTE\: This parameter is mandatory if 'CommonACLName' is not specified
                	**type**\:  str
                
                	**length:** 1..65
                
                

                """

                _prefix = 'ip-pfilter-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound, self).__init__()

                    self.yang_name = "inbound"
                    self.yang_parent_name = "ipv6-packet-filter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.acl_name_array = YLeafList(YType.str, "acl-name-array")

                    self.common_acl_name = YLeaf(YType.str, "common-acl-name")

                    self.compression_level = YLeaf(YType.uint32, "compression-level")

                    self.interface_statistics = YLeaf(YType.empty, "interface-statistics")

                    self.is_common_array = YLeafList(YType.boolean, "is-common-array")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "inbound"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Inbound, ['acl_name_array', 'common_acl_name', 'compression_level', 'interface_statistics', 'is_common_array', 'name'], name, value)


            class Outbound(Entity):
                """
                IPv6 Packet filter to be applied to outbound
                packets
                
                .. attribute:: acl_name_array
                
                	Array of IPv6 Packet Filter Names to be applied to Inbound packets
                	**type**\:  list of str
                
                	**length:** 1..65
                
                .. attribute:: compression_level
                
                	The level of compression applied to the ACL on this interface. The range is 0 to 3 with default being no compression (0)
                	**type**\:  int
                
                	**range:** 0..3
                
                .. attribute:: do_not_use
                
                	Reserved.  Error if specified
                	**type**\:  str
                
                	**length:** 1..65
                
                .. attribute:: interface_statistics
                
                	True if packets hitting the ACL should be counted in hardware per interface.The default is not to count them
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: is_common_array
                
                	Array of CommonACL flags for each ACL. TRUE indicates HW optimization on multiple interfaces is provided
                	**type**\:  list of bool
                
                .. attribute:: name
                
                	Reserved for backward compatibility. IPv6 Packet Filter Name to be applied to Outbound  packets
                	**type**\:  str
                
                	**length:** 1..65
                
                

                """

                _prefix = 'ip-pfilter-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound, self).__init__()

                    self.yang_name = "outbound"
                    self.yang_parent_name = "ipv6-packet-filter"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.acl_name_array = YLeafList(YType.str, "acl-name-array")

                    self.compression_level = YLeaf(YType.uint32, "compression-level")

                    self.do_not_use = YLeaf(YType.str, "do-not-use")

                    self.interface_statistics = YLeaf(YType.empty, "interface-statistics")

                    self.is_common_array = YLeafList(YType.boolean, "is-common-array")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "outbound"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ipv6PacketFilter.Outbound, ['acl_name_array', 'compression_level', 'do_not_use', 'interface_statistics', 'is_common_array', 'name'], name, value)


        class L2Transport(Entity):
            """
            Interface Layer 2 Transport service
            configuration data
            
            .. attribute:: atm_port_mode_parameters
            
            	ATM L2transport Port Mode Parameters Configuration
            	**type**\:   :py:class:`AtmPortModeParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters>`
            
            .. attribute:: cac
            
            	Connection Attachment Circuit configuration
            	**type**\:   :py:class:`Cac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac>`
            
            .. attribute:: enabled
            
            	This object is only valid on physical interfaces and it controls whether that interface is a port mode Layer 2 attachment circuit (note that for subinterfaces, the Layer 2 property is specified when the subinterface is created).The object must be set before any other L2Transport configuration is supplied for the interface, and must be the last per\-interface configuration object to be removed
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: l2_ethernet_features
            
            	L2 Ethernet Features Configuration
            	**type**\:   :py:class:`L2EthernetFeatures <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures>`
            
            .. attribute:: l2_protocols
            
            	Interface specific Layer 2 protocol handling
            	**type**\:   :py:class:`L2Protocols <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols>`
            
            .. attribute:: pac
            
            	Port Attachment Circuit configuration
            	**type**\:   :py:class:`Pac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac>`
            
            .. attribute:: propagate_remote_status
            
            	Enable propagation of the remote attachment\-circuit link state to the localattachment\-circuit link state
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: span_monitor_sessions
            
            	Monitor Session container for this source interface
            	**type**\:   :py:class:`SpanMonitorSessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions>`
            
            

            """

            _prefix = 'l2vpn-cfg'
            _revision = '2017-06-26'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport, self).__init__()

                self.yang_name = "l2-transport"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"atm-port-mode-parameters" : ("atm_port_mode_parameters", InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters), "cac" : ("cac", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac), "l2-ethernet-features" : ("l2_ethernet_features", InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures), "l2-protocols" : ("l2_protocols", InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols), "pac" : ("pac", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac), "span-monitor-sessions" : ("span_monitor_sessions", InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions)}
                self._child_list_classes = {}

                self.enabled = YLeaf(YType.empty, "enabled")

                self.propagate_remote_status = YLeaf(YType.empty, "Cisco-IOS-XR-l2-eth-infra-cfg:propagate-remote-status")

                self.atm_port_mode_parameters = InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters()
                self.atm_port_mode_parameters.parent = self
                self._children_name_map["atm_port_mode_parameters"] = "atm-port-mode-parameters"
                self._children_yang_names.add("atm-port-mode-parameters")

                self.cac = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac()
                self.cac.parent = self
                self._children_name_map["cac"] = "cac"
                self._children_yang_names.add("cac")

                self.l2_ethernet_features = InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures()
                self.l2_ethernet_features.parent = self
                self._children_name_map["l2_ethernet_features"] = "l2-ethernet-features"
                self._children_yang_names.add("l2-ethernet-features")

                self.l2_protocols = InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols()
                self.l2_protocols.parent = self
                self._children_name_map["l2_protocols"] = "l2-protocols"
                self._children_yang_names.add("l2-protocols")

                self.pac = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac()
                self.pac.parent = self
                self._children_name_map["pac"] = "pac"
                self._children_yang_names.add("pac")

                self.span_monitor_sessions = InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions()
                self.span_monitor_sessions.parent = self
                self._children_name_map["span_monitor_sessions"] = "span-monitor-sessions"
                self._children_yang_names.add("span-monitor-sessions")
                self._segment_path = lambda: "Cisco-IOS-XR-l2vpn-cfg:l2-transport"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport, ['enabled', 'propagate_remote_status'], name, value)


            class AtmPortModeParameters(Entity):
                """
                ATM L2transport Port Mode Parameters
                Configuration
                
                .. attribute:: cell_packing
                
                	Configure cell\-packing parameters.  All parameters are mandatory
                	**type**\:   :py:class:`CellPacking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters.CellPacking>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'atm-vcm-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters, self).__init__()

                    self.yang_name = "atm-port-mode-parameters"
                    self.yang_parent_name = "l2-transport"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"cell-packing" : ("cell_packing", InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters.CellPacking)}
                    self._child_list_classes = {}

                    self.cell_packing = None
                    self._children_name_map["cell_packing"] = "cell-packing"
                    self._children_yang_names.add("cell-packing")
                    self._segment_path = lambda: "Cisco-IOS-XR-atm-vcm-cfg:atm-port-mode-parameters"


                class CellPacking(Entity):
                    """
                    Configure cell\-packing parameters.  All
                    parameters are mandatory.
                    
                    .. attribute:: cell_packing_timer_id
                    
                    	Which cell packing timer to use
                    	**type**\:  int
                    
                    	**range:** 1..3
                    
                    	**mandatory**\: True
                    
                    .. attribute:: maximum_cells_packed
                    
                    	Maximum number of cells to be packed in a packet
                    	**type**\:  int
                    
                    	**range:** 2..255
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'atm-vcm-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters.CellPacking, self).__init__()

                        self.yang_name = "cell-packing"
                        self.yang_parent_name = "atm-port-mode-parameters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.cell_packing_timer_id = YLeaf(YType.uint32, "cell-packing-timer-id")

                        self.maximum_cells_packed = YLeaf(YType.uint32, "maximum-cells-packed")
                        self._segment_path = lambda: "cell-packing"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.AtmPortModeParameters.CellPacking, ['cell_packing_timer_id', 'maximum_cells_packed'], name, value)


            class Cac(Entity):
                """
                Connection Attachment Circuit configuration.
                
                .. attribute:: qos
                
                	Interface QOS configuration
                	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos>`
                
                

                """

                _prefix = 'qos-ma-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac, self).__init__()

                    self.yang_name = "cac"
                    self.yang_parent_name = "l2-transport"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"qos" : ("qos", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos)}
                    self._child_list_classes = {}

                    self.qos = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._children_yang_names.add("qos")
                    self._segment_path = lambda: "Cisco-IOS-XR-qos-ma-cfg:cac"


                class Qos(Entity):
                    """
                    Interface QOS configuration
                    
                    .. attribute:: input
                    
                    	Ingress service policy
                    	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input>`
                    
                    .. attribute:: output
                    
                    	Egress service policy
                    	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output>`
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "cac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"input" : ("input", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input), "output" : ("output", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output)}
                        self._child_list_classes = {}

                        self.input = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._children_yang_names.add("input")

                        self.output = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output()
                        self.output.parent = self
                        self._children_name_map["output"] = "output"
                        self._children_yang_names.add("output")
                        self._segment_path = lambda: "qos"


                    class Input(Entity):
                        """
                        Ingress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicy>`
                        
                        .. attribute:: service_policy_qos
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicy), "service-policy-qos" : ("service_policy_qos", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos)}

                            self.service_policy = YList(self)
                            self.service_policy_qos = YList(self)
                            self._segment_path = lambda: "input"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input, [], name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	service\-fragment\-parent\-policy
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicy, ['service_policy_name', 'account_type', 'l1_user_defined', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                        class ServicePolicyQos(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: subscriber_group_names
                            
                            	Subscriber Group Name Details
                            	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames>`
                            
                            .. attribute:: subscriber_parent
                            
                            	Subscriber Parent Details
                            	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent>`
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos, self).__init__()

                                self.yang_name = "service-policy-qos"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"subscriber-group-names" : ("subscriber_group_names", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames), "subscriber-parent" : ("subscriber_parent", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent)}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                self._children_yang_names.add("subscriber-group-names")

                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                self._children_yang_names.add("subscriber-parent")
                                self._segment_path = lambda: "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos, ['service_policy_name'], name, value)


                            class SubscriberGroupNames(Entity):
                                """
                                Subscriber Group Name Details
                                
                                .. attribute:: subscriber_group_name
                                
                                	Subscriber Group details
                                	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                                    self.yang_name = "subscriber-group-names"
                                    self.yang_parent_name = "service-policy-qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"subscriber-group-name" : ("subscriber_group_name", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName)}

                                    self.subscriber_group_name = YList(self)
                                    self._segment_path = lambda: "subscriber-group-names"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, [], name, value)


                                class SubscriberGroupName(Entity):
                                    """
                                    Subscriber Group details
                                    
                                    .. attribute:: subscriber_group_string  <key>
                                    
                                    	Name of policy\-map
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: account_type
                                    
                                    	Turn off L2 or L3 accounting
                                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                    
                                    .. attribute:: l1_user_defined
                                    
                                    	User specified value
                                    	**type**\:  int
                                    
                                    	**range:** \-63..63
                                    
                                    .. attribute:: policy_merge
                                    
                                    	Not supported (Leave unspecified)
                                    	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                    
                                    .. attribute:: resource_id
                                    
                                    	Resource ID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..3
                                    
                                    .. attribute:: service_fragment_parent_policy
                                    
                                    	TRUE if service\-policy applied is a service\-fragment policy)
                                    	**type**\:  bool
                                    
                                    .. attribute:: spi_name
                                    
                                    	Name of the SPI
                                    	**type**\:  str
                                    
                                    .. attribute:: subscriber_parent_policy
                                    
                                    	TRUE if service\-policy applied on svlan
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'qos-ma-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                        self.yang_name = "subscriber-group-name"
                                        self.yang_parent_name = "subscriber-group-names"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                        self.account_type = YLeaf(YType.enumeration, "account-type")

                                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                        self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                        self.spi_name = YLeaf(YType.str, "spi-name")

                                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                        self._segment_path = lambda: "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, ['subscriber_group_string', 'account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                            class SubscriberParent(Entity):
                                """
                                Subscriber Parent Details
                                
                                .. attribute:: account_type
                                
                                	Turn off L2 or L3 accounting
                                	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                
                                .. attribute:: l1_user_defined
                                
                                	User specified value
                                	**type**\:  int
                                
                                	**range:** \-63..63
                                
                                .. attribute:: policy_merge
                                
                                	Not supported (Leave unspecified)
                                	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                
                                .. attribute:: resource_id
                                
                                	Resource ID value
                                	**type**\:  int
                                
                                	**range:** 0..3
                                
                                .. attribute:: service_fragment_parent_policy
                                
                                	TRUE if service\-policy applied is a service\-fragment policy)
                                	**type**\:  bool
                                
                                .. attribute:: spi_name
                                
                                	Name of the SPI
                                	**type**\:  str
                                
                                .. attribute:: subscriber_parent_policy
                                
                                	TRUE if service\-policy applied on svlan
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent, self).__init__()

                                    self.yang_name = "subscriber-parent"
                                    self.yang_parent_name = "service-policy-qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.account_type = YLeaf(YType.enumeration, "account-type")

                                    self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                    self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                    self.resource_id = YLeaf(YType.uint32, "resource-id")

                                    self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                    self.spi_name = YLeaf(YType.str, "spi-name")

                                    self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                    self._segment_path = lambda: "subscriber-parent"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Input.ServicePolicyQos.SubscriberParent, ['account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                    class Output(Entity):
                        """
                        Egress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicy>`
                        
                        .. attribute:: service_policy_qos
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output, self).__init__()

                            self.yang_name = "output"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicy), "service-policy-qos" : ("service_policy_qos", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos)}

                            self.service_policy = YList(self)
                            self.service_policy_qos = YList(self)
                            self._segment_path = lambda: "output"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output, [], name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	service\-fragment\-parent\-policy
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "output"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicy, ['service_policy_name', 'account_type', 'l1_user_defined', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                        class ServicePolicyQos(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: subscriber_group_names
                            
                            	Subscriber Group Name Details
                            	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames>`
                            
                            .. attribute:: subscriber_parent
                            
                            	Subscriber Parent Details
                            	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent>`
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos, self).__init__()

                                self.yang_name = "service-policy-qos"
                                self.yang_parent_name = "output"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"subscriber-group-names" : ("subscriber_group_names", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames), "subscriber-parent" : ("subscriber_parent", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent)}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                self._children_yang_names.add("subscriber-group-names")

                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                self._children_yang_names.add("subscriber-parent")
                                self._segment_path = lambda: "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos, ['service_policy_name'], name, value)


                            class SubscriberGroupNames(Entity):
                                """
                                Subscriber Group Name Details
                                
                                .. attribute:: subscriber_group_name
                                
                                	Subscriber Group details
                                	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                                    self.yang_name = "subscriber-group-names"
                                    self.yang_parent_name = "service-policy-qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"subscriber-group-name" : ("subscriber_group_name", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName)}

                                    self.subscriber_group_name = YList(self)
                                    self._segment_path = lambda: "subscriber-group-names"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, [], name, value)


                                class SubscriberGroupName(Entity):
                                    """
                                    Subscriber Group details
                                    
                                    .. attribute:: subscriber_group_string  <key>
                                    
                                    	Name of policy\-map
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: account_type
                                    
                                    	Turn off L2 or L3 accounting
                                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                    
                                    .. attribute:: l1_user_defined
                                    
                                    	User specified value
                                    	**type**\:  int
                                    
                                    	**range:** \-63..63
                                    
                                    .. attribute:: policy_merge
                                    
                                    	Not supported (Leave unspecified)
                                    	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                    
                                    .. attribute:: resource_id
                                    
                                    	Resource ID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..3
                                    
                                    .. attribute:: service_fragment_parent_policy
                                    
                                    	TRUE if service\-policy applied is a service\-fragment policy)
                                    	**type**\:  bool
                                    
                                    .. attribute:: spi_name
                                    
                                    	Name of the SPI
                                    	**type**\:  str
                                    
                                    .. attribute:: subscriber_parent_policy
                                    
                                    	TRUE if service\-policy applied on svlan
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'qos-ma-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                        self.yang_name = "subscriber-group-name"
                                        self.yang_parent_name = "subscriber-group-names"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                        self.account_type = YLeaf(YType.enumeration, "account-type")

                                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                        self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                        self.spi_name = YLeaf(YType.str, "spi-name")

                                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                        self._segment_path = lambda: "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, ['subscriber_group_string', 'account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                            class SubscriberParent(Entity):
                                """
                                Subscriber Parent Details
                                
                                .. attribute:: account_type
                                
                                	Turn off L2 or L3 accounting
                                	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                
                                .. attribute:: l1_user_defined
                                
                                	User specified value
                                	**type**\:  int
                                
                                	**range:** \-63..63
                                
                                .. attribute:: policy_merge
                                
                                	Not supported (Leave unspecified)
                                	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                
                                .. attribute:: resource_id
                                
                                	Resource ID value
                                	**type**\:  int
                                
                                	**range:** 0..3
                                
                                .. attribute:: service_fragment_parent_policy
                                
                                	TRUE if service\-policy applied is a service\-fragment policy)
                                	**type**\:  bool
                                
                                .. attribute:: spi_name
                                
                                	Name of the SPI
                                	**type**\:  str
                                
                                .. attribute:: subscriber_parent_policy
                                
                                	TRUE if service\-policy applied on svlan
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent, self).__init__()

                                    self.yang_name = "subscriber-parent"
                                    self.yang_parent_name = "service-policy-qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.account_type = YLeaf(YType.enumeration, "account-type")

                                    self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                    self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                    self.resource_id = YLeaf(YType.uint32, "resource-id")

                                    self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                    self.spi_name = YLeaf(YType.str, "spi-name")

                                    self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                    self._segment_path = lambda: "subscriber-parent"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Cac.Qos.Output.ServicePolicyQos.SubscriberParent, ['account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


            class L2EthernetFeatures(Entity):
                """
                L2 Ethernet Features Configuration
                
                .. attribute:: egress_filtering
                
                	Egress Ethernet filtering
                	**type**\:   :py:class:`EgressFiltering <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_cfg.EgressFiltering>`
                
                	**default value**\: egress-filtering-type-default
                
                .. attribute:: source_bypass_egress_filtering
                
                	Mark all ingress packets to bypass any egress VLAN filter
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures, self).__init__()

                    self.yang_name = "l2-ethernet-features"
                    self.yang_parent_name = "l2-transport"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.egress_filtering = YLeaf(YType.enumeration, "egress-filtering")

                    self.source_bypass_egress_filtering = YLeaf(YType.empty, "source-bypass-egress-filtering")
                    self._segment_path = lambda: "Cisco-IOS-XR-l2-eth-infra-cfg:l2-ethernet-features"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2EthernetFeatures, ['egress_filtering', 'source_bypass_egress_filtering'], name, value)


            class L2Protocols(Entity):
                """
                Interface specific Layer 2 protocol handling
                
                .. attribute:: l2_protocol
                
                	Handling of a specific Layer 2 protocol
                	**type**\: list of    :py:class:`L2Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols.L2Protocol>`
                
                

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols, self).__init__()

                    self.yang_name = "l2-protocols"
                    self.yang_parent_name = "l2-transport"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"l2-protocol" : ("l2_protocol", InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols.L2Protocol)}

                    self.l2_protocol = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XR-l2-eth-infra-cfg:l2-protocols"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols, [], name, value)


                class L2Protocol(Entity):
                    """
                    Handling of a specific Layer 2 protocol
                    
                    .. attribute:: l2_protocol_name  <key>
                    
                    	Protocol name
                    	**type**\:   :py:class:`L2ProtocolName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_cfg.L2ProtocolName>`
                    
                    .. attribute:: mode
                    
                    	How to handle the protocol's packets
                    	**type**\:   :py:class:`L2ProtocolMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_cfg.L2ProtocolMode>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: mpls_exp_bits_value
                    
                    	The value to set the MPLS Exp bits to within the PW.This value may be specified if the mode is forward or tunnel and must not be specified if the mode is drop
                    	**type**\:  int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'l2-eth-infra-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols.L2Protocol, self).__init__()

                        self.yang_name = "l2-protocol"
                        self.yang_parent_name = "l2-protocols"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.l2_protocol_name = YLeaf(YType.enumeration, "l2-protocol-name")

                        self.mode = YLeaf(YType.enumeration, "mode")

                        self.mpls_exp_bits_value = YLeaf(YType.uint32, "mpls-exp-bits-value")
                        self._segment_path = lambda: "l2-protocol" + "[l2-protocol-name='" + self.l2_protocol_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.L2Protocols.L2Protocol, ['l2_protocol_name', 'mode', 'mpls_exp_bits_value'], name, value)


            class Pac(Entity):
                """
                Port Attachment Circuit configuration.
                
                .. attribute:: qos
                
                	Interface QOS configuration
                	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos>`
                
                

                """

                _prefix = 'qos-ma-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac, self).__init__()

                    self.yang_name = "pac"
                    self.yang_parent_name = "l2-transport"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"qos" : ("qos", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos)}
                    self._child_list_classes = {}

                    self.qos = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._children_yang_names.add("qos")
                    self._segment_path = lambda: "Cisco-IOS-XR-qos-ma-cfg:pac"


                class Qos(Entity):
                    """
                    Interface QOS configuration
                    
                    .. attribute:: input
                    
                    	Ingress service policy
                    	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input>`
                    
                    .. attribute:: output
                    
                    	Egress service policy
                    	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output>`
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "pac"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"input" : ("input", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input), "output" : ("output", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output)}
                        self._child_list_classes = {}

                        self.input = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._children_yang_names.add("input")

                        self.output = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output()
                        self.output.parent = self
                        self._children_name_map["output"] = "output"
                        self._children_yang_names.add("output")
                        self._segment_path = lambda: "qos"


                    class Input(Entity):
                        """
                        Ingress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicy>`
                        
                        .. attribute:: service_policy_qos
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicy), "service-policy-qos" : ("service_policy_qos", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos)}

                            self.service_policy = YList(self)
                            self.service_policy_qos = YList(self)
                            self._segment_path = lambda: "input"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input, [], name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	service\-fragment\-parent\-policy
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicy, ['service_policy_name', 'account_type', 'l1_user_defined', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                        class ServicePolicyQos(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: subscriber_group_names
                            
                            	Subscriber Group Name Details
                            	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames>`
                            
                            .. attribute:: subscriber_parent
                            
                            	Subscriber Parent Details
                            	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent>`
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos, self).__init__()

                                self.yang_name = "service-policy-qos"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"subscriber-group-names" : ("subscriber_group_names", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames), "subscriber-parent" : ("subscriber_parent", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent)}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                self._children_yang_names.add("subscriber-group-names")

                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                self._children_yang_names.add("subscriber-parent")
                                self._segment_path = lambda: "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos, ['service_policy_name'], name, value)


                            class SubscriberGroupNames(Entity):
                                """
                                Subscriber Group Name Details
                                
                                .. attribute:: subscriber_group_name
                                
                                	Subscriber Group details
                                	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                                    self.yang_name = "subscriber-group-names"
                                    self.yang_parent_name = "service-policy-qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"subscriber-group-name" : ("subscriber_group_name", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName)}

                                    self.subscriber_group_name = YList(self)
                                    self._segment_path = lambda: "subscriber-group-names"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames, [], name, value)


                                class SubscriberGroupName(Entity):
                                    """
                                    Subscriber Group details
                                    
                                    .. attribute:: subscriber_group_string  <key>
                                    
                                    	Name of policy\-map
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: account_type
                                    
                                    	Turn off L2 or L3 accounting
                                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                    
                                    .. attribute:: l1_user_defined
                                    
                                    	User specified value
                                    	**type**\:  int
                                    
                                    	**range:** \-63..63
                                    
                                    .. attribute:: policy_merge
                                    
                                    	Not supported (Leave unspecified)
                                    	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                    
                                    .. attribute:: resource_id
                                    
                                    	Resource ID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..3
                                    
                                    .. attribute:: service_fragment_parent_policy
                                    
                                    	TRUE if service\-policy applied is a service\-fragment policy)
                                    	**type**\:  bool
                                    
                                    .. attribute:: spi_name
                                    
                                    	Name of the SPI
                                    	**type**\:  str
                                    
                                    .. attribute:: subscriber_parent_policy
                                    
                                    	TRUE if service\-policy applied on svlan
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'qos-ma-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                        self.yang_name = "subscriber-group-name"
                                        self.yang_parent_name = "subscriber-group-names"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                        self.account_type = YLeaf(YType.enumeration, "account-type")

                                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                        self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                        self.spi_name = YLeaf(YType.str, "spi-name")

                                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                        self._segment_path = lambda: "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, ['subscriber_group_string', 'account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                            class SubscriberParent(Entity):
                                """
                                Subscriber Parent Details
                                
                                .. attribute:: account_type
                                
                                	Turn off L2 or L3 accounting
                                	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                
                                .. attribute:: l1_user_defined
                                
                                	User specified value
                                	**type**\:  int
                                
                                	**range:** \-63..63
                                
                                .. attribute:: policy_merge
                                
                                	Not supported (Leave unspecified)
                                	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                
                                .. attribute:: resource_id
                                
                                	Resource ID value
                                	**type**\:  int
                                
                                	**range:** 0..3
                                
                                .. attribute:: service_fragment_parent_policy
                                
                                	TRUE if service\-policy applied is a service\-fragment policy)
                                	**type**\:  bool
                                
                                .. attribute:: spi_name
                                
                                	Name of the SPI
                                	**type**\:  str
                                
                                .. attribute:: subscriber_parent_policy
                                
                                	TRUE if service\-policy applied on svlan
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent, self).__init__()

                                    self.yang_name = "subscriber-parent"
                                    self.yang_parent_name = "service-policy-qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.account_type = YLeaf(YType.enumeration, "account-type")

                                    self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                    self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                    self.resource_id = YLeaf(YType.uint32, "resource-id")

                                    self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                    self.spi_name = YLeaf(YType.str, "spi-name")

                                    self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                    self._segment_path = lambda: "subscriber-parent"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Input.ServicePolicyQos.SubscriberParent, ['account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                    class Output(Entity):
                        """
                        Egress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicy>`
                        
                        .. attribute:: service_policy_qos
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output, self).__init__()

                            self.yang_name = "output"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicy), "service-policy-qos" : ("service_policy_qos", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos)}

                            self.service_policy = YList(self)
                            self.service_policy_qos = YList(self)
                            self._segment_path = lambda: "output"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output, [], name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	service\-fragment\-parent\-policy
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "output"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicy, ['service_policy_name', 'account_type', 'l1_user_defined', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                        class ServicePolicyQos(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: subscriber_group_names
                            
                            	Subscriber Group Name Details
                            	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames>`
                            
                            .. attribute:: subscriber_parent
                            
                            	Subscriber Parent Details
                            	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent>`
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos, self).__init__()

                                self.yang_name = "service-policy-qos"
                                self.yang_parent_name = "output"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"subscriber-group-names" : ("subscriber_group_names", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames), "subscriber-parent" : ("subscriber_parent", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent)}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                                self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames()
                                self.subscriber_group_names.parent = self
                                self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                                self._children_yang_names.add("subscriber-group-names")

                                self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent()
                                self.subscriber_parent.parent = self
                                self._children_name_map["subscriber_parent"] = "subscriber-parent"
                                self._children_yang_names.add("subscriber-parent")
                                self._segment_path = lambda: "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos, ['service_policy_name'], name, value)


                            class SubscriberGroupNames(Entity):
                                """
                                Subscriber Group Name Details
                                
                                .. attribute:: subscriber_group_name
                                
                                	Subscriber Group details
                                	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                                    self.yang_name = "subscriber-group-names"
                                    self.yang_parent_name = "service-policy-qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"subscriber-group-name" : ("subscriber_group_name", InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName)}

                                    self.subscriber_group_name = YList(self)
                                    self._segment_path = lambda: "subscriber-group-names"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames, [], name, value)


                                class SubscriberGroupName(Entity):
                                    """
                                    Subscriber Group details
                                    
                                    .. attribute:: subscriber_group_string  <key>
                                    
                                    	Name of policy\-map
                                    	**type**\:  str
                                    
                                    	**length:** 0..64
                                    
                                    .. attribute:: account_type
                                    
                                    	Turn off L2 or L3 accounting
                                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                    
                                    .. attribute:: l1_user_defined
                                    
                                    	User specified value
                                    	**type**\:  int
                                    
                                    	**range:** \-63..63
                                    
                                    .. attribute:: policy_merge
                                    
                                    	Not supported (Leave unspecified)
                                    	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                    
                                    .. attribute:: resource_id
                                    
                                    	Resource ID value
                                    	**type**\:  int
                                    
                                    	**range:** 0..3
                                    
                                    .. attribute:: service_fragment_parent_policy
                                    
                                    	TRUE if service\-policy applied is a service\-fragment policy)
                                    	**type**\:  bool
                                    
                                    .. attribute:: spi_name
                                    
                                    	Name of the SPI
                                    	**type**\:  str
                                    
                                    .. attribute:: subscriber_parent_policy
                                    
                                    	TRUE if service\-policy applied on svlan
                                    	**type**\:  bool
                                    
                                    

                                    """

                                    _prefix = 'qos-ma-cfg'
                                    _revision = '2017-05-01'

                                    def __init__(self):
                                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                        self.yang_name = "subscriber-group-name"
                                        self.yang_parent_name = "subscriber-group-names"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                        self.account_type = YLeaf(YType.enumeration, "account-type")

                                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                        self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                        self.spi_name = YLeaf(YType.str, "spi-name")

                                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                        self._segment_path = lambda: "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, ['subscriber_group_string', 'account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                            class SubscriberParent(Entity):
                                """
                                Subscriber Parent Details
                                
                                .. attribute:: account_type
                                
                                	Turn off L2 or L3 accounting
                                	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                                
                                .. attribute:: l1_user_defined
                                
                                	User specified value
                                	**type**\:  int
                                
                                	**range:** \-63..63
                                
                                .. attribute:: policy_merge
                                
                                	Not supported (Leave unspecified)
                                	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                                
                                .. attribute:: resource_id
                                
                                	Resource ID value
                                	**type**\:  int
                                
                                	**range:** 0..3
                                
                                .. attribute:: service_fragment_parent_policy
                                
                                	TRUE if service\-policy applied is a service\-fragment policy)
                                	**type**\:  bool
                                
                                .. attribute:: spi_name
                                
                                	Name of the SPI
                                	**type**\:  str
                                
                                .. attribute:: subscriber_parent_policy
                                
                                	TRUE if service\-policy applied on svlan
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'qos-ma-cfg'
                                _revision = '2017-05-01'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent, self).__init__()

                                    self.yang_name = "subscriber-parent"
                                    self.yang_parent_name = "service-policy-qos"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}

                                    self.account_type = YLeaf(YType.enumeration, "account-type")

                                    self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                    self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                    self.resource_id = YLeaf(YType.uint32, "resource-id")

                                    self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                    self.spi_name = YLeaf(YType.str, "spi-name")

                                    self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                    self._segment_path = lambda: "subscriber-parent"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.Pac.Qos.Output.ServicePolicyQos.SubscriberParent, ['account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


            class SpanMonitorSessions(Entity):
                """
                Monitor Session container for this source
                interface
                
                .. attribute:: span_monitor_session
                
                	Configuration for a particular class of Monitor Session
                	**type**\: list of    :py:class:`SpanMonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession>`
                
                

                """

                _prefix = 'ethernet-span-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions, self).__init__()

                    self.yang_name = "span-monitor-sessions"
                    self.yang_parent_name = "l2-transport"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"span-monitor-session" : ("span_monitor_session", InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession)}

                    self.span_monitor_session = YList(self)
                    self._segment_path = lambda: "Cisco-IOS-XR-Ethernet-SPAN-cfg:span-monitor-sessions"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions, [], name, value)


                class SpanMonitorSession(Entity):
                    """
                    Configuration for a particular class of Monitor
                    Session
                    
                    .. attribute:: session_class  <key>
                    
                    	Session Class
                    	**type**\:   :py:class:`SpanSessionClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_datatypes.SpanSessionClass>`
                    
                    .. attribute:: acl
                    
                    	Enable ACL matching for traffic mirroring
                    	**type**\:   :py:class:`Acl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Acl>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: attachment
                    
                    	Attach the interface to a Monitor Session
                    	**type**\:   :py:class:`Attachment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Attachment>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: mirror_first
                    
                    	Mirror a specified number of bytes from start of packet
                    	**type**\:  int
                    
                    	**range:** 1..10000
                    
                    	**units**\: byte
                    
                    .. attribute:: mirror_interval
                    
                    	Specify the mirror interval
                    	**type**\:   :py:class:`SpanMirrorInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_cfg.SpanMirrorInterval>`
                    
                    

                    """

                    _prefix = 'ethernet-span-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession, self).__init__()

                        self.yang_name = "span-monitor-session"
                        self.yang_parent_name = "span-monitor-sessions"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"acl" : ("acl", InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Acl), "attachment" : ("attachment", InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Attachment)}
                        self._child_list_classes = {}

                        self.session_class = YLeaf(YType.enumeration, "session-class")

                        self.mirror_first = YLeaf(YType.uint32, "mirror-first")

                        self.mirror_interval = YLeaf(YType.enumeration, "mirror-interval")

                        self.acl = None
                        self._children_name_map["acl"] = "acl"
                        self._children_yang_names.add("acl")

                        self.attachment = None
                        self._children_name_map["attachment"] = "attachment"
                        self._children_yang_names.add("attachment")
                        self._segment_path = lambda: "span-monitor-session" + "[session-class='" + self.session_class.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession, ['session_class', 'mirror_first', 'mirror_interval'], name, value)


                    class Acl(Entity):
                        """
                        Enable ACL matching for traffic mirroring
                        
                        .. attribute:: acl_enable
                        
                        	Enable ACL
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        	**mandatory**\: True
                        
                        .. attribute:: acl_name
                        
                        	ACL Name
                        	**type**\:  str
                        
                        	**length:** 1..80
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ethernet-span-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Acl, self).__init__()

                            self.yang_name = "acl"
                            self.yang_parent_name = "span-monitor-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.acl_enable = YLeaf(YType.empty, "acl-enable")

                            self.acl_name = YLeaf(YType.str, "acl-name")
                            self._segment_path = lambda: "acl"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Acl, ['acl_enable', 'acl_name'], name, value)


                    class Attachment(Entity):
                        """
                        Attach the interface to a Monitor Session
                        
                        .. attribute:: direction
                        
                        	Specify the direction of traffic to replicate (optional)
                        	**type**\:   :py:class:`SpanTrafficDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_cfg.SpanTrafficDirection>`
                        
                        .. attribute:: port_level_enable
                        
                        	Enable port level traffic mirroring
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: session_name
                        
                        	Session Name
                        	**type**\:  str
                        
                        	**length:** 1..79
                        
                        	**mandatory**\: True
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'ethernet-span-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Attachment, self).__init__()

                            self.yang_name = "attachment"
                            self.yang_parent_name = "span-monitor-session"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.direction = YLeaf(YType.enumeration, "direction")

                            self.port_level_enable = YLeaf(YType.empty, "port-level-enable")

                            self.session_name = YLeaf(YType.str, "session-name")
                            self._segment_path = lambda: "attachment"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.L2Transport.SpanMonitorSessions.SpanMonitorSession.Attachment, ['direction', 'port_level_enable', 'session_name'], name, value)


        class Lacp(Entity):
            """
            Link Aggregation Control Protocol per\-interface
            configuration (for bundle or member)
            
            .. attribute:: churn_logging
            
            	Log churn notifications on the specified system(s)
            	**type**\:   :py:class:`ChurnLogging <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.ChurnLogging>`
            
            .. attribute:: cisco_extensions
            
            	Enable bundle Cisco extensions
            	**type**\:   :py:class:`CiscoExtensions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lacp.CiscoExtensions>`
            
            	**presence node**\: True
            
            .. attribute:: collector_max_delay
            
            	Collector Max Delay value to signal to the LACP partner
            	**type**\:  int
            
            	**range:** 0..65535
            
            .. attribute:: fast_switchover
            
            	Configure to enable the fast\-switchover mode
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: lacp_nonrevertive
            
            	Configure to enable lacp non\-revertive mode
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: mode
            
            	Lacp mode for the bundle
            	**type**\:   :py:class:`BundleMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleMode>`
            
            .. attribute:: period
            
            	Lacp period for the bundle
            	**type**\: one of the below types:
            
            	**type**\:   :py:class:`BundlePeriod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundlePeriod>`
            
            
            ----
            	**type**\:  int
            
            	**range:** 1..1000
            
            
            ----
            .. attribute:: period_short
            
            	LACP period to request from the partner (LACP standard short period, or rate in milliseconds for use with Cisco\-specific extensions). Default is LACP standard long period (30s)
            	**type**\: one of the below types:
            
            	**type**\:   :py:class:`PeriodShortEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.PeriodShortEnum>`
            
            	**units**\: millisecond
            
            
            ----
            	**type**\:  int
            
            	**range:** 1..1000
            
            	**units**\: millisecond
            
            
            ----
            .. attribute:: suppress_flaps
            
            	Suppress flaps on switchover for the specified period (in ms)
            	**type**\:  int
            
            	**range:** 100..65535
            
            .. attribute:: system_mac
            
            	System identifier for this bundle
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: system_priority
            
            	System priority for this bundle. Lower value is higher priority
            	**type**\:  int
            
            	**range:** 1..65535
            
            .. attribute:: timeout
            
            	Set timeout values for LACP\-related timers
            	**type**\:   :py:class:`Timeout <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout>`
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Lacp, self).__init__()

                self.yang_name = "lacp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"cisco-extensions" : ("cisco_extensions", InterfaceConfigurations.InterfaceConfiguration.Lacp.CiscoExtensions), "timeout" : ("timeout", InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout)}
                self._child_list_classes = {}

                self.churn_logging = YLeaf(YType.enumeration, "churn-logging")

                self.collector_max_delay = YLeaf(YType.uint32, "collector-max-delay")

                self.fast_switchover = YLeaf(YType.empty, "fast-switchover")

                self.lacp_nonrevertive = YLeaf(YType.empty, "lacp-nonrevertive")

                self.mode = YLeaf(YType.enumeration, "mode")

                self.period = YLeaf(YType.str, "period")

                self.period_short = YLeaf(YType.str, "period-short")

                self.suppress_flaps = YLeaf(YType.uint32, "suppress-flaps")

                self.system_mac = YLeaf(YType.str, "system-mac")

                self.system_priority = YLeaf(YType.uint32, "system-priority")

                self.cisco_extensions = None
                self._children_name_map["cisco_extensions"] = "cisco-extensions"
                self._children_yang_names.add("cisco-extensions")

                self.timeout = InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout()
                self.timeout.parent = self
                self._children_name_map["timeout"] = "timeout"
                self._children_yang_names.add("timeout")
                self._segment_path = lambda: "Cisco-IOS-XR-bundlemgr-cfg:lacp"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Lacp, ['churn_logging', 'collector_max_delay', 'fast_switchover', 'lacp_nonrevertive', 'mode', 'period', 'period_short', 'suppress_flaps', 'system_mac', 'system_priority'], name, value)


            class CiscoExtensions(Entity):
                """
                Enable bundle Cisco extensions
                
                .. attribute:: cisco_ext
                
                	Cisco extensions
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                	**mandatory**\: True
                
                .. attribute:: cisco_ext_type
                
                	Specific Cisco extension to enable / disable
                	**type**\:   :py:class:`BundleCiscoExtTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.BundleCiscoExtTypes>`
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Lacp.CiscoExtensions, self).__init__()

                    self.yang_name = "cisco-extensions"
                    self.yang_parent_name = "lacp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.cisco_ext = YLeaf(YType.empty, "cisco-ext")

                    self.cisco_ext_type = YLeaf(YType.enumeration, "cisco-ext-type")
                    self._segment_path = lambda: "cisco-extensions"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Lacp.CiscoExtensions, ['cisco_ext', 'cisco_ext_type'], name, value)


            class Timeout(Entity):
                """
                Set timeout values for LACP\-related timers
                
                .. attribute:: actor_churn
                
                	The time in milliseconds for which to run the timer
                	**type**\:  int
                
                	**range:** 0..120
                
                .. attribute:: partner_churn
                
                	Set the timeout to use before declaring partner churn
                	**type**\:  int
                
                	**range:** 0..120
                
                .. attribute:: rx_default
                
                	Set the timeout between expired and defaulted states
                	**type**\:  int
                
                	**range:** 0..3000
                
                

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout, self).__init__()

                    self.yang_name = "timeout"
                    self.yang_parent_name = "lacp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.actor_churn = YLeaf(YType.uint32, "actor-churn")

                    self.partner_churn = YLeaf(YType.uint32, "partner-churn")

                    self.rx_default = YLeaf(YType.uint32, "rx-default")
                    self._segment_path = lambda: "timeout"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Lacp.Timeout, ['actor_churn', 'partner_churn', 'rx_default'], name, value)


        class Lldp(Entity):
            """
            Disable LLDP TX or RX
            
            .. attribute:: lldp_intf_enter
            
            	enter LLDP interface submode
            	**type**\:  bool
            
            	**mandatory**\: True
            
            .. attribute:: receive
            
            	Disable LLDP RX
            	**type**\:   :py:class:`Receive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive>`
            
            .. attribute:: transmit
            
            	Disable LLDP TX
            	**type**\:   :py:class:`Transmit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit>`
            
            

            This class is a :ref:`presence class<presence-class>`

            """

            _prefix = 'ethernet-lldp-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Lldp, self).__init__()

                self.yang_name = "lldp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"receive" : ("receive", InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive), "transmit" : ("transmit", InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit)}
                self._child_list_classes = {}
                self.is_presence_container = True

                self.lldp_intf_enter = YLeaf(YType.boolean, "lldp-intf-enter")

                self.receive = InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive()
                self.receive.parent = self
                self._children_name_map["receive"] = "receive"
                self._children_yang_names.add("receive")

                self.transmit = InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit()
                self.transmit.parent = self
                self._children_name_map["transmit"] = "transmit"
                self._children_yang_names.add("transmit")
                self._segment_path = lambda: "Cisco-IOS-XR-ethernet-lldp-cfg:lldp"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Lldp, ['lldp_intf_enter'], name, value)


            class Receive(Entity):
                """
                Disable LLDP RX
                
                .. attribute:: disable
                
                	disable LLDP RX
                	**type**\:  bool
                
                	**default value**\: false
                
                

                """

                _prefix = 'ethernet-lldp-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive, self).__init__()

                    self.yang_name = "receive"
                    self.yang_parent_name = "lldp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.disable = YLeaf(YType.boolean, "disable")
                    self._segment_path = lambda: "receive"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Lldp.Receive, ['disable'], name, value)


            class Transmit(Entity):
                """
                Disable LLDP TX
                
                .. attribute:: disable
                
                	disable LLDP TX
                	**type**\:  bool
                
                	**default value**\: false
                
                

                """

                _prefix = 'ethernet-lldp-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit, self).__init__()

                    self.yang_name = "transmit"
                    self.yang_parent_name = "lldp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.disable = YLeaf(YType.boolean, "disable")
                    self._segment_path = lambda: "transmit"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Lldp.Transmit, ['disable'], name, value)


        class Loopbacks(Entity):
            """
            Configure Extended loopback (diagnostics)
            
            .. attribute:: loopback
            
            	Configure extended loopback mode
            	**type**\: list of    :py:class:`Loopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Loopbacks.Loopback>`
            
            

            """

            _prefix = 'drivers-icpe-ethernet-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Loopbacks, self).__init__()

                self.yang_name = "loopbacks"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {"loopback" : ("loopback", InterfaceConfigurations.InterfaceConfiguration.Loopbacks.Loopback)}

                self.loopback = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XR-drivers-icpe-ethernet-cfg:loopbacks"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Loopbacks, [], name, value)


            class Loopback(Entity):
                """
                Configure extended loopback mode
                
                .. attribute:: level  <key>
                
                	Level
                	**type**\:  int
                
                	**range:** 1..3
                
                .. attribute:: loopback
                
                	Loopback
                	**type**\:   :py:class:`ExtendedEthernetLoopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_drivers_icpe_ethernet_cfg.ExtendedEthernetLoopback>`
                
                	**mandatory**\: True
                
                

                """

                _prefix = 'drivers-icpe-ethernet-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Loopbacks.Loopback, self).__init__()

                    self.yang_name = "loopback"
                    self.yang_parent_name = "loopbacks"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.level = YLeaf(YType.uint32, "level")

                    self.loopback = YLeaf(YType.enumeration, "loopback")
                    self._segment_path = lambda: "loopback" + "[level='" + self.level.get() + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Loopbacks.Loopback, ['level', 'loopback'], name, value)


        class MacAccounting(Entity):
            """
            MAC Accounting Configuration
            
            .. attribute:: egress
            
            	Per MAC address accounting statistics
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: ingress
            
            	Per MAC address accounting statistics
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.MacAccounting, self).__init__()

                self.yang_name = "mac-accounting"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.egress = YLeaf(YType.empty, "egress")

                self.ingress = YLeaf(YType.empty, "ingress")
                self._segment_path = lambda: "Cisco-IOS-XR-l2-eth-infra-cfg:mac-accounting"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MacAccounting, ['egress', 'ingress'], name, value)


        class Macsec(Entity):
            """
            MACSec service for an interface
            
            .. attribute:: eap
            
            	Enabling MACSec eap Configuration on Interface
            	**type**\:   :py:class:`Eap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap>`
            
            .. attribute:: macsec_service
            
            	macsec\-service configuration on interface
            	**type**\:   :py:class:`MacsecService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Macsec.MacsecService>`
            
            	**presence node**\: True
            
            .. attribute:: psk_key_chain
            
            	MACSec MKA Configuration on Interface
            	**type**\:   :py:class:`PskKeyChain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Macsec.PskKeyChain>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'crypto-macsec-mka-if-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Macsec, self).__init__()

                self.yang_name = "macsec"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"eap" : ("eap", InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap), "macsec-service" : ("macsec_service", InterfaceConfigurations.InterfaceConfiguration.Macsec.MacsecService), "psk-key-chain" : ("psk_key_chain", InterfaceConfigurations.InterfaceConfiguration.Macsec.PskKeyChain)}
                self._child_list_classes = {}

                self.eap = InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap()
                self.eap.parent = self
                self._children_name_map["eap"] = "eap"
                self._children_yang_names.add("eap")

                self.macsec_service = None
                self._children_name_map["macsec_service"] = "macsec-service"
                self._children_yang_names.add("macsec-service")

                self.psk_key_chain = None
                self._children_name_map["psk_key_chain"] = "psk-key-chain"
                self._children_yang_names.add("psk-key-chain")
                self._segment_path = lambda: "Cisco-IOS-XR-crypto-macsec-mka-if-cfg:macsec"


            class Eap(Entity):
                """
                Enabling MACSec eap Configuration on Interface
                
                .. attribute:: eap_config
                
                	Eap config
                	**type**\:  str
                
                	**pattern:** (eap)
                
                .. attribute:: policy_name
                
                	Name of Policy
                	**type**\:  str
                
                	**length:** 1..16
                
                

                """

                _prefix = 'crypto-macsec-mka-if-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap, self).__init__()

                    self.yang_name = "eap"
                    self.yang_parent_name = "macsec"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.eap_config = YLeaf(YType.str, "eap-config")

                    self.policy_name = YLeaf(YType.str, "policy-name")
                    self._segment_path = lambda: "eap"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Macsec.Eap, ['eap_config', 'policy_name'], name, value)


            class MacsecService(Entity):
                """
                macsec\-service configuration on interface
                
                .. attribute:: decrypt_port
                
                	macsec service decryption port
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                	**mandatory**\: True
                
                .. attribute:: key_chain
                
                	name of keychain
                	**type**\:  str
                
                	**length:** 1..32
                
                	**mandatory**\: True
                
                .. attribute:: policy
                
                	name of policy
                	**type**\:  str
                
                	**length:** 1..16
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'crypto-macsec-mka-if-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Macsec.MacsecService, self).__init__()

                    self.yang_name = "macsec-service"
                    self.yang_parent_name = "macsec"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.decrypt_port = YLeaf(YType.str, "decrypt-port")

                    self.key_chain = YLeaf(YType.str, "key-chain")

                    self.policy = YLeaf(YType.str, "policy")
                    self._segment_path = lambda: "macsec-service"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Macsec.MacsecService, ['decrypt_port', 'key_chain', 'policy'], name, value)


            class PskKeyChain(Entity):
                """
                MACSec MKA Configuration on Interface
                
                .. attribute:: fallback_key_chain
                
                	name of fallback keychain
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: key_chain_name
                
                	Name of KeyChainName
                	**type**\:  str
                
                	**length:** 1..32
                
                	**mandatory**\: True
                
                .. attribute:: policy_name
                
                	Name of Policy
                	**type**\:  str
                
                	**length:** 1..16
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'crypto-macsec-mka-if-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Macsec.PskKeyChain, self).__init__()

                    self.yang_name = "psk-key-chain"
                    self.yang_parent_name = "macsec"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.fallback_key_chain = YLeaf(YType.str, "fallback-key-chain")

                    self.key_chain_name = YLeaf(YType.str, "key-chain-name")

                    self.policy_name = YLeaf(YType.str, "policy-name")
                    self._segment_path = lambda: "psk-key-chain"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Macsec.PskKeyChain, ['fallback_key_chain', 'key_chain_name', 'policy_name'], name, value)


        class Mlacp(Entity):
            """
            Multi\-chassis LACP configuration
            
            .. attribute:: iccp_group
            
            	Specify an ICCP Group in which this bundle should operate
            	**type**\:  int
            
            	**range:** 1..4294967295
            
            .. attribute:: maximize
            
            	Set parameters to maximize between the mLACP peers
            	**type**\:   :py:class:`Maximize <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mlacp.Maximize>`
            
            	**presence node**\: True
            
            .. attribute:: port_priority
            
            	The LACP port priority (lower value is higher priority)
            	**type**\:  int
            
            	**range:** 1..65535
            
            	**default value**\: 32768
            
            .. attribute:: recovery_delay
            
            	Set the delay before the bundle becomes active after recovery from failure
            	**type**\:  int
            
            	**range:** 0..65535
            
            	**default value**\: 300
            
            .. attribute:: switchover_type
            
            	Set the type of mLACP switchover to use for this bundle
            	**type**\:   :py:class:`MlacpSwitchover <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.MlacpSwitchover>`
            
            

            """

            _prefix = 'bundlemgr-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Mlacp, self).__init__()

                self.yang_name = "mlacp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"maximize" : ("maximize", InterfaceConfigurations.InterfaceConfiguration.Mlacp.Maximize)}
                self._child_list_classes = {}

                self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                self.port_priority = YLeaf(YType.uint16, "port-priority")

                self.recovery_delay = YLeaf(YType.uint32, "recovery-delay")

                self.switchover_type = YLeaf(YType.enumeration, "switchover-type")

                self.maximize = None
                self._children_name_map["maximize"] = "maximize"
                self._children_yang_names.add("maximize")
                self._segment_path = lambda: "Cisco-IOS-XR-bundlemgr-cfg:mlacp"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Mlacp, ['iccp_group', 'port_priority', 'recovery_delay', 'switchover_type'], name, value)


            class Maximize(Entity):
                """
                Set parameters to maximize between the mLACP
                peers
                
                .. attribute:: bandwidth_threshold
                
                	The bandwidth (in kbps) below which to switch to the peer if it has more bandwidth available . Only applicable if maximizing by bandwidth. If 0, no threshold is applied
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: link_threshold
                
                	The number of links below which to switch to the peer if it has more links available. Only applicable if maximizing by links. If 0, no threshold is applied
                	**type**\:  int
                
                	**range:** 0..64
                
                .. attribute:: maximize_by
                
                	The paramenter which should be maximized
                	**type**\:   :py:class:`MlacpMaximizeParameter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_bundlemgr_cfg.MlacpMaximizeParameter>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'bundlemgr-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Mlacp.Maximize, self).__init__()

                    self.yang_name = "maximize"
                    self.yang_parent_name = "mlacp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.bandwidth_threshold = YLeaf(YType.uint32, "bandwidth-threshold")

                    self.link_threshold = YLeaf(YType.uint32, "link-threshold")

                    self.maximize_by = YLeaf(YType.enumeration, "maximize-by")
                    self._segment_path = lambda: "maximize"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Mlacp.Maximize, ['bandwidth_threshold', 'link_threshold', 'maximize_by'], name, value)


        class Mpls(Entity):
            """
            MPLS configuration under an interface
            
            .. attribute:: label_security
            
            	MPLS label security
            	**type**\:   :py:class:`LabelSecurity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mpls.LabelSecurity>`
            
            .. attribute:: mtu
            
            	Set the MPLS MTU for the interface
            	**type**\:  int
            
            	**range:** 68..65535
            
            

            """

            _prefix = 'mpls-io-cfg'
            _revision = '2017-05-18'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Mpls, self).__init__()

                self.yang_name = "mpls"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"label-security" : ("label_security", InterfaceConfigurations.InterfaceConfiguration.Mpls.LabelSecurity)}
                self._child_list_classes = {}

                self.mtu = YLeaf(YType.uint32, "mtu")

                self.label_security = InterfaceConfigurations.InterfaceConfiguration.Mpls.LabelSecurity()
                self.label_security.parent = self
                self._children_name_map["label_security"] = "label-security"
                self._children_yang_names.add("label-security")
                self._segment_path = lambda: "Cisco-IOS-XR-mpls-io-cfg:mpls"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Mpls, ['mtu'], name, value)


            class LabelSecurity(Entity):
                """
                MPLS label security
                
                .. attribute:: multi_label_drop
                
                	Enable drop of multi\-labelled incoming packets on a Interface
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: rpf
                
                	Enable MPLS RPF for incoming packets on a Interface
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-io-cfg'
                _revision = '2017-05-18'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Mpls.LabelSecurity, self).__init__()

                    self.yang_name = "label-security"
                    self.yang_parent_name = "mpls"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.multi_label_drop = YLeaf(YType.empty, "multi-label-drop")

                    self.rpf = YLeaf(YType.empty, "rpf")
                    self._segment_path = lambda: "label-security"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Mpls.LabelSecurity, ['multi_label_drop', 'rpf'], name, value)


        class MteTunnelAttributes(Entity):
            """
            MPLS P2MP tunnel attributes
            
            .. attribute:: affinity_mask
            
            	P2MP tunnel affinity and mask
            	**type**\:   :py:class:`AffinityMask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask>`
            
            .. attribute:: bandwidth
            
            	P2MP tunnel bandwidth requirement
            	**type**\:   :py:class:`Bandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth>`
            
            .. attribute:: destination_leafs
            
            	P2MP destination table
            	**type**\:   :py:class:`DestinationLeafs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs>`
            
            .. attribute:: fast_reroute
            
            	Specify P2MP tunnel can be fast\-rerouted
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: impose_explicit_null
            
            	Impose an explicit null bellow the TE label
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: logging
            
            	Log tunnel LSP messages
            	**type**\:   :py:class:`Logging <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging>`
            
            .. attribute:: new_style_affinities
            
            	P2MP tunnel new style affinity attributes table
            	**type**\:   :py:class:`NewStyleAffinities <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities>`
            
            .. attribute:: path_selection_metric
            
            	Path selection configuration for this specific tunnel
            	**type**\:   :py:class:`MplsTePathSelectionMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathSelectionMetric>`
            
            .. attribute:: priority
            
            	P2MP tunnel setup and hold priorities
            	**type**\:   :py:class:`Priority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority>`
            
            	**presence node**\: True
            
            .. attribute:: record_route
            
            	Record route used by individual P2MP S2L(s)
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: signalled_name
            
            	The name of the P2MP tunnel to be included in signalling messages
            	**type**\:  str
            
            	**length:** 1..254
            
            .. attribute:: signalled_payload
            
            	P2MP tunnel ipv6 signalled payload
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            

            """

            _prefix = 'mpls-te-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes, self).__init__()

                self.yang_name = "mte-tunnel-attributes"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"affinity-mask" : ("affinity_mask", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask), "bandwidth" : ("bandwidth", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth), "destination-leafs" : ("destination_leafs", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs), "logging" : ("logging", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging), "new-style-affinities" : ("new_style_affinities", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities), "priority" : ("priority", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority)}
                self._child_list_classes = {}

                self.fast_reroute = YLeaf(YType.empty, "fast-reroute")

                self.impose_explicit_null = YLeaf(YType.empty, "impose-explicit-null")

                self.path_selection_metric = YLeaf(YType.enumeration, "path-selection-metric")

                self.record_route = YLeaf(YType.empty, "record-route")

                self.signalled_name = YLeaf(YType.str, "signalled-name")

                self.signalled_payload = YLeaf(YType.str, "signalled-payload")

                self.affinity_mask = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask()
                self.affinity_mask.parent = self
                self._children_name_map["affinity_mask"] = "affinity-mask"
                self._children_yang_names.add("affinity-mask")

                self.bandwidth = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth()
                self.bandwidth.parent = self
                self._children_name_map["bandwidth"] = "bandwidth"
                self._children_yang_names.add("bandwidth")

                self.destination_leafs = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs()
                self.destination_leafs.parent = self
                self._children_name_map["destination_leafs"] = "destination-leafs"
                self._children_yang_names.add("destination-leafs")

                self.logging = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"
                self._children_yang_names.add("logging")

                self.new_style_affinities = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities()
                self.new_style_affinities.parent = self
                self._children_name_map["new_style_affinities"] = "new-style-affinities"
                self._children_yang_names.add("new-style-affinities")

                self.priority = None
                self._children_name_map["priority"] = "priority"
                self._children_yang_names.add("priority")
                self._segment_path = lambda: "Cisco-IOS-XR-mpls-te-cfg:mte-tunnel-attributes"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes, ['fast_reroute', 'impose_explicit_null', 'path_selection_metric', 'record_route', 'signalled_name', 'signalled_payload'], name, value)


            class AffinityMask(Entity):
                """
                P2MP tunnel affinity and mask
                
                .. attribute:: affinity
                
                	Affinity flags
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                .. attribute:: mask
                
                	Affinity mask
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask, self).__init__()

                    self.yang_name = "affinity-mask"
                    self.yang_parent_name = "mte-tunnel-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.affinity = YLeaf(YType.str, "affinity")

                    self.mask = YLeaf(YType.str, "mask")
                    self._segment_path = lambda: "affinity-mask"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.AffinityMask, ['affinity', 'mask'], name, value)


            class Bandwidth(Entity):
                """
                P2MP tunnel bandwidth requirement
                
                .. attribute:: bandwidth
                
                	The value of the bandwidth reserved by this tunnel in kbps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: class_or_pool_type
                
                	Class type for the bandwidth allocation
                	**type**\:  int
                
                	**range:** 0..1
                
                .. attribute:: dste_type
                
                	DSTE\-standard flag
                	**type**\:   :py:class:`MplsTeBandwidthDste <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBandwidthDste>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "mte-tunnel-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                    self.class_or_pool_type = YLeaf(YType.uint32, "class-or-pool-type")

                    self.dste_type = YLeaf(YType.enumeration, "dste-type")
                    self._segment_path = lambda: "bandwidth"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Bandwidth, ['bandwidth', 'class_or_pool_type', 'dste_type'], name, value)


            class DestinationLeafs(Entity):
                """
                P2MP destination table
                
                .. attribute:: destination_leaf
                
                	P2MP destination leaf
                	**type**\: list of    :py:class:`DestinationLeaf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs, self).__init__()

                    self.yang_name = "destination-leafs"
                    self.yang_parent_name = "mte-tunnel-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"destination-leaf" : ("destination_leaf", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf)}

                    self.destination_leaf = YList(self)
                    self._segment_path = lambda: "destination-leafs"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs, [], name, value)


                class DestinationLeaf(Entity):
                    """
                    P2MP destination leaf
                    
                    .. attribute:: address  <key>
                    
                    	Address of P2MP destination
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: destination
                    
                    	Always set to true
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: destination_disable
                    
                    	Disables P2MP destination
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: path_options
                    
                    	P2MP destination path\-options attributes table
                    	**type**\:   :py:class:`PathOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions>`
                    
                    .. attribute:: s2l_logging
                    
                    	Log tunnel destination s2l messages
                    	**type**\:   :py:class:`S2LLogging <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf, self).__init__()

                        self.yang_name = "destination-leaf"
                        self.yang_parent_name = "destination-leafs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"path-options" : ("path_options", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions), "s2l-logging" : ("s2l_logging", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging)}
                        self._child_list_classes = {}

                        self.address = YLeaf(YType.str, "address")

                        self.destination = YLeaf(YType.empty, "destination")

                        self.destination_disable = YLeaf(YType.empty, "destination-disable")

                        self.path_options = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions()
                        self.path_options.parent = self
                        self._children_name_map["path_options"] = "path-options"
                        self._children_yang_names.add("path-options")

                        self.s2l_logging = InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging()
                        self.s2l_logging.parent = self
                        self._children_name_map["s2l_logging"] = "s2l-logging"
                        self._children_yang_names.add("s2l-logging")
                        self._segment_path = lambda: "destination-leaf" + "[address='" + self.address.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf, ['address', 'destination', 'destination_disable'], name, value)


                    class PathOptions(Entity):
                        """
                        P2MP destination path\-options attributes
                        table
                        
                        .. attribute:: path_option
                        
                        	P2MP destination path option
                        	**type**\: list of    :py:class:`PathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions.PathOption>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions, self).__init__()

                            self.yang_name = "path-options"
                            self.yang_parent_name = "destination-leaf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"path-option" : ("path_option", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions.PathOption)}

                            self.path_option = YList(self)
                            self._segment_path = lambda: "path-options"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions, [], name, value)


                        class PathOption(Entity):
                            """
                            P2MP destination path option
                            
                            .. attribute:: preference_level  <key>
                            
                            	Preference level for this path option
                            	**type**\:  int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: lockdown
                            
                            	Path option properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            .. attribute:: path_id
                            
                            	The ID of the IP explicit path associated with this option
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            .. attribute:: path_name
                            
                            	The name of the IP explicit path associated with this option
                            	**type**\:  str
                            
                            .. attribute:: path_type
                            
                            	The type of the path option
                            	**type**\:   :py:class:`MplsTePathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOption>`
                            
                            .. attribute:: verbatim
                            
                            	Path option properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            

                            """

                            _prefix = 'mpls-te-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions.PathOption, self).__init__()

                                self.yang_name = "path-option"
                                self.yang_parent_name = "path-options"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.preference_level = YLeaf(YType.uint32, "preference-level")

                                self.lockdown = YLeaf(YType.enumeration, "lockdown")

                                self.path_id = YLeaf(YType.uint32, "path-id")

                                self.path_name = YLeaf(YType.str, "path-name")

                                self.path_type = YLeaf(YType.enumeration, "path-type")

                                self.verbatim = YLeaf(YType.enumeration, "verbatim")
                                self._segment_path = lambda: "path-option" + "[preference-level='" + self.preference_level.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.PathOptions.PathOption, ['preference_level', 'lockdown', 'path_id', 'path_name', 'path_type', 'verbatim'], name, value)


                    class S2LLogging(Entity):
                        """
                        Log tunnel destination s2l messages
                        
                        .. attribute:: s2l_insufficient_bw_messsage
                        
                        	Log tunnel destination s2l insufficient BW messages
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s2l_pcalc_failure_message
                        
                        	Enable logging for destination s2l path\-calculation failures
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s2l_reroute_messsage
                        
                        	Log tunnel destination s2l rereoute messages
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        .. attribute:: s2l_state_message
                        
                        	Log tunnel destination s2l state messages
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging, self).__init__()

                            self.yang_name = "s2l-logging"
                            self.yang_parent_name = "destination-leaf"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.s2l_insufficient_bw_messsage = YLeaf(YType.empty, "s2l-insufficient-bw-messsage")

                            self.s2l_pcalc_failure_message = YLeaf(YType.empty, "s2l-pcalc-failure-message")

                            self.s2l_reroute_messsage = YLeaf(YType.empty, "s2l-reroute-messsage")

                            self.s2l_state_message = YLeaf(YType.empty, "s2l-state-message")
                            self._segment_path = lambda: "s2l-logging"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.DestinationLeafs.DestinationLeaf.S2LLogging, ['s2l_insufficient_bw_messsage', 's2l_pcalc_failure_message', 's2l_reroute_messsage', 's2l_state_message'], name, value)


            class Logging(Entity):
                """
                Log tunnel LSP messages
                
                .. attribute:: all
                
                	Log all events for a tunnel
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bandwidth_change_message
                
                	Log tunnel bandwidth change messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: insufficient_bw_message
                
                	Log tunnel messages for insufficient bandwidth
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pcalc_failure_message
                
                	Enable logging for path\-calculation failures
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reoptimize_attempts_message
                
                	Log tunnel reoptimization attempts messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reoptimized_message
                
                	Log tunnel reoptimized messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reroute_messsage
                
                	Log tunnel rereoute messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: state_message
                
                	Log tunnel state messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: sub_lsp_state_message
                
                	Log all tunnel sub\-LSP state messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "mte-tunnel-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.all = YLeaf(YType.empty, "all")

                    self.bandwidth_change_message = YLeaf(YType.empty, "bandwidth-change-message")

                    self.insufficient_bw_message = YLeaf(YType.empty, "insufficient-bw-message")

                    self.pcalc_failure_message = YLeaf(YType.empty, "pcalc-failure-message")

                    self.reoptimize_attempts_message = YLeaf(YType.empty, "reoptimize-attempts-message")

                    self.reoptimized_message = YLeaf(YType.empty, "reoptimized-message")

                    self.reroute_messsage = YLeaf(YType.empty, "reroute-messsage")

                    self.state_message = YLeaf(YType.empty, "state-message")

                    self.sub_lsp_state_message = YLeaf(YType.empty, "sub-lsp-state-message")
                    self._segment_path = lambda: "logging"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Logging, ['all', 'bandwidth_change_message', 'insufficient_bw_message', 'pcalc_failure_message', 'reoptimize_attempts_message', 'reoptimized_message', 'reroute_messsage', 'state_message', 'sub_lsp_state_message'], name, value)


            class NewStyleAffinities(Entity):
                """
                P2MP tunnel new style affinity attributes table
                
                .. attribute:: new_style_affinity
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities.NewStyleAffinity>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities, self).__init__()

                    self.yang_name = "new-style-affinities"
                    self.yang_parent_name = "mte-tunnel-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"new-style-affinity" : ("new_style_affinity", InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities.NewStyleAffinity)}

                    self.new_style_affinity = YList(self)
                    self._segment_path = lambda: "new-style-affinities"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities, [], name, value)


                class NewStyleAffinity(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity8  <key>
                    
                    	The name of the eighth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity9  <key>
                    
                    	The name of the nineth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity10  <key>
                    
                    	The name of the tenth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities.NewStyleAffinity, self).__init__()

                        self.yang_name = "new-style-affinity"
                        self.yang_parent_name = "new-style-affinities"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")

                        self.affinity8 = YLeaf(YType.str, "affinity8")

                        self.affinity9 = YLeaf(YType.str, "affinity9")

                        self.affinity10 = YLeaf(YType.str, "affinity10")
                        self._segment_path = lambda: "new-style-affinity" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']" + "[affinity8='" + self.affinity8.get() + "']" + "[affinity9='" + self.affinity9.get() + "']" + "[affinity10='" + self.affinity10.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.NewStyleAffinities.NewStyleAffinity, ['affinity_type', 'affinity1', 'affinity2', 'affinity3', 'affinity4', 'affinity5', 'affinity6', 'affinity7', 'affinity8', 'affinity9', 'affinity10'], name, value)


            class Priority(Entity):
                """
                P2MP tunnel setup and hold priorities
                
                .. attribute:: hold_priority
                
                	Hold Priority
                	**type**\:  int
                
                	**range:** 0..7
                
                	**mandatory**\: True
                
                .. attribute:: setup_priority
                
                	Setup Priority
                	**type**\:  int
                
                	**range:** 0..7
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority, self).__init__()

                    self.yang_name = "priority"
                    self.yang_parent_name = "mte-tunnel-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.hold_priority = YLeaf(YType.uint32, "hold-priority")

                    self.setup_priority = YLeaf(YType.uint32, "setup-priority")
                    self._segment_path = lambda: "priority"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.MteTunnelAttributes.Priority, ['hold_priority', 'setup_priority'], name, value)


        class Mtus(Entity):
            """
            The MTU configuration for the interface
            
            .. attribute:: mtu
            
            	The MTU for the interface
            	**type**\: list of    :py:class:`Mtu <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Mtus.Mtu>`
            
            

            """

            _prefix = 'ifmgr-cfg'
            _revision = '2015-07-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Mtus, self).__init__()

                self.yang_name = "mtus"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {"mtu" : ("mtu", InterfaceConfigurations.InterfaceConfiguration.Mtus.Mtu)}

                self.mtu = YList(self)
                self._segment_path = lambda: "mtus"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Mtus, [], name, value)


            class Mtu(Entity):
                """
                The MTU for the interface
                
                .. attribute:: owner  <key>
                
                	The Owner of the interface \- eg. for 'LoopbackX' main interface this is 'loopback'
                	**type**\:  str
                
                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                
                .. attribute:: mtu
                
                	The MTU value
                	**type**\:  int
                
                	**range:** 64..65535
                
                	**mandatory**\: True
                
                

                """

                _prefix = 'ifmgr-cfg'
                _revision = '2015-07-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Mtus.Mtu, self).__init__()

                    self.yang_name = "mtu"
                    self.yang_parent_name = "mtus"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.owner = YLeaf(YType.str, "owner")

                    self.mtu = YLeaf(YType.uint32, "mtu")
                    self._segment_path = lambda: "mtu" + "[owner='" + self.owner.get() + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Mtus.Mtu, ['owner', 'mtu'], name, value)


        class NetFlow(Entity):
            """
            Interface netflow configuration
            
            .. attribute:: data_link_frame_section
            
            	Configure datalinkframesection netflow
            	**type**\:   :py:class:`DataLinkFrameSection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection>`
            
            .. attribute:: ipv4
            
            	Configure IPv4 netflow
            	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4>`
            
            .. attribute:: ipv6
            
            	Configure IPv6 netflow
            	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6>`
            
            .. attribute:: mpls
            
            	Configure MPLS netflow
            	**type**\:   :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls>`
            
            

            """

            _prefix = 'traffmon-netflow-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow, self).__init__()

                self.yang_name = "net-flow"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"data-link-frame-section" : ("data_link_frame_section", InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection), "ipv4" : ("ipv4", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4), "ipv6" : ("ipv6", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6), "mpls" : ("mpls", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls)}
                self._child_list_classes = {}

                self.data_link_frame_section = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection()
                self.data_link_frame_section.parent = self
                self._children_name_map["data_link_frame_section"] = "data-link-frame-section"
                self._children_yang_names.add("data-link-frame-section")

                self.ipv4 = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4()
                self.ipv4.parent = self
                self._children_name_map["ipv4"] = "ipv4"
                self._children_yang_names.add("ipv4")

                self.ipv6 = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6()
                self.ipv6.parent = self
                self._children_name_map["ipv6"] = "ipv6"
                self._children_yang_names.add("ipv6")

                self.mpls = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls()
                self.mpls.parent = self
                self._children_name_map["mpls"] = "mpls"
                self._children_yang_names.add("mpls")
                self._segment_path = lambda: "Cisco-IOS-XR-traffmon-netflow-cfg:net-flow"


            class DataLinkFrameSection(Entity):
                """
                Configure datalinkframesection netflow
                
                .. attribute:: flow_monitor_map
                
                	Configure a flow monitor map
                	**type**\:   :py:class:`FlowMonitorMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap>`
                
                

                """

                _prefix = 'traffmon-netflow-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection, self).__init__()

                    self.yang_name = "data-link-frame-section"
                    self.yang_parent_name = "net-flow"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"flow-monitor-map" : ("flow_monitor_map", InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap)}
                    self._child_list_classes = {}

                    self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap()
                    self.flow_monitor_map.parent = self
                    self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                    self._children_yang_names.add("flow-monitor-map")
                    self._segment_path = lambda: "data-link-frame-section"


                class FlowMonitorMap(Entity):
                    """
                    Configure a flow monitor map
                    
                    .. attribute:: egress
                    
                    	Configure egress monitoring direction
                    	**type**\:   :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress>`
                    
                    .. attribute:: ingress
                    
                    	Configure ingress monitoring direction
                    	**type**\:   :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress>`
                    
                    

                    """

                    _prefix = 'traffmon-netflow-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap, self).__init__()

                        self.yang_name = "flow-monitor-map"
                        self.yang_parent_name = "data-link-frame-section"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"egress" : ("egress", InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress), "ingress" : ("ingress", InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress)}
                        self._child_list_classes = {}

                        self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress()
                        self.egress.parent = self
                        self._children_name_map["egress"] = "egress"
                        self._children_yang_names.add("egress")

                        self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress()
                        self.ingress.parent = self
                        self._children_name_map["ingress"] = "ingress"
                        self._children_yang_names.add("ingress")
                        self._segment_path = lambda: "flow-monitor-map"


                    class Egress(Entity):
                        """
                        Configure egress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress, self).__init__()

                            self.yang_name = "egress"
                            self.yang_parent_name = "flow-monitor-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flow-monitor-name" : ("flow_monitor_name", InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress.FlowMonitorName)}

                            self.flow_monitor_name = YList(self)
                            self._segment_path = lambda: "egress"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress, [], name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "egress"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")
                                self._segment_path = lambda: "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Egress.FlowMonitorName, ['monitor_map_name', 'sampler_map_name'], name, value)


                    class Ingress(Entity):
                        """
                        Configure ingress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress, self).__init__()

                            self.yang_name = "ingress"
                            self.yang_parent_name = "flow-monitor-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flow-monitor-name" : ("flow_monitor_name", InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress.FlowMonitorName)}

                            self.flow_monitor_name = YList(self)
                            self._segment_path = lambda: "ingress"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress, [], name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "ingress"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")
                                self._segment_path = lambda: "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.DataLinkFrameSection.FlowMonitorMap.Ingress.FlowMonitorName, ['monitor_map_name', 'sampler_map_name'], name, value)


            class Ipv4(Entity):
                """
                Configure IPv4 netflow
                
                .. attribute:: flow_monitor_map
                
                	Configure a flow monitor map
                	**type**\:   :py:class:`FlowMonitorMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap>`
                
                

                """

                _prefix = 'traffmon-netflow-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4, self).__init__()

                    self.yang_name = "ipv4"
                    self.yang_parent_name = "net-flow"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"flow-monitor-map" : ("flow_monitor_map", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap)}
                    self._child_list_classes = {}

                    self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap()
                    self.flow_monitor_map.parent = self
                    self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                    self._children_yang_names.add("flow-monitor-map")
                    self._segment_path = lambda: "ipv4"


                class FlowMonitorMap(Entity):
                    """
                    Configure a flow monitor map
                    
                    .. attribute:: egress
                    
                    	Configure egress monitoring direction
                    	**type**\:   :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress>`
                    
                    .. attribute:: ingress
                    
                    	Configure ingress monitoring direction
                    	**type**\:   :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress>`
                    
                    

                    """

                    _prefix = 'traffmon-netflow-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap, self).__init__()

                        self.yang_name = "flow-monitor-map"
                        self.yang_parent_name = "ipv4"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"egress" : ("egress", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress), "ingress" : ("ingress", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress)}
                        self._child_list_classes = {}

                        self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress()
                        self.egress.parent = self
                        self._children_name_map["egress"] = "egress"
                        self._children_yang_names.add("egress")

                        self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress()
                        self.ingress.parent = self
                        self._children_name_map["ingress"] = "ingress"
                        self._children_yang_names.add("ingress")
                        self._segment_path = lambda: "flow-monitor-map"


                    class Egress(Entity):
                        """
                        Configure egress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress, self).__init__()

                            self.yang_name = "egress"
                            self.yang_parent_name = "flow-monitor-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flow-monitor-name" : ("flow_monitor_name", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress.FlowMonitorName)}

                            self.flow_monitor_name = YList(self)
                            self._segment_path = lambda: "egress"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress, [], name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "egress"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")
                                self._segment_path = lambda: "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Egress.FlowMonitorName, ['monitor_map_name', 'sampler_map_name'], name, value)


                    class Ingress(Entity):
                        """
                        Configure ingress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress, self).__init__()

                            self.yang_name = "ingress"
                            self.yang_parent_name = "flow-monitor-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flow-monitor-name" : ("flow_monitor_name", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress.FlowMonitorName)}

                            self.flow_monitor_name = YList(self)
                            self._segment_path = lambda: "ingress"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress, [], name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "ingress"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")
                                self._segment_path = lambda: "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv4.FlowMonitorMap.Ingress.FlowMonitorName, ['monitor_map_name', 'sampler_map_name'], name, value)


            class Ipv6(Entity):
                """
                Configure IPv6 netflow
                
                .. attribute:: flow_monitor_map
                
                	Configure a flow monitor map
                	**type**\:   :py:class:`FlowMonitorMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap>`
                
                

                """

                _prefix = 'traffmon-netflow-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6, self).__init__()

                    self.yang_name = "ipv6"
                    self.yang_parent_name = "net-flow"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"flow-monitor-map" : ("flow_monitor_map", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap)}
                    self._child_list_classes = {}

                    self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap()
                    self.flow_monitor_map.parent = self
                    self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                    self._children_yang_names.add("flow-monitor-map")
                    self._segment_path = lambda: "ipv6"


                class FlowMonitorMap(Entity):
                    """
                    Configure a flow monitor map
                    
                    .. attribute:: egress
                    
                    	Configure egress monitoring direction
                    	**type**\:   :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress>`
                    
                    .. attribute:: ingress
                    
                    	Configure ingress monitoring direction
                    	**type**\:   :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress>`
                    
                    

                    """

                    _prefix = 'traffmon-netflow-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap, self).__init__()

                        self.yang_name = "flow-monitor-map"
                        self.yang_parent_name = "ipv6"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"egress" : ("egress", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress), "ingress" : ("ingress", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress)}
                        self._child_list_classes = {}

                        self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress()
                        self.egress.parent = self
                        self._children_name_map["egress"] = "egress"
                        self._children_yang_names.add("egress")

                        self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress()
                        self.ingress.parent = self
                        self._children_name_map["ingress"] = "ingress"
                        self._children_yang_names.add("ingress")
                        self._segment_path = lambda: "flow-monitor-map"


                    class Egress(Entity):
                        """
                        Configure egress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress, self).__init__()

                            self.yang_name = "egress"
                            self.yang_parent_name = "flow-monitor-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flow-monitor-name" : ("flow_monitor_name", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress.FlowMonitorName)}

                            self.flow_monitor_name = YList(self)
                            self._segment_path = lambda: "egress"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress, [], name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "egress"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")
                                self._segment_path = lambda: "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Egress.FlowMonitorName, ['monitor_map_name', 'sampler_map_name'], name, value)


                    class Ingress(Entity):
                        """
                        Configure ingress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress, self).__init__()

                            self.yang_name = "ingress"
                            self.yang_parent_name = "flow-monitor-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flow-monitor-name" : ("flow_monitor_name", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress.FlowMonitorName)}

                            self.flow_monitor_name = YList(self)
                            self._segment_path = lambda: "ingress"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress, [], name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "ingress"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")
                                self._segment_path = lambda: "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Ipv6.FlowMonitorMap.Ingress.FlowMonitorName, ['monitor_map_name', 'sampler_map_name'], name, value)


            class Mpls(Entity):
                """
                Configure MPLS netflow
                
                .. attribute:: flow_monitor_map
                
                	Configure a flow monitor map
                	**type**\:   :py:class:`FlowMonitorMap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap>`
                
                

                """

                _prefix = 'traffmon-netflow-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls, self).__init__()

                    self.yang_name = "mpls"
                    self.yang_parent_name = "net-flow"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"flow-monitor-map" : ("flow_monitor_map", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap)}
                    self._child_list_classes = {}

                    self.flow_monitor_map = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap()
                    self.flow_monitor_map.parent = self
                    self._children_name_map["flow_monitor_map"] = "flow-monitor-map"
                    self._children_yang_names.add("flow-monitor-map")
                    self._segment_path = lambda: "mpls"


                class FlowMonitorMap(Entity):
                    """
                    Configure a flow monitor map
                    
                    .. attribute:: egress
                    
                    	Configure egress monitoring direction
                    	**type**\:   :py:class:`Egress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress>`
                    
                    .. attribute:: ingress
                    
                    	Configure ingress monitoring direction
                    	**type**\:   :py:class:`Ingress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress>`
                    
                    

                    """

                    _prefix = 'traffmon-netflow-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap, self).__init__()

                        self.yang_name = "flow-monitor-map"
                        self.yang_parent_name = "mpls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"egress" : ("egress", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress), "ingress" : ("ingress", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress)}
                        self._child_list_classes = {}

                        self.egress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress()
                        self.egress.parent = self
                        self._children_name_map["egress"] = "egress"
                        self._children_yang_names.add("egress")

                        self.ingress = InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress()
                        self.ingress.parent = self
                        self._children_name_map["ingress"] = "ingress"
                        self._children_yang_names.add("ingress")
                        self._segment_path = lambda: "flow-monitor-map"


                    class Egress(Entity):
                        """
                        Configure egress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress, self).__init__()

                            self.yang_name = "egress"
                            self.yang_parent_name = "flow-monitor-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flow-monitor-name" : ("flow_monitor_name", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress.FlowMonitorName)}

                            self.flow_monitor_name = YList(self)
                            self._segment_path = lambda: "egress"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress, [], name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "egress"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")
                                self._segment_path = lambda: "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Egress.FlowMonitorName, ['monitor_map_name', 'sampler_map_name'], name, value)


                    class Ingress(Entity):
                        """
                        Configure ingress monitoring direction
                        
                        .. attribute:: flow_monitor_name
                        
                        	Specify a sampler for a flow monitor
                        	**type**\: list of    :py:class:`FlowMonitorName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress.FlowMonitorName>`
                        
                        

                        """

                        _prefix = 'traffmon-netflow-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress, self).__init__()

                            self.yang_name = "ingress"
                            self.yang_parent_name = "flow-monitor-map"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"flow-monitor-name" : ("flow_monitor_name", InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress.FlowMonitorName)}

                            self.flow_monitor_name = YList(self)
                            self._segment_path = lambda: "ingress"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress, [], name, value)


                        class FlowMonitorName(Entity):
                            """
                            Specify a sampler for a flow monitor
                            
                            .. attribute:: monitor_map_name  <key>
                            
                            	Flow monitor map name
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: sampler_map_name
                            
                            	Sampler map name
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'traffmon-netflow-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress.FlowMonitorName, self).__init__()

                                self.yang_name = "flow-monitor-name"
                                self.yang_parent_name = "ingress"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.monitor_map_name = YLeaf(YType.str, "monitor-map-name")

                                self.sampler_map_name = YLeaf(YType.str, "sampler-map-name")
                                self._segment_path = lambda: "flow-monitor-name" + "[monitor-map-name='" + self.monitor_map_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NetFlow.Mpls.FlowMonitorMap.Ingress.FlowMonitorName, ['monitor_map_name', 'sampler_map_name'], name, value)


        class NvSatelliteAccess(Entity):
            """
            nV Satellite Access Link Configuration
            
            .. attribute:: qos
            
            	Interface QOS configuration
            	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos>`
            
            

            """

            _prefix = 'icpe-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess, self).__init__()

                self.yang_name = "nv-satellite-access"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"qos" : ("qos", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos)}
                self._child_list_classes = {}

                self.qos = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos()
                self.qos.parent = self
                self._children_name_map["qos"] = "qos"
                self._children_yang_names.add("qos")
                self._segment_path = lambda: "Cisco-IOS-XR-icpe-infra-cfg:nv-satellite-access"


            class Qos(Entity):
                """
                Interface QOS configuration
                
                .. attribute:: input
                
                	Ingress service policy
                	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input>`
                
                .. attribute:: output
                
                	Egress service policy
                	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output>`
                
                

                """

                _prefix = 'qos-ma-sat-cfg'
                _revision = '2017-03-03'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos, self).__init__()

                    self.yang_name = "qos"
                    self.yang_parent_name = "nv-satellite-access"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"input" : ("input", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input), "output" : ("output", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output)}
                    self._child_list_classes = {}

                    self.input = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"
                    self._children_yang_names.add("input")

                    self.output = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._children_yang_names.add("output")
                    self._segment_path = lambda: "Cisco-IOS-XR-qos-ma-sat-cfg:qos"


                class Input(Entity):
                    """
                    Ingress service policy
                    
                    .. attribute:: service_policy
                    
                    	Service policy details
                    	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input.ServicePolicy)}

                        self.service_policy = YList(self)
                        self._segment_path = lambda: "input"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input, [], name, value)


                    class ServicePolicy(Entity):
                        """
                        Service policy details
                        
                        .. attribute:: service_policy_name  <key>
                        
                        	Name of policy\-map
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-03-03'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "input"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.service_policy_name = YLeaf(YType.str, "service-policy-name")
                            self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Input.ServicePolicy, ['service_policy_name'], name, value)


                class Output(Entity):
                    """
                    Egress service policy
                    
                    .. attribute:: service_policy
                    
                    	Service policy details
                    	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output.ServicePolicy)}

                        self.service_policy = YList(self)
                        self._segment_path = lambda: "output"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output, [], name, value)


                    class ServicePolicy(Entity):
                        """
                        Service policy details
                        
                        .. attribute:: service_policy_name  <key>
                        
                        	Name of policy\-map
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-03-03'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "output"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.service_policy_name = YLeaf(YType.str, "service-policy-name")
                            self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteAccess.Qos.Output.ServicePolicy, ['service_policy_name'], name, value)


        class NvSatelliteFabricLink(Entity):
            """
            nV Satellite Fabric Link Configuration
            
            .. attribute:: ethernet_features
            
            	Ethernet Satellite configuration
            	**type**\:   :py:class:`EthernetFeatures <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures>`
            
            .. attribute:: frequency_synchronization
            
            	Frequency Synchronization satellite configuration
            	**type**\:   :py:class:`FrequencySynchronization <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.FrequencySynchronization>`
            
            .. attribute:: minimum_required_links
            
            	Mininum number of active links required
            	**type**\:  int
            
            	**range:** 1..64
            
            .. attribute:: qos
            
            	Interface QOS configuration
            	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos>`
            
            .. attribute:: redundancy
            
            	Redundancy submode
            	**type**\:   :py:class:`Redundancy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy>`
            
            .. attribute:: remote_ports
            
            	Remote Ports table
            	**type**\:   :py:class:`RemotePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts>`
            
            .. attribute:: satellite
            
            	Hub & Spoke connection to a single Satellite
            	**type**\:  int
            
            	**range:** 100..65534
            
            

            """

            _prefix = 'icpe-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink, self).__init__()

                self.yang_name = "nv-satellite-fabric-link"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"ethernet-features" : ("ethernet_features", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures), "frequency-synchronization" : ("frequency_synchronization", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.FrequencySynchronization), "qos" : ("qos", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos), "redundancy" : ("redundancy", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy), "remote-ports" : ("remote_ports", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts)}
                self._child_list_classes = {}

                self.minimum_required_links = YLeaf(YType.uint32, "minimum-required-links")

                self.satellite = YLeaf(YType.uint32, "satellite")

                self.ethernet_features = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures()
                self.ethernet_features.parent = self
                self._children_name_map["ethernet_features"] = "ethernet-features"
                self._children_yang_names.add("ethernet-features")

                self.frequency_synchronization = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.FrequencySynchronization()
                self.frequency_synchronization.parent = self
                self._children_name_map["frequency_synchronization"] = "frequency-synchronization"
                self._children_yang_names.add("frequency-synchronization")

                self.qos = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos()
                self.qos.parent = self
                self._children_name_map["qos"] = "qos"
                self._children_yang_names.add("qos")

                self.redundancy = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy()
                self.redundancy.parent = self
                self._children_name_map["redundancy"] = "redundancy"
                self._children_yang_names.add("redundancy")

                self.remote_ports = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts()
                self.remote_ports.parent = self
                self._children_name_map["remote_ports"] = "remote-ports"
                self._children_yang_names.add("remote-ports")
                self._segment_path = lambda: "Cisco-IOS-XR-icpe-infra-cfg:nv-satellite-fabric-link"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink, ['minimum_required_links', 'satellite'], name, value)


            class EthernetFeatures(Entity):
                """
                Ethernet Satellite configuration
                
                .. attribute:: cfm
                
                	CFM Satellite configuration
                	**type**\:   :py:class:`Cfm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm>`
                
                

                """

                _prefix = 'ethernet-cfm-sat-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures, self).__init__()

                    self.yang_name = "ethernet-features"
                    self.yang_parent_name = "nv-satellite-fabric-link"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"cfm" : ("cfm", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm)}
                    self._child_list_classes = {}

                    self.cfm = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm()
                    self.cfm.parent = self
                    self._children_name_map["cfm"] = "cfm"
                    self._children_yang_names.add("cfm")
                    self._segment_path = lambda: "Cisco-IOS-XR-ethernet-cfm-sat-cfg:ethernet-features"


                class Cfm(Entity):
                    """
                    CFM Satellite configuration
                    
                    .. attribute:: continuity_check_interval
                    
                    	Continuity\-Check Interval
                    	**type**\:   :py:class:`CfmCcmInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ethernet_cfm_datatypes.CfmCcmInterval>`
                    
                    .. attribute:: enable
                    
                    	Enable CFM on Satellite
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: level
                    
                    	Maintenance Domain Level
                    	**type**\:  int
                    
                    	**range:** 0..7
                    
                    

                    """

                    _prefix = 'ethernet-cfm-sat-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm, self).__init__()

                        self.yang_name = "cfm"
                        self.yang_parent_name = "ethernet-features"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.continuity_check_interval = YLeaf(YType.enumeration, "continuity-check-interval")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.level = YLeaf(YType.uint32, "level")
                        self._segment_path = lambda: "cfm"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.EthernetFeatures.Cfm, ['continuity_check_interval', 'enable', 'level'], name, value)


            class FrequencySynchronization(Entity):
                """
                Frequency Synchronization satellite
                configuration
                
                .. attribute:: enable
                
                	Enable Frequency Synchronization
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'freqsync-sat-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.FrequencySynchronization, self).__init__()

                    self.yang_name = "frequency-synchronization"
                    self.yang_parent_name = "nv-satellite-fabric-link"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.enable = YLeaf(YType.empty, "enable")
                    self._segment_path = lambda: "Cisco-IOS-XR-freqsync-sat-cfg:frequency-synchronization"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.FrequencySynchronization, ['enable'], name, value)


            class Qos(Entity):
                """
                Interface QOS configuration
                
                .. attribute:: input
                
                	Ingress service policy
                	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input>`
                
                .. attribute:: output
                
                	Egress service policy
                	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output>`
                
                

                """

                _prefix = 'qos-ma-sat-cfg'
                _revision = '2017-03-03'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos, self).__init__()

                    self.yang_name = "qos"
                    self.yang_parent_name = "nv-satellite-fabric-link"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"input" : ("input", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input), "output" : ("output", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output)}
                    self._child_list_classes = {}

                    self.input = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input()
                    self.input.parent = self
                    self._children_name_map["input"] = "input"
                    self._children_yang_names.add("input")

                    self.output = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output()
                    self.output.parent = self
                    self._children_name_map["output"] = "output"
                    self._children_yang_names.add("output")
                    self._segment_path = lambda: "Cisco-IOS-XR-qos-ma-sat-cfg:qos"


                class Input(Entity):
                    """
                    Ingress service policy
                    
                    .. attribute:: service_policy
                    
                    	Service policy details
                    	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input, self).__init__()

                        self.yang_name = "input"
                        self.yang_parent_name = "qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input.ServicePolicy)}

                        self.service_policy = YList(self)
                        self._segment_path = lambda: "input"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input, [], name, value)


                    class ServicePolicy(Entity):
                        """
                        Service policy details
                        
                        .. attribute:: service_policy_name  <key>
                        
                        	Name of policy\-map
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-03-03'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "input"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.service_policy_name = YLeaf(YType.str, "service-policy-name")
                            self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Input.ServicePolicy, ['service_policy_name'], name, value)


                class Output(Entity):
                    """
                    Egress service policy
                    
                    .. attribute:: service_policy
                    
                    	Service policy details
                    	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output.ServicePolicy>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output, self).__init__()

                        self.yang_name = "output"
                        self.yang_parent_name = "qos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output.ServicePolicy)}

                        self.service_policy = YList(self)
                        self._segment_path = lambda: "output"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output, [], name, value)


                    class ServicePolicy(Entity):
                        """
                        Service policy details
                        
                        .. attribute:: service_policy_name  <key>
                        
                        	Name of policy\-map
                        	**type**\:  str
                        
                        	**length:** 0..64
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-03-03'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output.ServicePolicy, self).__init__()

                            self.yang_name = "service-policy"
                            self.yang_parent_name = "output"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.service_policy_name = YLeaf(YType.str, "service-policy-name")
                            self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Qos.Output.ServicePolicy, ['service_policy_name'], name, value)


            class Redundancy(Entity):
                """
                Redundancy submode
                
                .. attribute:: iccp_group
                
                	Links the satellite fabric to the given ICCP group
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: minimum_preferred_links
                
                	Mininum number of active links preferred
                	**type**\:  int
                
                	**range:** 1..64
                
                

                """

                _prefix = 'icpe-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy, self).__init__()

                    self.yang_name = "redundancy"
                    self.yang_parent_name = "nv-satellite-fabric-link"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.minimum_preferred_links = YLeaf(YType.uint32, "minimum-preferred-links")
                    self._segment_path = lambda: "redundancy"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.Redundancy, ['iccp_group', 'minimum_preferred_links'], name, value)


            class RemotePorts(Entity):
                """
                Remote Ports table
                
                .. attribute:: remote_port
                
                	Remote Ports
                	**type**\: list of    :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts.RemotePort>`
                
                

                """

                _prefix = 'icpe-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts, self).__init__()

                    self.yang_name = "remote-ports"
                    self.yang_parent_name = "nv-satellite-fabric-link"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"remote-port" : ("remote_port", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts.RemotePort)}

                    self.remote_port = YList(self)
                    self._segment_path = lambda: "remote-ports"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts, [], name, value)


                class RemotePort(Entity):
                    """
                    Remote Ports
                    
                    .. attribute:: port_type  <key>
                    
                    	Port type
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: slot  <key>
                    
                    	Slot
                    	**type**\:  int
                    
                    	**range:** 0..8
                    
                    .. attribute:: sub_slot  <key>
                    
                    	Sub slot
                    	**type**\:  int
                    
                    	**range:** 0..8
                    
                    .. attribute:: port_range
                    
                    	Port range
                    	**type**\:  str
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'icpe-infra-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts.RemotePort, self).__init__()

                        self.yang_name = "remote-port"
                        self.yang_parent_name = "remote-ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.port_type = YLeaf(YType.str, "port-type")

                        self.slot = YLeaf(YType.uint32, "slot")

                        self.sub_slot = YLeaf(YType.uint32, "sub-slot")

                        self.port_range = YLeaf(YType.str, "port-range")
                        self._segment_path = lambda: "remote-port" + "[port-type='" + self.port_type.get() + "']" + "[slot='" + self.slot.get() + "']" + "[sub-slot='" + self.sub_slot.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricLink.RemotePorts.RemotePort, ['port_type', 'slot', 'sub_slot', 'port_range'], name, value)


        class NvSatelliteFabricNetwork(Entity):
            """
            Complex Network connection to one or more
            Satellites
            
            .. attribute:: enable
            
            	Enable
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: redundancy
            
            	Redundancy submode
            	**type**\:   :py:class:`Redundancy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy>`
            
            .. attribute:: satellites
            
            	Connected Satellite table
            	**type**\:   :py:class:`Satellites <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites>`
            
            

            """

            _prefix = 'icpe-infra-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork, self).__init__()

                self.yang_name = "nv-satellite-fabric-network"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"redundancy" : ("redundancy", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy), "satellites" : ("satellites", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites)}
                self._child_list_classes = {}

                self.enable = YLeaf(YType.empty, "enable")

                self.redundancy = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy()
                self.redundancy.parent = self
                self._children_name_map["redundancy"] = "redundancy"
                self._children_yang_names.add("redundancy")

                self.satellites = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites()
                self.satellites.parent = self
                self._children_name_map["satellites"] = "satellites"
                self._children_yang_names.add("satellites")
                self._segment_path = lambda: "Cisco-IOS-XR-icpe-infra-cfg:nv-satellite-fabric-network"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork, ['enable'], name, value)


            class Redundancy(Entity):
                """
                Redundancy submode
                
                .. attribute:: iccp_group
                
                	Links the satellite fabric to the given ICCP group
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: minimum_preferred_links
                
                	Mininum number of active links preferred
                	**type**\:  int
                
                	**range:** 1..64
                
                

                """

                _prefix = 'icpe-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy, self).__init__()

                    self.yang_name = "redundancy"
                    self.yang_parent_name = "nv-satellite-fabric-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.iccp_group = YLeaf(YType.uint32, "iccp-group")

                    self.minimum_preferred_links = YLeaf(YType.uint32, "minimum-preferred-links")
                    self._segment_path = lambda: "redundancy"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Redundancy, ['iccp_group', 'minimum_preferred_links'], name, value)


            class Satellites(Entity):
                """
                Connected Satellite table
                
                .. attribute:: qos
                
                	Interface QOS configuration
                	**type**\:   :py:class:`Qos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos>`
                
                .. attribute:: satellite
                
                	Connected Satellite
                	**type**\: list of    :py:class:`Satellite <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite>`
                
                

                """

                _prefix = 'icpe-infra-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites, self).__init__()

                    self.yang_name = "satellites"
                    self.yang_parent_name = "nv-satellite-fabric-network"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"qos" : ("qos", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos)}
                    self._child_list_classes = {"satellite" : ("satellite", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite)}

                    self.qos = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos()
                    self.qos.parent = self
                    self._children_name_map["qos"] = "qos"
                    self._children_yang_names.add("qos")

                    self.satellite = YList(self)
                    self._segment_path = lambda: "satellites"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites, [], name, value)


                class Qos(Entity):
                    """
                    Interface QOS configuration
                    
                    .. attribute:: input
                    
                    	Ingress service policy
                    	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input>`
                    
                    .. attribute:: output
                    
                    	Egress service policy
                    	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output>`
                    
                    

                    """

                    _prefix = 'qos-ma-sat-cfg'
                    _revision = '2017-03-03'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos, self).__init__()

                        self.yang_name = "qos"
                        self.yang_parent_name = "satellites"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"input" : ("input", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input), "output" : ("output", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output)}
                        self._child_list_classes = {}

                        self.input = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input()
                        self.input.parent = self
                        self._children_name_map["input"] = "input"
                        self._children_yang_names.add("input")

                        self.output = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output()
                        self.output.parent = self
                        self._children_name_map["output"] = "output"
                        self._children_yang_names.add("output")
                        self._segment_path = lambda: "Cisco-IOS-XR-qos-ma-sat-cfg:qos"


                    class Input(Entity):
                        """
                        Ingress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input.ServicePolicy>`
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-03-03'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input, self).__init__()

                            self.yang_name = "input"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input.ServicePolicy)}

                            self.service_policy = YList(self)
                            self._segment_path = lambda: "input"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input, [], name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            

                            """

                            _prefix = 'qos-ma-sat-cfg'
                            _revision = '2017-03-03'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "input"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")
                                self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Input.ServicePolicy, ['service_policy_name'], name, value)


                    class Output(Entity):
                        """
                        Egress service policy
                        
                        .. attribute:: service_policy
                        
                        	Service policy details
                        	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output.ServicePolicy>`
                        
                        

                        """

                        _prefix = 'qos-ma-sat-cfg'
                        _revision = '2017-03-03'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output, self).__init__()

                            self.yang_name = "output"
                            self.yang_parent_name = "qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output.ServicePolicy)}

                            self.service_policy = YList(self)
                            self._segment_path = lambda: "output"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output, [], name, value)


                        class ServicePolicy(Entity):
                            """
                            Service policy details
                            
                            .. attribute:: service_policy_name  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            

                            """

                            _prefix = 'qos-ma-sat-cfg'
                            _revision = '2017-03-03'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output.ServicePolicy, self).__init__()

                                self.yang_name = "service-policy"
                                self.yang_parent_name = "output"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.service_policy_name = YLeaf(YType.str, "service-policy-name")
                                self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Qos.Output.ServicePolicy, ['service_policy_name'], name, value)


                class Satellite(Entity):
                    """
                    Connected Satellite
                    
                    .. attribute:: satellite_id  <key>
                    
                    	Satellite ID
                    	**type**\:  int
                    
                    	**range:** 100..65534
                    
                    .. attribute:: enable
                    
                    	Enable
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: remote_ports
                    
                    	Remote Ports table
                    	**type**\:   :py:class:`RemotePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts>`
                    
                    

                    """

                    _prefix = 'icpe-infra-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite, self).__init__()

                        self.yang_name = "satellite"
                        self.yang_parent_name = "satellites"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"remote-ports" : ("remote_ports", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts)}
                        self._child_list_classes = {}

                        self.satellite_id = YLeaf(YType.uint32, "satellite-id")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.remote_ports = InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts()
                        self.remote_ports.parent = self
                        self._children_name_map["remote_ports"] = "remote-ports"
                        self._children_yang_names.add("remote-ports")
                        self._segment_path = lambda: "satellite" + "[satellite-id='" + self.satellite_id.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite, ['satellite_id', 'enable'], name, value)


                    class RemotePorts(Entity):
                        """
                        Remote Ports table
                        
                        .. attribute:: remote_port
                        
                        	Remote Ports
                        	**type**\: list of    :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts.RemotePort>`
                        
                        

                        """

                        _prefix = 'icpe-infra-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts, self).__init__()

                            self.yang_name = "remote-ports"
                            self.yang_parent_name = "satellite"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"remote-port" : ("remote_port", InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts.RemotePort)}

                            self.remote_port = YList(self)
                            self._segment_path = lambda: "remote-ports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts, [], name, value)


                        class RemotePort(Entity):
                            """
                            Remote Ports
                            
                            .. attribute:: port_type  <key>
                            
                            	Port type
                            	**type**\:  str
                            
                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                            
                            .. attribute:: slot  <key>
                            
                            	Slot
                            	**type**\:  int
                            
                            	**range:** 0..8
                            
                            .. attribute:: sub_slot  <key>
                            
                            	Sub slot
                            	**type**\:  int
                            
                            	**range:** 0..8
                            
                            .. attribute:: port_range
                            
                            	Port range
                            	**type**\:  str
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'icpe-infra-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts.RemotePort, self).__init__()

                                self.yang_name = "remote-port"
                                self.yang_parent_name = "remote-ports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.port_type = YLeaf(YType.str, "port-type")

                                self.slot = YLeaf(YType.uint32, "slot")

                                self.sub_slot = YLeaf(YType.uint32, "sub-slot")

                                self.port_range = YLeaf(YType.str, "port-range")
                                self._segment_path = lambda: "remote-port" + "[port-type='" + self.port_type.get() + "']" + "[slot='" + self.slot.get() + "']" + "[sub-slot='" + self.sub_slot.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.NvSatelliteFabricNetwork.Satellites.Satellite.RemotePorts.RemotePort, ['port_type', 'slot', 'sub_slot', 'port_range'], name, value)


        class Nve(Entity):
            """
            NVE operational data
            
            .. attribute:: anycast
            
            	Enable anycast mode for this NVE interface
            	**type**\:   :py:class:`Anycast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast>`
            
            .. attribute:: ingress_replication_protocol
            
            	The Ingress Replication Protocol for this NVE
            	**type**\:   :py:class:`IrProtocolEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.IrProtocolEnum>`
            
            .. attribute:: member_vnis
            
            	VNI configuration Table for this NVE
            	**type**\:   :py:class:`MemberVnis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis>`
            
            .. attribute:: overlay_encapsulation
            
            	The Overlay Encapsulation for this NVE
            	**type**\:   :py:class:`OverlayEncapEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.OverlayEncapEnum>`
            
            	**default value**\: vx-lan-encapsulation
            
            .. attribute:: redundancy
            
            	Redundancy configuration for this NVE
            	**type**\:   :py:class:`Redundancy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy>`
            
            .. attribute:: source_interface
            
            	Source Interface for this NVE
            	**type**\:  str
            
            .. attribute:: vx_lan_udp_port
            
            	UDP port number in VxLAN encapsulation
            	**type**\:   :py:class:`VxlanUdpPortEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.VxlanUdpPortEnum>`
            
            	**default value**\: ietf-udp-port
            
            

            """

            _prefix = 'tunnel-nve-cfg'
            _revision = '2016-08-30'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Nve, self).__init__()

                self.yang_name = "nve"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"anycast" : ("anycast", InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast), "member-vnis" : ("member_vnis", InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis), "redundancy" : ("redundancy", InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy)}
                self._child_list_classes = {}

                self.ingress_replication_protocol = YLeaf(YType.enumeration, "ingress-replication-protocol")

                self.overlay_encapsulation = YLeaf(YType.enumeration, "overlay-encapsulation")

                self.source_interface = YLeaf(YType.str, "source-interface")

                self.vx_lan_udp_port = YLeaf(YType.enumeration, "vx-lan-udp-port")

                self.anycast = InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast()
                self.anycast.parent = self
                self._children_name_map["anycast"] = "anycast"
                self._children_yang_names.add("anycast")

                self.member_vnis = InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis()
                self.member_vnis.parent = self
                self._children_name_map["member_vnis"] = "member-vnis"
                self._children_yang_names.add("member-vnis")

                self.redundancy = InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy()
                self.redundancy.parent = self
                self._children_name_map["redundancy"] = "redundancy"
                self._children_yang_names.add("redundancy")
                self._segment_path = lambda: "Cisco-IOS-XR-tunnel-nve-cfg:nve"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Nve, ['ingress_replication_protocol', 'overlay_encapsulation', 'source_interface', 'vx_lan_udp_port'], name, value)


            class Anycast(Entity):
                """
                Enable anycast mode for this NVE interface
                
                .. attribute:: source_interface
                
                	Name of the Anycast mode source interface
                	**type**\:  str
                
                .. attribute:: sync_group
                
                	MCast group for syncing between Anycast gateways
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'tunnel-nve-cfg'
                _revision = '2016-08-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast, self).__init__()

                    self.yang_name = "anycast"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.source_interface = YLeaf(YType.str, "source-interface")

                    self.sync_group = YLeaf(YType.str, "sync-group")
                    self._segment_path = lambda: "anycast"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Nve.Anycast, ['source_interface', 'sync_group'], name, value)


            class MemberVnis(Entity):
                """
                VNI configuration Table for this NVE
                
                .. attribute:: member_vni
                
                	VNI member attributes
                	**type**\: list of    :py:class:`MemberVni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni>`
                
                

                """

                _prefix = 'tunnel-nve-cfg'
                _revision = '2016-08-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis, self).__init__()

                    self.yang_name = "member-vnis"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"member-vni" : ("member_vni", InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni)}

                    self.member_vni = YList(self)
                    self._segment_path = lambda: "member-vnis"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis, [], name, value)


                class MemberVni(Entity):
                    """
                    VNI member attributes
                    
                    .. attribute:: vni_start  <key>
                    
                    	Single VNI or Range Start
                    	**type**\:  int
                    
                    	**range:** 1..16777215
                    
                    .. attribute:: vni_end  <key>
                    
                    	Range End
                    	**type**\:  int
                    
                    	**range:** 1..16777215
                    
                    .. attribute:: enable
                    
                    	Enable VNI
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: host_reachability
                    
                    	Control protocol for VxLAN tunnel endpoint reachability
                    	**type**\:   :py:class:`HostReachProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.HostReachProtocol>`
                    
                    .. attribute:: load_balance_per_evi
                    
                    	Per\-evi load balance mode
                    	**type**\:   :py:class:`LoadBalanceEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.LoadBalanceEnum>`
                    
                    .. attribute:: multicast
                    
                    	Mulitcast core group range associated with the VxLAN segment(s)
                    	**type**\:   :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni.Multicast>`
                    
                    	**presence node**\: True
                    
                    .. attribute:: unknown_unicast_flooding
                    
                    	Suppression of unknown unicast flooding
                    	**type**\:   :py:class:`UnknownUnicastFloodingEnum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_nve_cfg.UnknownUnicastFloodingEnum>`
                    
                    .. attribute:: vrf
                    
                    	VRF associated with the VxLAN segment
                    	**type**\:  str
                    
                    

                    """

                    _prefix = 'tunnel-nve-cfg'
                    _revision = '2016-08-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni, self).__init__()

                        self.yang_name = "member-vni"
                        self.yang_parent_name = "member-vnis"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"multicast" : ("multicast", InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni.Multicast)}
                        self._child_list_classes = {}

                        self.vni_start = YLeaf(YType.uint32, "vni-start")

                        self.vni_end = YLeaf(YType.uint32, "vni-end")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.host_reachability = YLeaf(YType.enumeration, "host-reachability")

                        self.load_balance_per_evi = YLeaf(YType.enumeration, "load-balance-per-evi")

                        self.unknown_unicast_flooding = YLeaf(YType.enumeration, "unknown-unicast-flooding")

                        self.vrf = YLeaf(YType.str, "vrf")

                        self.multicast = None
                        self._children_name_map["multicast"] = "multicast"
                        self._children_yang_names.add("multicast")
                        self._segment_path = lambda: "member-vni" + "[vni-start='" + self.vni_start.get() + "']" + "[vni-end='" + self.vni_end.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni, ['vni_start', 'vni_end', 'enable', 'host_reachability', 'load_balance_per_evi', 'unknown_unicast_flooding', 'vrf'], name, value)


                    class Multicast(Entity):
                        """
                        Mulitcast core group range associated with
                        the VxLAN segment(s)
                        
                        .. attribute:: multicast_group_max
                        
                        	IPV4 group address MAX
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: multicast_group_min
                        
                        	IPV4 group address of the tunnel source
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        This class is a :ref:`presence class<presence-class>`

                        """

                        _prefix = 'tunnel-nve-cfg'
                        _revision = '2016-08-30'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni.Multicast, self).__init__()

                            self.yang_name = "multicast"
                            self.yang_parent_name = "member-vni"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}
                            self.is_presence_container = True

                            self.multicast_group_max = YLeaf(YType.str, "multicast-group-max")

                            self.multicast_group_min = YLeaf(YType.str, "multicast-group-min")
                            self._segment_path = lambda: "multicast"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Nve.MemberVnis.MemberVni.Multicast, ['multicast_group_max', 'multicast_group_min'], name, value)


            class Redundancy(Entity):
                """
                Redundancy configuration for this NVE
                
                .. attribute:: backbone_mpls
                
                	MPLS backbone
                	**type**\:   :py:class:`BackboneMpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls>`
                
                .. attribute:: backbone_vx_lan
                
                	VXLAN backbone
                	**type**\:   :py:class:`BackboneVxLan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan>`
                
                .. attribute:: enable
                
                	Enable Redundancy
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'tunnel-nve-cfg'
                _revision = '2016-08-30'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy, self).__init__()

                    self.yang_name = "redundancy"
                    self.yang_parent_name = "nve"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"backbone-mpls" : ("backbone_mpls", InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls), "backbone-vx-lan" : ("backbone_vx_lan", InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan)}
                    self._child_list_classes = {}

                    self.enable = YLeaf(YType.empty, "enable")

                    self.backbone_mpls = InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls()
                    self.backbone_mpls.parent = self
                    self._children_name_map["backbone_mpls"] = "backbone-mpls"
                    self._children_yang_names.add("backbone-mpls")

                    self.backbone_vx_lan = InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan()
                    self.backbone_vx_lan.parent = self
                    self._children_name_map["backbone_vx_lan"] = "backbone-vx-lan"
                    self._children_yang_names.add("backbone-vx-lan")
                    self._segment_path = lambda: "redundancy"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy, ['enable'], name, value)


                class BackboneMpls(Entity):
                    """
                    MPLS backbone
                    
                    .. attribute:: backbone_mplsiccp
                    
                    	MPLS backbone ICCP group
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: enable
                    
                    	Enable Backbone MPLS
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'tunnel-nve-cfg'
                    _revision = '2016-08-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls, self).__init__()

                        self.yang_name = "backbone-mpls"
                        self.yang_parent_name = "redundancy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.backbone_mplsiccp = YLeaf(YType.int32, "backbone-mplsiccp")

                        self.enable = YLeaf(YType.empty, "enable")
                        self._segment_path = lambda: "backbone-mpls"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneMpls, ['backbone_mplsiccp', 'enable'], name, value)


                class BackboneVxLan(Entity):
                    """
                    VXLAN backbone
                    
                    .. attribute:: backbone_vx_laniccp
                    
                    	VxLAN backbone ICCP group
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: enable
                    
                    	Enable Backbone VxLAN
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'tunnel-nve-cfg'
                    _revision = '2016-08-30'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan, self).__init__()

                        self.yang_name = "backbone-vx-lan"
                        self.yang_parent_name = "redundancy"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.backbone_vx_laniccp = YLeaf(YType.int32, "backbone-vx-laniccp")

                        self.enable = YLeaf(YType.empty, "enable")
                        self._segment_path = lambda: "backbone-vx-lan"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Nve.Redundancy.BackboneVxLan, ['backbone_vx_laniccp', 'enable'], name, value)


        class Optics(Entity):
            """
            Optics controller configuration
            
            .. attribute:: breakout
            
            	breakout mode configuration
            	**type**\:  str
            
            	**pattern:** (4x10)\|(4x25)
            
            .. attribute:: optics_cd_high_threshold
            
            	Select chromatic dispersion high threshold(in units of ps/nm)
            	**type**\:  int
            
            	**range:** \-280000..280000
            
            .. attribute:: optics_cd_low_threshold
            
            	Select chromatic dispersion low threshold(in units of ps/nm)
            	**type**\:  int
            
            	**range:** \-280000..280000
            
            .. attribute:: optics_cd_max
            
            	Select max chromatic dispersion (in units of ps/nm)
            	**type**\:  int
            
            	**range:** \-280000..280000
            
            .. attribute:: optics_cd_min
            
            	Select min chromatic dispersion (in units of ps/nm)
            	**type**\:  int
            
            	**range:** \-280000..280000
            
            .. attribute:: optics_description
            
            	Configure optics port description 
            	**type**\:  str
            
            	**length:** 1..255
            
            .. attribute:: optics_dgd_high_threshold
            
            	Select DGD high threshold(in units of 0.1ps)
            	**type**\:  int
            
            	**range:** 0..18000
            
            .. attribute:: optics_dwdm_carrier
            
            	Configure optics DWDM Carrier
            	**type**\:   :py:class:`OpticsDwdmCarrier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsDwdmCarrier>`
            
            	**presence node**\: True
            
            .. attribute:: optics_fec
            
            	Configure optics fec 
            	**type**\:   :py:class:`OpticsFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsFec>`
            
            	**default value**\: fec-none
            
            .. attribute:: optics_lanes
            
            	Optics lanes
            	**type**\:   :py:class:`OpticsLanes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes>`
            
            .. attribute:: optics_lbc_high_threshold
            
            	Select power level (in units of percentage)
            	**type**\:  int
            
            	**range:** 0..100
            
            .. attribute:: optics_loopback
            
            	Configure optics loopback mode 
            	**type**\:   :py:class:`OpticsLoopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsLoopback>`
            
            	**default value**\: none
            
            .. attribute:: optics_network_srlgs
            
            	Configure Network srlgs
            	**type**\:   :py:class:`OpticsNetworkSrlgs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs>`
            
            .. attribute:: optics_osnr_low_threshold
            
            	Select OSNR low threshold(in units of 0.01db)
            	**type**\:  int
            
            	**range:** 0..4000
            
            .. attribute:: optics_ots_amplifier_channel_power
            
            	Select Amplifier Channel Power(in units of 0 .1dBm)
            	**type**\:  int
            
            	**range:** \-500..300
            
            .. attribute:: optics_ots_amplifier_control_mode
            
            	Configure amplifier working mode
            	**type**\:   :py:class:`OpticsOtsAmpliControlMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsOtsAmpliControlMode>`
            
            .. attribute:: optics_ots_amplifier_gain
            
            	Select Amplifier Gain value(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..500
            
            .. attribute:: optics_ots_amplifier_gain_degrade_high_threshold
            
            	Select Amplifier Gain Degrade High Threshold(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..500
            
            .. attribute:: optics_ots_amplifier_gain_degrade_low_threshold
            
            	Select Amplifier Gain Degrade Low Threshold(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..500
            
            .. attribute:: optics_ots_amplifier_gain_range
            
            	Normal or extended Ampli Gain Range
            	**type**\:   :py:class:`OpticsOtsAmpliGainRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsOtsAmpliGainRange>`
            
            .. attribute:: optics_ots_amplifier_tilt
            
            	Select Amplifier Tilt value(in units of 0.1dB)
            	**type**\:  int
            
            	**range:** \-50..50
            
            .. attribute:: optics_ots_channel_power_max_delta
            
            	Configure max delta among all measured channel powers 
            	**type**\:  int
            
            	**range:** \-500..300
            
            .. attribute:: optics_ots_osri
            
            	Configure Optical safety remote interlock (OSRI)
            	**type**\:  bool
            
            .. attribute:: optics_ots_rx_voa_attenuation
            
            	Select RX Voa Attenuation Setpoint(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..200
            
            .. attribute:: optics_ots_safety_control_mode
            
            	Configure safety Control Mode
            	**type**\:   :py:class:`OpticsOtsSafetyControlMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsOtsSafetyControlMode>`
            
            .. attribute:: optics_ots_tx_voa_attenuation
            
            	Select TX Voa Attenuation Setpoint(in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** 0..200
            
            .. attribute:: optics_performance_monitoring
            
            	Select Performance Monitoring as Enable or Disable
            	**type**\:  bool
            
            	**default value**\: true
            
            .. attribute:: optics_transmit_power
            
            	Select power level (in units of 0.1dBm)
            	**type**\:  int
            
            	**range:** \-190..20
            
            .. attribute:: optics_transmit_shutdown
            
            	Configure optics transmit laser shutdown 
            	**type**\:  bool
            
            .. attribute:: rx_thresholds
            
            	Configure Rx threshold
            	**type**\:   :py:class:`RxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds>`
            
            .. attribute:: tx_thresholds
            
            	Configure Tx threshold
            	**type**\:   :py:class:`TxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds>`
            
            

            """

            _prefix = 'controller-optics-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Optics, self).__init__()

                self.yang_name = "optics"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"optics-dwdm-carrier" : ("optics_dwdm_carrier", InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsDwdmCarrier), "optics-lanes" : ("optics_lanes", InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes), "optics-network-srlgs" : ("optics_network_srlgs", InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs), "rx-thresholds" : ("rx_thresholds", InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds), "tx-thresholds" : ("tx_thresholds", InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds)}
                self._child_list_classes = {}

                self.breakout = YLeaf(YType.str, "Cisco-IOS-XR-optics-driver-cfg:breakout")

                self.optics_cd_high_threshold = YLeaf(YType.int32, "optics-cd-high-threshold")

                self.optics_cd_low_threshold = YLeaf(YType.int32, "optics-cd-low-threshold")

                self.optics_cd_max = YLeaf(YType.int32, "optics-cd-max")

                self.optics_cd_min = YLeaf(YType.int32, "optics-cd-min")

                self.optics_description = YLeaf(YType.str, "optics-description")

                self.optics_dgd_high_threshold = YLeaf(YType.int32, "optics-dgd-high-threshold")

                self.optics_fec = YLeaf(YType.enumeration, "optics-fec")

                self.optics_lbc_high_threshold = YLeaf(YType.int32, "optics-lbc-high-threshold")

                self.optics_loopback = YLeaf(YType.enumeration, "optics-loopback")

                self.optics_osnr_low_threshold = YLeaf(YType.int32, "optics-osnr-low-threshold")

                self.optics_ots_amplifier_channel_power = YLeaf(YType.int32, "optics-ots-amplifier-channel-power")

                self.optics_ots_amplifier_control_mode = YLeaf(YType.enumeration, "optics-ots-amplifier-control-mode")

                self.optics_ots_amplifier_gain = YLeaf(YType.int32, "optics-ots-amplifier-gain")

                self.optics_ots_amplifier_gain_degrade_high_threshold = YLeaf(YType.int32, "optics-ots-amplifier-gain-degrade-high-threshold")

                self.optics_ots_amplifier_gain_degrade_low_threshold = YLeaf(YType.int32, "optics-ots-amplifier-gain-degrade-low-threshold")

                self.optics_ots_amplifier_gain_range = YLeaf(YType.enumeration, "optics-ots-amplifier-gain-range")

                self.optics_ots_amplifier_tilt = YLeaf(YType.int32, "optics-ots-amplifier-tilt")

                self.optics_ots_channel_power_max_delta = YLeaf(YType.int32, "optics-ots-channel-power-max-delta")

                self.optics_ots_osri = YLeaf(YType.boolean, "optics-ots-osri")

                self.optics_ots_rx_voa_attenuation = YLeaf(YType.int32, "optics-ots-rx-voa-attenuation")

                self.optics_ots_safety_control_mode = YLeaf(YType.enumeration, "optics-ots-safety-control-mode")

                self.optics_ots_tx_voa_attenuation = YLeaf(YType.int32, "optics-ots-tx-voa-attenuation")

                self.optics_performance_monitoring = YLeaf(YType.boolean, "optics-performance-monitoring")

                self.optics_transmit_power = YLeaf(YType.int32, "optics-transmit-power")

                self.optics_transmit_shutdown = YLeaf(YType.boolean, "optics-transmit-shutdown")

                self.optics_dwdm_carrier = None
                self._children_name_map["optics_dwdm_carrier"] = "optics-dwdm-carrier"
                self._children_yang_names.add("optics-dwdm-carrier")

                self.optics_lanes = InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes()
                self.optics_lanes.parent = self
                self._children_name_map["optics_lanes"] = "optics-lanes"
                self._children_yang_names.add("optics-lanes")

                self.optics_network_srlgs = InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs()
                self.optics_network_srlgs.parent = self
                self._children_name_map["optics_network_srlgs"] = "optics-network-srlgs"
                self._children_yang_names.add("optics-network-srlgs")

                self.rx_thresholds = InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds()
                self.rx_thresholds.parent = self
                self._children_name_map["rx_thresholds"] = "rx-thresholds"
                self._children_yang_names.add("rx-thresholds")

                self.tx_thresholds = InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds()
                self.tx_thresholds.parent = self
                self._children_name_map["tx_thresholds"] = "tx-thresholds"
                self._children_yang_names.add("tx-thresholds")
                self._segment_path = lambda: "Cisco-IOS-XR-controller-optics-cfg:optics"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics, ['breakout', 'optics_cd_high_threshold', 'optics_cd_low_threshold', 'optics_cd_max', 'optics_cd_min', 'optics_description', 'optics_dgd_high_threshold', 'optics_fec', 'optics_lbc_high_threshold', 'optics_loopback', 'optics_osnr_low_threshold', 'optics_ots_amplifier_channel_power', 'optics_ots_amplifier_control_mode', 'optics_ots_amplifier_gain', 'optics_ots_amplifier_gain_degrade_high_threshold', 'optics_ots_amplifier_gain_degrade_low_threshold', 'optics_ots_amplifier_gain_range', 'optics_ots_amplifier_tilt', 'optics_ots_channel_power_max_delta', 'optics_ots_osri', 'optics_ots_rx_voa_attenuation', 'optics_ots_safety_control_mode', 'optics_ots_tx_voa_attenuation', 'optics_performance_monitoring', 'optics_transmit_power', 'optics_transmit_shutdown'], name, value)


            class OpticsDwdmCarrier(Entity):
                """
                Configure optics DWDM Carrier
                
                .. attribute:: grid_type
                
                	DWDM Channel Grid Type
                	**type**\:   :py:class:`OpticsDwdmCarrierGrid <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsDwdmCarrierGrid>`
                
                	**mandatory**\: True
                
                .. attribute:: param_type
                
                	DWDM Channel Parameter Type ITU\-Channel or Frequency or Wavelength
                	**type**\:   :py:class:`OpticsDwdmCarrierParam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.OpticsDwdmCarrierParam>`
                
                	**mandatory**\: True
                
                .. attribute:: param_value
                
                	Type ITU\-Channel Range 1\-100, Frequency Range 19115\-19610, Wavelength Range 1528773\-1568362, 100MHz Frequency Range 1911500\-1961000
                	**type**\:  int
                
                	**range:** 1..1961000
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsDwdmCarrier, self).__init__()

                    self.yang_name = "optics-dwdm-carrier"
                    self.yang_parent_name = "optics"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.grid_type = YLeaf(YType.enumeration, "grid-type")

                    self.param_type = YLeaf(YType.enumeration, "param-type")

                    self.param_value = YLeaf(YType.uint32, "param-value")
                    self._segment_path = lambda: "optics-dwdm-carrier"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsDwdmCarrier, ['grid_type', 'param_type', 'param_value'], name, value)


            class OpticsLanes(Entity):
                """
                Optics lanes
                
                .. attribute:: optics_lane
                
                	Lane
                	**type**\: list of    :py:class:`OpticsLane <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes.OpticsLane>`
                
                

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes, self).__init__()

                    self.yang_name = "optics-lanes"
                    self.yang_parent_name = "optics"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"optics-lane" : ("optics_lane", InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes.OpticsLane)}

                    self.optics_lane = YList(self)
                    self._segment_path = lambda: "optics-lanes"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes, [], name, value)


                class OpticsLane(Entity):
                    """
                    Lane
                    
                    .. attribute:: index  <key>
                    
                    	Lane Number
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: description
                    
                    	Configure description for this Lane
                    	**type**\:  str
                    
                    	**length:** 1..255
                    
                    

                    """

                    _prefix = 'controller-optics-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes.OpticsLane, self).__init__()

                        self.yang_name = "optics-lane"
                        self.yang_parent_name = "optics-lanes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.index = YLeaf(YType.int32, "index")

                        self.description = YLeaf(YType.str, "description")
                        self._segment_path = lambda: "optics-lane" + "[index='" + self.index.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsLanes.OpticsLane, ['index', 'description'], name, value)


            class OpticsNetworkSrlgs(Entity):
                """
                Configure Network srlgs
                
                .. attribute:: optics_network_srlg
                
                	Configure network srlg sets
                	**type**\: list of    :py:class:`OpticsNetworkSrlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs.OpticsNetworkSrlg>`
                
                

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs, self).__init__()

                    self.yang_name = "optics-network-srlgs"
                    self.yang_parent_name = "optics"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"optics-network-srlg" : ("optics_network_srlg", InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs.OpticsNetworkSrlg)}

                    self.optics_network_srlg = YList(self)
                    self._segment_path = lambda: "optics-network-srlgs"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs, [], name, value)


                class OpticsNetworkSrlg(Entity):
                    """
                    Configure network srlg sets
                    
                    .. attribute:: set_id  <key>
                    
                    	Set index
                    	**type**\:  int
                    
                    	**range:** 1..17
                    
                    .. attribute:: srlg1
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg2
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg3
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg4
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg5
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg6
                    
                    	none
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    

                    """

                    _prefix = 'controller-optics-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs.OpticsNetworkSrlg, self).__init__()

                        self.yang_name = "optics-network-srlg"
                        self.yang_parent_name = "optics-network-srlgs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.set_id = YLeaf(YType.uint32, "set-id")

                        self.srlg1 = YLeaf(YType.uint32, "srlg1")

                        self.srlg2 = YLeaf(YType.uint32, "srlg2")

                        self.srlg3 = YLeaf(YType.uint32, "srlg3")

                        self.srlg4 = YLeaf(YType.uint32, "srlg4")

                        self.srlg5 = YLeaf(YType.uint32, "srlg5")

                        self.srlg6 = YLeaf(YType.uint32, "srlg6")
                        self._segment_path = lambda: "optics-network-srlg" + "[set-id='" + self.set_id.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics.OpticsNetworkSrlgs.OpticsNetworkSrlg, ['set_id', 'srlg1', 'srlg2', 'srlg3', 'srlg4', 'srlg5', 'srlg6'], name, value)


            class RxThresholds(Entity):
                """
                Configure Rx threshold
                
                .. attribute:: rx_threshold
                
                	Optics RX Low or high threshold configuration
                	**type**\: list of    :py:class:`RxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds.RxThreshold>`
                
                

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds, self).__init__()

                    self.yang_name = "rx-thresholds"
                    self.yang_parent_name = "optics"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"rx-threshold" : ("rx_threshold", InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds.RxThreshold)}

                    self.rx_threshold = YList(self)
                    self._segment_path = lambda: "rx-thresholds"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds, [], name, value)


                class RxThreshold(Entity):
                    """
                    Optics RX Low or high threshold configuration
                    
                    .. attribute:: rx_threshold_type  <key>
                    
                    	Low or high rx threshold
                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.Threshold>`
                    
                    .. attribute:: rx_threshold
                    
                    	Select power level (in units of 0.1dBm)
                    	**type**\:  int
                    
                    	**range:** \-400..300
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'controller-optics-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds.RxThreshold, self).__init__()

                        self.yang_name = "rx-threshold"
                        self.yang_parent_name = "rx-thresholds"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.rx_threshold_type = YLeaf(YType.enumeration, "rx-threshold-type")

                        self.rx_threshold = YLeaf(YType.int32, "rx-threshold")
                        self._segment_path = lambda: "rx-threshold" + "[rx-threshold-type='" + self.rx_threshold_type.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics.RxThresholds.RxThreshold, ['rx_threshold_type', 'rx_threshold'], name, value)


            class TxThresholds(Entity):
                """
                Configure Tx threshold
                
                .. attribute:: tx_threshold
                
                	Optics TX Low or high threshold configuration
                	**type**\: list of    :py:class:`TxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds.TxThreshold>`
                
                

                """

                _prefix = 'controller-optics-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds, self).__init__()

                    self.yang_name = "tx-thresholds"
                    self.yang_parent_name = "optics"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"tx-threshold" : ("tx_threshold", InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds.TxThreshold)}

                    self.tx_threshold = YList(self)
                    self._segment_path = lambda: "tx-thresholds"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds, [], name, value)


                class TxThreshold(Entity):
                    """
                    Optics TX Low or high threshold configuration
                    
                    .. attribute:: tx_threshold_type  <key>
                    
                    	Low or high tx threshold
                    	**type**\:   :py:class:`Threshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_optics_cfg.Threshold>`
                    
                    .. attribute:: tx_threshold
                    
                    	Select power level (in units of 0.1dBm)
                    	**type**\:  int
                    
                    	**range:** \-400..300
                    
                    	**mandatory**\: True
                    
                    

                    """

                    _prefix = 'controller-optics-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds.TxThreshold, self).__init__()

                        self.yang_name = "tx-threshold"
                        self.yang_parent_name = "tx-thresholds"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.tx_threshold_type = YLeaf(YType.enumeration, "tx-threshold-type")

                        self.tx_threshold = YLeaf(YType.int32, "tx-threshold")
                        self._segment_path = lambda: "tx-threshold" + "[tx-threshold-type='" + self.tx_threshold_type.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Optics.TxThresholds.TxThreshold, ['tx_threshold_type', 'tx_threshold'], name, value)


        class Otu(Entity):
            """
            OTU port controller configuration
            
            .. attribute:: fec
            
            	Configure forward error correction
            	**type**\:   :py:class:`OtuForwardErrorCorrection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtuForwardErrorCorrection>`
            
            	**default value**\: none
            
            .. attribute:: gcc
            
            	General Communication Channel configuration
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: loopback
            
            	Type of Loopback
            	**type**\:   :py:class:`OtnLoopback <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnLoopback>`
            
            .. attribute:: network_srlgs
            
            	Configure Network srlgs
            	**type**\:   :py:class:`NetworkSrlgs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs>`
            
            .. attribute:: otn_expected_tti
            
            	Configure OTN Expected TTI value for Full ASCII/HEX
            	**type**\:   :py:class:`OtnExpectedTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti>`
            
            .. attribute:: otn_expected_ttisapi
            
            	Configure OTN Expected TTI value for SAPI configs
            	**type**\:   :py:class:`OtnExpectedTtisapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi>`
            
            .. attribute:: otn_expected_ttitcmdapi
            
            	Configure OTN Expected TTI value for DAPI configs
            	**type**\:   :py:class:`OtnExpectedTtitcmdapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi>`
            
            .. attribute:: otn_expected_ttitcmos
            
            	Configure OTN Expected TTI value for OS config
            	**type**\:   :py:class:`OtnExpectedTtitcmos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos>`
            
            .. attribute:: otn_send_tti
            
            	Configure OTN Send TTI value for Full ASCII/HEX
            	**type**\:   :py:class:`OtnSendTti <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti>`
            
            .. attribute:: otn_send_ttisapi
            
            	Configure OTN Send TTI value for SAPI configs
            	**type**\:   :py:class:`OtnSendTtisapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi>`
            
            .. attribute:: otn_send_ttitcmdapi
            
            	Configure OTN Send TTI value for DAPI configs
            	**type**\:   :py:class:`OtnSendTtitcmdapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi>`
            
            .. attribute:: otn_send_ttitcmos
            
            	Configure OTN Send TTI value for OS config
            	**type**\:   :py:class:`OtnSendTtitcmos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos>`
            
            .. attribute:: performance_monitoring
            
            	Configure performance monitoring
            	**type**\:   :py:class:`OtnPerMon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnPerMon>`
            
            	**default value**\: enable
            
            .. attribute:: prbs
            
            	Enable Prbs And configure
            	**type**\:   :py:class:`Prbs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.Prbs>`
            
            .. attribute:: proactive_protection
            
            	Configure Proactive Protection
            	**type**\:   :py:class:`ProactiveProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection>`
            
            .. attribute:: sd
            
            	Signal degrade threshold
            	**type**\:  int
            
            	**range:** 5..9
            
            .. attribute:: secondary_admin_state
            
            	Configure secondary admin state 
            	**type**\:   :py:class:`OtnSecAdminState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSecAdminState>`
            
            	**default value**\: normal
            
            .. attribute:: sf
            
            	Signal failure threshold
            	**type**\:  int
            
            	**range:** 5..9
            
            

            """

            _prefix = 'controller-otu-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Otu, self).__init__()

                self.yang_name = "otu"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"network-srlgs" : ("network_srlgs", InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs), "otn-expected-tti" : ("otn_expected_tti", InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti), "otn-expected-ttisapi" : ("otn_expected_ttisapi", InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi), "otn-expected-ttitcmdapi" : ("otn_expected_ttitcmdapi", InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi), "otn-expected-ttitcmos" : ("otn_expected_ttitcmos", InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos), "otn-send-tti" : ("otn_send_tti", InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti), "otn-send-ttisapi" : ("otn_send_ttisapi", InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi), "otn-send-ttitcmdapi" : ("otn_send_ttitcmdapi", InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi), "otn-send-ttitcmos" : ("otn_send_ttitcmos", InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos), "prbs" : ("prbs", InterfaceConfigurations.InterfaceConfiguration.Otu.Prbs), "proactive-protection" : ("proactive_protection", InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection)}
                self._child_list_classes = {}

                self.fec = YLeaf(YType.enumeration, "fec")

                self.gcc = YLeaf(YType.empty, "gcc")

                self.loopback = YLeaf(YType.enumeration, "loopback")

                self.performance_monitoring = YLeaf(YType.enumeration, "performance-monitoring")

                self.sd = YLeaf(YType.uint32, "sd")

                self.secondary_admin_state = YLeaf(YType.enumeration, "secondary-admin-state")

                self.sf = YLeaf(YType.uint32, "sf")

                self.network_srlgs = InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs()
                self.network_srlgs.parent = self
                self._children_name_map["network_srlgs"] = "network-srlgs"
                self._children_yang_names.add("network-srlgs")

                self.otn_expected_tti = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti()
                self.otn_expected_tti.parent = self
                self._children_name_map["otn_expected_tti"] = "otn-expected-tti"
                self._children_yang_names.add("otn-expected-tti")

                self.otn_expected_ttisapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi()
                self.otn_expected_ttisapi.parent = self
                self._children_name_map["otn_expected_ttisapi"] = "otn-expected-ttisapi"
                self._children_yang_names.add("otn-expected-ttisapi")

                self.otn_expected_ttitcmdapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi()
                self.otn_expected_ttitcmdapi.parent = self
                self._children_name_map["otn_expected_ttitcmdapi"] = "otn-expected-ttitcmdapi"
                self._children_yang_names.add("otn-expected-ttitcmdapi")

                self.otn_expected_ttitcmos = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos()
                self.otn_expected_ttitcmos.parent = self
                self._children_name_map["otn_expected_ttitcmos"] = "otn-expected-ttitcmos"
                self._children_yang_names.add("otn-expected-ttitcmos")

                self.otn_send_tti = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti()
                self.otn_send_tti.parent = self
                self._children_name_map["otn_send_tti"] = "otn-send-tti"
                self._children_yang_names.add("otn-send-tti")

                self.otn_send_ttisapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi()
                self.otn_send_ttisapi.parent = self
                self._children_name_map["otn_send_ttisapi"] = "otn-send-ttisapi"
                self._children_yang_names.add("otn-send-ttisapi")

                self.otn_send_ttitcmdapi = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi()
                self.otn_send_ttitcmdapi.parent = self
                self._children_name_map["otn_send_ttitcmdapi"] = "otn-send-ttitcmdapi"
                self._children_yang_names.add("otn-send-ttitcmdapi")

                self.otn_send_ttitcmos = InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos()
                self.otn_send_ttitcmos.parent = self
                self._children_name_map["otn_send_ttitcmos"] = "otn-send-ttitcmos"
                self._children_yang_names.add("otn-send-ttitcmos")

                self.prbs = InterfaceConfigurations.InterfaceConfiguration.Otu.Prbs()
                self.prbs.parent = self
                self._children_name_map["prbs"] = "prbs"
                self._children_yang_names.add("prbs")

                self.proactive_protection = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection()
                self.proactive_protection.parent = self
                self._children_name_map["proactive_protection"] = "proactive-protection"
                self._children_yang_names.add("proactive-protection")
                self._segment_path = lambda: "Cisco-IOS-XR-controller-otu-cfg:otu"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu, ['fec', 'gcc', 'loopback', 'performance_monitoring', 'sd', 'secondary_admin_state', 'sf'], name, value)


            class NetworkSrlgs(Entity):
                """
                Configure Network srlgs
                
                .. attribute:: network_srlg
                
                	Configure network srlg sets
                	**type**\: list of    :py:class:`NetworkSrlg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs.NetworkSrlg>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs, self).__init__()

                    self.yang_name = "network-srlgs"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"network-srlg" : ("network_srlg", InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs.NetworkSrlg)}

                    self.network_srlg = YList(self)
                    self._segment_path = lambda: "network-srlgs"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs, [], name, value)


                class NetworkSrlg(Entity):
                    """
                    Configure network srlg sets
                    
                    .. attribute:: set_id  <key>
                    
                    	Set index
                    	**type**\:  int
                    
                    	**range:** 1..17
                    
                    .. attribute:: srlg1
                    
                    	First value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg2
                    
                    	Second value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg3
                    
                    	Third value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg4
                    
                    	Forth value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg5
                    
                    	Fifth value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    .. attribute:: srlg6
                    
                    	Sixth value for Network SRLG
                    	**type**\:  int
                    
                    	**range:** 0..4294967294
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs.NetworkSrlg, self).__init__()

                        self.yang_name = "network-srlg"
                        self.yang_parent_name = "network-srlgs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.set_id = YLeaf(YType.uint32, "set-id")

                        self.srlg1 = YLeaf(YType.uint32, "srlg1")

                        self.srlg2 = YLeaf(YType.uint32, "srlg2")

                        self.srlg3 = YLeaf(YType.uint32, "srlg3")

                        self.srlg4 = YLeaf(YType.uint32, "srlg4")

                        self.srlg5 = YLeaf(YType.uint32, "srlg5")

                        self.srlg6 = YLeaf(YType.uint32, "srlg6")
                        self._segment_path = lambda: "network-srlg" + "[set-id='" + self.set_id.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.NetworkSrlgs.NetworkSrlg, ['set_id', 'srlg1', 'srlg2', 'srlg3', 'srlg4', 'srlg5', 'srlg6'], name, value)


            class OtnExpectedTti(Entity):
                """
                Configure OTN Expected TTI value for Full
                ASCII/HEX
                
                .. attribute:: full_ascii_string
                
                	Full ASCII text (Max 64 characters)
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: hex_string
                
                	Hex nibbles (Max 128 \- The string length should be an even number)
                	**type**\:  str
                
                	**length:** 1..128
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnExpTtiTypeFull <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnExpTtiTypeFull>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti, self).__init__()

                    self.yang_name = "otn-expected-tti"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.full_ascii_string = YLeaf(YType.str, "full-ascii-string")

                    self.hex_string = YLeaf(YType.str, "hex-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")
                    self._segment_path = lambda: "otn-expected-tti"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTti, ['full_ascii_string', 'hex_string', 'string_type'], name, value)


            class OtnExpectedTtisapi(Entity):
                """
                Configure OTN Expected TTI value for SAPI
                configs
                
                .. attribute:: sapi_ascii_string
                
                	SAPI ASCII text (Max 14 characters)
                	**type**\:  str
                
                	**length:** 1..14
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnExpTtiTypeSapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnExpTtiTypeSapi>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi, self).__init__()

                    self.yang_name = "otn-expected-ttisapi"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.sapi_ascii_string = YLeaf(YType.str, "sapi-ascii-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")
                    self._segment_path = lambda: "otn-expected-ttisapi"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtisapi, ['sapi_ascii_string', 'string_type'], name, value)


            class OtnExpectedTtitcmdapi(Entity):
                """
                Configure OTN Expected TTI value for DAPI
                configs
                
                .. attribute:: dapi_ascii_string
                
                	DAPI ASCII text (Max 14 characters)
                	**type**\:  str
                
                	**length:** 1..14
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnExpTtiTypeDapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnExpTtiTypeDapi>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi, self).__init__()

                    self.yang_name = "otn-expected-ttitcmdapi"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.dapi_ascii_string = YLeaf(YType.str, "dapi-ascii-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")
                    self._segment_path = lambda: "otn-expected-ttitcmdapi"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmdapi, ['dapi_ascii_string', 'string_type'], name, value)


            class OtnExpectedTtitcmos(Entity):
                """
                Configure OTN Expected TTI value for OS config
                
                .. attribute:: osascii_string
                
                	OS ASCII text (Max 32 characters)
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: oshex_string
                
                	OS HEX text (Max 64 characters)
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnExpTtiTypeOs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnExpTtiTypeOs>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos, self).__init__()

                    self.yang_name = "otn-expected-ttitcmos"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.osascii_string = YLeaf(YType.str, "osascii-string")

                    self.oshex_string = YLeaf(YType.str, "oshex-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")
                    self._segment_path = lambda: "otn-expected-ttitcmos"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnExpectedTtitcmos, ['osascii_string', 'oshex_string', 'string_type'], name, value)


            class OtnSendTti(Entity):
                """
                Configure OTN Send TTI value for Full ASCII/HEX
                
                .. attribute:: full_ascii_string
                
                	Full ASCII text (Max 64 characters)
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: hex_string
                
                	Hex nibbles (Max 128 \- The string length should be an even number)
                	**type**\:  str
                
                	**length:** 1..128
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnSendTtiTypeFull <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSendTtiTypeFull>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti, self).__init__()

                    self.yang_name = "otn-send-tti"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.full_ascii_string = YLeaf(YType.str, "full-ascii-string")

                    self.hex_string = YLeaf(YType.str, "hex-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")
                    self._segment_path = lambda: "otn-send-tti"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTti, ['full_ascii_string', 'hex_string', 'string_type'], name, value)


            class OtnSendTtisapi(Entity):
                """
                Configure OTN Send TTI value for SAPI configs
                
                .. attribute:: sapi_ascii_string
                
                	SAPI ASCII text (Max 14 characters)
                	**type**\:  str
                
                	**length:** 1..14
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnSendTtiTypeSapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSendTtiTypeSapi>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi, self).__init__()

                    self.yang_name = "otn-send-ttisapi"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.sapi_ascii_string = YLeaf(YType.str, "sapi-ascii-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")
                    self._segment_path = lambda: "otn-send-ttisapi"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtisapi, ['sapi_ascii_string', 'string_type'], name, value)


            class OtnSendTtitcmdapi(Entity):
                """
                Configure OTN Send TTI value for DAPI configs
                
                .. attribute:: dapi_ascii_string
                
                	DAPI ASCII text (Max 14 characters)
                	**type**\:  str
                
                	**length:** 1..14
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnSendTtiTypeDapi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSendTtiTypeDapi>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi, self).__init__()

                    self.yang_name = "otn-send-ttitcmdapi"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.dapi_ascii_string = YLeaf(YType.str, "dapi-ascii-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")
                    self._segment_path = lambda: "otn-send-ttitcmdapi"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmdapi, ['dapi_ascii_string', 'string_type'], name, value)


            class OtnSendTtitcmos(Entity):
                """
                Configure OTN Send TTI value for OS config
                
                .. attribute:: osascii_string
                
                	OS ASCII text (Max 32 characters)
                	**type**\:  str
                
                	**length:** 1..32
                
                .. attribute:: oshex_string
                
                	OS HEX text (Max 64 characters)
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: string_type
                
                	TTI string type (FULL ASCII or  DAPI ASCII or SAPI ASCII or hex format or OS ASCII or OS HEX)
                	**type**\:   :py:class:`OtnSendTtiTypeOs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtnSendTtiTypeOs>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos, self).__init__()

                    self.yang_name = "otn-send-ttitcmos"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.osascii_string = YLeaf(YType.str, "osascii-string")

                    self.oshex_string = YLeaf(YType.str, "oshex-string")

                    self.string_type = YLeaf(YType.enumeration, "string-type")
                    self._segment_path = lambda: "otn-send-ttitcmos"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.OtnSendTtitcmos, ['osascii_string', 'oshex_string', 'string_type'], name, value)


            class Prbs(Entity):
                """
                Enable Prbs And configure
                
                .. attribute:: mode_value
                
                	Mode value
                	**type**\:   :py:class:`OtuMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtuMode>`
                
                .. attribute:: patternvalue
                
                	Pattern value
                	**type**\:   :py:class:`OtuPattern <ydk.models.cisco_ios_xr.Cisco_IOS_XR_controller_otu_cfg.OtuPattern>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.Prbs, self).__init__()

                    self.yang_name = "prbs"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.mode_value = YLeaf(YType.enumeration, "mode-value")

                    self.patternvalue = YLeaf(YType.enumeration, "patternvalue")
                    self._segment_path = lambda: "prbs"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.Prbs, ['mode_value', 'patternvalue'], name, value)


            class ProactiveProtection(Entity):
                """
                Configure Proactive Protection
                
                .. attribute:: revert_threshold
                
                	Proactive Protection Threshold
                	**type**\:   :py:class:`RevertThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold>`
                
                .. attribute:: revert_window
                
                	Proactive Protection Window
                	**type**\:   :py:class:`RevertWindow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow>`
                
                .. attribute:: status
                
                	Enable Proactive Protection
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: trigger_threshold
                
                	Proactive Protection Threshold
                	**type**\:   :py:class:`TriggerThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold>`
                
                .. attribute:: trigger_window
                
                	Proactive Protection Window
                	**type**\:   :py:class:`TriggerWindow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow>`
                
                

                """

                _prefix = 'controller-otu-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection, self).__init__()

                    self.yang_name = "proactive-protection"
                    self.yang_parent_name = "otu"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"revert-threshold" : ("revert_threshold", InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold), "revert-window" : ("revert_window", InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow), "trigger-threshold" : ("trigger_threshold", InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold), "trigger-window" : ("trigger_window", InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow)}
                    self._child_list_classes = {}

                    self.status = YLeaf(YType.empty, "status")

                    self.revert_threshold = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold()
                    self.revert_threshold.parent = self
                    self._children_name_map["revert_threshold"] = "revert-threshold"
                    self._children_yang_names.add("revert-threshold")

                    self.revert_window = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow()
                    self.revert_window.parent = self
                    self._children_name_map["revert_window"] = "revert-window"
                    self._children_yang_names.add("revert-window")

                    self.trigger_threshold = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold()
                    self.trigger_threshold.parent = self
                    self._children_name_map["trigger_threshold"] = "trigger-threshold"
                    self._children_yang_names.add("trigger-threshold")

                    self.trigger_window = InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow()
                    self.trigger_window.parent = self
                    self._children_name_map["trigger_window"] = "trigger-window"
                    self._children_yang_names.add("trigger-window")
                    self._segment_path = lambda: "proactive-protection"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection, ['status'], name, value)


                class RevertThreshold(Entity):
                    """
                    Proactive Protection Threshold
                    
                    .. attribute:: coefficient
                    
                    	Bit error rate coefficient
                    	**type**\:  int
                    
                    	**range:** 1..9
                    
                    .. attribute:: enable
                    
                    	Proactive Protection supported
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power
                    
                    	Bit error rate power
                    	**type**\:  int
                    
                    	**range:** 4..10
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold, self).__init__()

                        self.yang_name = "revert-threshold"
                        self.yang_parent_name = "proactive-protection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.coefficient = YLeaf(YType.uint32, "coefficient")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.power = YLeaf(YType.uint32, "power")
                        self._segment_path = lambda: "revert-threshold"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertThreshold, ['coefficient', 'enable', 'power'], name, value)


                class RevertWindow(Entity):
                    """
                    Proactive Protection Window
                    
                    .. attribute:: enable
                    
                    	Enable Proactive Protection
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: value
                    
                    	Integration window for FRR trigger in MS
                    	**type**\:  int
                    
                    	**range:** 2000..10000
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow, self).__init__()

                        self.yang_name = "revert-window"
                        self.yang_parent_name = "proactive-protection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.enable = YLeaf(YType.empty, "enable")

                        self.value = YLeaf(YType.uint32, "value")
                        self._segment_path = lambda: "revert-window"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.RevertWindow, ['enable', 'value'], name, value)


                class TriggerThreshold(Entity):
                    """
                    Proactive Protection Threshold
                    
                    .. attribute:: coefficient
                    
                    	Bit error rate coefficient
                    	**type**\:  int
                    
                    	**range:** 1..9
                    
                    .. attribute:: enable
                    
                    	Proactive Protection supported
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: power
                    
                    	Bit error rate power
                    	**type**\:  int
                    
                    	**range:** 3..9
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold, self).__init__()

                        self.yang_name = "trigger-threshold"
                        self.yang_parent_name = "proactive-protection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.coefficient = YLeaf(YType.uint32, "coefficient")

                        self.enable = YLeaf(YType.empty, "enable")

                        self.power = YLeaf(YType.uint32, "power")
                        self._segment_path = lambda: "trigger-threshold"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerThreshold, ['coefficient', 'enable', 'power'], name, value)


                class TriggerWindow(Entity):
                    """
                    Proactive Protection Window
                    
                    .. attribute:: enable
                    
                    	Enable Proactive Protection
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: value
                    
                    	Integration window for FRR trigger in MS
                    	**type**\:  int
                    
                    	**range:** 10..10000
                    
                    

                    """

                    _prefix = 'controller-otu-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow, self).__init__()

                        self.yang_name = "trigger-window"
                        self.yang_parent_name = "proactive-protection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.enable = YLeaf(YType.empty, "enable")

                        self.value = YLeaf(YType.uint32, "value")
                        self._segment_path = lambda: "trigger-window"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Otu.ProactiveProtection.TriggerWindow, ['enable', 'value'], name, value)


        class Pbr(Entity):
            """
            Interface PBR configuration
            
            .. attribute:: service_policy
            
            	PBR service policy configuration
            	**type**\:   :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy>`
            
            .. attribute:: service_policy_in
            
            	Class for subscriber ingress policy
            	**type**\:  str
            
            

            """

            _prefix = 'pbr-cfg'
            _revision = '2016-03-08'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Pbr, self).__init__()

                self.yang_name = "pbr"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy)}
                self._child_list_classes = {}

                self.service_policy_in = YLeaf(YType.str, "service-policy-in")

                self.service_policy = InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy()
                self.service_policy.parent = self
                self._children_name_map["service_policy"] = "service-policy"
                self._children_yang_names.add("service-policy")
                self._segment_path = lambda: "Cisco-IOS-XR-pbr-cfg:pbr"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Pbr, ['service_policy_in'], name, value)


            class ServicePolicy(Entity):
                """
                PBR service policy configuration
                
                .. attribute:: input
                
                	Ingress service policy
                	**type**\:  str
                
                

                """

                _prefix = 'pbr-cfg'
                _revision = '2016-03-08'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "pbr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.input = YLeaf(YType.str, "input")
                    self._segment_path = lambda: "service-policy"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Pbr.ServicePolicy, ['input'], name, value)


        class PerformanceManagement(Entity):
            """
            Configure pm parameters
            
            .. attribute:: ethernet_hour24
            
            	Configure pm parameters of 24 hour interval
            	**type**\:   :py:class:`EthernetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24>`
            
            .. attribute:: ethernet_minute15
            
            	set opr min threshold
            	**type**\:   :py:class:`EthernetMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15>`
            
            .. attribute:: ethernet_second30
            
            	Configure ethernet performance monitoring for 30 sec
            	**type**\:   :py:class:`EthernetSecond30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30>`
            
            .. attribute:: ho_vc_hour24
            
            	set HO\_VC threshold
            	**type**\:   :py:class:`HoVcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24>`
            
            .. attribute:: ho_vc_minute15
            
            	set HO\_VC threshold
            	**type**\:   :py:class:`HoVcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15>`
            
            .. attribute:: hour24
            
            	Configure pm parameters of 24 hour interval
            	**type**\:   :py:class:`Hour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24>`
            
            .. attribute:: hour24_gfp
            
            	Configure pm parameters of gfp 24 hour interval
            	**type**\:   :py:class:`Hour24Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp>`
            
            .. attribute:: hour24_path
            
            	Configure pm parameters of pathmonitor 24 hour interval
            	**type**\:   :py:class:`Hour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path>`
            
            .. attribute:: hour24otn_tcms
            
            	Configure pm parameters of tcm's 24 hour interval
            	**type**\:   :py:class:`Hour24OtnTcms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms>`
            
            .. attribute:: minute15
            
            	set opr min threshold
            	**type**\:   :py:class:`Minute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15>`
            
            .. attribute:: minute15_gfp
            
            	set opr min threshold
            	**type**\:   :py:class:`Minute15Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp>`
            
            .. attribute:: minute15_path
            
            	set opr min threshold
            	**type**\:   :py:class:`Minute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path>`
            
            .. attribute:: minute15otn_tcms
            
            	set opr min threshold
            	**type**\:   :py:class:`Minute15OtnTcms <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms>`
            
            .. attribute:: oc_hour24
            
            	set Oc threshold
            	**type**\:   :py:class:`OcHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24>`
            
            .. attribute:: oc_minute15
            
            	set OC threshold
            	**type**\:   :py:class:`OcMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15>`
            
            .. attribute:: second30
            
            	Configure optics performance monitoring for 30 sec
            	**type**\:   :py:class:`Second30 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30>`
            
            .. attribute:: sonet_hour24
            
            	set Sonet threshold
            	**type**\:   :py:class:`SonetHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24>`
            
            .. attribute:: sonet_minute15
            
            	set Sonet threshold
            	**type**\:   :py:class:`SonetMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15>`
            
            .. attribute:: stm_hour24
            
            	set STM threshold
            	**type**\:   :py:class:`StmHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24>`
            
            .. attribute:: stm_minute15
            
            	set STM threshold
            	**type**\:   :py:class:`StmMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15>`
            
            .. attribute:: sts_hour24
            
            	set STS threshold
            	**type**\:   :py:class:`StsHour24 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24>`
            
            .. attribute:: sts_minute15
            
            	set STS threshold
            	**type**\:   :py:class:`StsMinute15 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15>`
            
            

            """

            _prefix = 'pmengine-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement, self).__init__()

                self.yang_name = "performance-management"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"ethernet-hour24" : ("ethernet_hour24", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24), "ethernet-minute15" : ("ethernet_minute15", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15), "ethernet-second30" : ("ethernet_second30", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30), "ho-vc-hour24" : ("ho_vc_hour24", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24), "ho-vc-minute15" : ("ho_vc_minute15", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15), "hour24" : ("hour24", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24), "hour24-gfp" : ("hour24_gfp", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp), "hour24-path" : ("hour24_path", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path), "hour24otn-tcms" : ("hour24otn_tcms", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms), "minute15" : ("minute15", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15), "minute15-gfp" : ("minute15_gfp", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp), "minute15-path" : ("minute15_path", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path), "minute15otn-tcms" : ("minute15otn_tcms", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms), "oc-hour24" : ("oc_hour24", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24), "oc-minute15" : ("oc_minute15", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15), "second30" : ("second30", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30), "sonet-hour24" : ("sonet_hour24", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24), "sonet-minute15" : ("sonet_minute15", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15), "stm-hour24" : ("stm_hour24", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24), "stm-minute15" : ("stm_minute15", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15), "sts-hour24" : ("sts_hour24", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24), "sts-minute15" : ("sts_minute15", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15)}
                self._child_list_classes = {}

                self.ethernet_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24()
                self.ethernet_hour24.parent = self
                self._children_name_map["ethernet_hour24"] = "ethernet-hour24"
                self._children_yang_names.add("ethernet-hour24")

                self.ethernet_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15()
                self.ethernet_minute15.parent = self
                self._children_name_map["ethernet_minute15"] = "ethernet-minute15"
                self._children_yang_names.add("ethernet-minute15")

                self.ethernet_second30 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30()
                self.ethernet_second30.parent = self
                self._children_name_map["ethernet_second30"] = "ethernet-second30"
                self._children_yang_names.add("ethernet-second30")

                self.ho_vc_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24()
                self.ho_vc_hour24.parent = self
                self._children_name_map["ho_vc_hour24"] = "ho-vc-hour24"
                self._children_yang_names.add("ho-vc-hour24")

                self.ho_vc_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15()
                self.ho_vc_minute15.parent = self
                self._children_name_map["ho_vc_minute15"] = "ho-vc-minute15"
                self._children_yang_names.add("ho-vc-minute15")

                self.hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24()
                self.hour24.parent = self
                self._children_name_map["hour24"] = "hour24"
                self._children_yang_names.add("hour24")

                self.hour24_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp()
                self.hour24_gfp.parent = self
                self._children_name_map["hour24_gfp"] = "hour24-gfp"
                self._children_yang_names.add("hour24-gfp")

                self.hour24_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path()
                self.hour24_path.parent = self
                self._children_name_map["hour24_path"] = "hour24-path"
                self._children_yang_names.add("hour24-path")

                self.hour24otn_tcms = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms()
                self.hour24otn_tcms.parent = self
                self._children_name_map["hour24otn_tcms"] = "hour24otn-tcms"
                self._children_yang_names.add("hour24otn-tcms")

                self.minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15()
                self.minute15.parent = self
                self._children_name_map["minute15"] = "minute15"
                self._children_yang_names.add("minute15")

                self.minute15_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp()
                self.minute15_gfp.parent = self
                self._children_name_map["minute15_gfp"] = "minute15-gfp"
                self._children_yang_names.add("minute15-gfp")

                self.minute15_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path()
                self.minute15_path.parent = self
                self._children_name_map["minute15_path"] = "minute15-path"
                self._children_yang_names.add("minute15-path")

                self.minute15otn_tcms = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms()
                self.minute15otn_tcms.parent = self
                self._children_name_map["minute15otn_tcms"] = "minute15otn-tcms"
                self._children_yang_names.add("minute15otn-tcms")

                self.oc_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24()
                self.oc_hour24.parent = self
                self._children_name_map["oc_hour24"] = "oc-hour24"
                self._children_yang_names.add("oc-hour24")

                self.oc_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15()
                self.oc_minute15.parent = self
                self._children_name_map["oc_minute15"] = "oc-minute15"
                self._children_yang_names.add("oc-minute15")

                self.second30 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30()
                self.second30.parent = self
                self._children_name_map["second30"] = "second30"
                self._children_yang_names.add("second30")

                self.sonet_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24()
                self.sonet_hour24.parent = self
                self._children_name_map["sonet_hour24"] = "sonet-hour24"
                self._children_yang_names.add("sonet-hour24")

                self.sonet_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15()
                self.sonet_minute15.parent = self
                self._children_name_map["sonet_minute15"] = "sonet-minute15"
                self._children_yang_names.add("sonet-minute15")

                self.stm_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24()
                self.stm_hour24.parent = self
                self._children_name_map["stm_hour24"] = "stm-hour24"
                self._children_yang_names.add("stm-hour24")

                self.stm_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15()
                self.stm_minute15.parent = self
                self._children_name_map["stm_minute15"] = "stm-minute15"
                self._children_yang_names.add("stm-minute15")

                self.sts_hour24 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24()
                self.sts_hour24.parent = self
                self._children_name_map["sts_hour24"] = "sts-hour24"
                self._children_yang_names.add("sts-hour24")

                self.sts_minute15 = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15()
                self.sts_minute15.parent = self
                self._children_name_map["sts_minute15"] = "sts-minute15"
                self._children_yang_names.add("sts-minute15")
                self._segment_path = lambda: "Cisco-IOS-XR-pmengine-cfg:performance-management"


            class EthernetHour24(Entity):
                """
                Configure pm parameters of 24 hour interval
                
                .. attribute:: hour24_ether
                
                	Configure ether performance monitoring
                	**type**\:   :py:class:`Hour24Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24, self).__init__()

                    self.yang_name = "ethernet-hour24"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"hour24-ether" : ("hour24_ether", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether)}
                    self._child_list_classes = {}

                    self.hour24_ether = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether()
                    self.hour24_ether.parent = self
                    self._children_name_map["hour24_ether"] = "hour24-ether"
                    self._children_yang_names.add("hour24-ether")
                    self._segment_path = lambda: "ethernet-hour24"


                class Hour24Ether(Entity):
                    """
                    Configure ether performance monitoring
                    
                    .. attribute:: hour24_ether_reports
                    
                    	set ether TCA reporting status
                    	**type**\:   :py:class:`Hour24EtherReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports>`
                    
                    .. attribute:: hour24_ether_thresholds
                    
                    	Configure threshold on ether parameters
                    	**type**\:   :py:class:`Hour24EtherThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether, self).__init__()

                        self.yang_name = "hour24-ether"
                        self.yang_parent_name = "ethernet-hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24-ether-reports" : ("hour24_ether_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports), "hour24-ether-thresholds" : ("hour24_ether_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds)}
                        self._child_list_classes = {}

                        self.hour24_ether_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports()
                        self.hour24_ether_reports.parent = self
                        self._children_name_map["hour24_ether_reports"] = "hour24-ether-reports"
                        self._children_yang_names.add("hour24-ether-reports")

                        self.hour24_ether_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds()
                        self.hour24_ether_thresholds.parent = self
                        self._children_name_map["hour24_ether_thresholds"] = "hour24-ether-thresholds"
                        self._children_yang_names.add("hour24-ether-thresholds")
                        self._segment_path = lambda: "hour24-ether"


                    class Hour24EtherReports(Entity):
                        """
                        set ether TCA reporting status
                        
                        .. attribute:: hour24_ether_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports.Hour24EtherReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports, self).__init__()

                            self.yang_name = "hour24-ether-reports"
                            self.yang_parent_name = "hour24-ether"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24-ether-report" : ("hour24_ether_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports.Hour24EtherReport)}

                            self.hour24_ether_report = YList(self)
                            self._segment_path = lambda: "hour24-ether-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports, [], name, value)


                        class Hour24EtherReport(Entity):
                            """
                            none
                            
                            .. attribute:: ether_report  <key>
                            
                            	Ether Report Type
                            	**type**\:   :py:class:`EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports.Hour24EtherReport, self).__init__()

                                self.yang_name = "hour24-ether-report"
                                self.yang_parent_name = "hour24-ether-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ether_report = YLeaf(YType.enumeration, "ether-report")
                                self._segment_path = lambda: "hour24-ether-report" + "[ether-report='" + self.ether_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherReports.Hour24EtherReport, ['ether_report'], name, value)


                    class Hour24EtherThresholds(Entity):
                        """
                        Configure threshold on ether parameters
                        
                        .. attribute:: hour24_ether_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds.Hour24EtherThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds, self).__init__()

                            self.yang_name = "hour24-ether-thresholds"
                            self.yang_parent_name = "hour24-ether"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24-ether-threshold" : ("hour24_ether_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds.Hour24EtherThreshold)}

                            self.hour24_ether_threshold = YList(self)
                            self._segment_path = lambda: "hour24-ether-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds, [], name, value)


                        class Hour24EtherThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ether_threshold  <key>
                            
                            	Ether Threshold Type
                            	**type**\:   :py:class:`EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherThreshold>`
                            
                            .. attribute:: ether_threshold_value
                            
                            	Ether Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds.Hour24EtherThreshold, self).__init__()

                                self.yang_name = "hour24-ether-threshold"
                                self.yang_parent_name = "hour24-ether-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ether_threshold = YLeaf(YType.enumeration, "ether-threshold")

                                self.ether_threshold_value = YLeaf(YType.int32, "ether-threshold-value")
                                self._segment_path = lambda: "hour24-ether-threshold" + "[ether-threshold='" + self.ether_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetHour24.Hour24Ether.Hour24EtherThresholds.Hour24EtherThreshold, ['ether_threshold', 'ether_threshold_value'], name, value)


            class EthernetMinute15(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15_ether
                
                	Configure ether performance monitoring
                	**type**\:   :py:class:`Minute15Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15, self).__init__()

                    self.yang_name = "ethernet-minute15"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"minute15-ether" : ("minute15_ether", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether)}
                    self._child_list_classes = {}

                    self.minute15_ether = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether()
                    self.minute15_ether.parent = self
                    self._children_name_map["minute15_ether"] = "minute15-ether"
                    self._children_yang_names.add("minute15-ether")
                    self._segment_path = lambda: "ethernet-minute15"


                class Minute15Ether(Entity):
                    """
                    Configure ether performance monitoring
                    
                    .. attribute:: minute15_ether_reports
                    
                    	set ether TCA reporting status
                    	**type**\:   :py:class:`Minute15EtherReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports>`
                    
                    .. attribute:: minute15_ether_thresholds
                    
                    	Configure threshold on ether parameters
                    	**type**\:   :py:class:`Minute15EtherThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether, self).__init__()

                        self.yang_name = "minute15-ether"
                        self.yang_parent_name = "ethernet-minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"minute15-ether-reports" : ("minute15_ether_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports), "minute15-ether-thresholds" : ("minute15_ether_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds)}
                        self._child_list_classes = {}

                        self.minute15_ether_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports()
                        self.minute15_ether_reports.parent = self
                        self._children_name_map["minute15_ether_reports"] = "minute15-ether-reports"
                        self._children_yang_names.add("minute15-ether-reports")

                        self.minute15_ether_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds()
                        self.minute15_ether_thresholds.parent = self
                        self._children_name_map["minute15_ether_thresholds"] = "minute15-ether-thresholds"
                        self._children_yang_names.add("minute15-ether-thresholds")
                        self._segment_path = lambda: "minute15-ether"


                    class Minute15EtherReports(Entity):
                        """
                        set ether TCA reporting status
                        
                        .. attribute:: minute15_ether_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports.Minute15EtherReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports, self).__init__()

                            self.yang_name = "minute15-ether-reports"
                            self.yang_parent_name = "minute15-ether"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15-ether-report" : ("minute15_ether_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports.Minute15EtherReport)}

                            self.minute15_ether_report = YList(self)
                            self._segment_path = lambda: "minute15-ether-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports, [], name, value)


                        class Minute15EtherReport(Entity):
                            """
                            none
                            
                            .. attribute:: ether_report  <key>
                            
                            	Ether Report Type
                            	**type**\:   :py:class:`EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports.Minute15EtherReport, self).__init__()

                                self.yang_name = "minute15-ether-report"
                                self.yang_parent_name = "minute15-ether-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ether_report = YLeaf(YType.enumeration, "ether-report")
                                self._segment_path = lambda: "minute15-ether-report" + "[ether-report='" + self.ether_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherReports.Minute15EtherReport, ['ether_report'], name, value)


                    class Minute15EtherThresholds(Entity):
                        """
                        Configure threshold on ether parameters
                        
                        .. attribute:: minute15_ether_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds.Minute15EtherThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds, self).__init__()

                            self.yang_name = "minute15-ether-thresholds"
                            self.yang_parent_name = "minute15-ether"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15-ether-threshold" : ("minute15_ether_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds.Minute15EtherThreshold)}

                            self.minute15_ether_threshold = YList(self)
                            self._segment_path = lambda: "minute15-ether-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds, [], name, value)


                        class Minute15EtherThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ether_threshold  <key>
                            
                            	Ether Threshold Type
                            	**type**\:   :py:class:`EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherThreshold>`
                            
                            .. attribute:: ether_threshold_value
                            
                            	Ether Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds.Minute15EtherThreshold, self).__init__()

                                self.yang_name = "minute15-ether-threshold"
                                self.yang_parent_name = "minute15-ether-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ether_threshold = YLeaf(YType.enumeration, "ether-threshold")

                                self.ether_threshold_value = YLeaf(YType.int32, "ether-threshold-value")
                                self._segment_path = lambda: "minute15-ether-threshold" + "[ether-threshold='" + self.ether_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetMinute15.Minute15Ether.Minute15EtherThresholds.Minute15EtherThreshold, ['ether_threshold', 'ether_threshold_value'], name, value)


            class EthernetSecond30(Entity):
                """
                Configure ethernet performance monitoring for
                30 sec
                
                .. attribute:: second30_ether
                
                	Configure ether performance monitoring
                	**type**\:   :py:class:`Second30Ether <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30, self).__init__()

                    self.yang_name = "ethernet-second30"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"second30-ether" : ("second30_ether", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether)}
                    self._child_list_classes = {}

                    self.second30_ether = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether()
                    self.second30_ether.parent = self
                    self._children_name_map["second30_ether"] = "second30-ether"
                    self._children_yang_names.add("second30-ether")
                    self._segment_path = lambda: "ethernet-second30"


                class Second30Ether(Entity):
                    """
                    Configure ether performance monitoring
                    
                    .. attribute:: second30_ether_reports
                    
                    	set ether TCA reporting status
                    	**type**\:   :py:class:`Second30EtherReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports>`
                    
                    .. attribute:: second30_ether_thresholds
                    
                    	Configure threshold on ether parameters
                    	**type**\:   :py:class:`Second30EtherThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether, self).__init__()

                        self.yang_name = "second30-ether"
                        self.yang_parent_name = "ethernet-second30"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"second30-ether-reports" : ("second30_ether_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports), "second30-ether-thresholds" : ("second30_ether_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds)}
                        self._child_list_classes = {}

                        self.second30_ether_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports()
                        self.second30_ether_reports.parent = self
                        self._children_name_map["second30_ether_reports"] = "second30-ether-reports"
                        self._children_yang_names.add("second30-ether-reports")

                        self.second30_ether_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds()
                        self.second30_ether_thresholds.parent = self
                        self._children_name_map["second30_ether_thresholds"] = "second30-ether-thresholds"
                        self._children_yang_names.add("second30-ether-thresholds")
                        self._segment_path = lambda: "second30-ether"


                    class Second30EtherReports(Entity):
                        """
                        set ether TCA reporting status
                        
                        .. attribute:: second30_ether_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports.Second30EtherReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports, self).__init__()

                            self.yang_name = "second30-ether-reports"
                            self.yang_parent_name = "second30-ether"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30-ether-report" : ("second30_ether_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports.Second30EtherReport)}

                            self.second30_ether_report = YList(self)
                            self._segment_path = lambda: "second30-ether-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports, [], name, value)


                        class Second30EtherReport(Entity):
                            """
                            none
                            
                            .. attribute:: ether_report  <key>
                            
                            	Ether Report Type
                            	**type**\:   :py:class:`EtherReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports.Second30EtherReport, self).__init__()

                                self.yang_name = "second30-ether-report"
                                self.yang_parent_name = "second30-ether-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ether_report = YLeaf(YType.enumeration, "ether-report")
                                self._segment_path = lambda: "second30-ether-report" + "[ether-report='" + self.ether_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherReports.Second30EtherReport, ['ether_report'], name, value)


                    class Second30EtherThresholds(Entity):
                        """
                        Configure threshold on ether parameters
                        
                        .. attribute:: second30_ether_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Second30EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds.Second30EtherThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds, self).__init__()

                            self.yang_name = "second30-ether-thresholds"
                            self.yang_parent_name = "second30-ether"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30-ether-threshold" : ("second30_ether_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds.Second30EtherThreshold)}

                            self.second30_ether_threshold = YList(self)
                            self._segment_path = lambda: "second30-ether-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds, [], name, value)


                        class Second30EtherThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ether_threshold  <key>
                            
                            	Ether Threshold Type
                            	**type**\:   :py:class:`EtherThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.EtherThreshold>`
                            
                            .. attribute:: ether_threshold_value
                            
                            	Ether Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds.Second30EtherThreshold, self).__init__()

                                self.yang_name = "second30-ether-threshold"
                                self.yang_parent_name = "second30-ether-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ether_threshold = YLeaf(YType.enumeration, "ether-threshold")

                                self.ether_threshold_value = YLeaf(YType.int32, "ether-threshold-value")
                                self._segment_path = lambda: "second30-ether-threshold" + "[ether-threshold='" + self.ether_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.EthernetSecond30.Second30Ether.Second30EtherThresholds.Second30EtherThreshold, ['ether_threshold', 'ether_threshold_value'], name, value)


            class HoVcHour24(Entity):
                """
                set HO\_VC threshold
                
                .. attribute:: ho_vc_hour24ho_vc
                
                	Configure ho\_vc performance monitoring
                	**type**\:   :py:class:`HoVcHour24HoVc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24, self).__init__()

                    self.yang_name = "ho-vc-hour24"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"ho-vc-hour24ho-vc" : ("ho_vc_hour24ho_vc", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc)}
                    self._child_list_classes = {}

                    self.ho_vc_hour24ho_vc = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc()
                    self.ho_vc_hour24ho_vc.parent = self
                    self._children_name_map["ho_vc_hour24ho_vc"] = "ho-vc-hour24ho-vc"
                    self._children_yang_names.add("ho-vc-hour24ho-vc")
                    self._segment_path = lambda: "ho-vc-hour24"


                class HoVcHour24HoVc(Entity):
                    """
                    Configure ho\_vc performance monitoring
                    
                    .. attribute:: ho_vc_hour24ho_vc_reports
                    
                    	set ho\_vc TCA reporting status
                    	**type**\:   :py:class:`HoVcHour24HoVcReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports>`
                    
                    .. attribute:: ho_vc_hour24ho_vc_thresholds
                    
                    	Configure threshold on ho\_vc parameters
                    	**type**\:   :py:class:`HoVcHour24HoVcThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc, self).__init__()

                        self.yang_name = "ho-vc-hour24ho-vc"
                        self.yang_parent_name = "ho-vc-hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"ho-vc-hour24ho-vc-reports" : ("ho_vc_hour24ho_vc_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports), "ho-vc-hour24ho-vc-thresholds" : ("ho_vc_hour24ho_vc_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds)}
                        self._child_list_classes = {}

                        self.ho_vc_hour24ho_vc_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports()
                        self.ho_vc_hour24ho_vc_reports.parent = self
                        self._children_name_map["ho_vc_hour24ho_vc_reports"] = "ho-vc-hour24ho-vc-reports"
                        self._children_yang_names.add("ho-vc-hour24ho-vc-reports")

                        self.ho_vc_hour24ho_vc_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds()
                        self.ho_vc_hour24ho_vc_thresholds.parent = self
                        self._children_name_map["ho_vc_hour24ho_vc_thresholds"] = "ho-vc-hour24ho-vc-thresholds"
                        self._children_yang_names.add("ho-vc-hour24ho-vc-thresholds")
                        self._segment_path = lambda: "ho-vc-hour24ho-vc"


                    class HoVcHour24HoVcReports(Entity):
                        """
                        set ho\_vc TCA reporting status
                        
                        .. attribute:: ho_vc_hour24ho_vc_report
                        
                        	none
                        	**type**\: list of    :py:class:`HoVcHour24HoVcReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports.HoVcHour24HoVcReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports, self).__init__()

                            self.yang_name = "ho-vc-hour24ho-vc-reports"
                            self.yang_parent_name = "ho-vc-hour24ho-vc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"ho-vc-hour24ho-vc-report" : ("ho_vc_hour24ho_vc_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports.HoVcHour24HoVcReport)}

                            self.ho_vc_hour24ho_vc_report = YList(self)
                            self._segment_path = lambda: "ho-vc-hour24ho-vc-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports, [], name, value)


                        class HoVcHour24HoVcReport(Entity):
                            """
                            none
                            
                            .. attribute:: ho_vc_report  <key>
                            
                            	ho\_vc Report Type
                            	**type**\:   :py:class:`HoVcReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.HoVcReport>`
                            
                            .. attribute:: enable
                            
                            	ho\_vc Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports.HoVcHour24HoVcReport, self).__init__()

                                self.yang_name = "ho-vc-hour24ho-vc-report"
                                self.yang_parent_name = "ho-vc-hour24ho-vc-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ho_vc_report = YLeaf(YType.enumeration, "ho-vc-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "ho-vc-hour24ho-vc-report" + "[ho-vc-report='" + self.ho_vc_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcReports.HoVcHour24HoVcReport, ['ho_vc_report', 'enable'], name, value)


                    class HoVcHour24HoVcThresholds(Entity):
                        """
                        Configure threshold on ho\_vc parameters
                        
                        .. attribute:: ho_vc_hour24ho_vc_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`HoVcHour24HoVcThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds.HoVcHour24HoVcThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds, self).__init__()

                            self.yang_name = "ho-vc-hour24ho-vc-thresholds"
                            self.yang_parent_name = "ho-vc-hour24ho-vc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"ho-vc-hour24ho-vc-threshold" : ("ho_vc_hour24ho_vc_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds.HoVcHour24HoVcThreshold)}

                            self.ho_vc_hour24ho_vc_threshold = YList(self)
                            self._segment_path = lambda: "ho-vc-hour24ho-vc-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds, [], name, value)


                        class HoVcHour24HoVcThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ho_vc_threshold  <key>
                            
                            	ho\_vc Threshold Type
                            	**type**\:   :py:class:`HoVcThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.HoVcThreshold>`
                            
                            .. attribute:: ho_vc_threshold_value
                            
                            	ho\_vc Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds.HoVcHour24HoVcThreshold, self).__init__()

                                self.yang_name = "ho-vc-hour24ho-vc-threshold"
                                self.yang_parent_name = "ho-vc-hour24ho-vc-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ho_vc_threshold = YLeaf(YType.enumeration, "ho-vc-threshold")

                                self.ho_vc_threshold_value = YLeaf(YType.int32, "ho-vc-threshold-value")
                                self._segment_path = lambda: "ho-vc-hour24ho-vc-threshold" + "[ho-vc-threshold='" + self.ho_vc_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcHour24.HoVcHour24HoVc.HoVcHour24HoVcThresholds.HoVcHour24HoVcThreshold, ['ho_vc_threshold', 'ho_vc_threshold_value'], name, value)


            class HoVcMinute15(Entity):
                """
                set HO\_VC threshold
                
                .. attribute:: ho_vc_minute15ho_vc
                
                	Configure ho\_vc performance monitoring
                	**type**\:   :py:class:`HoVcMinute15HoVc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15, self).__init__()

                    self.yang_name = "ho-vc-minute15"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"ho-vc-minute15ho-vc" : ("ho_vc_minute15ho_vc", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc)}
                    self._child_list_classes = {}

                    self.ho_vc_minute15ho_vc = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc()
                    self.ho_vc_minute15ho_vc.parent = self
                    self._children_name_map["ho_vc_minute15ho_vc"] = "ho-vc-minute15ho-vc"
                    self._children_yang_names.add("ho-vc-minute15ho-vc")
                    self._segment_path = lambda: "ho-vc-minute15"


                class HoVcMinute15HoVc(Entity):
                    """
                    Configure ho\_vc performance monitoring
                    
                    .. attribute:: ho_vc_minute15ho_vc_reports
                    
                    	set ho\_vc TCA reporting status
                    	**type**\:   :py:class:`HoVcMinute15HoVcReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports>`
                    
                    .. attribute:: ho_vc_minute15ho_vc_thresholds
                    
                    	Configure threshold on ho\_vc parameters
                    	**type**\:   :py:class:`HoVcMinute15HoVcThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc, self).__init__()

                        self.yang_name = "ho-vc-minute15ho-vc"
                        self.yang_parent_name = "ho-vc-minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"ho-vc-minute15ho-vc-reports" : ("ho_vc_minute15ho_vc_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports), "ho-vc-minute15ho-vc-thresholds" : ("ho_vc_minute15ho_vc_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds)}
                        self._child_list_classes = {}

                        self.ho_vc_minute15ho_vc_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports()
                        self.ho_vc_minute15ho_vc_reports.parent = self
                        self._children_name_map["ho_vc_minute15ho_vc_reports"] = "ho-vc-minute15ho-vc-reports"
                        self._children_yang_names.add("ho-vc-minute15ho-vc-reports")

                        self.ho_vc_minute15ho_vc_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds()
                        self.ho_vc_minute15ho_vc_thresholds.parent = self
                        self._children_name_map["ho_vc_minute15ho_vc_thresholds"] = "ho-vc-minute15ho-vc-thresholds"
                        self._children_yang_names.add("ho-vc-minute15ho-vc-thresholds")
                        self._segment_path = lambda: "ho-vc-minute15ho-vc"


                    class HoVcMinute15HoVcReports(Entity):
                        """
                        set ho\_vc TCA reporting status
                        
                        .. attribute:: ho_vc_minute15ho_vc_report
                        
                        	none
                        	**type**\: list of    :py:class:`HoVcMinute15HoVcReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports.HoVcMinute15HoVcReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports, self).__init__()

                            self.yang_name = "ho-vc-minute15ho-vc-reports"
                            self.yang_parent_name = "ho-vc-minute15ho-vc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"ho-vc-minute15ho-vc-report" : ("ho_vc_minute15ho_vc_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports.HoVcMinute15HoVcReport)}

                            self.ho_vc_minute15ho_vc_report = YList(self)
                            self._segment_path = lambda: "ho-vc-minute15ho-vc-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports, [], name, value)


                        class HoVcMinute15HoVcReport(Entity):
                            """
                            none
                            
                            .. attribute:: ho_vc_report  <key>
                            
                            	ho\_vc Report Type
                            	**type**\:   :py:class:`HoVcReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.HoVcReport>`
                            
                            .. attribute:: enable
                            
                            	ho\_vc Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports.HoVcMinute15HoVcReport, self).__init__()

                                self.yang_name = "ho-vc-minute15ho-vc-report"
                                self.yang_parent_name = "ho-vc-minute15ho-vc-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ho_vc_report = YLeaf(YType.enumeration, "ho-vc-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "ho-vc-minute15ho-vc-report" + "[ho-vc-report='" + self.ho_vc_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcReports.HoVcMinute15HoVcReport, ['ho_vc_report', 'enable'], name, value)


                    class HoVcMinute15HoVcThresholds(Entity):
                        """
                        Configure threshold on ho\_vc parameters
                        
                        .. attribute:: ho_vc_minute15ho_vc_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`HoVcMinute15HoVcThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds.HoVcMinute15HoVcThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds, self).__init__()

                            self.yang_name = "ho-vc-minute15ho-vc-thresholds"
                            self.yang_parent_name = "ho-vc-minute15ho-vc"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"ho-vc-minute15ho-vc-threshold" : ("ho_vc_minute15ho_vc_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds.HoVcMinute15HoVcThreshold)}

                            self.ho_vc_minute15ho_vc_threshold = YList(self)
                            self._segment_path = lambda: "ho-vc-minute15ho-vc-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds, [], name, value)


                        class HoVcMinute15HoVcThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ho_vc_threshold  <key>
                            
                            	ho\_vc Threshold Type
                            	**type**\:   :py:class:`HoVcThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.HoVcThreshold>`
                            
                            .. attribute:: ho_vc_threshold_value
                            
                            	ho\_vc Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds.HoVcMinute15HoVcThreshold, self).__init__()

                                self.yang_name = "ho-vc-minute15ho-vc-threshold"
                                self.yang_parent_name = "ho-vc-minute15ho-vc-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ho_vc_threshold = YLeaf(YType.enumeration, "ho-vc-threshold")

                                self.ho_vc_threshold_value = YLeaf(YType.int32, "ho-vc-threshold-value")
                                self._segment_path = lambda: "ho-vc-minute15ho-vc-threshold" + "[ho-vc-threshold='" + self.ho_vc_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.HoVcMinute15.HoVcMinute15HoVc.HoVcMinute15HoVcThresholds.HoVcMinute15HoVcThreshold, ['ho_vc_threshold', 'ho_vc_threshold_value'], name, value)


            class Hour24(Entity):
                """
                Configure pm parameters of 24 hour interval
                
                .. attribute:: hour24_optics
                
                	Configure optics performance monitoring
                	**type**\:   :py:class:`Hour24Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics>`
                
                .. attribute:: hour24fec
                
                	Configure fec g709 performance monitoring
                	**type**\:   :py:class:`Hour24Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec>`
                
                .. attribute:: hour24otn
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Hour24Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn>`
                
                .. attribute:: hour24secyif
                
                	Configure secy\-if performance monitoring
                	**type**\:   :py:class:`Hour24Secyif <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif>`
                
                .. attribute:: hour24secyrx
                
                	Configure secy\-rx performance monitoring
                	**type**\:   :py:class:`Hour24Secyrx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx>`
                
                .. attribute:: hour24secytx
                
                	Configure secy\-tx performance monitoring
                	**type**\:   :py:class:`Hour24Secytx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24, self).__init__()

                    self.yang_name = "hour24"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"hour24-optics" : ("hour24_optics", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics), "hour24fec" : ("hour24fec", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec), "hour24otn" : ("hour24otn", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn), "hour24secyif" : ("hour24secyif", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif), "hour24secyrx" : ("hour24secyrx", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx), "hour24secytx" : ("hour24secytx", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx)}
                    self._child_list_classes = {}

                    self.hour24_optics = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics()
                    self.hour24_optics.parent = self
                    self._children_name_map["hour24_optics"] = "hour24-optics"
                    self._children_yang_names.add("hour24-optics")

                    self.hour24fec = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec()
                    self.hour24fec.parent = self
                    self._children_name_map["hour24fec"] = "hour24fec"
                    self._children_yang_names.add("hour24fec")

                    self.hour24otn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn()
                    self.hour24otn.parent = self
                    self._children_name_map["hour24otn"] = "hour24otn"
                    self._children_yang_names.add("hour24otn")

                    self.hour24secyif = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif()
                    self.hour24secyif.parent = self
                    self._children_name_map["hour24secyif"] = "hour24secyif"
                    self._children_yang_names.add("hour24secyif")

                    self.hour24secyrx = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx()
                    self.hour24secyrx.parent = self
                    self._children_name_map["hour24secyrx"] = "hour24secyrx"
                    self._children_yang_names.add("hour24secyrx")

                    self.hour24secytx = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx()
                    self.hour24secytx.parent = self
                    self._children_name_map["hour24secytx"] = "hour24secytx"
                    self._children_yang_names.add("hour24secytx")
                    self._segment_path = lambda: "hour24"


                class Hour24Fec(Entity):
                    """
                    Configure fec g709 performance monitoring
                    
                    .. attribute:: hour24fec_reports
                    
                    	set fec TCA reporting status
                    	**type**\:   :py:class:`Hour24FecReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports>`
                    
                    .. attribute:: hour24fec_thresholds
                    
                    	Configure fec threshold
                    	**type**\:   :py:class:`Hour24FecThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec, self).__init__()

                        self.yang_name = "hour24fec"
                        self.yang_parent_name = "hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24fec-reports" : ("hour24fec_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports), "hour24fec-thresholds" : ("hour24fec_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds)}
                        self._child_list_classes = {}

                        self.hour24fec_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports()
                        self.hour24fec_reports.parent = self
                        self._children_name_map["hour24fec_reports"] = "hour24fec-reports"
                        self._children_yang_names.add("hour24fec-reports")

                        self.hour24fec_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds()
                        self.hour24fec_thresholds.parent = self
                        self._children_name_map["hour24fec_thresholds"] = "hour24fec-thresholds"
                        self._children_yang_names.add("hour24fec-thresholds")
                        self._segment_path = lambda: "hour24fec"


                    class Hour24FecReports(Entity):
                        """
                        set fec TCA reporting status
                        
                        .. attribute:: hour24fec_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports.Hour24FecReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports, self).__init__()

                            self.yang_name = "hour24fec-reports"
                            self.yang_parent_name = "hour24fec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24fec-report" : ("hour24fec_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports.Hour24FecReport)}

                            self.hour24fec_report = YList(self)
                            self._segment_path = lambda: "hour24fec-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports, [], name, value)


                        class Hour24FecReport(Entity):
                            """
                            none
                            
                            .. attribute:: fec_report  <key>
                            
                            	Fec Report type
                            	**type**\:   :py:class:`FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecReport>`
                            
                            .. attribute:: enable
                            
                            	Fec Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports.Hour24FecReport, self).__init__()

                                self.yang_name = "hour24fec-report"
                                self.yang_parent_name = "hour24fec-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.fec_report = YLeaf(YType.enumeration, "fec-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "hour24fec-report" + "[fec-report='" + self.fec_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecReports.Hour24FecReport, ['fec_report', 'enable'], name, value)


                    class Hour24FecThresholds(Entity):
                        """
                        Configure fec threshold
                        
                        .. attribute:: hour24fec_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds.Hour24FecThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds, self).__init__()

                            self.yang_name = "hour24fec-thresholds"
                            self.yang_parent_name = "hour24fec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24fec-threshold" : ("hour24fec_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds.Hour24FecThreshold)}

                            self.hour24fec_threshold = YList(self)
                            self._segment_path = lambda: "hour24fec-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds, [], name, value)


                        class Hour24FecThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: fec_threshold  <key>
                            
                            	Fec Threshold Type
                            	**type**\:   :py:class:`FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecThreshold>`
                            
                            .. attribute:: fec_threshold_value
                            
                            	Fec threshold value
                            	**type**\:  str
                            
                            	**length:** 1..16
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds.Hour24FecThreshold, self).__init__()

                                self.yang_name = "hour24fec-threshold"
                                self.yang_parent_name = "hour24fec-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.fec_threshold = YLeaf(YType.enumeration, "fec-threshold")

                                self.fec_threshold_value = YLeaf(YType.str, "fec-threshold-value")
                                self._segment_path = lambda: "hour24fec-threshold" + "[fec-threshold='" + self.fec_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Fec.Hour24FecThresholds.Hour24FecThreshold, ['fec_threshold', 'fec_threshold_value'], name, value)


                class Hour24Optics(Entity):
                    """
                    Configure optics performance monitoring
                    
                    .. attribute:: hour24_optics_reports
                    
                    	set optics TCA reporting status
                    	**type**\:   :py:class:`Hour24OpticsReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports>`
                    
                    .. attribute:: hour24_optics_thresholds
                    
                    	Configure threshold on optics parameters
                    	**type**\:   :py:class:`Hour24OpticsThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics, self).__init__()

                        self.yang_name = "hour24-optics"
                        self.yang_parent_name = "hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24-optics-reports" : ("hour24_optics_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports), "hour24-optics-thresholds" : ("hour24_optics_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds)}
                        self._child_list_classes = {}

                        self.hour24_optics_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports()
                        self.hour24_optics_reports.parent = self
                        self._children_name_map["hour24_optics_reports"] = "hour24-optics-reports"
                        self._children_yang_names.add("hour24-optics-reports")

                        self.hour24_optics_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds()
                        self.hour24_optics_thresholds.parent = self
                        self._children_name_map["hour24_optics_thresholds"] = "hour24-optics-thresholds"
                        self._children_yang_names.add("hour24-optics-thresholds")
                        self._segment_path = lambda: "hour24-optics"


                    class Hour24OpticsReports(Entity):
                        """
                        set optics TCA reporting status
                        
                        .. attribute:: hour24_optics_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports.Hour24OpticsReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports, self).__init__()

                            self.yang_name = "hour24-optics-reports"
                            self.yang_parent_name = "hour24-optics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24-optics-report" : ("hour24_optics_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports.Hour24OpticsReport)}

                            self.hour24_optics_report = YList(self)
                            self._segment_path = lambda: "hour24-optics-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports, [], name, value)


                        class Hour24OpticsReport(Entity):
                            """
                            none
                            
                            .. attribute:: optics_report  <key>
                            
                            	Optics Report Type
                            	**type**\:   :py:class:`OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports.Hour24OpticsReport, self).__init__()

                                self.yang_name = "hour24-optics-report"
                                self.yang_parent_name = "hour24-optics-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.optics_report = YLeaf(YType.enumeration, "optics-report")
                                self._segment_path = lambda: "hour24-optics-report" + "[optics-report='" + self.optics_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsReports.Hour24OpticsReport, ['optics_report'], name, value)


                    class Hour24OpticsThresholds(Entity):
                        """
                        Configure threshold on optics parameters
                        
                        .. attribute:: hour24_optics_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds.Hour24OpticsThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds, self).__init__()

                            self.yang_name = "hour24-optics-thresholds"
                            self.yang_parent_name = "hour24-optics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24-optics-threshold" : ("hour24_optics_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds.Hour24OpticsThreshold)}

                            self.hour24_optics_threshold = YList(self)
                            self._segment_path = lambda: "hour24-optics-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds, [], name, value)


                        class Hour24OpticsThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: optics_threshold  <key>
                            
                            	Optics Threshold Type
                            	**type**\:   :py:class:`OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsThreshold>`
                            
                            .. attribute:: dbm
                            
                            	Used only for Opt and Opr,To Enter Threshold in dbm use 1
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: optics_threshold_value
                            
                            	Optics Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds.Hour24OpticsThreshold, self).__init__()

                                self.yang_name = "hour24-optics-threshold"
                                self.yang_parent_name = "hour24-optics-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.optics_threshold = YLeaf(YType.enumeration, "optics-threshold")

                                self.dbm = YLeaf(YType.int32, "dbm")

                                self.optics_threshold_value = YLeaf(YType.int32, "optics-threshold-value")
                                self._segment_path = lambda: "hour24-optics-threshold" + "[optics-threshold='" + self.optics_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Optics.Hour24OpticsThresholds.Hour24OpticsThreshold, ['optics_threshold', 'dbm', 'optics_threshold_value'], name, value)


                class Hour24Otn(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: hour24otn_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Hour24OtnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports>`
                    
                    .. attribute:: hour24otn_thresholds
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Hour24OtnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn, self).__init__()

                        self.yang_name = "hour24otn"
                        self.yang_parent_name = "hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24otn-reports" : ("hour24otn_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports), "hour24otn-thresholds" : ("hour24otn_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds)}
                        self._child_list_classes = {}

                        self.hour24otn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports()
                        self.hour24otn_reports.parent = self
                        self._children_name_map["hour24otn_reports"] = "hour24otn-reports"
                        self._children_yang_names.add("hour24otn-reports")

                        self.hour24otn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds()
                        self.hour24otn_thresholds.parent = self
                        self._children_name_map["hour24otn_thresholds"] = "hour24otn-thresholds"
                        self._children_yang_names.add("hour24otn-thresholds")
                        self._segment_path = lambda: "hour24otn"


                    class Hour24OtnReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: hour24otn_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports.Hour24OtnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports, self).__init__()

                            self.yang_name = "hour24otn-reports"
                            self.yang_parent_name = "hour24otn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24otn-report" : ("hour24otn_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports.Hour24OtnReport)}

                            self.hour24otn_report = YList(self)
                            self._segment_path = lambda: "hour24otn-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports, [], name, value)


                        class Hour24OtnReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports.Hour24OtnReport, self).__init__()

                                self.yang_name = "hour24otn-report"
                                self.yang_parent_name = "hour24otn-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "hour24otn-report" + "[otn-report='" + self.otn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnReports.Hour24OtnReport, ['otn_report', 'enable'], name, value)


                    class Hour24OtnThresholds(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: hour24otn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds.Hour24OtnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds, self).__init__()

                            self.yang_name = "hour24otn-thresholds"
                            self.yang_parent_name = "hour24otn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24otn-threshold" : ("hour24otn_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds.Hour24OtnThreshold)}

                            self.hour24otn_threshold = YList(self)
                            self._segment_path = lambda: "hour24otn-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds, [], name, value)


                        class Hour24OtnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds.Hour24OtnThreshold, self).__init__()

                                self.yang_name = "hour24otn-threshold"
                                self.yang_parent_name = "hour24otn-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")
                                self._segment_path = lambda: "hour24otn-threshold" + "[otn-threshold='" + self.otn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Otn.Hour24OtnThresholds.Hour24OtnThreshold, ['otn_threshold', 'otn_threshold_value'], name, value)


                class Hour24Secyif(Entity):
                    """
                    Configure secy\-if performance monitoring
                    
                    .. attribute:: hour24secyif_reports
                    
                    	set secyif TCA reporting status
                    	**type**\:   :py:class:`Hour24SecyifReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifReports>`
                    
                    .. attribute:: hour24secyif_thresholds
                    
                    	Configure secyif threshold
                    	**type**\:   :py:class:`Hour24SecyifThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif, self).__init__()

                        self.yang_name = "hour24secyif"
                        self.yang_parent_name = "hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24secyif-reports" : ("hour24secyif_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifReports), "hour24secyif-thresholds" : ("hour24secyif_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifThresholds)}
                        self._child_list_classes = {}

                        self.hour24secyif_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifReports()
                        self.hour24secyif_reports.parent = self
                        self._children_name_map["hour24secyif_reports"] = "hour24secyif-reports"
                        self._children_yang_names.add("hour24secyif-reports")

                        self.hour24secyif_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifThresholds()
                        self.hour24secyif_thresholds.parent = self
                        self._children_name_map["hour24secyif_thresholds"] = "hour24secyif-thresholds"
                        self._children_yang_names.add("hour24secyif-thresholds")
                        self._segment_path = lambda: "hour24secyif"


                    class Hour24SecyifReports(Entity):
                        """
                        set secyif TCA reporting status
                        
                        .. attribute:: hour24secyif_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24SecyifReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifReports.Hour24SecyifReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifReports, self).__init__()

                            self.yang_name = "hour24secyif-reports"
                            self.yang_parent_name = "hour24secyif"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24secyif-report" : ("hour24secyif_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifReports.Hour24SecyifReport)}

                            self.hour24secyif_report = YList(self)
                            self._segment_path = lambda: "hour24secyif-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifReports, [], name, value)


                        class Hour24SecyifReport(Entity):
                            """
                            none
                            
                            .. attribute:: secyif_report  <key>
                            
                            	Secyif Report type
                            	**type**\:   :py:class:`SecyifReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyifReport>`
                            
                            .. attribute:: enable
                            
                            	Secyif Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifReports.Hour24SecyifReport, self).__init__()

                                self.yang_name = "hour24secyif-report"
                                self.yang_parent_name = "hour24secyif-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyif_report = YLeaf(YType.enumeration, "secyif-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "hour24secyif-report" + "[secyif-report='" + self.secyif_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifReports.Hour24SecyifReport, ['secyif_report', 'enable'], name, value)


                    class Hour24SecyifThresholds(Entity):
                        """
                        Configure secyif threshold
                        
                        .. attribute:: hour24secyif_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24SecyifThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifThresholds.Hour24SecyifThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifThresholds, self).__init__()

                            self.yang_name = "hour24secyif-thresholds"
                            self.yang_parent_name = "hour24secyif"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24secyif-threshold" : ("hour24secyif_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifThresholds.Hour24SecyifThreshold)}

                            self.hour24secyif_threshold = YList(self)
                            self._segment_path = lambda: "hour24secyif-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifThresholds, [], name, value)


                        class Hour24SecyifThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: secyif_threshold  <key>
                            
                            	Secyif Threshold Type
                            	**type**\:   :py:class:`SecyifThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyifThreshold>`
                            
                            .. attribute:: secyif_threshold_value
                            
                            	Secyif threshold value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifThresholds.Hour24SecyifThreshold, self).__init__()

                                self.yang_name = "hour24secyif-threshold"
                                self.yang_parent_name = "hour24secyif-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyif_threshold = YLeaf(YType.enumeration, "secyif-threshold")

                                self.secyif_threshold_value = YLeaf(YType.int32, "secyif-threshold-value")
                                self._segment_path = lambda: "hour24secyif-threshold" + "[secyif-threshold='" + self.secyif_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyif.Hour24SecyifThresholds.Hour24SecyifThreshold, ['secyif_threshold', 'secyif_threshold_value'], name, value)


                class Hour24Secyrx(Entity):
                    """
                    Configure secy\-rx performance monitoring
                    
                    .. attribute:: hour24secyrx_reports
                    
                    	set secyrx TCA reporting status
                    	**type**\:   :py:class:`Hour24SecyrxReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxReports>`
                    
                    .. attribute:: hour24secyrx_thresholds
                    
                    	Configure secyrx threshold
                    	**type**\:   :py:class:`Hour24SecyrxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx, self).__init__()

                        self.yang_name = "hour24secyrx"
                        self.yang_parent_name = "hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24secyrx-reports" : ("hour24secyrx_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxReports), "hour24secyrx-thresholds" : ("hour24secyrx_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxThresholds)}
                        self._child_list_classes = {}

                        self.hour24secyrx_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxReports()
                        self.hour24secyrx_reports.parent = self
                        self._children_name_map["hour24secyrx_reports"] = "hour24secyrx-reports"
                        self._children_yang_names.add("hour24secyrx-reports")

                        self.hour24secyrx_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxThresholds()
                        self.hour24secyrx_thresholds.parent = self
                        self._children_name_map["hour24secyrx_thresholds"] = "hour24secyrx-thresholds"
                        self._children_yang_names.add("hour24secyrx-thresholds")
                        self._segment_path = lambda: "hour24secyrx"


                    class Hour24SecyrxReports(Entity):
                        """
                        set secyrx TCA reporting status
                        
                        .. attribute:: hour24secyrx_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24SecyrxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxReports.Hour24SecyrxReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxReports, self).__init__()

                            self.yang_name = "hour24secyrx-reports"
                            self.yang_parent_name = "hour24secyrx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24secyrx-report" : ("hour24secyrx_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxReports.Hour24SecyrxReport)}

                            self.hour24secyrx_report = YList(self)
                            self._segment_path = lambda: "hour24secyrx-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxReports, [], name, value)


                        class Hour24SecyrxReport(Entity):
                            """
                            none
                            
                            .. attribute:: secyrx_report  <key>
                            
                            	Secyrx Report type
                            	**type**\:   :py:class:`SecyrxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyrxReport>`
                            
                            .. attribute:: enable
                            
                            	Secyrx Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxReports.Hour24SecyrxReport, self).__init__()

                                self.yang_name = "hour24secyrx-report"
                                self.yang_parent_name = "hour24secyrx-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyrx_report = YLeaf(YType.enumeration, "secyrx-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "hour24secyrx-report" + "[secyrx-report='" + self.secyrx_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxReports.Hour24SecyrxReport, ['secyrx_report', 'enable'], name, value)


                    class Hour24SecyrxThresholds(Entity):
                        """
                        Configure secyrx threshold
                        
                        .. attribute:: hour24secyrx_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24SecyrxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxThresholds.Hour24SecyrxThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxThresholds, self).__init__()

                            self.yang_name = "hour24secyrx-thresholds"
                            self.yang_parent_name = "hour24secyrx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24secyrx-threshold" : ("hour24secyrx_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxThresholds.Hour24SecyrxThreshold)}

                            self.hour24secyrx_threshold = YList(self)
                            self._segment_path = lambda: "hour24secyrx-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxThresholds, [], name, value)


                        class Hour24SecyrxThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: secyrx_threshold  <key>
                            
                            	Secyrx Threshold Type
                            	**type**\:   :py:class:`SecyrxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyrxThreshold>`
                            
                            .. attribute:: secyrx_threshold_value
                            
                            	Secyrx threshold value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxThresholds.Hour24SecyrxThreshold, self).__init__()

                                self.yang_name = "hour24secyrx-threshold"
                                self.yang_parent_name = "hour24secyrx-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyrx_threshold = YLeaf(YType.enumeration, "secyrx-threshold")

                                self.secyrx_threshold_value = YLeaf(YType.int32, "secyrx-threshold-value")
                                self._segment_path = lambda: "hour24secyrx-threshold" + "[secyrx-threshold='" + self.secyrx_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secyrx.Hour24SecyrxThresholds.Hour24SecyrxThreshold, ['secyrx_threshold', 'secyrx_threshold_value'], name, value)


                class Hour24Secytx(Entity):
                    """
                    Configure secy\-tx performance monitoring
                    
                    .. attribute:: hour24secytx_reports
                    
                    	set secytx TCA reporting status
                    	**type**\:   :py:class:`Hour24SecytxReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxReports>`
                    
                    .. attribute:: hour24secytx_thresholds
                    
                    	Configure secytx threshold
                    	**type**\:   :py:class:`Hour24SecytxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx, self).__init__()

                        self.yang_name = "hour24secytx"
                        self.yang_parent_name = "hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24secytx-reports" : ("hour24secytx_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxReports), "hour24secytx-thresholds" : ("hour24secytx_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxThresholds)}
                        self._child_list_classes = {}

                        self.hour24secytx_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxReports()
                        self.hour24secytx_reports.parent = self
                        self._children_name_map["hour24secytx_reports"] = "hour24secytx-reports"
                        self._children_yang_names.add("hour24secytx-reports")

                        self.hour24secytx_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxThresholds()
                        self.hour24secytx_thresholds.parent = self
                        self._children_name_map["hour24secytx_thresholds"] = "hour24secytx-thresholds"
                        self._children_yang_names.add("hour24secytx-thresholds")
                        self._segment_path = lambda: "hour24secytx"


                    class Hour24SecytxReports(Entity):
                        """
                        set secytx TCA reporting status
                        
                        .. attribute:: hour24secytx_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24SecytxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxReports.Hour24SecytxReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxReports, self).__init__()

                            self.yang_name = "hour24secytx-reports"
                            self.yang_parent_name = "hour24secytx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24secytx-report" : ("hour24secytx_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxReports.Hour24SecytxReport)}

                            self.hour24secytx_report = YList(self)
                            self._segment_path = lambda: "hour24secytx-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxReports, [], name, value)


                        class Hour24SecytxReport(Entity):
                            """
                            none
                            
                            .. attribute:: secytx_report  <key>
                            
                            	Secytx Report type
                            	**type**\:   :py:class:`SecytxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecytxReport>`
                            
                            .. attribute:: enable
                            
                            	Secytx Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxReports.Hour24SecytxReport, self).__init__()

                                self.yang_name = "hour24secytx-report"
                                self.yang_parent_name = "hour24secytx-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secytx_report = YLeaf(YType.enumeration, "secytx-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "hour24secytx-report" + "[secytx-report='" + self.secytx_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxReports.Hour24SecytxReport, ['secytx_report', 'enable'], name, value)


                    class Hour24SecytxThresholds(Entity):
                        """
                        Configure secytx threshold
                        
                        .. attribute:: hour24secytx_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24SecytxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxThresholds.Hour24SecytxThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxThresholds, self).__init__()

                            self.yang_name = "hour24secytx-thresholds"
                            self.yang_parent_name = "hour24secytx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24secytx-threshold" : ("hour24secytx_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxThresholds.Hour24SecytxThreshold)}

                            self.hour24secytx_threshold = YList(self)
                            self._segment_path = lambda: "hour24secytx-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxThresholds, [], name, value)


                        class Hour24SecytxThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: secytx_threshold  <key>
                            
                            	Secytx Threshold Type
                            	**type**\:   :py:class:`SecytxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecytxThreshold>`
                            
                            .. attribute:: secytx_threshold_value
                            
                            	Secytx threshold value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxThresholds.Hour24SecytxThreshold, self).__init__()

                                self.yang_name = "hour24secytx-threshold"
                                self.yang_parent_name = "hour24secytx-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secytx_threshold = YLeaf(YType.enumeration, "secytx-threshold")

                                self.secytx_threshold_value = YLeaf(YType.int32, "secytx-threshold-value")
                                self._segment_path = lambda: "hour24secytx-threshold" + "[secytx-threshold='" + self.secytx_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24.Hour24Secytx.Hour24SecytxThresholds.Hour24SecytxThreshold, ['secytx_threshold', 'secytx_threshold_value'], name, value)


            class Hour24Gfp(Entity):
                """
                Configure pm parameters of gfp 24 hour interval
                
                .. attribute:: hour24_gfp
                
                	Configure gfp performance monitoring
                	**type**\:   :py:class:`Hour24Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp, self).__init__()

                    self.yang_name = "hour24-gfp"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"hour24-gfp" : ("hour24_gfp", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp)}
                    self._child_list_classes = {}

                    self.hour24_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp()
                    self.hour24_gfp.parent = self
                    self._children_name_map["hour24_gfp"] = "hour24-gfp"
                    self._children_yang_names.add("hour24-gfp")
                    self._segment_path = lambda: "hour24-gfp"


                class Hour24Gfp(Entity):
                    """
                    Configure gfp performance monitoring
                    
                    .. attribute:: hour24_gfp_reports
                    
                    	set gfp TCA reporting status
                    	**type**\:   :py:class:`Hour24GfpReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports>`
                    
                    .. attribute:: hour24_gfp_thresholds
                    
                    	Configure threshold on gfp parameters
                    	**type**\:   :py:class:`Hour24GfpThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp, self).__init__()

                        self.yang_name = "hour24-gfp"
                        self.yang_parent_name = "hour24-gfp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24-gfp-reports" : ("hour24_gfp_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports), "hour24-gfp-thresholds" : ("hour24_gfp_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds)}
                        self._child_list_classes = {}

                        self.hour24_gfp_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports()
                        self.hour24_gfp_reports.parent = self
                        self._children_name_map["hour24_gfp_reports"] = "hour24-gfp-reports"
                        self._children_yang_names.add("hour24-gfp-reports")

                        self.hour24_gfp_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds()
                        self.hour24_gfp_thresholds.parent = self
                        self._children_name_map["hour24_gfp_thresholds"] = "hour24-gfp-thresholds"
                        self._children_yang_names.add("hour24-gfp-thresholds")
                        self._segment_path = lambda: "hour24-gfp"


                    class Hour24GfpReports(Entity):
                        """
                        set gfp TCA reporting status
                        
                        .. attribute:: hour24_gfp_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24GfpReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports.Hour24GfpReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports, self).__init__()

                            self.yang_name = "hour24-gfp-reports"
                            self.yang_parent_name = "hour24-gfp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24-gfp-report" : ("hour24_gfp_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports.Hour24GfpReport)}

                            self.hour24_gfp_report = YList(self)
                            self._segment_path = lambda: "hour24-gfp-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports, [], name, value)


                        class Hour24GfpReport(Entity):
                            """
                            none
                            
                            .. attribute:: gfp_report  <key>
                            
                            	Gfp Report Type
                            	**type**\:   :py:class:`GfpReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.GfpReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports.Hour24GfpReport, self).__init__()

                                self.yang_name = "hour24-gfp-report"
                                self.yang_parent_name = "hour24-gfp-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.gfp_report = YLeaf(YType.enumeration, "gfp-report")
                                self._segment_path = lambda: "hour24-gfp-report" + "[gfp-report='" + self.gfp_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpReports.Hour24GfpReport, ['gfp_report'], name, value)


                    class Hour24GfpThresholds(Entity):
                        """
                        Configure threshold on gfp parameters
                        
                        .. attribute:: hour24_gfp_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24GfpThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds.Hour24GfpThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds, self).__init__()

                            self.yang_name = "hour24-gfp-thresholds"
                            self.yang_parent_name = "hour24-gfp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24-gfp-threshold" : ("hour24_gfp_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds.Hour24GfpThreshold)}

                            self.hour24_gfp_threshold = YList(self)
                            self._segment_path = lambda: "hour24-gfp-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds, [], name, value)


                        class Hour24GfpThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: gfp_threshold  <key>
                            
                            	Gfp Threshold Type
                            	**type**\:   :py:class:`GfpThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.GfpThreshold>`
                            
                            .. attribute:: gfp_threshold_value
                            
                            	Gfp Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds.Hour24GfpThreshold, self).__init__()

                                self.yang_name = "hour24-gfp-threshold"
                                self.yang_parent_name = "hour24-gfp-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.gfp_threshold = YLeaf(YType.enumeration, "gfp-threshold")

                                self.gfp_threshold_value = YLeaf(YType.int32, "gfp-threshold-value")
                                self._segment_path = lambda: "hour24-gfp-threshold" + "[gfp-threshold='" + self.gfp_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Gfp.Hour24Gfp.Hour24GfpThresholds.Hour24GfpThreshold, ['gfp_threshold', 'gfp_threshold_value'], name, value)


            class Hour24OtnTcms(Entity):
                """
                Configure pm parameters of tcm's 24 hour
                interval
                
                .. attribute:: hour24otn_tcm
                
                	configure otn g709 tcm's performance monitoring
                	**type**\: list of    :py:class:`Hour24OtnTcm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms, self).__init__()

                    self.yang_name = "hour24otn-tcms"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"hour24otn-tcm" : ("hour24otn_tcm", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm)}

                    self.hour24otn_tcm = YList(self)
                    self._segment_path = lambda: "hour24otn-tcms"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms, [], name, value)


                class Hour24OtnTcm(Entity):
                    """
                    configure otn g709 tcm's performance
                    monitoring
                    
                    .. attribute:: tcm_number  <key>
                    
                    	TCM number
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: hour24otn_tcm_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Hour24OtnTcmReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports>`
                    
                    .. attribute:: hour24otn_tcm_thresholds
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Hour24OtnTcmThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm, self).__init__()

                        self.yang_name = "hour24otn-tcm"
                        self.yang_parent_name = "hour24otn-tcms"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24otn-tcm-reports" : ("hour24otn_tcm_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports), "hour24otn-tcm-thresholds" : ("hour24otn_tcm_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds)}
                        self._child_list_classes = {}

                        self.tcm_number = YLeaf(YType.int32, "tcm-number")

                        self.hour24otn_tcm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports()
                        self.hour24otn_tcm_reports.parent = self
                        self._children_name_map["hour24otn_tcm_reports"] = "hour24otn-tcm-reports"
                        self._children_yang_names.add("hour24otn-tcm-reports")

                        self.hour24otn_tcm_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds()
                        self.hour24otn_tcm_thresholds.parent = self
                        self._children_name_map["hour24otn_tcm_thresholds"] = "hour24otn-tcm-thresholds"
                        self._children_yang_names.add("hour24otn-tcm-thresholds")
                        self._segment_path = lambda: "hour24otn-tcm" + "[tcm-number='" + self.tcm_number.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm, ['tcm_number'], name, value)


                    class Hour24OtnTcmReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: hour24otn_tcm_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnTcmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports.Hour24OtnTcmReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports, self).__init__()

                            self.yang_name = "hour24otn-tcm-reports"
                            self.yang_parent_name = "hour24otn-tcm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24otn-tcm-report" : ("hour24otn_tcm_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports.Hour24OtnTcmReport)}

                            self.hour24otn_tcm_report = YList(self)
                            self._segment_path = lambda: "hour24otn-tcm-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports, [], name, value)


                        class Hour24OtnTcmReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnTcmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnTcmReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports.Hour24OtnTcmReport, self).__init__()

                                self.yang_name = "hour24otn-tcm-report"
                                self.yang_parent_name = "hour24otn-tcm-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "hour24otn-tcm-report" + "[otn-report='" + self.otn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmReports.Hour24OtnTcmReport, ['otn_report', 'enable'], name, value)


                    class Hour24OtnTcmThresholds(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: hour24otn_tcm_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnTcmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds.Hour24OtnTcmThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds, self).__init__()

                            self.yang_name = "hour24otn-tcm-thresholds"
                            self.yang_parent_name = "hour24otn-tcm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24otn-tcm-threshold" : ("hour24otn_tcm_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds.Hour24OtnTcmThreshold)}

                            self.hour24otn_tcm_threshold = YList(self)
                            self._segment_path = lambda: "hour24otn-tcm-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds, [], name, value)


                        class Hour24OtnTcmThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnTcmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnTcmThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds.Hour24OtnTcmThreshold, self).__init__()

                                self.yang_name = "hour24otn-tcm-threshold"
                                self.yang_parent_name = "hour24otn-tcm-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")
                                self._segment_path = lambda: "hour24otn-tcm-threshold" + "[otn-threshold='" + self.otn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24OtnTcms.Hour24OtnTcm.Hour24OtnTcmThresholds.Hour24OtnTcmThreshold, ['otn_threshold', 'otn_threshold_value'], name, value)


            class Hour24Path(Entity):
                """
                Configure pm parameters of pathmonitor 24 hour
                interval
                
                .. attribute:: hour24otn_path
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Hour24OtnPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path, self).__init__()

                    self.yang_name = "hour24-path"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"hour24otn-path" : ("hour24otn_path", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath)}
                    self._child_list_classes = {}

                    self.hour24otn_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath()
                    self.hour24otn_path.parent = self
                    self._children_name_map["hour24otn_path"] = "hour24otn-path"
                    self._children_yang_names.add("hour24otn-path")
                    self._segment_path = lambda: "hour24-path"


                class Hour24OtnPath(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: hour24otn_path_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Hour24OtnPathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports>`
                    
                    .. attribute:: hour24otn_path_thresholds
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Hour24OtnPathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath, self).__init__()

                        self.yang_name = "hour24otn-path"
                        self.yang_parent_name = "hour24-path"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"hour24otn-path-reports" : ("hour24otn_path_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports), "hour24otn-path-thresholds" : ("hour24otn_path_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds)}
                        self._child_list_classes = {}

                        self.hour24otn_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports()
                        self.hour24otn_path_reports.parent = self
                        self._children_name_map["hour24otn_path_reports"] = "hour24otn-path-reports"
                        self._children_yang_names.add("hour24otn-path-reports")

                        self.hour24otn_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds()
                        self.hour24otn_path_thresholds.parent = self
                        self._children_name_map["hour24otn_path_thresholds"] = "hour24otn-path-thresholds"
                        self._children_yang_names.add("hour24otn-path-thresholds")
                        self._segment_path = lambda: "hour24otn-path"


                    class Hour24OtnPathReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: hour24otn_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnPathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports.Hour24OtnPathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports, self).__init__()

                            self.yang_name = "hour24otn-path-reports"
                            self.yang_parent_name = "hour24otn-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24otn-path-report" : ("hour24otn_path_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports.Hour24OtnPathReport)}

                            self.hour24otn_path_report = YList(self)
                            self._segment_path = lambda: "hour24otn-path-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports, [], name, value)


                        class Hour24OtnPathReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports.Hour24OtnPathReport, self).__init__()

                                self.yang_name = "hour24otn-path-report"
                                self.yang_parent_name = "hour24otn-path-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "hour24otn-path-report" + "[otn-report='" + self.otn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathReports.Hour24OtnPathReport, ['otn_report', 'enable'], name, value)


                    class Hour24OtnPathThresholds(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: hour24otn_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Hour24OtnPathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds.Hour24OtnPathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds, self).__init__()

                            self.yang_name = "hour24otn-path-thresholds"
                            self.yang_parent_name = "hour24otn-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"hour24otn-path-threshold" : ("hour24otn_path_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds.Hour24OtnPathThreshold)}

                            self.hour24otn_path_threshold = YList(self)
                            self._segment_path = lambda: "hour24otn-path-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds, [], name, value)


                        class Hour24OtnPathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds.Hour24OtnPathThreshold, self).__init__()

                                self.yang_name = "hour24otn-path-threshold"
                                self.yang_parent_name = "hour24otn-path-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")
                                self._segment_path = lambda: "hour24otn-path-threshold" + "[otn-threshold='" + self.otn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Hour24Path.Hour24OtnPath.Hour24OtnPathThresholds.Hour24OtnPathThreshold, ['otn_threshold', 'otn_threshold_value'], name, value)


            class Minute15(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15_optics
                
                	Configure optics performance monitoring
                	**type**\:   :py:class:`Minute15Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics>`
                
                .. attribute:: minute15fec
                
                	Configure fec g709 performance monitoring
                	**type**\:   :py:class:`Minute15Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec>`
                
                .. attribute:: minute15otn
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Minute15Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn>`
                
                .. attribute:: minute15secyif
                
                	Configure secy\-if performance monitoring
                	**type**\:   :py:class:`Minute15Secyif <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif>`
                
                .. attribute:: minute15secyrx
                
                	Configure secy\-rx performance monitoring
                	**type**\:   :py:class:`Minute15Secyrx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx>`
                
                .. attribute:: minute15secytx
                
                	Configure secy\-tx performance monitoring
                	**type**\:   :py:class:`Minute15Secytx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15, self).__init__()

                    self.yang_name = "minute15"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"minute15-optics" : ("minute15_optics", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics), "minute15fec" : ("minute15fec", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec), "minute15otn" : ("minute15otn", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn), "minute15secyif" : ("minute15secyif", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif), "minute15secyrx" : ("minute15secyrx", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx), "minute15secytx" : ("minute15secytx", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx)}
                    self._child_list_classes = {}

                    self.minute15_optics = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics()
                    self.minute15_optics.parent = self
                    self._children_name_map["minute15_optics"] = "minute15-optics"
                    self._children_yang_names.add("minute15-optics")

                    self.minute15fec = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec()
                    self.minute15fec.parent = self
                    self._children_name_map["minute15fec"] = "minute15fec"
                    self._children_yang_names.add("minute15fec")

                    self.minute15otn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn()
                    self.minute15otn.parent = self
                    self._children_name_map["minute15otn"] = "minute15otn"
                    self._children_yang_names.add("minute15otn")

                    self.minute15secyif = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif()
                    self.minute15secyif.parent = self
                    self._children_name_map["minute15secyif"] = "minute15secyif"
                    self._children_yang_names.add("minute15secyif")

                    self.minute15secyrx = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx()
                    self.minute15secyrx.parent = self
                    self._children_name_map["minute15secyrx"] = "minute15secyrx"
                    self._children_yang_names.add("minute15secyrx")

                    self.minute15secytx = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx()
                    self.minute15secytx.parent = self
                    self._children_name_map["minute15secytx"] = "minute15secytx"
                    self._children_yang_names.add("minute15secytx")
                    self._segment_path = lambda: "minute15"


                class Minute15Fec(Entity):
                    """
                    Configure fec g709 performance monitoring
                    
                    .. attribute:: minute15fec_reports
                    
                    	set fec TCA reporting status
                    	**type**\:   :py:class:`Minute15FecReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports>`
                    
                    .. attribute:: minute15fec_thresholds
                    
                    	Configure fec threshold
                    	**type**\:   :py:class:`Minute15FecThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec, self).__init__()

                        self.yang_name = "minute15fec"
                        self.yang_parent_name = "minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"minute15fec-reports" : ("minute15fec_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports), "minute15fec-thresholds" : ("minute15fec_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds)}
                        self._child_list_classes = {}

                        self.minute15fec_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports()
                        self.minute15fec_reports.parent = self
                        self._children_name_map["minute15fec_reports"] = "minute15fec-reports"
                        self._children_yang_names.add("minute15fec-reports")

                        self.minute15fec_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds()
                        self.minute15fec_thresholds.parent = self
                        self._children_name_map["minute15fec_thresholds"] = "minute15fec-thresholds"
                        self._children_yang_names.add("minute15fec-thresholds")
                        self._segment_path = lambda: "minute15fec"


                    class Minute15FecReports(Entity):
                        """
                        set fec TCA reporting status
                        
                        .. attribute:: minute15fec_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports.Minute15FecReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports, self).__init__()

                            self.yang_name = "minute15fec-reports"
                            self.yang_parent_name = "minute15fec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15fec-report" : ("minute15fec_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports.Minute15FecReport)}

                            self.minute15fec_report = YList(self)
                            self._segment_path = lambda: "minute15fec-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports, [], name, value)


                        class Minute15FecReport(Entity):
                            """
                            none
                            
                            .. attribute:: fec_report  <key>
                            
                            	Fec Report Type
                            	**type**\:   :py:class:`FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecReport>`
                            
                            .. attribute:: enable
                            
                            	Fec Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports.Minute15FecReport, self).__init__()

                                self.yang_name = "minute15fec-report"
                                self.yang_parent_name = "minute15fec-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.fec_report = YLeaf(YType.enumeration, "fec-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "minute15fec-report" + "[fec-report='" + self.fec_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecReports.Minute15FecReport, ['fec_report', 'enable'], name, value)


                    class Minute15FecThresholds(Entity):
                        """
                        Configure fec threshold
                        
                        .. attribute:: minute15fec_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds.Minute15FecThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds, self).__init__()

                            self.yang_name = "minute15fec-thresholds"
                            self.yang_parent_name = "minute15fec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15fec-threshold" : ("minute15fec_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds.Minute15FecThreshold)}

                            self.minute15fec_threshold = YList(self)
                            self._segment_path = lambda: "minute15fec-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds, [], name, value)


                        class Minute15FecThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: fec_threshold  <key>
                            
                            	Fec Threshold Type
                            	**type**\:   :py:class:`FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecThreshold>`
                            
                            .. attribute:: fec_threshold_value
                            
                            	Fec Threshold Value
                            	**type**\:  str
                            
                            	**length:** 1..16
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds.Minute15FecThreshold, self).__init__()

                                self.yang_name = "minute15fec-threshold"
                                self.yang_parent_name = "minute15fec-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.fec_threshold = YLeaf(YType.enumeration, "fec-threshold")

                                self.fec_threshold_value = YLeaf(YType.str, "fec-threshold-value")
                                self._segment_path = lambda: "minute15fec-threshold" + "[fec-threshold='" + self.fec_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Fec.Minute15FecThresholds.Minute15FecThreshold, ['fec_threshold', 'fec_threshold_value'], name, value)


                class Minute15Optics(Entity):
                    """
                    Configure optics performance monitoring
                    
                    .. attribute:: minute15_optics_reports
                    
                    	set optics TCA reporting status
                    	**type**\:   :py:class:`Minute15OpticsReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports>`
                    
                    .. attribute:: minute15_optics_thresholds
                    
                    	Configure threshold on optics parameters
                    	**type**\:   :py:class:`Minute15OpticsThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics, self).__init__()

                        self.yang_name = "minute15-optics"
                        self.yang_parent_name = "minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"minute15-optics-reports" : ("minute15_optics_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports), "minute15-optics-thresholds" : ("minute15_optics_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds)}
                        self._child_list_classes = {}

                        self.minute15_optics_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports()
                        self.minute15_optics_reports.parent = self
                        self._children_name_map["minute15_optics_reports"] = "minute15-optics-reports"
                        self._children_yang_names.add("minute15-optics-reports")

                        self.minute15_optics_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds()
                        self.minute15_optics_thresholds.parent = self
                        self._children_name_map["minute15_optics_thresholds"] = "minute15-optics-thresholds"
                        self._children_yang_names.add("minute15-optics-thresholds")
                        self._segment_path = lambda: "minute15-optics"


                    class Minute15OpticsReports(Entity):
                        """
                        set optics TCA reporting status
                        
                        .. attribute:: minute15_optics_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports.Minute15OpticsReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports, self).__init__()

                            self.yang_name = "minute15-optics-reports"
                            self.yang_parent_name = "minute15-optics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15-optics-report" : ("minute15_optics_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports.Minute15OpticsReport)}

                            self.minute15_optics_report = YList(self)
                            self._segment_path = lambda: "minute15-optics-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports, [], name, value)


                        class Minute15OpticsReport(Entity):
                            """
                            none
                            
                            .. attribute:: optics_report  <key>
                            
                            	Optics Report Type
                            	**type**\:   :py:class:`OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports.Minute15OpticsReport, self).__init__()

                                self.yang_name = "minute15-optics-report"
                                self.yang_parent_name = "minute15-optics-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.optics_report = YLeaf(YType.enumeration, "optics-report")
                                self._segment_path = lambda: "minute15-optics-report" + "[optics-report='" + self.optics_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsReports.Minute15OpticsReport, ['optics_report'], name, value)


                    class Minute15OpticsThresholds(Entity):
                        """
                        Configure threshold on optics parameters
                        
                        .. attribute:: minute15_optics_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds.Minute15OpticsThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds, self).__init__()

                            self.yang_name = "minute15-optics-thresholds"
                            self.yang_parent_name = "minute15-optics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15-optics-threshold" : ("minute15_optics_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds.Minute15OpticsThreshold)}

                            self.minute15_optics_threshold = YList(self)
                            self._segment_path = lambda: "minute15-optics-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds, [], name, value)


                        class Minute15OpticsThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: optics_threshold  <key>
                            
                            	Optics Threshold Type
                            	**type**\:   :py:class:`OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsThreshold>`
                            
                            .. attribute:: dbm
                            
                            	Used only for Opt and Opr,To Enter Threshold in dbm use 1
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: optics_threshold_value
                            
                            	Optics Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds.Minute15OpticsThreshold, self).__init__()

                                self.yang_name = "minute15-optics-threshold"
                                self.yang_parent_name = "minute15-optics-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.optics_threshold = YLeaf(YType.enumeration, "optics-threshold")

                                self.dbm = YLeaf(YType.int32, "dbm")

                                self.optics_threshold_value = YLeaf(YType.int32, "optics-threshold-value")
                                self._segment_path = lambda: "minute15-optics-threshold" + "[optics-threshold='" + self.optics_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Optics.Minute15OpticsThresholds.Minute15OpticsThreshold, ['optics_threshold', 'dbm', 'optics_threshold_value'], name, value)


                class Minute15Otn(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: min15_otn_threshes
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Min15OtnThreshes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes>`
                    
                    .. attribute:: minute15otn_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Minute15OtnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn, self).__init__()

                        self.yang_name = "minute15otn"
                        self.yang_parent_name = "minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"min15-otn-threshes" : ("min15_otn_threshes", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes), "minute15otn-reports" : ("minute15otn_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports)}
                        self._child_list_classes = {}

                        self.min15_otn_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes()
                        self.min15_otn_threshes.parent = self
                        self._children_name_map["min15_otn_threshes"] = "min15-otn-threshes"
                        self._children_yang_names.add("min15-otn-threshes")

                        self.minute15otn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports()
                        self.minute15otn_reports.parent = self
                        self._children_name_map["minute15otn_reports"] = "minute15otn-reports"
                        self._children_yang_names.add("minute15otn-reports")
                        self._segment_path = lambda: "minute15otn"


                    class Min15OtnThreshes(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: min15_otn_thresh
                        
                        	none
                        	**type**\: list of    :py:class:`Min15OtnThresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes.Min15OtnThresh>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes, self).__init__()

                            self.yang_name = "min15-otn-threshes"
                            self.yang_parent_name = "minute15otn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"min15-otn-thresh" : ("min15_otn_thresh", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes.Min15OtnThresh)}

                            self.min15_otn_thresh = YList(self)
                            self._segment_path = lambda: "min15-otn-threshes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes, [], name, value)


                        class Min15OtnThresh(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes.Min15OtnThresh, self).__init__()

                                self.yang_name = "min15-otn-thresh"
                                self.yang_parent_name = "min15-otn-threshes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")
                                self._segment_path = lambda: "min15-otn-thresh" + "[otn-threshold='" + self.otn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Min15OtnThreshes.Min15OtnThresh, ['otn_threshold', 'otn_threshold_value'], name, value)


                    class Minute15OtnReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: minute15otn_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports.Minute15OtnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports, self).__init__()

                            self.yang_name = "minute15otn-reports"
                            self.yang_parent_name = "minute15otn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15otn-report" : ("minute15otn_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports.Minute15OtnReport)}

                            self.minute15otn_report = YList(self)
                            self._segment_path = lambda: "minute15otn-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports, [], name, value)


                        class Minute15OtnReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports.Minute15OtnReport, self).__init__()

                                self.yang_name = "minute15otn-report"
                                self.yang_parent_name = "minute15otn-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "minute15otn-report" + "[otn-report='" + self.otn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Otn.Minute15OtnReports.Minute15OtnReport, ['otn_report', 'enable'], name, value)


                class Minute15Secyif(Entity):
                    """
                    Configure secy\-if performance monitoring
                    
                    .. attribute:: minute15secyif_reports
                    
                    	set secyif TCA reporting status
                    	**type**\:   :py:class:`Minute15SecyifReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifReports>`
                    
                    .. attribute:: minute15secyif_thresholds
                    
                    	Configure threshold on secyif parameters
                    	**type**\:   :py:class:`Minute15SecyifThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif, self).__init__()

                        self.yang_name = "minute15secyif"
                        self.yang_parent_name = "minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"minute15secyif-reports" : ("minute15secyif_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifReports), "minute15secyif-thresholds" : ("minute15secyif_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifThresholds)}
                        self._child_list_classes = {}

                        self.minute15secyif_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifReports()
                        self.minute15secyif_reports.parent = self
                        self._children_name_map["minute15secyif_reports"] = "minute15secyif-reports"
                        self._children_yang_names.add("minute15secyif-reports")

                        self.minute15secyif_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifThresholds()
                        self.minute15secyif_thresholds.parent = self
                        self._children_name_map["minute15secyif_thresholds"] = "minute15secyif-thresholds"
                        self._children_yang_names.add("minute15secyif-thresholds")
                        self._segment_path = lambda: "minute15secyif"


                    class Minute15SecyifReports(Entity):
                        """
                        set secyif TCA reporting status
                        
                        .. attribute:: minute15secyif_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15SecyifReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifReports.Minute15SecyifReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifReports, self).__init__()

                            self.yang_name = "minute15secyif-reports"
                            self.yang_parent_name = "minute15secyif"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15secyif-report" : ("minute15secyif_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifReports.Minute15SecyifReport)}

                            self.minute15secyif_report = YList(self)
                            self._segment_path = lambda: "minute15secyif-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifReports, [], name, value)


                        class Minute15SecyifReport(Entity):
                            """
                            none
                            
                            .. attribute:: secyif_report  <key>
                            
                            	Secyif Report Type
                            	**type**\:   :py:class:`SecyifReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyifReport>`
                            
                            .. attribute:: enable
                            
                            	Enabled Secyif Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifReports.Minute15SecyifReport, self).__init__()

                                self.yang_name = "minute15secyif-report"
                                self.yang_parent_name = "minute15secyif-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyif_report = YLeaf(YType.enumeration, "secyif-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "minute15secyif-report" + "[secyif-report='" + self.secyif_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifReports.Minute15SecyifReport, ['secyif_report', 'enable'], name, value)


                    class Minute15SecyifThresholds(Entity):
                        """
                        Configure threshold on secyif parameters
                        
                        .. attribute:: minute15secyif_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15SecyifThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifThresholds.Minute15SecyifThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifThresholds, self).__init__()

                            self.yang_name = "minute15secyif-thresholds"
                            self.yang_parent_name = "minute15secyif"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15secyif-threshold" : ("minute15secyif_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifThresholds.Minute15SecyifThreshold)}

                            self.minute15secyif_threshold = YList(self)
                            self._segment_path = lambda: "minute15secyif-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifThresholds, [], name, value)


                        class Minute15SecyifThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: secyif_threshold  <key>
                            
                            	Secyif Threshold Type
                            	**type**\:   :py:class:`SecyifThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyifThreshold>`
                            
                            .. attribute:: secyif_threshold_value
                            
                            	Secyif Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifThresholds.Minute15SecyifThreshold, self).__init__()

                                self.yang_name = "minute15secyif-threshold"
                                self.yang_parent_name = "minute15secyif-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyif_threshold = YLeaf(YType.enumeration, "secyif-threshold")

                                self.secyif_threshold_value = YLeaf(YType.int32, "secyif-threshold-value")
                                self._segment_path = lambda: "minute15secyif-threshold" + "[secyif-threshold='" + self.secyif_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyif.Minute15SecyifThresholds.Minute15SecyifThreshold, ['secyif_threshold', 'secyif_threshold_value'], name, value)


                class Minute15Secyrx(Entity):
                    """
                    Configure secy\-rx performance monitoring
                    
                    .. attribute:: minute15secyrx_reports
                    
                    	set secyrx TCA reporting status
                    	**type**\:   :py:class:`Minute15SecyrxReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxReports>`
                    
                    .. attribute:: minute15secyrx_thresholds
                    
                    	Configure threshold on secyrx parameters
                    	**type**\:   :py:class:`Minute15SecyrxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx, self).__init__()

                        self.yang_name = "minute15secyrx"
                        self.yang_parent_name = "minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"minute15secyrx-reports" : ("minute15secyrx_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxReports), "minute15secyrx-thresholds" : ("minute15secyrx_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxThresholds)}
                        self._child_list_classes = {}

                        self.minute15secyrx_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxReports()
                        self.minute15secyrx_reports.parent = self
                        self._children_name_map["minute15secyrx_reports"] = "minute15secyrx-reports"
                        self._children_yang_names.add("minute15secyrx-reports")

                        self.minute15secyrx_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxThresholds()
                        self.minute15secyrx_thresholds.parent = self
                        self._children_name_map["minute15secyrx_thresholds"] = "minute15secyrx-thresholds"
                        self._children_yang_names.add("minute15secyrx-thresholds")
                        self._segment_path = lambda: "minute15secyrx"


                    class Minute15SecyrxReports(Entity):
                        """
                        set secyrx TCA reporting status
                        
                        .. attribute:: minute15secyrx_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15SecyrxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxReports.Minute15SecyrxReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxReports, self).__init__()

                            self.yang_name = "minute15secyrx-reports"
                            self.yang_parent_name = "minute15secyrx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15secyrx-report" : ("minute15secyrx_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxReports.Minute15SecyrxReport)}

                            self.minute15secyrx_report = YList(self)
                            self._segment_path = lambda: "minute15secyrx-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxReports, [], name, value)


                        class Minute15SecyrxReport(Entity):
                            """
                            none
                            
                            .. attribute:: secyrx_report  <key>
                            
                            	Secyrx Report Type
                            	**type**\:   :py:class:`SecyrxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyrxReport>`
                            
                            .. attribute:: enable
                            
                            	Enabled Secyrx Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxReports.Minute15SecyrxReport, self).__init__()

                                self.yang_name = "minute15secyrx-report"
                                self.yang_parent_name = "minute15secyrx-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyrx_report = YLeaf(YType.enumeration, "secyrx-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "minute15secyrx-report" + "[secyrx-report='" + self.secyrx_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxReports.Minute15SecyrxReport, ['secyrx_report', 'enable'], name, value)


                    class Minute15SecyrxThresholds(Entity):
                        """
                        Configure threshold on secyrx parameters
                        
                        .. attribute:: minute15secyrx_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15SecyrxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxThresholds.Minute15SecyrxThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxThresholds, self).__init__()

                            self.yang_name = "minute15secyrx-thresholds"
                            self.yang_parent_name = "minute15secyrx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15secyrx-threshold" : ("minute15secyrx_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxThresholds.Minute15SecyrxThreshold)}

                            self.minute15secyrx_threshold = YList(self)
                            self._segment_path = lambda: "minute15secyrx-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxThresholds, [], name, value)


                        class Minute15SecyrxThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: secyrx_threshold  <key>
                            
                            	Secyrx Threshold Type
                            	**type**\:   :py:class:`SecyrxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyrxThreshold>`
                            
                            .. attribute:: secyrx_threshold_value
                            
                            	Secyrx Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxThresholds.Minute15SecyrxThreshold, self).__init__()

                                self.yang_name = "minute15secyrx-threshold"
                                self.yang_parent_name = "minute15secyrx-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyrx_threshold = YLeaf(YType.enumeration, "secyrx-threshold")

                                self.secyrx_threshold_value = YLeaf(YType.int32, "secyrx-threshold-value")
                                self._segment_path = lambda: "minute15secyrx-threshold" + "[secyrx-threshold='" + self.secyrx_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secyrx.Minute15SecyrxThresholds.Minute15SecyrxThreshold, ['secyrx_threshold', 'secyrx_threshold_value'], name, value)


                class Minute15Secytx(Entity):
                    """
                    Configure secy\-tx performance monitoring
                    
                    .. attribute:: minute15secytx_reports
                    
                    	set secytx TCA reporting status
                    	**type**\:   :py:class:`Minute15SecytxReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxReports>`
                    
                    .. attribute:: minute15secytx_thresholds
                    
                    	Configure threshold on secytx parameters
                    	**type**\:   :py:class:`Minute15SecytxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx, self).__init__()

                        self.yang_name = "minute15secytx"
                        self.yang_parent_name = "minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"minute15secytx-reports" : ("minute15secytx_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxReports), "minute15secytx-thresholds" : ("minute15secytx_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxThresholds)}
                        self._child_list_classes = {}

                        self.minute15secytx_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxReports()
                        self.minute15secytx_reports.parent = self
                        self._children_name_map["minute15secytx_reports"] = "minute15secytx-reports"
                        self._children_yang_names.add("minute15secytx-reports")

                        self.minute15secytx_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxThresholds()
                        self.minute15secytx_thresholds.parent = self
                        self._children_name_map["minute15secytx_thresholds"] = "minute15secytx-thresholds"
                        self._children_yang_names.add("minute15secytx-thresholds")
                        self._segment_path = lambda: "minute15secytx"


                    class Minute15SecytxReports(Entity):
                        """
                        set secytx TCA reporting status
                        
                        .. attribute:: minute15secytx_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15SecytxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxReports.Minute15SecytxReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxReports, self).__init__()

                            self.yang_name = "minute15secytx-reports"
                            self.yang_parent_name = "minute15secytx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15secytx-report" : ("minute15secytx_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxReports.Minute15SecytxReport)}

                            self.minute15secytx_report = YList(self)
                            self._segment_path = lambda: "minute15secytx-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxReports, [], name, value)


                        class Minute15SecytxReport(Entity):
                            """
                            none
                            
                            .. attribute:: secytx_report  <key>
                            
                            	Secytx Report Type
                            	**type**\:   :py:class:`SecytxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecytxReport>`
                            
                            .. attribute:: enable
                            
                            	Enabled Secytx Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxReports.Minute15SecytxReport, self).__init__()

                                self.yang_name = "minute15secytx-report"
                                self.yang_parent_name = "minute15secytx-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secytx_report = YLeaf(YType.enumeration, "secytx-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "minute15secytx-report" + "[secytx-report='" + self.secytx_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxReports.Minute15SecytxReport, ['secytx_report', 'enable'], name, value)


                    class Minute15SecytxThresholds(Entity):
                        """
                        Configure threshold on secytx parameters
                        
                        .. attribute:: minute15secytx_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15SecytxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxThresholds.Minute15SecytxThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxThresholds, self).__init__()

                            self.yang_name = "minute15secytx-thresholds"
                            self.yang_parent_name = "minute15secytx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15secytx-threshold" : ("minute15secytx_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxThresholds.Minute15SecytxThreshold)}

                            self.minute15secytx_threshold = YList(self)
                            self._segment_path = lambda: "minute15secytx-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxThresholds, [], name, value)


                        class Minute15SecytxThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: secytx_threshold  <key>
                            
                            	Secytx Threshold Type
                            	**type**\:   :py:class:`SecytxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecytxThreshold>`
                            
                            .. attribute:: secytx_threshold_value
                            
                            	Secytx Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxThresholds.Minute15SecytxThreshold, self).__init__()

                                self.yang_name = "minute15secytx-threshold"
                                self.yang_parent_name = "minute15secytx-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secytx_threshold = YLeaf(YType.enumeration, "secytx-threshold")

                                self.secytx_threshold_value = YLeaf(YType.int32, "secytx-threshold-value")
                                self._segment_path = lambda: "minute15secytx-threshold" + "[secytx-threshold='" + self.secytx_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15.Minute15Secytx.Minute15SecytxThresholds.Minute15SecytxThreshold, ['secytx_threshold', 'secytx_threshold_value'], name, value)


            class Minute15Gfp(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15_gfp
                
                	Configure gfp performance monitoring
                	**type**\:   :py:class:`Minute15Gfp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp, self).__init__()

                    self.yang_name = "minute15-gfp"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"minute15-gfp" : ("minute15_gfp", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp)}
                    self._child_list_classes = {}

                    self.minute15_gfp = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp()
                    self.minute15_gfp.parent = self
                    self._children_name_map["minute15_gfp"] = "minute15-gfp"
                    self._children_yang_names.add("minute15-gfp")
                    self._segment_path = lambda: "minute15-gfp"


                class Minute15Gfp(Entity):
                    """
                    Configure gfp performance monitoring
                    
                    .. attribute:: minute15_gfp_reports
                    
                    	set gfp TCA reporting status
                    	**type**\:   :py:class:`Minute15GfpReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports>`
                    
                    .. attribute:: minute15_gfp_thresholds
                    
                    	Configure threshold on gfp parameters
                    	**type**\:   :py:class:`Minute15GfpThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp, self).__init__()

                        self.yang_name = "minute15-gfp"
                        self.yang_parent_name = "minute15-gfp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"minute15-gfp-reports" : ("minute15_gfp_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports), "minute15-gfp-thresholds" : ("minute15_gfp_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds)}
                        self._child_list_classes = {}

                        self.minute15_gfp_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports()
                        self.minute15_gfp_reports.parent = self
                        self._children_name_map["minute15_gfp_reports"] = "minute15-gfp-reports"
                        self._children_yang_names.add("minute15-gfp-reports")

                        self.minute15_gfp_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds()
                        self.minute15_gfp_thresholds.parent = self
                        self._children_name_map["minute15_gfp_thresholds"] = "minute15-gfp-thresholds"
                        self._children_yang_names.add("minute15-gfp-thresholds")
                        self._segment_path = lambda: "minute15-gfp"


                    class Minute15GfpReports(Entity):
                        """
                        set gfp TCA reporting status
                        
                        .. attribute:: minute15_gfp_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15GfpReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports.Minute15GfpReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports, self).__init__()

                            self.yang_name = "minute15-gfp-reports"
                            self.yang_parent_name = "minute15-gfp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15-gfp-report" : ("minute15_gfp_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports.Minute15GfpReport)}

                            self.minute15_gfp_report = YList(self)
                            self._segment_path = lambda: "minute15-gfp-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports, [], name, value)


                        class Minute15GfpReport(Entity):
                            """
                            none
                            
                            .. attribute:: gfp_report  <key>
                            
                            	Gfp Report Type
                            	**type**\:   :py:class:`GfpReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.GfpReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports.Minute15GfpReport, self).__init__()

                                self.yang_name = "minute15-gfp-report"
                                self.yang_parent_name = "minute15-gfp-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.gfp_report = YLeaf(YType.enumeration, "gfp-report")
                                self._segment_path = lambda: "minute15-gfp-report" + "[gfp-report='" + self.gfp_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpReports.Minute15GfpReport, ['gfp_report'], name, value)


                    class Minute15GfpThresholds(Entity):
                        """
                        Configure threshold on gfp parameters
                        
                        .. attribute:: minute15_gfp_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15GfpThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds.Minute15GfpThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds, self).__init__()

                            self.yang_name = "minute15-gfp-thresholds"
                            self.yang_parent_name = "minute15-gfp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15-gfp-threshold" : ("minute15_gfp_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds.Minute15GfpThreshold)}

                            self.minute15_gfp_threshold = YList(self)
                            self._segment_path = lambda: "minute15-gfp-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds, [], name, value)


                        class Minute15GfpThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: gfp_threshold  <key>
                            
                            	Gfp Threshold Type
                            	**type**\:   :py:class:`GfpThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.GfpThreshold>`
                            
                            .. attribute:: gfp_threshold_value
                            
                            	Gfp Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds.Minute15GfpThreshold, self).__init__()

                                self.yang_name = "minute15-gfp-threshold"
                                self.yang_parent_name = "minute15-gfp-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.gfp_threshold = YLeaf(YType.enumeration, "gfp-threshold")

                                self.gfp_threshold_value = YLeaf(YType.int32, "gfp-threshold-value")
                                self._segment_path = lambda: "minute15-gfp-threshold" + "[gfp-threshold='" + self.gfp_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Gfp.Minute15Gfp.Minute15GfpThresholds.Minute15GfpThreshold, ['gfp_threshold', 'gfp_threshold_value'], name, value)


            class Minute15OtnTcms(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15otn_tcm
                
                	configure otn g709 tcm's performance monitoring
                	**type**\: list of    :py:class:`Minute15OtnTcm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms, self).__init__()

                    self.yang_name = "minute15otn-tcms"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"minute15otn-tcm" : ("minute15otn_tcm", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm)}

                    self.minute15otn_tcm = YList(self)
                    self._segment_path = lambda: "minute15otn-tcms"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms, [], name, value)


                class Minute15OtnTcm(Entity):
                    """
                    configure otn g709 tcm's performance
                    monitoring
                    
                    .. attribute:: tcm_number  <key>
                    
                    	TCM number
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: min15_otn_tcm_threshes
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Min15OtnTcmThreshes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes>`
                    
                    .. attribute:: minute15otn_tcm_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Minute15OtnTcmReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm, self).__init__()

                        self.yang_name = "minute15otn-tcm"
                        self.yang_parent_name = "minute15otn-tcms"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"min15-otn-tcm-threshes" : ("min15_otn_tcm_threshes", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes), "minute15otn-tcm-reports" : ("minute15otn_tcm_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports)}
                        self._child_list_classes = {}

                        self.tcm_number = YLeaf(YType.int32, "tcm-number")

                        self.min15_otn_tcm_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes()
                        self.min15_otn_tcm_threshes.parent = self
                        self._children_name_map["min15_otn_tcm_threshes"] = "min15-otn-tcm-threshes"
                        self._children_yang_names.add("min15-otn-tcm-threshes")

                        self.minute15otn_tcm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports()
                        self.minute15otn_tcm_reports.parent = self
                        self._children_name_map["minute15otn_tcm_reports"] = "minute15otn-tcm-reports"
                        self._children_yang_names.add("minute15otn-tcm-reports")
                        self._segment_path = lambda: "minute15otn-tcm" + "[tcm-number='" + self.tcm_number.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm, ['tcm_number'], name, value)


                    class Min15OtnTcmThreshes(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: min15_otn_tcm_thresh
                        
                        	none
                        	**type**\: list of    :py:class:`Min15OtnTcmThresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes.Min15OtnTcmThresh>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes, self).__init__()

                            self.yang_name = "min15-otn-tcm-threshes"
                            self.yang_parent_name = "minute15otn-tcm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"min15-otn-tcm-thresh" : ("min15_otn_tcm_thresh", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes.Min15OtnTcmThresh)}

                            self.min15_otn_tcm_thresh = YList(self)
                            self._segment_path = lambda: "min15-otn-tcm-threshes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes, [], name, value)


                        class Min15OtnTcmThresh(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnTcmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnTcmThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes.Min15OtnTcmThresh, self).__init__()

                                self.yang_name = "min15-otn-tcm-thresh"
                                self.yang_parent_name = "min15-otn-tcm-threshes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")
                                self._segment_path = lambda: "min15-otn-tcm-thresh" + "[otn-threshold='" + self.otn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Min15OtnTcmThreshes.Min15OtnTcmThresh, ['otn_threshold', 'otn_threshold_value'], name, value)


                    class Minute15OtnTcmReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: minute15otn_tcm_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OtnTcmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports.Minute15OtnTcmReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports, self).__init__()

                            self.yang_name = "minute15otn-tcm-reports"
                            self.yang_parent_name = "minute15otn-tcm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15otn-tcm-report" : ("minute15otn_tcm_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports.Minute15OtnTcmReport)}

                            self.minute15otn_tcm_report = YList(self)
                            self._segment_path = lambda: "minute15otn-tcm-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports, [], name, value)


                        class Minute15OtnTcmReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnTcmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnTcmReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports.Minute15OtnTcmReport, self).__init__()

                                self.yang_name = "minute15otn-tcm-report"
                                self.yang_parent_name = "minute15otn-tcm-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "minute15otn-tcm-report" + "[otn-report='" + self.otn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15OtnTcms.Minute15OtnTcm.Minute15OtnTcmReports.Minute15OtnTcmReport, ['otn_report', 'enable'], name, value)


            class Minute15Path(Entity):
                """
                set opr min threshold
                
                .. attribute:: minute15otn_path
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Minute15OtnPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path, self).__init__()

                    self.yang_name = "minute15-path"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"minute15otn-path" : ("minute15otn_path", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath)}
                    self._child_list_classes = {}

                    self.minute15otn_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath()
                    self.minute15otn_path.parent = self
                    self._children_name_map["minute15otn_path"] = "minute15otn-path"
                    self._children_yang_names.add("minute15otn-path")
                    self._segment_path = lambda: "minute15-path"


                class Minute15OtnPath(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: min15_otn_path_threshes
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Min15OtnPathThreshes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes>`
                    
                    .. attribute:: minute15otn_path_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Minute15OtnPathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath, self).__init__()

                        self.yang_name = "minute15otn-path"
                        self.yang_parent_name = "minute15-path"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"min15-otn-path-threshes" : ("min15_otn_path_threshes", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes), "minute15otn-path-reports" : ("minute15otn_path_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports)}
                        self._child_list_classes = {}

                        self.min15_otn_path_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes()
                        self.min15_otn_path_threshes.parent = self
                        self._children_name_map["min15_otn_path_threshes"] = "min15-otn-path-threshes"
                        self._children_yang_names.add("min15-otn-path-threshes")

                        self.minute15otn_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports()
                        self.minute15otn_path_reports.parent = self
                        self._children_name_map["minute15otn_path_reports"] = "minute15otn-path-reports"
                        self._children_yang_names.add("minute15otn-path-reports")
                        self._segment_path = lambda: "minute15otn-path"


                    class Min15OtnPathThreshes(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: min15_otn_path_thresh
                        
                        	none
                        	**type**\: list of    :py:class:`Min15OtnPathThresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes.Min15OtnPathThresh>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes, self).__init__()

                            self.yang_name = "min15-otn-path-threshes"
                            self.yang_parent_name = "minute15otn-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"min15-otn-path-thresh" : ("min15_otn_path_thresh", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes.Min15OtnPathThresh)}

                            self.min15_otn_path_thresh = YList(self)
                            self._segment_path = lambda: "min15-otn-path-threshes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes, [], name, value)


                        class Min15OtnPathThresh(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes.Min15OtnPathThresh, self).__init__()

                                self.yang_name = "min15-otn-path-thresh"
                                self.yang_parent_name = "min15-otn-path-threshes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")
                                self._segment_path = lambda: "min15-otn-path-thresh" + "[otn-threshold='" + self.otn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Min15OtnPathThreshes.Min15OtnPathThresh, ['otn_threshold', 'otn_threshold_value'], name, value)


                    class Minute15OtnPathReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: minute15otn_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`Minute15OtnPathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports.Minute15OtnPathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports, self).__init__()

                            self.yang_name = "minute15otn-path-reports"
                            self.yang_parent_name = "minute15otn-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"minute15otn-path-report" : ("minute15otn_path_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports.Minute15OtnPathReport)}

                            self.minute15otn_path_report = YList(self)
                            self._segment_path = lambda: "minute15otn-path-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports, [], name, value)


                        class Minute15OtnPathReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports.Minute15OtnPathReport, self).__init__()

                                self.yang_name = "minute15otn-path-report"
                                self.yang_parent_name = "minute15otn-path-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "minute15otn-path-report" + "[otn-report='" + self.otn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Minute15Path.Minute15OtnPath.Minute15OtnPathReports.Minute15OtnPathReport, ['otn_report', 'enable'], name, value)


            class OcHour24(Entity):
                """
                set Oc threshold
                
                .. attribute:: oc_hour24_ocn
                
                	Configure ocn performance monitoring
                	**type**\:   :py:class:`OcHour24Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24, self).__init__()

                    self.yang_name = "oc-hour24"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"oc-hour24-ocn" : ("oc_hour24_ocn", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn)}
                    self._child_list_classes = {}

                    self.oc_hour24_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn()
                    self.oc_hour24_ocn.parent = self
                    self._children_name_map["oc_hour24_ocn"] = "oc-hour24-ocn"
                    self._children_yang_names.add("oc-hour24-ocn")
                    self._segment_path = lambda: "oc-hour24"


                class OcHour24Ocn(Entity):
                    """
                    Configure ocn performance monitoring
                    
                    .. attribute:: oc_hour24_ocn_reports
                    
                    	set ocn TCA reporting status
                    	**type**\:   :py:class:`OcHour24OcnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports>`
                    
                    .. attribute:: oc_hour24_ocn_thresholds
                    
                    	Configure threshold on ocn parameters
                    	**type**\:   :py:class:`OcHour24OcnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn, self).__init__()

                        self.yang_name = "oc-hour24-ocn"
                        self.yang_parent_name = "oc-hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"oc-hour24-ocn-reports" : ("oc_hour24_ocn_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports), "oc-hour24-ocn-thresholds" : ("oc_hour24_ocn_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds)}
                        self._child_list_classes = {}

                        self.oc_hour24_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports()
                        self.oc_hour24_ocn_reports.parent = self
                        self._children_name_map["oc_hour24_ocn_reports"] = "oc-hour24-ocn-reports"
                        self._children_yang_names.add("oc-hour24-ocn-reports")

                        self.oc_hour24_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds()
                        self.oc_hour24_ocn_thresholds.parent = self
                        self._children_name_map["oc_hour24_ocn_thresholds"] = "oc-hour24-ocn-thresholds"
                        self._children_yang_names.add("oc-hour24-ocn-thresholds")
                        self._segment_path = lambda: "oc-hour24-ocn"


                    class OcHour24OcnReports(Entity):
                        """
                        set ocn TCA reporting status
                        
                        .. attribute:: oc_hour24_ocn_report
                        
                        	none
                        	**type**\: list of    :py:class:`OcHour24OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports.OcHour24OcnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports, self).__init__()

                            self.yang_name = "oc-hour24-ocn-reports"
                            self.yang_parent_name = "oc-hour24-ocn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"oc-hour24-ocn-report" : ("oc_hour24_ocn_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports.OcHour24OcnReport)}

                            self.oc_hour24_ocn_report = YList(self)
                            self._segment_path = lambda: "oc-hour24-ocn-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports, [], name, value)


                        class OcHour24OcnReport(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_report  <key>
                            
                            	Ocn Report Type
                            	**type**\:   :py:class:`OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnReport>`
                            
                            .. attribute:: enable
                            
                            	Ocn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports.OcHour24OcnReport, self).__init__()

                                self.yang_name = "oc-hour24-ocn-report"
                                self.yang_parent_name = "oc-hour24-ocn-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ocn_report = YLeaf(YType.enumeration, "ocn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "oc-hour24-ocn-report" + "[ocn-report='" + self.ocn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnReports.OcHour24OcnReport, ['ocn_report', 'enable'], name, value)


                    class OcHour24OcnThresholds(Entity):
                        """
                        Configure threshold on ocn parameters
                        
                        .. attribute:: oc_hour24_ocn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`OcHour24OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds.OcHour24OcnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds, self).__init__()

                            self.yang_name = "oc-hour24-ocn-thresholds"
                            self.yang_parent_name = "oc-hour24-ocn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"oc-hour24-ocn-threshold" : ("oc_hour24_ocn_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds.OcHour24OcnThreshold)}

                            self.oc_hour24_ocn_threshold = YList(self)
                            self._segment_path = lambda: "oc-hour24-ocn-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds, [], name, value)


                        class OcHour24OcnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_threshold  <key>
                            
                            	Ocn Threshold Type
                            	**type**\:   :py:class:`OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnThreshold>`
                            
                            .. attribute:: ocn_threshold_value
                            
                            	Ocn Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds.OcHour24OcnThreshold, self).__init__()

                                self.yang_name = "oc-hour24-ocn-threshold"
                                self.yang_parent_name = "oc-hour24-ocn-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ocn_threshold = YLeaf(YType.enumeration, "ocn-threshold")

                                self.ocn_threshold_value = YLeaf(YType.int32, "ocn-threshold-value")
                                self._segment_path = lambda: "oc-hour24-ocn-threshold" + "[ocn-threshold='" + self.ocn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcHour24.OcHour24Ocn.OcHour24OcnThresholds.OcHour24OcnThreshold, ['ocn_threshold', 'ocn_threshold_value'], name, value)


            class OcMinute15(Entity):
                """
                set OC threshold
                
                .. attribute:: oc_minute15_ocn
                
                	Configure ocn performance monitoring
                	**type**\:   :py:class:`OcMinute15Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15, self).__init__()

                    self.yang_name = "oc-minute15"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"oc-minute15-ocn" : ("oc_minute15_ocn", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn)}
                    self._child_list_classes = {}

                    self.oc_minute15_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn()
                    self.oc_minute15_ocn.parent = self
                    self._children_name_map["oc_minute15_ocn"] = "oc-minute15-ocn"
                    self._children_yang_names.add("oc-minute15-ocn")
                    self._segment_path = lambda: "oc-minute15"


                class OcMinute15Ocn(Entity):
                    """
                    Configure ocn performance monitoring
                    
                    .. attribute:: oc_minute15_ocn_reports
                    
                    	set ocn TCA reporting status
                    	**type**\:   :py:class:`OcMinute15OcnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports>`
                    
                    .. attribute:: oc_minute15_ocn_thresholds
                    
                    	Configure threshold on ocn parameters
                    	**type**\:   :py:class:`OcMinute15OcnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn, self).__init__()

                        self.yang_name = "oc-minute15-ocn"
                        self.yang_parent_name = "oc-minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"oc-minute15-ocn-reports" : ("oc_minute15_ocn_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports), "oc-minute15-ocn-thresholds" : ("oc_minute15_ocn_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds)}
                        self._child_list_classes = {}

                        self.oc_minute15_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports()
                        self.oc_minute15_ocn_reports.parent = self
                        self._children_name_map["oc_minute15_ocn_reports"] = "oc-minute15-ocn-reports"
                        self._children_yang_names.add("oc-minute15-ocn-reports")

                        self.oc_minute15_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds()
                        self.oc_minute15_ocn_thresholds.parent = self
                        self._children_name_map["oc_minute15_ocn_thresholds"] = "oc-minute15-ocn-thresholds"
                        self._children_yang_names.add("oc-minute15-ocn-thresholds")
                        self._segment_path = lambda: "oc-minute15-ocn"


                    class OcMinute15OcnReports(Entity):
                        """
                        set ocn TCA reporting status
                        
                        .. attribute:: oc_minute15_ocn_report
                        
                        	none
                        	**type**\: list of    :py:class:`OcMinute15OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports.OcMinute15OcnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports, self).__init__()

                            self.yang_name = "oc-minute15-ocn-reports"
                            self.yang_parent_name = "oc-minute15-ocn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"oc-minute15-ocn-report" : ("oc_minute15_ocn_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports.OcMinute15OcnReport)}

                            self.oc_minute15_ocn_report = YList(self)
                            self._segment_path = lambda: "oc-minute15-ocn-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports, [], name, value)


                        class OcMinute15OcnReport(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_report  <key>
                            
                            	Ocn Report Type
                            	**type**\:   :py:class:`OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnReport>`
                            
                            .. attribute:: enable
                            
                            	Ocn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports.OcMinute15OcnReport, self).__init__()

                                self.yang_name = "oc-minute15-ocn-report"
                                self.yang_parent_name = "oc-minute15-ocn-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ocn_report = YLeaf(YType.enumeration, "ocn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "oc-minute15-ocn-report" + "[ocn-report='" + self.ocn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnReports.OcMinute15OcnReport, ['ocn_report', 'enable'], name, value)


                    class OcMinute15OcnThresholds(Entity):
                        """
                        Configure threshold on ocn parameters
                        
                        .. attribute:: oc_minute15_ocn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`OcMinute15OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds.OcMinute15OcnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds, self).__init__()

                            self.yang_name = "oc-minute15-ocn-thresholds"
                            self.yang_parent_name = "oc-minute15-ocn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"oc-minute15-ocn-threshold" : ("oc_minute15_ocn_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds.OcMinute15OcnThreshold)}

                            self.oc_minute15_ocn_threshold = YList(self)
                            self._segment_path = lambda: "oc-minute15-ocn-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds, [], name, value)


                        class OcMinute15OcnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_threshold  <key>
                            
                            	Ocn Threshold Type
                            	**type**\:   :py:class:`OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnThreshold>`
                            
                            .. attribute:: ocn_threshold_value
                            
                            	Ocn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds.OcMinute15OcnThreshold, self).__init__()

                                self.yang_name = "oc-minute15-ocn-threshold"
                                self.yang_parent_name = "oc-minute15-ocn-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ocn_threshold = YLeaf(YType.enumeration, "ocn-threshold")

                                self.ocn_threshold_value = YLeaf(YType.int32, "ocn-threshold-value")
                                self._segment_path = lambda: "oc-minute15-ocn-threshold" + "[ocn-threshold='" + self.ocn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.OcMinute15.OcMinute15Ocn.OcMinute15OcnThresholds.OcMinute15OcnThreshold, ['ocn_threshold', 'ocn_threshold_value'], name, value)


            class Second30(Entity):
                """
                Configure optics performance monitoring for 30
                sec
                
                .. attribute:: second30_optics
                
                	Configure optics performance monitoring
                	**type**\:   :py:class:`Second30Optics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics>`
                
                .. attribute:: second30fec
                
                	Configure fec g709 performance monitoring
                	**type**\:   :py:class:`Second30Fec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec>`
                
                .. attribute:: second30otn
                
                	configure otn g709 performance monitoring
                	**type**\:   :py:class:`Second30Otn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn>`
                
                .. attribute:: second30secyif
                
                	Configure secy\-if performance monitoring
                	**type**\:   :py:class:`Second30Secyif <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif>`
                
                .. attribute:: second30secyrx
                
                	Configure secy\-rx performance monitoring
                	**type**\:   :py:class:`Second30Secyrx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx>`
                
                .. attribute:: second30secytx
                
                	Configure secy\-tx performance monitoring
                	**type**\:   :py:class:`Second30Secytx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30, self).__init__()

                    self.yang_name = "second30"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"second30-optics" : ("second30_optics", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics), "second30fec" : ("second30fec", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec), "second30otn" : ("second30otn", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn), "second30secyif" : ("second30secyif", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif), "second30secyrx" : ("second30secyrx", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx), "second30secytx" : ("second30secytx", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx)}
                    self._child_list_classes = {}

                    self.second30_optics = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics()
                    self.second30_optics.parent = self
                    self._children_name_map["second30_optics"] = "second30-optics"
                    self._children_yang_names.add("second30-optics")

                    self.second30fec = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec()
                    self.second30fec.parent = self
                    self._children_name_map["second30fec"] = "second30fec"
                    self._children_yang_names.add("second30fec")

                    self.second30otn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn()
                    self.second30otn.parent = self
                    self._children_name_map["second30otn"] = "second30otn"
                    self._children_yang_names.add("second30otn")

                    self.second30secyif = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif()
                    self.second30secyif.parent = self
                    self._children_name_map["second30secyif"] = "second30secyif"
                    self._children_yang_names.add("second30secyif")

                    self.second30secyrx = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx()
                    self.second30secyrx.parent = self
                    self._children_name_map["second30secyrx"] = "second30secyrx"
                    self._children_yang_names.add("second30secyrx")

                    self.second30secytx = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx()
                    self.second30secytx.parent = self
                    self._children_name_map["second30secytx"] = "second30secytx"
                    self._children_yang_names.add("second30secytx")
                    self._segment_path = lambda: "second30"


                class Second30Fec(Entity):
                    """
                    Configure fec g709 performance monitoring
                    
                    .. attribute:: second30fec_reports
                    
                    	set fec TCA reporting status
                    	**type**\:   :py:class:`Second30FecReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports>`
                    
                    .. attribute:: second30fec_thresholds
                    
                    	Configure fec threshold
                    	**type**\:   :py:class:`Second30FecThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec, self).__init__()

                        self.yang_name = "second30fec"
                        self.yang_parent_name = "second30"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"second30fec-reports" : ("second30fec_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports), "second30fec-thresholds" : ("second30fec_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds)}
                        self._child_list_classes = {}

                        self.second30fec_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports()
                        self.second30fec_reports.parent = self
                        self._children_name_map["second30fec_reports"] = "second30fec-reports"
                        self._children_yang_names.add("second30fec-reports")

                        self.second30fec_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds()
                        self.second30fec_thresholds.parent = self
                        self._children_name_map["second30fec_thresholds"] = "second30fec-thresholds"
                        self._children_yang_names.add("second30fec-thresholds")
                        self._segment_path = lambda: "second30fec"


                    class Second30FecReports(Entity):
                        """
                        set fec TCA reporting status
                        
                        .. attribute:: second30fec_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports.Second30FecReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports, self).__init__()

                            self.yang_name = "second30fec-reports"
                            self.yang_parent_name = "second30fec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30fec-report" : ("second30fec_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports.Second30FecReport)}

                            self.second30fec_report = YList(self)
                            self._segment_path = lambda: "second30fec-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports, [], name, value)


                        class Second30FecReport(Entity):
                            """
                            none
                            
                            .. attribute:: fec_report  <key>
                            
                            	Fec Report Type
                            	**type**\:   :py:class:`FecReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecReport>`
                            
                            .. attribute:: enable
                            
                            	Fec Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports.Second30FecReport, self).__init__()

                                self.yang_name = "second30fec-report"
                                self.yang_parent_name = "second30fec-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.fec_report = YLeaf(YType.enumeration, "fec-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "second30fec-report" + "[fec-report='" + self.fec_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecReports.Second30FecReport, ['fec_report', 'enable'], name, value)


                    class Second30FecThresholds(Entity):
                        """
                        Configure fec threshold
                        
                        .. attribute:: second30fec_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Second30FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds.Second30FecThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds, self).__init__()

                            self.yang_name = "second30fec-thresholds"
                            self.yang_parent_name = "second30fec"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30fec-threshold" : ("second30fec_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds.Second30FecThreshold)}

                            self.second30fec_threshold = YList(self)
                            self._segment_path = lambda: "second30fec-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds, [], name, value)


                        class Second30FecThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: fec_threshold  <key>
                            
                            	Fec Threshold Type
                            	**type**\:   :py:class:`FecThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.FecThreshold>`
                            
                            .. attribute:: fec_threshold_value
                            
                            	Fec Threshold Value
                            	**type**\:  str
                            
                            	**length:** 1..16
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds.Second30FecThreshold, self).__init__()

                                self.yang_name = "second30fec-threshold"
                                self.yang_parent_name = "second30fec-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.fec_threshold = YLeaf(YType.enumeration, "fec-threshold")

                                self.fec_threshold_value = YLeaf(YType.str, "fec-threshold-value")
                                self._segment_path = lambda: "second30fec-threshold" + "[fec-threshold='" + self.fec_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Fec.Second30FecThresholds.Second30FecThreshold, ['fec_threshold', 'fec_threshold_value'], name, value)


                class Second30Optics(Entity):
                    """
                    Configure optics performance monitoring
                    
                    .. attribute:: second30_optics_reports
                    
                    	set optics TCA reporting status
                    	**type**\:   :py:class:`Second30OpticsReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports>`
                    
                    .. attribute:: second30_optics_thresholds
                    
                    	Configure threshold on optics parameters
                    	**type**\:   :py:class:`Second30OpticsThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics, self).__init__()

                        self.yang_name = "second30-optics"
                        self.yang_parent_name = "second30"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"second30-optics-reports" : ("second30_optics_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports), "second30-optics-thresholds" : ("second30_optics_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds)}
                        self._child_list_classes = {}

                        self.second30_optics_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports()
                        self.second30_optics_reports.parent = self
                        self._children_name_map["second30_optics_reports"] = "second30-optics-reports"
                        self._children_yang_names.add("second30-optics-reports")

                        self.second30_optics_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds()
                        self.second30_optics_thresholds.parent = self
                        self._children_name_map["second30_optics_thresholds"] = "second30-optics-thresholds"
                        self._children_yang_names.add("second30-optics-thresholds")
                        self._segment_path = lambda: "second30-optics"


                    class Second30OpticsReports(Entity):
                        """
                        set optics TCA reporting status
                        
                        .. attribute:: second30_optics_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports.Second30OpticsReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports, self).__init__()

                            self.yang_name = "second30-optics-reports"
                            self.yang_parent_name = "second30-optics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30-optics-report" : ("second30_optics_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports.Second30OpticsReport)}

                            self.second30_optics_report = YList(self)
                            self._segment_path = lambda: "second30-optics-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports, [], name, value)


                        class Second30OpticsReport(Entity):
                            """
                            none
                            
                            .. attribute:: optics_report  <key>
                            
                            	Optics Report Type
                            	**type**\:   :py:class:`OpticsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports.Second30OpticsReport, self).__init__()

                                self.yang_name = "second30-optics-report"
                                self.yang_parent_name = "second30-optics-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.optics_report = YLeaf(YType.enumeration, "optics-report")
                                self._segment_path = lambda: "second30-optics-report" + "[optics-report='" + self.optics_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsReports.Second30OpticsReport, ['optics_report'], name, value)


                    class Second30OpticsThresholds(Entity):
                        """
                        Configure threshold on optics parameters
                        
                        .. attribute:: second30_optics_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Second30OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds.Second30OpticsThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds, self).__init__()

                            self.yang_name = "second30-optics-thresholds"
                            self.yang_parent_name = "second30-optics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30-optics-threshold" : ("second30_optics_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds.Second30OpticsThreshold)}

                            self.second30_optics_threshold = YList(self)
                            self._segment_path = lambda: "second30-optics-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds, [], name, value)


                        class Second30OpticsThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: optics_threshold  <key>
                            
                            	Optics Threshold Type
                            	**type**\:   :py:class:`OpticsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OpticsThreshold>`
                            
                            .. attribute:: dbm
                            
                            	Used only for Opt and Opr,To Enter Threshold in dbm use 1
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: optics_threshold_value
                            
                            	Optics Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds.Second30OpticsThreshold, self).__init__()

                                self.yang_name = "second30-optics-threshold"
                                self.yang_parent_name = "second30-optics-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.optics_threshold = YLeaf(YType.enumeration, "optics-threshold")

                                self.dbm = YLeaf(YType.int32, "dbm")

                                self.optics_threshold_value = YLeaf(YType.int32, "optics-threshold-value")
                                self._segment_path = lambda: "second30-optics-threshold" + "[optics-threshold='" + self.optics_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Optics.Second30OpticsThresholds.Second30OpticsThreshold, ['optics_threshold', 'dbm', 'optics_threshold_value'], name, value)


                class Second30Otn(Entity):
                    """
                    configure otn g709 performance monitoring
                    
                    .. attribute:: second30_otn_threshes
                    
                    	Configure threshold on otn parameters
                    	**type**\:   :py:class:`Second30OtnThreshes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes>`
                    
                    .. attribute:: second30otn_reports
                    
                    	set otn TCA reporting status
                    	**type**\:   :py:class:`Second30OtnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn, self).__init__()

                        self.yang_name = "second30otn"
                        self.yang_parent_name = "second30"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"second30-otn-threshes" : ("second30_otn_threshes", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes), "second30otn-reports" : ("second30otn_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports)}
                        self._child_list_classes = {}

                        self.second30_otn_threshes = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes()
                        self.second30_otn_threshes.parent = self
                        self._children_name_map["second30_otn_threshes"] = "second30-otn-threshes"
                        self._children_yang_names.add("second30-otn-threshes")

                        self.second30otn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports()
                        self.second30otn_reports.parent = self
                        self._children_name_map["second30otn_reports"] = "second30otn-reports"
                        self._children_yang_names.add("second30otn-reports")
                        self._segment_path = lambda: "second30otn"


                    class Second30OtnReports(Entity):
                        """
                        set otn TCA reporting status
                        
                        .. attribute:: second30otn_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports.Second30OtnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports, self).__init__()

                            self.yang_name = "second30otn-reports"
                            self.yang_parent_name = "second30otn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30otn-report" : ("second30otn_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports.Second30OtnReport)}

                            self.second30otn_report = YList(self)
                            self._segment_path = lambda: "second30otn-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports, [], name, value)


                        class Second30OtnReport(Entity):
                            """
                            none
                            
                            .. attribute:: otn_report  <key>
                            
                            	Otn Report Type
                            	**type**\:   :py:class:`OtnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnReport>`
                            
                            .. attribute:: enable
                            
                            	Otn Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports.Second30OtnReport, self).__init__()

                                self.yang_name = "second30otn-report"
                                self.yang_parent_name = "second30otn-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_report = YLeaf(YType.enumeration, "otn-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "second30otn-report" + "[otn-report='" + self.otn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnReports.Second30OtnReport, ['otn_report', 'enable'], name, value)


                    class Second30OtnThreshes(Entity):
                        """
                        Configure threshold on otn parameters
                        
                        .. attribute:: second30_otn_thresh
                        
                        	none
                        	**type**\: list of    :py:class:`Second30OtnThresh <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes.Second30OtnThresh>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes, self).__init__()

                            self.yang_name = "second30-otn-threshes"
                            self.yang_parent_name = "second30otn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30-otn-thresh" : ("second30_otn_thresh", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes.Second30OtnThresh)}

                            self.second30_otn_thresh = YList(self)
                            self._segment_path = lambda: "second30-otn-threshes"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes, [], name, value)


                        class Second30OtnThresh(Entity):
                            """
                            none
                            
                            .. attribute:: otn_threshold  <key>
                            
                            	Otn Threshold Type
                            	**type**\:   :py:class:`OtnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OtnThreshold>`
                            
                            .. attribute:: otn_threshold_value
                            
                            	Otn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes.Second30OtnThresh, self).__init__()

                                self.yang_name = "second30-otn-thresh"
                                self.yang_parent_name = "second30-otn-threshes"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.otn_threshold = YLeaf(YType.enumeration, "otn-threshold")

                                self.otn_threshold_value = YLeaf(YType.int32, "otn-threshold-value")
                                self._segment_path = lambda: "second30-otn-thresh" + "[otn-threshold='" + self.otn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Otn.Second30OtnThreshes.Second30OtnThresh, ['otn_threshold', 'otn_threshold_value'], name, value)


                class Second30Secyif(Entity):
                    """
                    Configure secy\-if performance monitoring
                    
                    .. attribute:: second30secyif_reports
                    
                    	set secyif TCA reporting status
                    	**type**\:   :py:class:`Second30SecyifReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifReports>`
                    
                    .. attribute:: second30secyif_thresholds
                    
                    	Configure threshold on secyif parameters
                    	**type**\:   :py:class:`Second30SecyifThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif, self).__init__()

                        self.yang_name = "second30secyif"
                        self.yang_parent_name = "second30"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"second30secyif-reports" : ("second30secyif_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifReports), "second30secyif-thresholds" : ("second30secyif_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifThresholds)}
                        self._child_list_classes = {}

                        self.second30secyif_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifReports()
                        self.second30secyif_reports.parent = self
                        self._children_name_map["second30secyif_reports"] = "second30secyif-reports"
                        self._children_yang_names.add("second30secyif-reports")

                        self.second30secyif_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifThresholds()
                        self.second30secyif_thresholds.parent = self
                        self._children_name_map["second30secyif_thresholds"] = "second30secyif-thresholds"
                        self._children_yang_names.add("second30secyif-thresholds")
                        self._segment_path = lambda: "second30secyif"


                    class Second30SecyifReports(Entity):
                        """
                        set secyif TCA reporting status
                        
                        .. attribute:: second30secyif_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30SecyifReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifReports.Second30SecyifReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifReports, self).__init__()

                            self.yang_name = "second30secyif-reports"
                            self.yang_parent_name = "second30secyif"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30secyif-report" : ("second30secyif_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifReports.Second30SecyifReport)}

                            self.second30secyif_report = YList(self)
                            self._segment_path = lambda: "second30secyif-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifReports, [], name, value)


                        class Second30SecyifReport(Entity):
                            """
                            none
                            
                            .. attribute:: secyif_report  <key>
                            
                            	Secyif Report Type
                            	**type**\:   :py:class:`SecyifReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyifReport>`
                            
                            .. attribute:: enable
                            
                            	Enabled Secyif Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifReports.Second30SecyifReport, self).__init__()

                                self.yang_name = "second30secyif-report"
                                self.yang_parent_name = "second30secyif-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyif_report = YLeaf(YType.enumeration, "secyif-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "second30secyif-report" + "[secyif-report='" + self.secyif_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifReports.Second30SecyifReport, ['secyif_report', 'enable'], name, value)


                    class Second30SecyifThresholds(Entity):
                        """
                        Configure threshold on secyif parameters
                        
                        .. attribute:: second30secyif_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Second30SecyifThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifThresholds.Second30SecyifThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifThresholds, self).__init__()

                            self.yang_name = "second30secyif-thresholds"
                            self.yang_parent_name = "second30secyif"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30secyif-threshold" : ("second30secyif_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifThresholds.Second30SecyifThreshold)}

                            self.second30secyif_threshold = YList(self)
                            self._segment_path = lambda: "second30secyif-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifThresholds, [], name, value)


                        class Second30SecyifThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: secyif_threshold  <key>
                            
                            	Secyif Threshold Type
                            	**type**\:   :py:class:`SecyifThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyifThreshold>`
                            
                            .. attribute:: secyif_threshold_value
                            
                            	Secyif Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifThresholds.Second30SecyifThreshold, self).__init__()

                                self.yang_name = "second30secyif-threshold"
                                self.yang_parent_name = "second30secyif-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyif_threshold = YLeaf(YType.enumeration, "secyif-threshold")

                                self.secyif_threshold_value = YLeaf(YType.int32, "secyif-threshold-value")
                                self._segment_path = lambda: "second30secyif-threshold" + "[secyif-threshold='" + self.secyif_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyif.Second30SecyifThresholds.Second30SecyifThreshold, ['secyif_threshold', 'secyif_threshold_value'], name, value)


                class Second30Secyrx(Entity):
                    """
                    Configure secy\-rx performance monitoring
                    
                    .. attribute:: second30secyrx_reports
                    
                    	set secyrx TCA reporting status
                    	**type**\:   :py:class:`Second30SecyrxReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxReports>`
                    
                    .. attribute:: second30secyrx_thresholds
                    
                    	Configure threshold on secyrx parameters
                    	**type**\:   :py:class:`Second30SecyrxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx, self).__init__()

                        self.yang_name = "second30secyrx"
                        self.yang_parent_name = "second30"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"second30secyrx-reports" : ("second30secyrx_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxReports), "second30secyrx-thresholds" : ("second30secyrx_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxThresholds)}
                        self._child_list_classes = {}

                        self.second30secyrx_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxReports()
                        self.second30secyrx_reports.parent = self
                        self._children_name_map["second30secyrx_reports"] = "second30secyrx-reports"
                        self._children_yang_names.add("second30secyrx-reports")

                        self.second30secyrx_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxThresholds()
                        self.second30secyrx_thresholds.parent = self
                        self._children_name_map["second30secyrx_thresholds"] = "second30secyrx-thresholds"
                        self._children_yang_names.add("second30secyrx-thresholds")
                        self._segment_path = lambda: "second30secyrx"


                    class Second30SecyrxReports(Entity):
                        """
                        set secyrx TCA reporting status
                        
                        .. attribute:: second30secyrx_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30SecyrxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxReports.Second30SecyrxReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxReports, self).__init__()

                            self.yang_name = "second30secyrx-reports"
                            self.yang_parent_name = "second30secyrx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30secyrx-report" : ("second30secyrx_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxReports.Second30SecyrxReport)}

                            self.second30secyrx_report = YList(self)
                            self._segment_path = lambda: "second30secyrx-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxReports, [], name, value)


                        class Second30SecyrxReport(Entity):
                            """
                            none
                            
                            .. attribute:: secyrx_report  <key>
                            
                            	Secyrx Report Type
                            	**type**\:   :py:class:`SecyrxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyrxReport>`
                            
                            .. attribute:: enable
                            
                            	Enabled Secyrx Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxReports.Second30SecyrxReport, self).__init__()

                                self.yang_name = "second30secyrx-report"
                                self.yang_parent_name = "second30secyrx-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyrx_report = YLeaf(YType.enumeration, "secyrx-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "second30secyrx-report" + "[secyrx-report='" + self.secyrx_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxReports.Second30SecyrxReport, ['secyrx_report', 'enable'], name, value)


                    class Second30SecyrxThresholds(Entity):
                        """
                        Configure threshold on secyrx parameters
                        
                        .. attribute:: second30secyrx_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Second30SecyrxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxThresholds.Second30SecyrxThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxThresholds, self).__init__()

                            self.yang_name = "second30secyrx-thresholds"
                            self.yang_parent_name = "second30secyrx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30secyrx-threshold" : ("second30secyrx_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxThresholds.Second30SecyrxThreshold)}

                            self.second30secyrx_threshold = YList(self)
                            self._segment_path = lambda: "second30secyrx-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxThresholds, [], name, value)


                        class Second30SecyrxThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: secyrx_threshold  <key>
                            
                            	Secyrx Threshold Type
                            	**type**\:   :py:class:`SecyrxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecyrxThreshold>`
                            
                            .. attribute:: secyrx_threshold_value
                            
                            	Secyrx Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxThresholds.Second30SecyrxThreshold, self).__init__()

                                self.yang_name = "second30secyrx-threshold"
                                self.yang_parent_name = "second30secyrx-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secyrx_threshold = YLeaf(YType.enumeration, "secyrx-threshold")

                                self.secyrx_threshold_value = YLeaf(YType.int32, "secyrx-threshold-value")
                                self._segment_path = lambda: "second30secyrx-threshold" + "[secyrx-threshold='" + self.secyrx_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secyrx.Second30SecyrxThresholds.Second30SecyrxThreshold, ['secyrx_threshold', 'secyrx_threshold_value'], name, value)


                class Second30Secytx(Entity):
                    """
                    Configure secy\-tx performance monitoring
                    
                    .. attribute:: second30secytx_reports
                    
                    	set secytx TCA reporting status
                    	**type**\:   :py:class:`Second30SecytxReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxReports>`
                    
                    .. attribute:: second30secytx_thresholds
                    
                    	Configure threshold on secytx parameters
                    	**type**\:   :py:class:`Second30SecytxThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx, self).__init__()

                        self.yang_name = "second30secytx"
                        self.yang_parent_name = "second30"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"second30secytx-reports" : ("second30secytx_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxReports), "second30secytx-thresholds" : ("second30secytx_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxThresholds)}
                        self._child_list_classes = {}

                        self.second30secytx_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxReports()
                        self.second30secytx_reports.parent = self
                        self._children_name_map["second30secytx_reports"] = "second30secytx-reports"
                        self._children_yang_names.add("second30secytx-reports")

                        self.second30secytx_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxThresholds()
                        self.second30secytx_thresholds.parent = self
                        self._children_name_map["second30secytx_thresholds"] = "second30secytx-thresholds"
                        self._children_yang_names.add("second30secytx-thresholds")
                        self._segment_path = lambda: "second30secytx"


                    class Second30SecytxReports(Entity):
                        """
                        set secytx TCA reporting status
                        
                        .. attribute:: second30secytx_report
                        
                        	none
                        	**type**\: list of    :py:class:`Second30SecytxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxReports.Second30SecytxReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxReports, self).__init__()

                            self.yang_name = "second30secytx-reports"
                            self.yang_parent_name = "second30secytx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30secytx-report" : ("second30secytx_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxReports.Second30SecytxReport)}

                            self.second30secytx_report = YList(self)
                            self._segment_path = lambda: "second30secytx-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxReports, [], name, value)


                        class Second30SecytxReport(Entity):
                            """
                            none
                            
                            .. attribute:: secytx_report  <key>
                            
                            	Secytx Report Type
                            	**type**\:   :py:class:`SecytxReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecytxReport>`
                            
                            .. attribute:: enable
                            
                            	Enabled Secytx Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxReports.Second30SecytxReport, self).__init__()

                                self.yang_name = "second30secytx-report"
                                self.yang_parent_name = "second30secytx-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secytx_report = YLeaf(YType.enumeration, "secytx-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "second30secytx-report" + "[secytx-report='" + self.secytx_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxReports.Second30SecytxReport, ['secytx_report', 'enable'], name, value)


                    class Second30SecytxThresholds(Entity):
                        """
                        Configure threshold on secytx parameters
                        
                        .. attribute:: second30secytx_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`Second30SecytxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxThresholds.Second30SecytxThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxThresholds, self).__init__()

                            self.yang_name = "second30secytx-thresholds"
                            self.yang_parent_name = "second30secytx"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"second30secytx-threshold" : ("second30secytx_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxThresholds.Second30SecytxThreshold)}

                            self.second30secytx_threshold = YList(self)
                            self._segment_path = lambda: "second30secytx-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxThresholds, [], name, value)


                        class Second30SecytxThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: secytx_threshold  <key>
                            
                            	Secytx Threshold Type
                            	**type**\:   :py:class:`SecytxThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.SecytxThreshold>`
                            
                            .. attribute:: secytx_threshold_value
                            
                            	Secytx Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxThresholds.Second30SecytxThreshold, self).__init__()

                                self.yang_name = "second30secytx-threshold"
                                self.yang_parent_name = "second30secytx-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.secytx_threshold = YLeaf(YType.enumeration, "secytx-threshold")

                                self.secytx_threshold_value = YLeaf(YType.int32, "secytx-threshold-value")
                                self._segment_path = lambda: "second30secytx-threshold" + "[secytx-threshold='" + self.secytx_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.Second30.Second30Secytx.Second30SecytxThresholds.Second30SecytxThreshold, ['secytx_threshold', 'secytx_threshold_value'], name, value)


            class SonetHour24(Entity):
                """
                set Sonet threshold
                
                .. attribute:: sonet_hour24_ocn
                
                	Configure ocn performance monitoring
                	**type**\:   :py:class:`SonetHour24Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn>`
                
                .. attribute:: sonet_hour24_path
                
                	Configure Path performance monitoring
                	**type**\:   :py:class:`SonetHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24, self).__init__()

                    self.yang_name = "sonet-hour24"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"sonet-hour24-ocn" : ("sonet_hour24_ocn", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn), "sonet-hour24-path" : ("sonet_hour24_path", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path)}
                    self._child_list_classes = {}

                    self.sonet_hour24_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn()
                    self.sonet_hour24_ocn.parent = self
                    self._children_name_map["sonet_hour24_ocn"] = "sonet-hour24-ocn"
                    self._children_yang_names.add("sonet-hour24-ocn")

                    self.sonet_hour24_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path()
                    self.sonet_hour24_path.parent = self
                    self._children_name_map["sonet_hour24_path"] = "sonet-hour24-path"
                    self._children_yang_names.add("sonet-hour24-path")
                    self._segment_path = lambda: "sonet-hour24"


                class SonetHour24Ocn(Entity):
                    """
                    Configure ocn performance monitoring
                    
                    .. attribute:: sonet_hour24_ocn_reports
                    
                    	set ocn TCA reporting status
                    	**type**\:   :py:class:`SonetHour24OcnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports>`
                    
                    .. attribute:: sonet_hour24_ocn_thresholds
                    
                    	Configure threshold on ocn parameters
                    	**type**\:   :py:class:`SonetHour24OcnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn, self).__init__()

                        self.yang_name = "sonet-hour24-ocn"
                        self.yang_parent_name = "sonet-hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"sonet-hour24-ocn-reports" : ("sonet_hour24_ocn_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports), "sonet-hour24-ocn-thresholds" : ("sonet_hour24_ocn_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds)}
                        self._child_list_classes = {}

                        self.sonet_hour24_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports()
                        self.sonet_hour24_ocn_reports.parent = self
                        self._children_name_map["sonet_hour24_ocn_reports"] = "sonet-hour24-ocn-reports"
                        self._children_yang_names.add("sonet-hour24-ocn-reports")

                        self.sonet_hour24_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds()
                        self.sonet_hour24_ocn_thresholds.parent = self
                        self._children_name_map["sonet_hour24_ocn_thresholds"] = "sonet-hour24-ocn-thresholds"
                        self._children_yang_names.add("sonet-hour24-ocn-thresholds")
                        self._segment_path = lambda: "sonet-hour24-ocn"


                    class SonetHour24OcnReports(Entity):
                        """
                        set ocn TCA reporting status
                        
                        .. attribute:: sonet_hour24_ocn_report
                        
                        	none
                        	**type**\: list of    :py:class:`SonetHour24OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports.SonetHour24OcnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports, self).__init__()

                            self.yang_name = "sonet-hour24-ocn-reports"
                            self.yang_parent_name = "sonet-hour24-ocn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sonet-hour24-ocn-report" : ("sonet_hour24_ocn_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports.SonetHour24OcnReport)}

                            self.sonet_hour24_ocn_report = YList(self)
                            self._segment_path = lambda: "sonet-hour24-ocn-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports, [], name, value)


                        class SonetHour24OcnReport(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_report  <key>
                            
                            	Ocn Report Type
                            	**type**\:   :py:class:`OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports.SonetHour24OcnReport, self).__init__()

                                self.yang_name = "sonet-hour24-ocn-report"
                                self.yang_parent_name = "sonet-hour24-ocn-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ocn_report = YLeaf(YType.enumeration, "ocn-report")
                                self._segment_path = lambda: "sonet-hour24-ocn-report" + "[ocn-report='" + self.ocn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnReports.SonetHour24OcnReport, ['ocn_report'], name, value)


                    class SonetHour24OcnThresholds(Entity):
                        """
                        Configure threshold on ocn parameters
                        
                        .. attribute:: sonet_hour24_ocn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`SonetHour24OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds.SonetHour24OcnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds, self).__init__()

                            self.yang_name = "sonet-hour24-ocn-thresholds"
                            self.yang_parent_name = "sonet-hour24-ocn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sonet-hour24-ocn-threshold" : ("sonet_hour24_ocn_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds.SonetHour24OcnThreshold)}

                            self.sonet_hour24_ocn_threshold = YList(self)
                            self._segment_path = lambda: "sonet-hour24-ocn-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds, [], name, value)


                        class SonetHour24OcnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_threshold  <key>
                            
                            	Ocn Threshold Type
                            	**type**\:   :py:class:`OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnThreshold>`
                            
                            .. attribute:: ocn_threshold_value
                            
                            	Ocn Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds.SonetHour24OcnThreshold, self).__init__()

                                self.yang_name = "sonet-hour24-ocn-threshold"
                                self.yang_parent_name = "sonet-hour24-ocn-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ocn_threshold = YLeaf(YType.enumeration, "ocn-threshold")

                                self.ocn_threshold_value = YLeaf(YType.int32, "ocn-threshold-value")
                                self._segment_path = lambda: "sonet-hour24-ocn-threshold" + "[ocn-threshold='" + self.ocn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Ocn.SonetHour24OcnThresholds.SonetHour24OcnThreshold, ['ocn_threshold', 'ocn_threshold_value'], name, value)


                class SonetHour24Path(Entity):
                    """
                    Configure Path performance monitoring
                    
                    .. attribute:: sonet_hour24_path_reports
                    
                    	set Path TCA reporting status
                    	**type**\:   :py:class:`SonetHour24PathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports>`
                    
                    .. attribute:: sonet_hour24_path_thresholds
                    
                    	Configure threshold on Path parameters
                    	**type**\:   :py:class:`SonetHour24PathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path, self).__init__()

                        self.yang_name = "sonet-hour24-path"
                        self.yang_parent_name = "sonet-hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"sonet-hour24-path-reports" : ("sonet_hour24_path_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports), "sonet-hour24-path-thresholds" : ("sonet_hour24_path_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds)}
                        self._child_list_classes = {}

                        self.sonet_hour24_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports()
                        self.sonet_hour24_path_reports.parent = self
                        self._children_name_map["sonet_hour24_path_reports"] = "sonet-hour24-path-reports"
                        self._children_yang_names.add("sonet-hour24-path-reports")

                        self.sonet_hour24_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds()
                        self.sonet_hour24_path_thresholds.parent = self
                        self._children_name_map["sonet_hour24_path_thresholds"] = "sonet-hour24-path-thresholds"
                        self._children_yang_names.add("sonet-hour24-path-thresholds")
                        self._segment_path = lambda: "sonet-hour24-path"


                    class SonetHour24PathReports(Entity):
                        """
                        set Path TCA reporting status
                        
                        .. attribute:: sonet_hour24_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`SonetHour24PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports.SonetHour24PathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports, self).__init__()

                            self.yang_name = "sonet-hour24-path-reports"
                            self.yang_parent_name = "sonet-hour24-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sonet-hour24-path-report" : ("sonet_hour24_path_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports.SonetHour24PathReport)}

                            self.sonet_hour24_path_report = YList(self)
                            self._segment_path = lambda: "sonet-hour24-path-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports, [], name, value)


                        class SonetHour24PathReport(Entity):
                            """
                            none
                            
                            .. attribute:: path_report  <key>
                            
                            	Path Report Type
                            	**type**\:   :py:class:`PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.PathReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports.SonetHour24PathReport, self).__init__()

                                self.yang_name = "sonet-hour24-path-report"
                                self.yang_parent_name = "sonet-hour24-path-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.path_report = YLeaf(YType.enumeration, "path-report")
                                self._segment_path = lambda: "sonet-hour24-path-report" + "[path-report='" + self.path_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathReports.SonetHour24PathReport, ['path_report'], name, value)


                    class SonetHour24PathThresholds(Entity):
                        """
                        Configure threshold on Path parameters
                        
                        .. attribute:: sonet_hour24_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`SonetHour24PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds.SonetHour24PathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds, self).__init__()

                            self.yang_name = "sonet-hour24-path-thresholds"
                            self.yang_parent_name = "sonet-hour24-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sonet-hour24-path-threshold" : ("sonet_hour24_path_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds.SonetHour24PathThreshold)}

                            self.sonet_hour24_path_threshold = YList(self)
                            self._segment_path = lambda: "sonet-hour24-path-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds, [], name, value)


                        class SonetHour24PathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: path_threshold  <key>
                            
                            	Path Threshold Type
                            	**type**\:   :py:class:`PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.PathThreshold>`
                            
                            .. attribute:: path_threshold_value
                            
                            	Path Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds.SonetHour24PathThreshold, self).__init__()

                                self.yang_name = "sonet-hour24-path-threshold"
                                self.yang_parent_name = "sonet-hour24-path-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.path_threshold = YLeaf(YType.enumeration, "path-threshold")

                                self.path_threshold_value = YLeaf(YType.int32, "path-threshold-value")
                                self._segment_path = lambda: "sonet-hour24-path-threshold" + "[path-threshold='" + self.path_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetHour24.SonetHour24Path.SonetHour24PathThresholds.SonetHour24PathThreshold, ['path_threshold', 'path_threshold_value'], name, value)


            class SonetMinute15(Entity):
                """
                set Sonet threshold
                
                .. attribute:: sonet_minute15_ocn
                
                	Configure ocn performance monitoring
                	**type**\:   :py:class:`SonetMinute15Ocn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn>`
                
                .. attribute:: sonet_minute15_path
                
                	Configure Path performance monitoring
                	**type**\:   :py:class:`SonetMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15, self).__init__()

                    self.yang_name = "sonet-minute15"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"sonet-minute15-ocn" : ("sonet_minute15_ocn", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn), "sonet-minute15-path" : ("sonet_minute15_path", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path)}
                    self._child_list_classes = {}

                    self.sonet_minute15_ocn = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn()
                    self.sonet_minute15_ocn.parent = self
                    self._children_name_map["sonet_minute15_ocn"] = "sonet-minute15-ocn"
                    self._children_yang_names.add("sonet-minute15-ocn")

                    self.sonet_minute15_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path()
                    self.sonet_minute15_path.parent = self
                    self._children_name_map["sonet_minute15_path"] = "sonet-minute15-path"
                    self._children_yang_names.add("sonet-minute15-path")
                    self._segment_path = lambda: "sonet-minute15"


                class SonetMinute15Ocn(Entity):
                    """
                    Configure ocn performance monitoring
                    
                    .. attribute:: sonet_minute15_ocn_reports
                    
                    	set ocn TCA reporting status
                    	**type**\:   :py:class:`SonetMinute15OcnReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports>`
                    
                    .. attribute:: sonet_minute15_ocn_thresholds
                    
                    	Configure threshold on ocn parameters
                    	**type**\:   :py:class:`SonetMinute15OcnThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn, self).__init__()

                        self.yang_name = "sonet-minute15-ocn"
                        self.yang_parent_name = "sonet-minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"sonet-minute15-ocn-reports" : ("sonet_minute15_ocn_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports), "sonet-minute15-ocn-thresholds" : ("sonet_minute15_ocn_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds)}
                        self._child_list_classes = {}

                        self.sonet_minute15_ocn_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports()
                        self.sonet_minute15_ocn_reports.parent = self
                        self._children_name_map["sonet_minute15_ocn_reports"] = "sonet-minute15-ocn-reports"
                        self._children_yang_names.add("sonet-minute15-ocn-reports")

                        self.sonet_minute15_ocn_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds()
                        self.sonet_minute15_ocn_thresholds.parent = self
                        self._children_name_map["sonet_minute15_ocn_thresholds"] = "sonet-minute15-ocn-thresholds"
                        self._children_yang_names.add("sonet-minute15-ocn-thresholds")
                        self._segment_path = lambda: "sonet-minute15-ocn"


                    class SonetMinute15OcnReports(Entity):
                        """
                        set ocn TCA reporting status
                        
                        .. attribute:: sonet_minute15_ocn_report
                        
                        	none
                        	**type**\: list of    :py:class:`SonetMinute15OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports.SonetMinute15OcnReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports, self).__init__()

                            self.yang_name = "sonet-minute15-ocn-reports"
                            self.yang_parent_name = "sonet-minute15-ocn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sonet-minute15-ocn-report" : ("sonet_minute15_ocn_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports.SonetMinute15OcnReport)}

                            self.sonet_minute15_ocn_report = YList(self)
                            self._segment_path = lambda: "sonet-minute15-ocn-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports, [], name, value)


                        class SonetMinute15OcnReport(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_report  <key>
                            
                            	Ocn Report Type
                            	**type**\:   :py:class:`OcnReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports.SonetMinute15OcnReport, self).__init__()

                                self.yang_name = "sonet-minute15-ocn-report"
                                self.yang_parent_name = "sonet-minute15-ocn-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ocn_report = YLeaf(YType.enumeration, "ocn-report")
                                self._segment_path = lambda: "sonet-minute15-ocn-report" + "[ocn-report='" + self.ocn_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnReports.SonetMinute15OcnReport, ['ocn_report'], name, value)


                    class SonetMinute15OcnThresholds(Entity):
                        """
                        Configure threshold on ocn parameters
                        
                        .. attribute:: sonet_minute15_ocn_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`SonetMinute15OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds.SonetMinute15OcnThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds, self).__init__()

                            self.yang_name = "sonet-minute15-ocn-thresholds"
                            self.yang_parent_name = "sonet-minute15-ocn"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sonet-minute15-ocn-threshold" : ("sonet_minute15_ocn_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds.SonetMinute15OcnThreshold)}

                            self.sonet_minute15_ocn_threshold = YList(self)
                            self._segment_path = lambda: "sonet-minute15-ocn-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds, [], name, value)


                        class SonetMinute15OcnThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: ocn_threshold  <key>
                            
                            	Ocn Threshold Type
                            	**type**\:   :py:class:`OcnThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.OcnThreshold>`
                            
                            .. attribute:: ocn_threshold_value
                            
                            	Ocn Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds.SonetMinute15OcnThreshold, self).__init__()

                                self.yang_name = "sonet-minute15-ocn-threshold"
                                self.yang_parent_name = "sonet-minute15-ocn-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.ocn_threshold = YLeaf(YType.enumeration, "ocn-threshold")

                                self.ocn_threshold_value = YLeaf(YType.int32, "ocn-threshold-value")
                                self._segment_path = lambda: "sonet-minute15-ocn-threshold" + "[ocn-threshold='" + self.ocn_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Ocn.SonetMinute15OcnThresholds.SonetMinute15OcnThreshold, ['ocn_threshold', 'ocn_threshold_value'], name, value)


                class SonetMinute15Path(Entity):
                    """
                    Configure Path performance monitoring
                    
                    .. attribute:: sonet_minute15_path_reports
                    
                    	set Path TCA reporting status
                    	**type**\:   :py:class:`SonetMinute15PathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports>`
                    
                    .. attribute:: sonet_minute15_path_thresholds
                    
                    	Configure threshold on Path parameters
                    	**type**\:   :py:class:`SonetMinute15PathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path, self).__init__()

                        self.yang_name = "sonet-minute15-path"
                        self.yang_parent_name = "sonet-minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"sonet-minute15-path-reports" : ("sonet_minute15_path_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports), "sonet-minute15-path-thresholds" : ("sonet_minute15_path_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds)}
                        self._child_list_classes = {}

                        self.sonet_minute15_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports()
                        self.sonet_minute15_path_reports.parent = self
                        self._children_name_map["sonet_minute15_path_reports"] = "sonet-minute15-path-reports"
                        self._children_yang_names.add("sonet-minute15-path-reports")

                        self.sonet_minute15_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds()
                        self.sonet_minute15_path_thresholds.parent = self
                        self._children_name_map["sonet_minute15_path_thresholds"] = "sonet-minute15-path-thresholds"
                        self._children_yang_names.add("sonet-minute15-path-thresholds")
                        self._segment_path = lambda: "sonet-minute15-path"


                    class SonetMinute15PathReports(Entity):
                        """
                        set Path TCA reporting status
                        
                        .. attribute:: sonet_minute15_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`SonetMinute15PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports.SonetMinute15PathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports, self).__init__()

                            self.yang_name = "sonet-minute15-path-reports"
                            self.yang_parent_name = "sonet-minute15-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sonet-minute15-path-report" : ("sonet_minute15_path_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports.SonetMinute15PathReport)}

                            self.sonet_minute15_path_report = YList(self)
                            self._segment_path = lambda: "sonet-minute15-path-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports, [], name, value)


                        class SonetMinute15PathReport(Entity):
                            """
                            none
                            
                            .. attribute:: path_report  <key>
                            
                            	Path Report Type
                            	**type**\:   :py:class:`PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.PathReport>`
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports.SonetMinute15PathReport, self).__init__()

                                self.yang_name = "sonet-minute15-path-report"
                                self.yang_parent_name = "sonet-minute15-path-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.path_report = YLeaf(YType.enumeration, "path-report")
                                self._segment_path = lambda: "sonet-minute15-path-report" + "[path-report='" + self.path_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathReports.SonetMinute15PathReport, ['path_report'], name, value)


                    class SonetMinute15PathThresholds(Entity):
                        """
                        Configure threshold on Path parameters
                        
                        .. attribute:: sonet_minute15_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`SonetMinute15PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds.SonetMinute15PathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds, self).__init__()

                            self.yang_name = "sonet-minute15-path-thresholds"
                            self.yang_parent_name = "sonet-minute15-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sonet-minute15-path-threshold" : ("sonet_minute15_path_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds.SonetMinute15PathThreshold)}

                            self.sonet_minute15_path_threshold = YList(self)
                            self._segment_path = lambda: "sonet-minute15-path-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds, [], name, value)


                        class SonetMinute15PathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: path_threshold  <key>
                            
                            	Path Threshold Type
                            	**type**\:   :py:class:`PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.PathThreshold>`
                            
                            .. attribute:: path_threshold_value
                            
                            	Path Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds.SonetMinute15PathThreshold, self).__init__()

                                self.yang_name = "sonet-minute15-path-threshold"
                                self.yang_parent_name = "sonet-minute15-path-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.path_threshold = YLeaf(YType.enumeration, "path-threshold")

                                self.path_threshold_value = YLeaf(YType.int32, "path-threshold-value")
                                self._segment_path = lambda: "sonet-minute15-path-threshold" + "[path-threshold='" + self.path_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.SonetMinute15.SonetMinute15Path.SonetMinute15PathThresholds.SonetMinute15PathThreshold, ['path_threshold', 'path_threshold_value'], name, value)


            class StmHour24(Entity):
                """
                set STM threshold
                
                .. attribute:: stm_hour24_stm
                
                	Configure stm performance monitoring
                	**type**\:   :py:class:`StmHour24Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24, self).__init__()

                    self.yang_name = "stm-hour24"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"stm-hour24-stm" : ("stm_hour24_stm", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm)}
                    self._child_list_classes = {}

                    self.stm_hour24_stm = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm()
                    self.stm_hour24_stm.parent = self
                    self._children_name_map["stm_hour24_stm"] = "stm-hour24-stm"
                    self._children_yang_names.add("stm-hour24-stm")
                    self._segment_path = lambda: "stm-hour24"


                class StmHour24Stm(Entity):
                    """
                    Configure stm performance monitoring
                    
                    .. attribute:: stm_hour24_stm_reports
                    
                    	set stm TCA reporting status
                    	**type**\:   :py:class:`StmHour24StmReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports>`
                    
                    .. attribute:: stm_hour24_stm_thresholds
                    
                    	Configure threshold on stm parameters
                    	**type**\:   :py:class:`StmHour24StmThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm, self).__init__()

                        self.yang_name = "stm-hour24-stm"
                        self.yang_parent_name = "stm-hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"stm-hour24-stm-reports" : ("stm_hour24_stm_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports), "stm-hour24-stm-thresholds" : ("stm_hour24_stm_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds)}
                        self._child_list_classes = {}

                        self.stm_hour24_stm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports()
                        self.stm_hour24_stm_reports.parent = self
                        self._children_name_map["stm_hour24_stm_reports"] = "stm-hour24-stm-reports"
                        self._children_yang_names.add("stm-hour24-stm-reports")

                        self.stm_hour24_stm_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds()
                        self.stm_hour24_stm_thresholds.parent = self
                        self._children_name_map["stm_hour24_stm_thresholds"] = "stm-hour24-stm-thresholds"
                        self._children_yang_names.add("stm-hour24-stm-thresholds")
                        self._segment_path = lambda: "stm-hour24-stm"


                    class StmHour24StmReports(Entity):
                        """
                        set stm TCA reporting status
                        
                        .. attribute:: stm_hour24_stm_report
                        
                        	none
                        	**type**\: list of    :py:class:`StmHour24StmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports.StmHour24StmReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports, self).__init__()

                            self.yang_name = "stm-hour24-stm-reports"
                            self.yang_parent_name = "stm-hour24-stm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"stm-hour24-stm-report" : ("stm_hour24_stm_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports.StmHour24StmReport)}

                            self.stm_hour24_stm_report = YList(self)
                            self._segment_path = lambda: "stm-hour24-stm-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports, [], name, value)


                        class StmHour24StmReport(Entity):
                            """
                            none
                            
                            .. attribute:: stm_report  <key>
                            
                            	Stm Report Type
                            	**type**\:   :py:class:`StmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StmReport>`
                            
                            .. attribute:: enable
                            
                            	Stm Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports.StmHour24StmReport, self).__init__()

                                self.yang_name = "stm-hour24-stm-report"
                                self.yang_parent_name = "stm-hour24-stm-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.stm_report = YLeaf(YType.enumeration, "stm-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "stm-hour24-stm-report" + "[stm-report='" + self.stm_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmReports.StmHour24StmReport, ['stm_report', 'enable'], name, value)


                    class StmHour24StmThresholds(Entity):
                        """
                        Configure threshold on stm parameters
                        
                        .. attribute:: stm_hour24_stm_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`StmHour24StmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds.StmHour24StmThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds, self).__init__()

                            self.yang_name = "stm-hour24-stm-thresholds"
                            self.yang_parent_name = "stm-hour24-stm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"stm-hour24-stm-threshold" : ("stm_hour24_stm_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds.StmHour24StmThreshold)}

                            self.stm_hour24_stm_threshold = YList(self)
                            self._segment_path = lambda: "stm-hour24-stm-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds, [], name, value)


                        class StmHour24StmThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: stm_threshold  <key>
                            
                            	Stm Threshold Type
                            	**type**\:   :py:class:`StmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StmThreshold>`
                            
                            .. attribute:: stm_threshold_value
                            
                            	Stm Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds.StmHour24StmThreshold, self).__init__()

                                self.yang_name = "stm-hour24-stm-threshold"
                                self.yang_parent_name = "stm-hour24-stm-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.stm_threshold = YLeaf(YType.enumeration, "stm-threshold")

                                self.stm_threshold_value = YLeaf(YType.int32, "stm-threshold-value")
                                self._segment_path = lambda: "stm-hour24-stm-threshold" + "[stm-threshold='" + self.stm_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmHour24.StmHour24Stm.StmHour24StmThresholds.StmHour24StmThreshold, ['stm_threshold', 'stm_threshold_value'], name, value)


            class StmMinute15(Entity):
                """
                set STM threshold
                
                .. attribute:: stm_minute15_stm
                
                	Configure stm performance monitoring
                	**type**\:   :py:class:`StmMinute15Stm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15, self).__init__()

                    self.yang_name = "stm-minute15"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"stm-minute15-stm" : ("stm_minute15_stm", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm)}
                    self._child_list_classes = {}

                    self.stm_minute15_stm = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm()
                    self.stm_minute15_stm.parent = self
                    self._children_name_map["stm_minute15_stm"] = "stm-minute15-stm"
                    self._children_yang_names.add("stm-minute15-stm")
                    self._segment_path = lambda: "stm-minute15"


                class StmMinute15Stm(Entity):
                    """
                    Configure stm performance monitoring
                    
                    .. attribute:: stm_minute15_stm_reports
                    
                    	set stm TCA reporting status
                    	**type**\:   :py:class:`StmMinute15StmReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports>`
                    
                    .. attribute:: stm_minute15_stm_thresholds
                    
                    	Configure threshold on stm parameters
                    	**type**\:   :py:class:`StmMinute15StmThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm, self).__init__()

                        self.yang_name = "stm-minute15-stm"
                        self.yang_parent_name = "stm-minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"stm-minute15-stm-reports" : ("stm_minute15_stm_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports), "stm-minute15-stm-thresholds" : ("stm_minute15_stm_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds)}
                        self._child_list_classes = {}

                        self.stm_minute15_stm_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports()
                        self.stm_minute15_stm_reports.parent = self
                        self._children_name_map["stm_minute15_stm_reports"] = "stm-minute15-stm-reports"
                        self._children_yang_names.add("stm-minute15-stm-reports")

                        self.stm_minute15_stm_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds()
                        self.stm_minute15_stm_thresholds.parent = self
                        self._children_name_map["stm_minute15_stm_thresholds"] = "stm-minute15-stm-thresholds"
                        self._children_yang_names.add("stm-minute15-stm-thresholds")
                        self._segment_path = lambda: "stm-minute15-stm"


                    class StmMinute15StmReports(Entity):
                        """
                        set stm TCA reporting status
                        
                        .. attribute:: stm_minute15_stm_report
                        
                        	none
                        	**type**\: list of    :py:class:`StmMinute15StmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports.StmMinute15StmReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports, self).__init__()

                            self.yang_name = "stm-minute15-stm-reports"
                            self.yang_parent_name = "stm-minute15-stm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"stm-minute15-stm-report" : ("stm_minute15_stm_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports.StmMinute15StmReport)}

                            self.stm_minute15_stm_report = YList(self)
                            self._segment_path = lambda: "stm-minute15-stm-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports, [], name, value)


                        class StmMinute15StmReport(Entity):
                            """
                            none
                            
                            .. attribute:: stm_report  <key>
                            
                            	Stm Report Type
                            	**type**\:   :py:class:`StmReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StmReport>`
                            
                            .. attribute:: enable
                            
                            	Stm Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports.StmMinute15StmReport, self).__init__()

                                self.yang_name = "stm-minute15-stm-report"
                                self.yang_parent_name = "stm-minute15-stm-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.stm_report = YLeaf(YType.enumeration, "stm-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "stm-minute15-stm-report" + "[stm-report='" + self.stm_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmReports.StmMinute15StmReport, ['stm_report', 'enable'], name, value)


                    class StmMinute15StmThresholds(Entity):
                        """
                        Configure threshold on stm parameters
                        
                        .. attribute:: stm_minute15_stm_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`StmMinute15StmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds.StmMinute15StmThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds, self).__init__()

                            self.yang_name = "stm-minute15-stm-thresholds"
                            self.yang_parent_name = "stm-minute15-stm"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"stm-minute15-stm-threshold" : ("stm_minute15_stm_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds.StmMinute15StmThreshold)}

                            self.stm_minute15_stm_threshold = YList(self)
                            self._segment_path = lambda: "stm-minute15-stm-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds, [], name, value)


                        class StmMinute15StmThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: stm_threshold  <key>
                            
                            	Stm Threshold Type
                            	**type**\:   :py:class:`StmThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StmThreshold>`
                            
                            .. attribute:: stm_threshold_value
                            
                            	Stm Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds.StmMinute15StmThreshold, self).__init__()

                                self.yang_name = "stm-minute15-stm-threshold"
                                self.yang_parent_name = "stm-minute15-stm-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.stm_threshold = YLeaf(YType.enumeration, "stm-threshold")

                                self.stm_threshold_value = YLeaf(YType.int32, "stm-threshold-value")
                                self._segment_path = lambda: "stm-minute15-stm-threshold" + "[stm-threshold='" + self.stm_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StmMinute15.StmMinute15Stm.StmMinute15StmThresholds.StmMinute15StmThreshold, ['stm_threshold', 'stm_threshold_value'], name, value)


            class StsHour24(Entity):
                """
                set STS threshold
                
                .. attribute:: sts_hour24_path
                
                	Configure Path performance monitoring
                	**type**\:   :py:class:`StsHour24Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24, self).__init__()

                    self.yang_name = "sts-hour24"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"sts-hour24-path" : ("sts_hour24_path", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path)}
                    self._child_list_classes = {}

                    self.sts_hour24_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path()
                    self.sts_hour24_path.parent = self
                    self._children_name_map["sts_hour24_path"] = "sts-hour24-path"
                    self._children_yang_names.add("sts-hour24-path")
                    self._segment_path = lambda: "sts-hour24"


                class StsHour24Path(Entity):
                    """
                    Configure Path performance monitoring
                    
                    .. attribute:: sts_hour24_path_reports
                    
                    	set Path TCA reporting status
                    	**type**\:   :py:class:`StsHour24PathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports>`
                    
                    .. attribute:: sts_hour24_path_thresholds
                    
                    	Configure threshold on Path parameters
                    	**type**\:   :py:class:`StsHour24PathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path, self).__init__()

                        self.yang_name = "sts-hour24-path"
                        self.yang_parent_name = "sts-hour24"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"sts-hour24-path-reports" : ("sts_hour24_path_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports), "sts-hour24-path-thresholds" : ("sts_hour24_path_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds)}
                        self._child_list_classes = {}

                        self.sts_hour24_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports()
                        self.sts_hour24_path_reports.parent = self
                        self._children_name_map["sts_hour24_path_reports"] = "sts-hour24-path-reports"
                        self._children_yang_names.add("sts-hour24-path-reports")

                        self.sts_hour24_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds()
                        self.sts_hour24_path_thresholds.parent = self
                        self._children_name_map["sts_hour24_path_thresholds"] = "sts-hour24-path-thresholds"
                        self._children_yang_names.add("sts-hour24-path-thresholds")
                        self._segment_path = lambda: "sts-hour24-path"


                    class StsHour24PathReports(Entity):
                        """
                        set Path TCA reporting status
                        
                        .. attribute:: sts_hour24_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`StsHour24PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports.StsHour24PathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports, self).__init__()

                            self.yang_name = "sts-hour24-path-reports"
                            self.yang_parent_name = "sts-hour24-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sts-hour24-path-report" : ("sts_hour24_path_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports.StsHour24PathReport)}

                            self.sts_hour24_path_report = YList(self)
                            self._segment_path = lambda: "sts-hour24-path-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports, [], name, value)


                        class StsHour24PathReport(Entity):
                            """
                            none
                            
                            .. attribute:: path_report  <key>
                            
                            	Path Report Type
                            	**type**\:   :py:class:`StsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StsReport>`
                            
                            .. attribute:: enable
                            
                            	Path Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports.StsHour24PathReport, self).__init__()

                                self.yang_name = "sts-hour24-path-report"
                                self.yang_parent_name = "sts-hour24-path-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.path_report = YLeaf(YType.enumeration, "path-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "sts-hour24-path-report" + "[path-report='" + self.path_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathReports.StsHour24PathReport, ['path_report', 'enable'], name, value)


                    class StsHour24PathThresholds(Entity):
                        """
                        Configure threshold on Path parameters
                        
                        .. attribute:: sts_hour24_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`StsHour24PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds.StsHour24PathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds, self).__init__()

                            self.yang_name = "sts-hour24-path-thresholds"
                            self.yang_parent_name = "sts-hour24-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sts-hour24-path-threshold" : ("sts_hour24_path_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds.StsHour24PathThreshold)}

                            self.sts_hour24_path_threshold = YList(self)
                            self._segment_path = lambda: "sts-hour24-path-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds, [], name, value)


                        class StsHour24PathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: path_threshold  <key>
                            
                            	Path Threshold Type
                            	**type**\:   :py:class:`StsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StsThreshold>`
                            
                            .. attribute:: path_threshold_value
                            
                            	Path Thresh Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds.StsHour24PathThreshold, self).__init__()

                                self.yang_name = "sts-hour24-path-threshold"
                                self.yang_parent_name = "sts-hour24-path-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.path_threshold = YLeaf(YType.enumeration, "path-threshold")

                                self.path_threshold_value = YLeaf(YType.int32, "path-threshold-value")
                                self._segment_path = lambda: "sts-hour24-path-threshold" + "[path-threshold='" + self.path_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsHour24.StsHour24Path.StsHour24PathThresholds.StsHour24PathThreshold, ['path_threshold', 'path_threshold_value'], name, value)


            class StsMinute15(Entity):
                """
                set STS threshold
                
                .. attribute:: sts_minute15_path
                
                	Configure Path performance monitoring
                	**type**\:   :py:class:`StsMinute15Path <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path>`
                
                

                """

                _prefix = 'pmengine-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15, self).__init__()

                    self.yang_name = "sts-minute15"
                    self.yang_parent_name = "performance-management"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"sts-minute15-path" : ("sts_minute15_path", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path)}
                    self._child_list_classes = {}

                    self.sts_minute15_path = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path()
                    self.sts_minute15_path.parent = self
                    self._children_name_map["sts_minute15_path"] = "sts-minute15-path"
                    self._children_yang_names.add("sts-minute15-path")
                    self._segment_path = lambda: "sts-minute15"


                class StsMinute15Path(Entity):
                    """
                    Configure Path performance monitoring
                    
                    .. attribute:: sts_minute15_path_reports
                    
                    	set Path TCA reporting status
                    	**type**\:   :py:class:`StsMinute15PathReports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports>`
                    
                    .. attribute:: sts_minute15_path_thresholds
                    
                    	Configure threshold on Path parameters
                    	**type**\:   :py:class:`StsMinute15PathThresholds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds>`
                    
                    

                    """

                    _prefix = 'pmengine-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path, self).__init__()

                        self.yang_name = "sts-minute15-path"
                        self.yang_parent_name = "sts-minute15"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"sts-minute15-path-reports" : ("sts_minute15_path_reports", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports), "sts-minute15-path-thresholds" : ("sts_minute15_path_thresholds", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds)}
                        self._child_list_classes = {}

                        self.sts_minute15_path_reports = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports()
                        self.sts_minute15_path_reports.parent = self
                        self._children_name_map["sts_minute15_path_reports"] = "sts-minute15-path-reports"
                        self._children_yang_names.add("sts-minute15-path-reports")

                        self.sts_minute15_path_thresholds = InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds()
                        self.sts_minute15_path_thresholds.parent = self
                        self._children_name_map["sts_minute15_path_thresholds"] = "sts-minute15-path-thresholds"
                        self._children_yang_names.add("sts-minute15-path-thresholds")
                        self._segment_path = lambda: "sts-minute15-path"


                    class StsMinute15PathReports(Entity):
                        """
                        set Path TCA reporting status
                        
                        .. attribute:: sts_minute15_path_report
                        
                        	none
                        	**type**\: list of    :py:class:`StsMinute15PathReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports.StsMinute15PathReport>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports, self).__init__()

                            self.yang_name = "sts-minute15-path-reports"
                            self.yang_parent_name = "sts-minute15-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sts-minute15-path-report" : ("sts_minute15_path_report", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports.StsMinute15PathReport)}

                            self.sts_minute15_path_report = YList(self)
                            self._segment_path = lambda: "sts-minute15-path-reports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports, [], name, value)


                        class StsMinute15PathReport(Entity):
                            """
                            none
                            
                            .. attribute:: path_report  <key>
                            
                            	Path Report Type
                            	**type**\:   :py:class:`StsReport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StsReport>`
                            
                            .. attribute:: enable
                            
                            	Path Report
                            	**type**\:   :py:class:`Report <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.Report>`
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports.StsMinute15PathReport, self).__init__()

                                self.yang_name = "sts-minute15-path-report"
                                self.yang_parent_name = "sts-minute15-path-reports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.path_report = YLeaf(YType.enumeration, "path-report")

                                self.enable = YLeaf(YType.enumeration, "enable")
                                self._segment_path = lambda: "sts-minute15-path-report" + "[path-report='" + self.path_report.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathReports.StsMinute15PathReport, ['path_report', 'enable'], name, value)


                    class StsMinute15PathThresholds(Entity):
                        """
                        Configure threshold on Path parameters
                        
                        .. attribute:: sts_minute15_path_threshold
                        
                        	none
                        	**type**\: list of    :py:class:`StsMinute15PathThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds.StsMinute15PathThreshold>`
                        
                        

                        """

                        _prefix = 'pmengine-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds, self).__init__()

                            self.yang_name = "sts-minute15-path-thresholds"
                            self.yang_parent_name = "sts-minute15-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"sts-minute15-path-threshold" : ("sts_minute15_path_threshold", InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds.StsMinute15PathThreshold)}

                            self.sts_minute15_path_threshold = YList(self)
                            self._segment_path = lambda: "sts-minute15-path-thresholds"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds, [], name, value)


                        class StsMinute15PathThreshold(Entity):
                            """
                            none
                            
                            .. attribute:: path_threshold  <key>
                            
                            	Path Threshold Type
                            	**type**\:   :py:class:`StsThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_pmengine_cfg.StsThreshold>`
                            
                            .. attribute:: path_threshold_value
                            
                            	Path Threshold Value
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**mandatory**\: True
                            
                            

                            """

                            _prefix = 'pmengine-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds.StsMinute15PathThreshold, self).__init__()

                                self.yang_name = "sts-minute15-path-threshold"
                                self.yang_parent_name = "sts-minute15-path-thresholds"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.path_threshold = YLeaf(YType.enumeration, "path-threshold")

                                self.path_threshold_value = YLeaf(YType.int32, "path-threshold-value")
                                self._segment_path = lambda: "sts-minute15-path-threshold" + "[path-threshold='" + self.path_threshold.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PerformanceManagement.StsMinute15.StsMinute15Path.StsMinute15PathThresholds.StsMinute15PathThreshold, ['path_threshold', 'path_threshold_value'], name, value)


        class Portmode(Entity):
            """
            Configure through port\-mode
            
            .. attribute:: diff_sel
            
            	Select Diff
            	**type**\:   :py:class:`DiffSel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs5500_coherent_portmode_cfg.DiffSel>`
            
            .. attribute:: fec_sel
            
            	Select Fec
            	**type**\:   :py:class:`FecSel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs5500_coherent_portmode_cfg.FecSel>`
            
            .. attribute:: speed_sel
            
            	Select speed
            	**type**\:   :py:class:`SpeedSel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ncs5500_coherent_portmode_cfg.SpeedSel>`
            
            

            """

            _prefix = 'ncs5500-coherent-portmode-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Portmode, self).__init__()

                self.yang_name = "portmode"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.diff_sel = YLeaf(YType.enumeration, "diff-sel")

                self.fec_sel = YLeaf(YType.enumeration, "fec-sel")

                self.speed_sel = YLeaf(YType.enumeration, "speed-sel")
                self._segment_path = lambda: "Cisco-IOS-XR-ncs5500-coherent-portmode-cfg:portmode"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Portmode, ['diff_sel', 'fec_sel', 'speed_sel'], name, value)


        class Pppoe(Entity):
            """
            Interface PPPoE configuration data
            
            .. attribute:: enable_bba_group
            
            	Use this BBA\-Group to enable PPPoE on this interface
            	**type**\:   :py:class:`EnableBbaGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Pppoe.EnableBbaGroup>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'subscriber-pppoe-ma-cmd-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Pppoe, self).__init__()

                self.yang_name = "pppoe"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"enable-bba-group" : ("enable_bba_group", InterfaceConfigurations.InterfaceConfiguration.Pppoe.EnableBbaGroup)}
                self._child_list_classes = {}

                self.enable_bba_group = None
                self._children_name_map["enable_bba_group"] = "enable-bba-group"
                self._children_yang_names.add("enable-bba-group")
                self._segment_path = lambda: "Cisco-IOS-XR-subscriber-pppoe-ma-cmd-cfg:pppoe"


            class EnableBbaGroup(Entity):
                """
                Use this BBA\-Group to enable PPPoE on this
                interface
                
                .. attribute:: bba_group_name
                
                	Name of the BBA\-Group
                	**type**\:  str
                
                .. attribute:: enable
                
                	Enable PPPoE on this interface
                	**type**\:  bool
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'subscriber-pppoe-ma-cmd-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Pppoe.EnableBbaGroup, self).__init__()

                    self.yang_name = "enable-bba-group"
                    self.yang_parent_name = "pppoe"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.bba_group_name = YLeaf(YType.str, "bba-group-name")

                    self.enable = YLeaf(YType.boolean, "enable")
                    self._segment_path = lambda: "enable-bba-group"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Pppoe.EnableBbaGroup, ['bba_group_name', 'enable'], name, value)


        class PseudowireEther(Entity):
            """
            PW\-Ether attributes
            
            .. attribute:: generic_interface_list
            
            	Name of the interface list
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: l2_overhead
            
            	PW Ether L2 overhead requirement
            	**type**\:  int
            
            	**range:** 1..64
            
            

            """

            _prefix = 'l2vpn-cfg'
            _revision = '2017-06-26'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.PseudowireEther, self).__init__()

                self.yang_name = "pseudowire-ether"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.generic_interface_list = YLeaf(YType.str, "generic-interface-list")

                self.l2_overhead = YLeaf(YType.uint32, "l2-overhead")
                self._segment_path = lambda: "Cisco-IOS-XR-l2vpn-cfg:pseudowire-ether"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PseudowireEther, ['generic_interface_list', 'l2_overhead'], name, value)


        class PseudowireIw(Entity):
            """
            PW\-IW attributes
            
            .. attribute:: generic_interface_list
            
            	Name of the interface list
            	**type**\:  str
            
            	**length:** 1..32
            
            .. attribute:: l2_overhead
            
            	L2 overhead size in bytes
            	**type**\:  int
            
            	**range:** 1..64
            
            	**units**\: byte
            
            

            """

            _prefix = 'l2vpn-cfg'
            _revision = '2017-06-26'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.PseudowireIw, self).__init__()

                self.yang_name = "pseudowire-iw"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.generic_interface_list = YLeaf(YType.str, "generic-interface-list")

                self.l2_overhead = YLeaf(YType.uint32, "l2-overhead")
                self._segment_path = lambda: "Cisco-IOS-XR-l2vpn-cfg:pseudowire-iw"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.PseudowireIw, ['generic_interface_list', 'l2_overhead'], name, value)


        class Ptp(Entity):
            """
            Precision Time Protocol interface configuration
            
            .. attribute:: announce_grant_duration
            
            	Announce unicast grant duration, in seconds
            	**type**\:  int
            
            	**range:** 60..1000
            
            	**units**\: second
            
            	**default value**\: 300
            
            .. attribute:: announce_interval
            
            	Announce interval
            	**type**\:   :py:class:`AnnounceInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.AnnounceInterval>`
            
            .. attribute:: announce_timeout
            
            	Announce Timeout
            	**type**\:  int
            
            	**range:** 2..10
            
            	**default value**\: 3
            
            .. attribute:: clock_operation
            
            	Clock Operation
            	**type**\:   :py:class:`PtpClockOperation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpClockOperation>`
            
            	**default value**\: two-step
            
            .. attribute:: communication
            
            	Communication model
            	**type**\:   :py:class:`Communication <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Communication>`
            
            .. attribute:: cos
            
            	COS
            	**type**\:  int
            
            	**range:** 0..7
            
            	**default value**\: 6
            
            .. attribute:: delay_request_minimum_interval
            
            	Minimum delay request interval
            	**type**\:   :py:class:`DelayRequestMinimumInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.DelayRequestMinimumInterval>`
            
            .. attribute:: delay_response_grant_duration
            
            	Delay\-Response unicast grant duration, in seconds
            	**type**\:  int
            
            	**range:** 60..1000
            
            	**units**\: second
            
            	**default value**\: 300
            
            .. attribute:: delay_response_timeout
            
            	Delay\-Response timeout, in milliseconds
            	**type**\:  int
            
            	**range:** 100..100000
            
            	**units**\: millisecond
            
            	**default value**\: 5000
            
            .. attribute:: dscp
            
            	DSCP
            	**type**\:  int
            
            	**range:** 0..63
            
            	**default value**\: 46
            
            .. attribute:: enable
            
            	Enable the precision time protocol
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: event_cos
            
            	Event COS
            	**type**\:  int
            
            	**range:** 0..7
            
            	**default value**\: 6
            
            .. attribute:: event_dscp
            
            	Event DSCP
            	**type**\:  int
            
            	**range:** 0..63
            
            	**default value**\: 46
            
            .. attribute:: general_cos
            
            	General COS
            	**type**\:  int
            
            	**range:** 0..7
            
            	**default value**\: 6
            
            .. attribute:: general_dscp
            
            	General DSCP
            	**type**\:  int
            
            	**range:** 0..63
            
            	**default value**\: 46
            
            .. attribute:: local_priority
            
            	Local priority
            	**type**\:  int
            
            	**range:** 1..255
            
            	**default value**\: 128
            
            .. attribute:: masters
            
            	Table for master configuration
            	**type**\:   :py:class:`Masters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters>`
            
            .. attribute:: port_state
            
            	Port state restriction
            	**type**\:   :py:class:`PtpPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpPortState>`
            
            	**default value**\: any
            
            .. attribute:: profile
            
            	Precision Time Protocol configuration profile
            	**type**\:  str
            
            .. attribute:: slaves
            
            	Table for slave configuration
            	**type**\:   :py:class:`Slaves <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves>`
            
            .. attribute:: source_ipv4_address
            
            	Source IPv4 Address
            	**type**\:   :py:class:`SourceIpv4Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv4Address>`
            
            .. attribute:: source_ipv6_address
            
            	Source IPv6 Address
            	**type**\:   :py:class:`SourceIpv6Address <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv6Address>`
            
            .. attribute:: sync_grant_duration
            
            	Sync unicast grant duration, in seconds
            	**type**\:  int
            
            	**range:** 60..1000
            
            	**units**\: second
            
            	**default value**\: 300
            
            .. attribute:: sync_interval
            
            	Sync interval
            	**type**\:   :py:class:`SyncInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.SyncInterval>`
            
            .. attribute:: sync_timeout
            
            	Sync timeout, in milliseconds
            	**type**\:  int
            
            	**range:** 100..100000
            
            	**units**\: millisecond
            
            	**default value**\: 5000
            
            .. attribute:: transport
            
            	Transport
            	**type**\:   :py:class:`PtpEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpEncap>`
            
            	**default value**\: ipv4
            
            .. attribute:: unicast_grant_invalid_request
            
            	Invalid unicast grant request response
            	**type**\:   :py:class:`PtpInvalidUnicastGrantRequestResponse <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpInvalidUnicastGrantRequestResponse>`
            
            	**default value**\: reduce
            
            

            """

            _prefix = 'ptp-cfg'
            _revision = '2017-02-02'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Ptp, self).__init__()

                self.yang_name = "ptp"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"announce-interval" : ("announce_interval", InterfaceConfigurations.InterfaceConfiguration.Ptp.AnnounceInterval), "communication" : ("communication", InterfaceConfigurations.InterfaceConfiguration.Ptp.Communication), "delay-request-minimum-interval" : ("delay_request_minimum_interval", InterfaceConfigurations.InterfaceConfiguration.Ptp.DelayRequestMinimumInterval), "masters" : ("masters", InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters), "slaves" : ("slaves", InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves), "source-ipv4-address" : ("source_ipv4_address", InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv4Address), "source-ipv6-address" : ("source_ipv6_address", InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv6Address), "sync-interval" : ("sync_interval", InterfaceConfigurations.InterfaceConfiguration.Ptp.SyncInterval)}
                self._child_list_classes = {}

                self.announce_grant_duration = YLeaf(YType.uint32, "announce-grant-duration")

                self.announce_timeout = YLeaf(YType.uint32, "announce-timeout")

                self.clock_operation = YLeaf(YType.enumeration, "clock-operation")

                self.cos = YLeaf(YType.uint32, "cos")

                self.delay_response_grant_duration = YLeaf(YType.uint32, "delay-response-grant-duration")

                self.delay_response_timeout = YLeaf(YType.uint32, "delay-response-timeout")

                self.dscp = YLeaf(YType.uint32, "dscp")

                self.enable = YLeaf(YType.empty, "enable")

                self.event_cos = YLeaf(YType.uint32, "event-cos")

                self.event_dscp = YLeaf(YType.uint32, "event-dscp")

                self.general_cos = YLeaf(YType.uint32, "general-cos")

                self.general_dscp = YLeaf(YType.uint32, "general-dscp")

                self.local_priority = YLeaf(YType.uint32, "local-priority")

                self.port_state = YLeaf(YType.enumeration, "port-state")

                self.profile = YLeaf(YType.str, "profile")

                self.sync_grant_duration = YLeaf(YType.uint32, "sync-grant-duration")

                self.sync_timeout = YLeaf(YType.uint32, "sync-timeout")

                self.transport = YLeaf(YType.enumeration, "transport")

                self.unicast_grant_invalid_request = YLeaf(YType.enumeration, "unicast-grant-invalid-request")

                self.announce_interval = InterfaceConfigurations.InterfaceConfiguration.Ptp.AnnounceInterval()
                self.announce_interval.parent = self
                self._children_name_map["announce_interval"] = "announce-interval"
                self._children_yang_names.add("announce-interval")

                self.communication = InterfaceConfigurations.InterfaceConfiguration.Ptp.Communication()
                self.communication.parent = self
                self._children_name_map["communication"] = "communication"
                self._children_yang_names.add("communication")

                self.delay_request_minimum_interval = InterfaceConfigurations.InterfaceConfiguration.Ptp.DelayRequestMinimumInterval()
                self.delay_request_minimum_interval.parent = self
                self._children_name_map["delay_request_minimum_interval"] = "delay-request-minimum-interval"
                self._children_yang_names.add("delay-request-minimum-interval")

                self.masters = InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters()
                self.masters.parent = self
                self._children_name_map["masters"] = "masters"
                self._children_yang_names.add("masters")

                self.slaves = InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves()
                self.slaves.parent = self
                self._children_name_map["slaves"] = "slaves"
                self._children_yang_names.add("slaves")

                self.source_ipv4_address = InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv4Address()
                self.source_ipv4_address.parent = self
                self._children_name_map["source_ipv4_address"] = "source-ipv4-address"
                self._children_yang_names.add("source-ipv4-address")

                self.source_ipv6_address = InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv6Address()
                self.source_ipv6_address.parent = self
                self._children_name_map["source_ipv6_address"] = "source-ipv6-address"
                self._children_yang_names.add("source-ipv6-address")

                self.sync_interval = InterfaceConfigurations.InterfaceConfiguration.Ptp.SyncInterval()
                self.sync_interval.parent = self
                self._children_name_map["sync_interval"] = "sync-interval"
                self._children_yang_names.add("sync-interval")
                self._segment_path = lambda: "Cisco-IOS-XR-ptp-cfg:ptp"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp, ['announce_grant_duration', 'announce_timeout', 'clock_operation', 'cos', 'delay_response_grant_duration', 'delay_response_timeout', 'dscp', 'enable', 'event_cos', 'event_dscp', 'general_cos', 'general_dscp', 'local_priority', 'port_state', 'profile', 'sync_grant_duration', 'sync_timeout', 'transport', 'unicast_grant_invalid_request'], name, value)


            class AnnounceInterval(Entity):
                """
                Announce interval
                
                .. attribute:: time_period
                
                	Time Period
                	**type**\:   :py:class:`PtpTimePeriod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpTimePeriod>`
                
                	**default value**\: 2
                
                .. attribute:: time_type
                
                	Interval or Frequency
                	**type**\:   :py:class:`PtpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpTime>`
                
                	**default value**\: interval
                
                

                """

                _prefix = 'ptp-cfg'
                _revision = '2017-02-02'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ptp.AnnounceInterval, self).__init__()

                    self.yang_name = "announce-interval"
                    self.yang_parent_name = "ptp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.time_period = YLeaf(YType.enumeration, "time-period")

                    self.time_type = YLeaf(YType.enumeration, "time-type")
                    self._segment_path = lambda: "announce-interval"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.AnnounceInterval, ['time_period', 'time_type'], name, value)


            class Communication(Entity):
                """
                Communication model
                
                .. attribute:: model
                
                	Communication Model
                	**type**\:   :py:class:`PtpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpTransport>`
                
                	**default value**\: unicast
                
                .. attribute:: target_address
                
                	Target address
                	**type**\:  str
                
                .. attribute:: target_address_set
                
                	Target address set
                	**type**\:  bool
                
                	**default value**\: false
                
                

                """

                _prefix = 'ptp-cfg'
                _revision = '2017-02-02'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Communication, self).__init__()

                    self.yang_name = "communication"
                    self.yang_parent_name = "ptp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.model = YLeaf(YType.enumeration, "model")

                    self.target_address = YLeaf(YType.str, "target-address")

                    self.target_address_set = YLeaf(YType.boolean, "target-address-set")
                    self._segment_path = lambda: "communication"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Communication, ['model', 'target_address', 'target_address_set'], name, value)


            class DelayRequestMinimumInterval(Entity):
                """
                Minimum delay request interval
                
                .. attribute:: time_period
                
                	Time Period
                	**type**\:   :py:class:`PtpTimePeriod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpTimePeriod>`
                
                	**default value**\: 1
                
                .. attribute:: time_type
                
                	Interval or Frequency
                	**type**\:   :py:class:`PtpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpTime>`
                
                	**default value**\: interval
                
                

                """

                _prefix = 'ptp-cfg'
                _revision = '2017-02-02'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ptp.DelayRequestMinimumInterval, self).__init__()

                    self.yang_name = "delay-request-minimum-interval"
                    self.yang_parent_name = "ptp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.time_period = YLeaf(YType.enumeration, "time-period")

                    self.time_type = YLeaf(YType.enumeration, "time-type")
                    self._segment_path = lambda: "delay-request-minimum-interval"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.DelayRequestMinimumInterval, ['time_period', 'time_type'], name, value)


            class Masters(Entity):
                """
                Table for master configuration
                
                .. attribute:: master
                
                	Master configuration
                	**type**\: list of    :py:class:`Master <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master>`
                
                

                """

                _prefix = 'ptp-cfg'
                _revision = '2017-02-02'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters, self).__init__()

                    self.yang_name = "masters"
                    self.yang_parent_name = "ptp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"master" : ("master", InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master)}

                    self.master = YList(self)
                    self._segment_path = lambda: "masters"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters, [], name, value)


                class Master(Entity):
                    """
                    Master configuration
                    
                    .. attribute:: transport  <key>
                    
                    	Master Transport Type
                    	**type**\:   :py:class:`PtpEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpEncap>`
                    
                    .. attribute:: ethernet
                    
                    	ethernet
                    	**type**\: list of    :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ethernet>`
                    
                    .. attribute:: ipv4_or_ipv6
                    
                    	ipv4 or ipv6
                    	**type**\: list of    :py:class:`Ipv4OrIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ipv4OrIpv6>`
                    
                    

                    """

                    _prefix = 'ptp-cfg'
                    _revision = '2017-02-02'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master, self).__init__()

                        self.yang_name = "master"
                        self.yang_parent_name = "masters"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ethernet" : ("ethernet", InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ethernet), "ipv4-or-ipv6" : ("ipv4_or_ipv6", InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ipv4OrIpv6)}

                        self.transport = YLeaf(YType.enumeration, "transport")

                        self.ethernet = YList(self)
                        self.ipv4_or_ipv6 = YList(self)
                        self._segment_path = lambda: "master" + "[transport='" + self.transport.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master, ['transport'], name, value)


                    class Ethernet(Entity):
                        """
                        ethernet
                        
                        .. attribute:: master_mac_address  <key>
                        
                        	Master MAC Address \- only used if Transport is Ethernet
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: communication
                        
                        	Communication Model
                        	**type**\:   :py:class:`PtpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpTransport>`
                        
                        	**default value**\: unicast
                        
                        .. attribute:: delay_asymmetry
                        
                        	The delay asymmetry for this master
                        	**type**\:   :py:class:`DelayAsymmetry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ethernet.DelayAsymmetry>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: master_clock_class
                        
                        	Master clock class
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: non_negotiated
                        
                        	Enable non\-negotiated unicast on this interface
                        	**type**\:  bool
                        
                        .. attribute:: priority
                        
                        	Master priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ptp-cfg'
                        _revision = '2017-02-02'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ethernet, self).__init__()

                            self.yang_name = "ethernet"
                            self.yang_parent_name = "master"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"delay-asymmetry" : ("delay_asymmetry", InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ethernet.DelayAsymmetry)}
                            self._child_list_classes = {}

                            self.master_mac_address = YLeaf(YType.str, "master-mac-address")

                            self.communication = YLeaf(YType.enumeration, "communication")

                            self.master_clock_class = YLeaf(YType.uint32, "master-clock-class")

                            self.non_negotiated = YLeaf(YType.boolean, "non-negotiated")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.delay_asymmetry = None
                            self._children_name_map["delay_asymmetry"] = "delay-asymmetry"
                            self._children_yang_names.add("delay-asymmetry")
                            self._segment_path = lambda: "ethernet" + "[master-mac-address='" + self.master_mac_address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ethernet, ['master_mac_address', 'communication', 'master_clock_class', 'non_negotiated', 'priority'], name, value)


                        class DelayAsymmetry(Entity):
                            """
                            The delay asymmetry for this master
                            
                            .. attribute:: magnitude
                            
                            	How much longer the master to slave path takes than the reverse
                            	**type**\:  int
                            
                            	**range:** \-500000000..500000000
                            
                            	**mandatory**\: True
                            
                            .. attribute:: units
                            
                            	The units to use for the delay asymmetry
                            	**type**\:   :py:class:`PtpDelayAsymmetryUnits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpDelayAsymmetryUnits>`
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ptp-cfg'
                            _revision = '2017-02-02'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ethernet.DelayAsymmetry, self).__init__()

                                self.yang_name = "delay-asymmetry"
                                self.yang_parent_name = "ethernet"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.magnitude = YLeaf(YType.int32, "magnitude")

                                self.units = YLeaf(YType.enumeration, "units")
                                self._segment_path = lambda: "delay-asymmetry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ethernet.DelayAsymmetry, ['magnitude', 'units'], name, value)


                    class Ipv4OrIpv6(Entity):
                        """
                        ipv4 or ipv6
                        
                        .. attribute:: master_ip_address  <key>
                        
                        	Master IP Address \- used if Transport is not Ethernet
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: communication
                        
                        	Communication Model
                        	**type**\:   :py:class:`PtpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpTransport>`
                        
                        	**default value**\: unicast
                        
                        .. attribute:: delay_asymmetry
                        
                        	The delay asymmetry for this master
                        	**type**\:   :py:class:`DelayAsymmetry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ipv4OrIpv6.DelayAsymmetry>`
                        
                        	**presence node**\: True
                        
                        .. attribute:: master_clock_class
                        
                        	Master clock class
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: non_negotiated
                        
                        	Enable non\-negotiated unicast on this interface
                        	**type**\:  bool
                        
                        .. attribute:: priority
                        
                        	Master priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'ptp-cfg'
                        _revision = '2017-02-02'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ipv4OrIpv6, self).__init__()

                            self.yang_name = "ipv4-or-ipv6"
                            self.yang_parent_name = "master"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"delay-asymmetry" : ("delay_asymmetry", InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ipv4OrIpv6.DelayAsymmetry)}
                            self._child_list_classes = {}

                            self.master_ip_address = YLeaf(YType.str, "master-ip-address")

                            self.communication = YLeaf(YType.enumeration, "communication")

                            self.master_clock_class = YLeaf(YType.uint32, "master-clock-class")

                            self.non_negotiated = YLeaf(YType.boolean, "non-negotiated")

                            self.priority = YLeaf(YType.uint32, "priority")

                            self.delay_asymmetry = None
                            self._children_name_map["delay_asymmetry"] = "delay-asymmetry"
                            self._children_yang_names.add("delay-asymmetry")
                            self._segment_path = lambda: "ipv4-or-ipv6" + "[master-ip-address='" + self.master_ip_address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ipv4OrIpv6, ['master_ip_address', 'communication', 'master_clock_class', 'non_negotiated', 'priority'], name, value)


                        class DelayAsymmetry(Entity):
                            """
                            The delay asymmetry for this master
                            
                            .. attribute:: magnitude
                            
                            	How much longer the master to slave path takes than the reverse
                            	**type**\:  int
                            
                            	**range:** \-500000000..500000000
                            
                            	**mandatory**\: True
                            
                            .. attribute:: units
                            
                            	The units to use for the delay asymmetry
                            	**type**\:   :py:class:`PtpDelayAsymmetryUnits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpDelayAsymmetryUnits>`
                            
                            	**mandatory**\: True
                            
                            

                            This class is a :ref:`presence class<presence-class>`

                            """

                            _prefix = 'ptp-cfg'
                            _revision = '2017-02-02'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ipv4OrIpv6.DelayAsymmetry, self).__init__()

                                self.yang_name = "delay-asymmetry"
                                self.yang_parent_name = "ipv4-or-ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}
                                self.is_presence_container = True

                                self.magnitude = YLeaf(YType.int32, "magnitude")

                                self.units = YLeaf(YType.enumeration, "units")
                                self._segment_path = lambda: "delay-asymmetry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Masters.Master.Ipv4OrIpv6.DelayAsymmetry, ['magnitude', 'units'], name, value)


            class Slaves(Entity):
                """
                Table for slave configuration
                
                .. attribute:: slave
                
                	Slave configuration
                	**type**\: list of    :py:class:`Slave <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave>`
                
                

                """

                _prefix = 'ptp-cfg'
                _revision = '2017-02-02'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves, self).__init__()

                    self.yang_name = "slaves"
                    self.yang_parent_name = "ptp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"slave" : ("slave", InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave)}

                    self.slave = YList(self)
                    self._segment_path = lambda: "slaves"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves, [], name, value)


                class Slave(Entity):
                    """
                    Slave configuration
                    
                    .. attribute:: transport  <key>
                    
                    	Slave Transport Type
                    	**type**\:   :py:class:`PtpEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpEncap>`
                    
                    .. attribute:: ethernet
                    
                    	ethernet
                    	**type**\: list of    :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave.Ethernet>`
                    
                    .. attribute:: ipv4_or_ipv6
                    
                    	ipv4 or ipv6
                    	**type**\: list of    :py:class:`Ipv4OrIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave.Ipv4OrIpv6>`
                    
                    

                    """

                    _prefix = 'ptp-cfg'
                    _revision = '2017-02-02'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave, self).__init__()

                        self.yang_name = "slave"
                        self.yang_parent_name = "slaves"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"ethernet" : ("ethernet", InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave.Ethernet), "ipv4-or-ipv6" : ("ipv4_or_ipv6", InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave.Ipv4OrIpv6)}

                        self.transport = YLeaf(YType.enumeration, "transport")

                        self.ethernet = YList(self)
                        self.ipv4_or_ipv6 = YList(self)
                        self._segment_path = lambda: "slave" + "[transport='" + self.transport.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave, ['transport'], name, value)


                    class Ethernet(Entity):
                        """
                        ethernet
                        
                        .. attribute:: slave_mac_address  <key>
                        
                        	Slave MAC Address
                        	**type**\:  str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: non_negotiated
                        
                        	Enable non\-negotiated unicast on this interface
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ptp-cfg'
                        _revision = '2017-02-02'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave.Ethernet, self).__init__()

                            self.yang_name = "ethernet"
                            self.yang_parent_name = "slave"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.slave_mac_address = YLeaf(YType.str, "slave-mac-address")

                            self.non_negotiated = YLeaf(YType.boolean, "non-negotiated")
                            self._segment_path = lambda: "ethernet" + "[slave-mac-address='" + self.slave_mac_address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave.Ethernet, ['slave_mac_address', 'non_negotiated'], name, value)


                    class Ipv4OrIpv6(Entity):
                        """
                        ipv4 or ipv6
                        
                        .. attribute:: slave_ip_address  <key>
                        
                        	Slave IP Address
                        	**type**\: one of the below types:
                        
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        	**type**\:  str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        
                        ----
                        .. attribute:: non_negotiated
                        
                        	Enable non\-negotiated unicast on this interface
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'ptp-cfg'
                        _revision = '2017-02-02'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave.Ipv4OrIpv6, self).__init__()

                            self.yang_name = "ipv4-or-ipv6"
                            self.yang_parent_name = "slave"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.slave_ip_address = YLeaf(YType.str, "slave-ip-address")

                            self.non_negotiated = YLeaf(YType.boolean, "non-negotiated")
                            self._segment_path = lambda: "ipv4-or-ipv6" + "[slave-ip-address='" + self.slave_ip_address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.Slaves.Slave.Ipv4OrIpv6, ['slave_ip_address', 'non_negotiated'], name, value)


            class SourceIpv4Address(Entity):
                """
                Source IPv4 Address
                
                .. attribute:: enable
                
                	Enable source IP address
                	**type**\:  bool
                
                .. attribute:: source_ip
                
                	Source IP address to use
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ptp-cfg'
                _revision = '2017-02-02'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv4Address, self).__init__()

                    self.yang_name = "source-ipv4-address"
                    self.yang_parent_name = "ptp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.enable = YLeaf(YType.boolean, "enable")

                    self.source_ip = YLeaf(YType.str, "source-ip")
                    self._segment_path = lambda: "source-ipv4-address"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv4Address, ['enable', 'source_ip'], name, value)


            class SourceIpv6Address(Entity):
                """
                Source IPv6 Address
                
                .. attribute:: enable
                
                	Enable source IPv6 address
                	**type**\:  bool
                
                .. attribute:: source_ipv6
                
                	Source IPv6 address to use
                	**type**\:  str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ptp-cfg'
                _revision = '2017-02-02'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv6Address, self).__init__()

                    self.yang_name = "source-ipv6-address"
                    self.yang_parent_name = "ptp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.enable = YLeaf(YType.boolean, "enable")

                    self.source_ipv6 = YLeaf(YType.str, "source-ipv6")
                    self._segment_path = lambda: "source-ipv6-address"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.SourceIpv6Address, ['enable', 'source_ipv6'], name, value)


            class SyncInterval(Entity):
                """
                Sync interval
                
                .. attribute:: time_period
                
                	Time Period
                	**type**\:   :py:class:`PtpTimePeriod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpTimePeriod>`
                
                	**default value**\: 1
                
                .. attribute:: time_type
                
                	Interval or Frequency
                	**type**\:   :py:class:`PtpTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ptp_datatypes.PtpTime>`
                
                	**default value**\: interval
                
                

                """

                _prefix = 'ptp-cfg'
                _revision = '2017-02-02'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Ptp.SyncInterval, self).__init__()

                    self.yang_name = "sync-interval"
                    self.yang_parent_name = "ptp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.time_period = YLeaf(YType.enumeration, "time-period")

                    self.time_type = YLeaf(YType.enumeration, "time-type")
                    self._segment_path = lambda: "sync-interval"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Ptp.SyncInterval, ['time_period', 'time_type'], name, value)


        class Qos(Entity):
            """
            Interface QOS configuration
            
            .. attribute:: input
            
            	Ingress service policy
            	**type**\:   :py:class:`Input <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input>`
            
            .. attribute:: output
            
            	Egress service policy
            	**type**\:   :py:class:`Output <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output>`
            
            

            """

            _prefix = 'qos-ma-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Qos, self).__init__()

                self.yang_name = "qos"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"input" : ("input", InterfaceConfigurations.InterfaceConfiguration.Qos.Input), "output" : ("output", InterfaceConfigurations.InterfaceConfiguration.Qos.Output)}
                self._child_list_classes = {}

                self.input = InterfaceConfigurations.InterfaceConfiguration.Qos.Input()
                self.input.parent = self
                self._children_name_map["input"] = "input"
                self._children_yang_names.add("input")

                self.output = InterfaceConfigurations.InterfaceConfiguration.Qos.Output()
                self.output.parent = self
                self._children_name_map["output"] = "output"
                self._children_yang_names.add("output")
                self._segment_path = lambda: "Cisco-IOS-XR-qos-ma-cfg:qos"


            class Input(Entity):
                """
                Ingress service policy
                
                .. attribute:: service_policy
                
                	Service policy details
                	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicy>`
                
                .. attribute:: service_policy_qos
                
                	Service policy details
                	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos>`
                
                

                """

                _prefix = 'qos-ma-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input, self).__init__()

                    self.yang_name = "input"
                    self.yang_parent_name = "qos"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicy), "service-policy-qos" : ("service_policy_qos", InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos)}

                    self.service_policy = YList(self)
                    self.service_policy_qos = YList(self)
                    self._segment_path = lambda: "input"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Input, [], name, value)


                class ServicePolicy(Entity):
                    """
                    Service policy details
                    
                    .. attribute:: service_policy_name  <key>
                    
                    	Name of policy\-map
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: account_type
                    
                    	Turn off L2 or L3 accounting
                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                    
                    .. attribute:: l1_user_defined
                    
                    	User specified value
                    	**type**\:  int
                    
                    	**range:** \-63..63
                    
                    .. attribute:: resource_id
                    
                    	Resource ID value
                    	**type**\:  int
                    
                    	**range:** 0..3
                    
                    .. attribute:: service_fragment_parent_policy
                    
                    	service\-fragment\-parent\-policy
                    	**type**\:  bool
                    
                    .. attribute:: spi_name
                    
                    	Name of the SPI
                    	**type**\:  str
                    
                    .. attribute:: subscriber_parent_policy
                    
                    	TRUE if service\-policy applied on svlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "input"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        self.account_type = YLeaf(YType.enumeration, "account-type")

                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                        self.spi_name = YLeaf(YType.str, "spi-name")

                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                        self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicy, ['service_policy_name', 'account_type', 'l1_user_defined', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                class ServicePolicyQos(Entity):
                    """
                    Service policy details
                    
                    .. attribute:: service_policy_name  <key>
                    
                    	Name of policy\-map
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: subscriber_group_names
                    
                    	Subscriber Group Name Details
                    	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames>`
                    
                    .. attribute:: subscriber_parent
                    
                    	Subscriber Parent Details
                    	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent>`
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos, self).__init__()

                        self.yang_name = "service-policy-qos"
                        self.yang_parent_name = "input"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"subscriber-group-names" : ("subscriber_group_names", InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames), "subscriber-parent" : ("subscriber_parent", InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent)}
                        self._child_list_classes = {}

                        self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames()
                        self.subscriber_group_names.parent = self
                        self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                        self._children_yang_names.add("subscriber-group-names")

                        self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent()
                        self.subscriber_parent.parent = self
                        self._children_name_map["subscriber_parent"] = "subscriber-parent"
                        self._children_yang_names.add("subscriber-parent")
                        self._segment_path = lambda: "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos, ['service_policy_name'], name, value)


                    class SubscriberGroupNames(Entity):
                        """
                        Subscriber Group Name Details
                        
                        .. attribute:: subscriber_group_name
                        
                        	Subscriber Group details
                        	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                            self.yang_name = "subscriber-group-names"
                            self.yang_parent_name = "service-policy-qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"subscriber-group-name" : ("subscriber_group_name", InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName)}

                            self.subscriber_group_name = YList(self)
                            self._segment_path = lambda: "subscriber-group-names"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames, [], name, value)


                        class SubscriberGroupName(Entity):
                            """
                            Subscriber Group details
                            
                            .. attribute:: subscriber_group_string  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: policy_merge
                            
                            	Not supported (Leave unspecified)
                            	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	TRUE if service\-policy applied is a service\-fragment policy)
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                self.yang_name = "subscriber-group-name"
                                self.yang_parent_name = "subscriber-group-names"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                self._segment_path = lambda: "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, ['subscriber_group_string', 'account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                    class SubscriberParent(Entity):
                        """
                        Subscriber Parent Details
                        
                        .. attribute:: account_type
                        
                        	Turn off L2 or L3 accounting
                        	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                        
                        .. attribute:: l1_user_defined
                        
                        	User specified value
                        	**type**\:  int
                        
                        	**range:** \-63..63
                        
                        .. attribute:: policy_merge
                        
                        	Not supported (Leave unspecified)
                        	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                        
                        .. attribute:: resource_id
                        
                        	Resource ID value
                        	**type**\:  int
                        
                        	**range:** 0..3
                        
                        .. attribute:: service_fragment_parent_policy
                        
                        	TRUE if service\-policy applied is a service\-fragment policy)
                        	**type**\:  bool
                        
                        .. attribute:: spi_name
                        
                        	Name of the SPI
                        	**type**\:  str
                        
                        .. attribute:: subscriber_parent_policy
                        
                        	TRUE if service\-policy applied on svlan
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent, self).__init__()

                            self.yang_name = "subscriber-parent"
                            self.yang_parent_name = "service-policy-qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.account_type = YLeaf(YType.enumeration, "account-type")

                            self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                            self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                            self.resource_id = YLeaf(YType.uint32, "resource-id")

                            self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                            self.spi_name = YLeaf(YType.str, "spi-name")

                            self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                            self._segment_path = lambda: "subscriber-parent"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Input.ServicePolicyQos.SubscriberParent, ['account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


            class Output(Entity):
                """
                Egress service policy
                
                .. attribute:: service_policy
                
                	Service policy details
                	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicy>`
                
                .. attribute:: service_policy_qos
                
                	Service policy details
                	**type**\: list of    :py:class:`ServicePolicyQos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos>`
                
                

                """

                _prefix = 'qos-ma-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output, self).__init__()

                    self.yang_name = "output"
                    self.yang_parent_name = "qos"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicy), "service-policy-qos" : ("service_policy_qos", InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos)}

                    self.service_policy = YList(self)
                    self.service_policy_qos = YList(self)
                    self._segment_path = lambda: "output"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Output, [], name, value)


                class ServicePolicy(Entity):
                    """
                    Service policy details
                    
                    .. attribute:: service_policy_name  <key>
                    
                    	Name of policy\-map
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: account_type
                    
                    	Turn off L2 or L3 accounting
                    	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                    
                    .. attribute:: l1_user_defined
                    
                    	User specified value
                    	**type**\:  int
                    
                    	**range:** \-63..63
                    
                    .. attribute:: resource_id
                    
                    	Resource ID value
                    	**type**\:  int
                    
                    	**range:** 0..3
                    
                    .. attribute:: service_fragment_parent_policy
                    
                    	service\-fragment\-parent\-policy
                    	**type**\:  bool
                    
                    .. attribute:: spi_name
                    
                    	Name of the SPI
                    	**type**\:  str
                    
                    .. attribute:: subscriber_parent_policy
                    
                    	TRUE if service\-policy applied on svlan
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicy, self).__init__()

                        self.yang_name = "service-policy"
                        self.yang_parent_name = "output"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        self.account_type = YLeaf(YType.enumeration, "account-type")

                        self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                        self.resource_id = YLeaf(YType.uint32, "resource-id")

                        self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                        self.spi_name = YLeaf(YType.str, "spi-name")

                        self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                        self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicy, ['service_policy_name', 'account_type', 'l1_user_defined', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                class ServicePolicyQos(Entity):
                    """
                    Service policy details
                    
                    .. attribute:: service_policy_name  <key>
                    
                    	Name of policy\-map
                    	**type**\:  str
                    
                    	**length:** 0..64
                    
                    .. attribute:: subscriber_group_names
                    
                    	Subscriber Group Name Details
                    	**type**\:   :py:class:`SubscriberGroupNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames>`
                    
                    .. attribute:: subscriber_parent
                    
                    	Subscriber Parent Details
                    	**type**\:   :py:class:`SubscriberParent <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent>`
                    
                    

                    """

                    _prefix = 'qos-ma-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos, self).__init__()

                        self.yang_name = "service-policy-qos"
                        self.yang_parent_name = "output"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"subscriber-group-names" : ("subscriber_group_names", InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames), "subscriber-parent" : ("subscriber_parent", InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent)}
                        self._child_list_classes = {}

                        self.service_policy_name = YLeaf(YType.str, "service-policy-name")

                        self.subscriber_group_names = InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames()
                        self.subscriber_group_names.parent = self
                        self._children_name_map["subscriber_group_names"] = "subscriber-group-names"
                        self._children_yang_names.add("subscriber-group-names")

                        self.subscriber_parent = InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent()
                        self.subscriber_parent.parent = self
                        self._children_name_map["subscriber_parent"] = "subscriber-parent"
                        self._children_yang_names.add("subscriber-parent")
                        self._segment_path = lambda: "service-policy-qos" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos, ['service_policy_name'], name, value)


                    class SubscriberGroupNames(Entity):
                        """
                        Subscriber Group Name Details
                        
                        .. attribute:: subscriber_group_name
                        
                        	Subscriber Group details
                        	**type**\: list of    :py:class:`SubscriberGroupName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName>`
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames, self).__init__()

                            self.yang_name = "subscriber-group-names"
                            self.yang_parent_name = "service-policy-qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"subscriber-group-name" : ("subscriber_group_name", InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName)}

                            self.subscriber_group_name = YList(self)
                            self._segment_path = lambda: "subscriber-group-names"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames, [], name, value)


                        class SubscriberGroupName(Entity):
                            """
                            Subscriber Group details
                            
                            .. attribute:: subscriber_group_string  <key>
                            
                            	Name of policy\-map
                            	**type**\:  str
                            
                            	**length:** 0..64
                            
                            .. attribute:: account_type
                            
                            	Turn off L2 or L3 accounting
                            	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                            
                            .. attribute:: l1_user_defined
                            
                            	User specified value
                            	**type**\:  int
                            
                            	**range:** \-63..63
                            
                            .. attribute:: policy_merge
                            
                            	Not supported (Leave unspecified)
                            	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                            
                            .. attribute:: resource_id
                            
                            	Resource ID value
                            	**type**\:  int
                            
                            	**range:** 0..3
                            
                            .. attribute:: service_fragment_parent_policy
                            
                            	TRUE if service\-policy applied is a service\-fragment policy)
                            	**type**\:  bool
                            
                            .. attribute:: spi_name
                            
                            	Name of the SPI
                            	**type**\:  str
                            
                            .. attribute:: subscriber_parent_policy
                            
                            	TRUE if service\-policy applied on svlan
                            	**type**\:  bool
                            
                            

                            """

                            _prefix = 'qos-ma-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, self).__init__()

                                self.yang_name = "subscriber-group-name"
                                self.yang_parent_name = "subscriber-group-names"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.subscriber_group_string = YLeaf(YType.str, "subscriber-group-string")

                                self.account_type = YLeaf(YType.enumeration, "account-type")

                                self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                                self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                                self.resource_id = YLeaf(YType.uint32, "resource-id")

                                self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                                self.spi_name = YLeaf(YType.str, "spi-name")

                                self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                                self._segment_path = lambda: "subscriber-group-name" + "[subscriber-group-string='" + self.subscriber_group_string.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberGroupNames.SubscriberGroupName, ['subscriber_group_string', 'account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


                    class SubscriberParent(Entity):
                        """
                        Subscriber Parent Details
                        
                        .. attribute:: account_type
                        
                        	Turn off L2 or L3 accounting
                        	**type**\:   :py:class:`QosPolicyAccount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosPolicyAccount>`
                        
                        .. attribute:: l1_user_defined
                        
                        	User specified value
                        	**type**\:  int
                        
                        	**range:** \-63..63
                        
                        .. attribute:: policy_merge
                        
                        	Not supported (Leave unspecified)
                        	**type**\:   :py:class:`QosFieldNotSupported <ydk.models.cisco_ios_xr.Cisco_IOS_XR_qos_ma_cfg.QosFieldNotSupported>`
                        
                        .. attribute:: resource_id
                        
                        	Resource ID value
                        	**type**\:  int
                        
                        	**range:** 0..3
                        
                        .. attribute:: service_fragment_parent_policy
                        
                        	TRUE if service\-policy applied is a service\-fragment policy)
                        	**type**\:  bool
                        
                        .. attribute:: spi_name
                        
                        	Name of the SPI
                        	**type**\:  str
                        
                        .. attribute:: subscriber_parent_policy
                        
                        	TRUE if service\-policy applied on svlan
                        	**type**\:  bool
                        
                        

                        """

                        _prefix = 'qos-ma-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent, self).__init__()

                            self.yang_name = "subscriber-parent"
                            self.yang_parent_name = "service-policy-qos"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.account_type = YLeaf(YType.enumeration, "account-type")

                            self.l1_user_defined = YLeaf(YType.int32, "l1-user-defined")

                            self.policy_merge = YLeaf(YType.enumeration, "policy-merge")

                            self.resource_id = YLeaf(YType.uint32, "resource-id")

                            self.service_fragment_parent_policy = YLeaf(YType.boolean, "service-fragment-parent-policy")

                            self.spi_name = YLeaf(YType.str, "spi-name")

                            self.subscriber_parent_policy = YLeaf(YType.boolean, "subscriber-parent-policy")
                            self._segment_path = lambda: "subscriber-parent"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Qos.Output.ServicePolicyQos.SubscriberParent, ['account_type', 'l1_user_defined', 'policy_merge', 'resource_id', 'service_fragment_parent_policy', 'spi_name', 'subscriber_parent_policy'], name, value)


        class ServicePolicies(Entity):
            """
            Interface control subscriber policy
            configuration
            
            .. attribute:: service_policy
            
            	Service policy to be applied to access interface  for subscribers
            	**type**\: list of    :py:class:`ServicePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.ServicePolicies.ServicePolicy>`
            
            

            """

            _prefix = 'iedge4710-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies, self).__init__()

                self.yang_name = "service-policies"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {"service-policy" : ("service_policy", InterfaceConfigurations.InterfaceConfiguration.ServicePolicies.ServicePolicy)}

                self.service_policy = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XR-iedge4710-cfg:service-policies"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies, [], name, value)


            class ServicePolicy(Entity):
                """
                Service policy to be applied to access
                interface  for subscribers
                
                .. attribute:: service_policy_name  <key>
                
                	Name of policy\-map
                	**type**\:  str
                
                	**length:** 1..63
                
                

                """

                _prefix = 'iedge4710-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies.ServicePolicy, self).__init__()

                    self.yang_name = "service-policy"
                    self.yang_parent_name = "service-policies"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.service_policy_name = YLeaf(YType.str, "service-policy-name")
                    self._segment_path = lambda: "service-policy" + "[service-policy-name='" + self.service_policy_name.get() + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.ServicePolicies.ServicePolicy, ['service_policy_name'], name, value)


        class SpanMonitorSessions(Entity):
            """
            Monitor Session container for this source
            interface
            
            .. attribute:: span_monitor_session
            
            	Configuration for a particular class of Monitor Session
            	**type**\: list of    :py:class:`SpanMonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession>`
            
            

            """

            _prefix = 'ethernet-span-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions, self).__init__()

                self.yang_name = "span-monitor-sessions"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {"span-monitor-session" : ("span_monitor_session", InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession)}

                self.span_monitor_session = YList(self)
                self._segment_path = lambda: "Cisco-IOS-XR-Ethernet-SPAN-cfg:span-monitor-sessions"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions, [], name, value)


            class SpanMonitorSession(Entity):
                """
                Configuration for a particular class of Monitor
                Session
                
                .. attribute:: session_class  <key>
                
                	Session Class
                	**type**\:   :py:class:`SpanSessionClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_datatypes.SpanSessionClass>`
                
                .. attribute:: acl
                
                	Enable ACL matching for traffic mirroring
                	**type**\:   :py:class:`Acl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Acl>`
                
                	**presence node**\: True
                
                .. attribute:: attachment
                
                	Attach the interface to a Monitor Session
                	**type**\:   :py:class:`Attachment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Attachment>`
                
                	**presence node**\: True
                
                .. attribute:: mirror_first
                
                	Mirror a specified number of bytes from start of packet
                	**type**\:  int
                
                	**range:** 1..10000
                
                	**units**\: byte
                
                .. attribute:: mirror_interval
                
                	Specify the mirror interval
                	**type**\:   :py:class:`SpanMirrorInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_cfg.SpanMirrorInterval>`
                
                

                """

                _prefix = 'ethernet-span-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession, self).__init__()

                    self.yang_name = "span-monitor-session"
                    self.yang_parent_name = "span-monitor-sessions"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"acl" : ("acl", InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Acl), "attachment" : ("attachment", InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Attachment)}
                    self._child_list_classes = {}

                    self.session_class = YLeaf(YType.enumeration, "session-class")

                    self.mirror_first = YLeaf(YType.uint32, "mirror-first")

                    self.mirror_interval = YLeaf(YType.enumeration, "mirror-interval")

                    self.acl = None
                    self._children_name_map["acl"] = "acl"
                    self._children_yang_names.add("acl")

                    self.attachment = None
                    self._children_name_map["attachment"] = "attachment"
                    self._children_yang_names.add("attachment")
                    self._segment_path = lambda: "span-monitor-session" + "[session-class='" + self.session_class.get() + "']"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession, ['session_class', 'mirror_first', 'mirror_interval'], name, value)


                class Acl(Entity):
                    """
                    Enable ACL matching for traffic mirroring
                    
                    .. attribute:: acl_enable
                    
                    	Enable ACL
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: acl_name
                    
                    	ACL Name
                    	**type**\:  str
                    
                    	**length:** 1..80
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ethernet-span-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Acl, self).__init__()

                        self.yang_name = "acl"
                        self.yang_parent_name = "span-monitor-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.acl_enable = YLeaf(YType.empty, "acl-enable")

                        self.acl_name = YLeaf(YType.str, "acl-name")
                        self._segment_path = lambda: "acl"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Acl, ['acl_enable', 'acl_name'], name, value)


                class Attachment(Entity):
                    """
                    Attach the interface to a Monitor Session
                    
                    .. attribute:: direction
                    
                    	Specify the direction of traffic to replicate (optional)
                    	**type**\:   :py:class:`SpanTrafficDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_Ethernet_SPAN_cfg.SpanTrafficDirection>`
                    
                    .. attribute:: port_level_enable
                    
                    	Enable port level traffic mirroring
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: session_name
                    
                    	Session Name
                    	**type**\:  str
                    
                    	**length:** 1..79
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'ethernet-span-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Attachment, self).__init__()

                        self.yang_name = "attachment"
                        self.yang_parent_name = "span-monitor-session"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.direction = YLeaf(YType.enumeration, "direction")

                        self.port_level_enable = YLeaf(YType.empty, "port-level-enable")

                        self.session_name = YLeaf(YType.str, "session-name")
                        self._segment_path = lambda: "attachment"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.SpanMonitorSessions.SpanMonitorSession.Attachment, ['direction', 'port_level_enable', 'session_name'], name, value)


        class SsrpSession(Entity):
            """
            SSRP Config
            
            .. attribute:: group_id
            
            	This specifies the SSRP group and session\-id
            	**type**\:   :py:class:`GroupId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId>`
            
            

            """

            _prefix = 'ppp-ma-ssrp-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.SsrpSession, self).__init__()

                self.yang_name = "ssrp-session"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"group-id" : ("group_id", InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId)}
                self._child_list_classes = {}

                self.group_id = InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId()
                self.group_id.parent = self
                self._children_name_map["group_id"] = "group-id"
                self._children_yang_names.add("group-id")
                self._segment_path = lambda: "Cisco-IOS-XR-ppp-ma-ssrp-cfg:ssrp-session"


            class GroupId(Entity):
                """
                This specifies the SSRP group and session\-id
                
                .. attribute:: group
                
                	SSRP Group\-ID
                	**type**\:  int
                
                	**range:** 1..65535
                
                .. attribute:: id
                
                	SSRP Session\-ID
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                

                """

                _prefix = 'ppp-ma-ssrp-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId, self).__init__()

                    self.yang_name = "group-id"
                    self.yang_parent_name = "ssrp-session"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.group = YLeaf(YType.uint32, "group")

                    self.id = YLeaf(YType.uint32, "id")
                    self._segment_path = lambda: "group-id"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.SsrpSession.GroupId, ['group', 'id'], name, value)


        class Statistics(Entity):
            """
            Per\-interface statistics configuration
            
            .. attribute:: load_interval
            
            	Specify interval for load calculation for an interface
            	**type**\:  int
            
            	**range:** 0..600
            
            	**default value**\: 300
            
            

            """

            _prefix = 'infra-statsd-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Statistics, self).__init__()

                self.yang_name = "statistics"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.load_interval = YLeaf(YType.uint32, "load-interval")
                self._segment_path = lambda: "Cisco-IOS-XR-infra-statsd-cfg:statistics"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Statistics, ['load_interval'], name, value)


        class Subscriber(Entity):
            """
            Subscribers on interface
            
            .. attribute:: ip_subscriber
            
            	IP subscribers on interface
            	**type**\:   :py:class:`IpSubscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber>`
            
            

            """

            _prefix = 'subscriber-ipsub-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber, self).__init__()

                self.yang_name = "subscriber"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"ip-subscriber" : ("ip_subscriber", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber)}
                self._child_list_classes = {}

                self.ip_subscriber = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber()
                self.ip_subscriber.parent = self
                self._children_name_map["ip_subscriber"] = "ip-subscriber"
                self._children_yang_names.add("ip-subscriber")
                self._segment_path = lambda: "Cisco-IOS-XR-subscriber-ipsub-cfg:subscriber"


            class IpSubscriber(Entity):
                """
                IP subscribers on interface
                
                .. attribute:: interface
                
                	Enable IP Static subscriber
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: ipv4
                
                	IPv4 subscriber
                	**type**\:   :py:class:`Ipv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4>`
                
                .. attribute:: ipv6
                
                	IPv6 subscriber
                	**type**\:   :py:class:`Ipv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6>`
                
                .. attribute:: session_limit
                
                	IP subscriber session limit
                	**type**\:   :py:class:`SessionLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit>`
                
                .. attribute:: subscriber_templates
                
                	Enable subscriber templates on this access interface
                	**type**\:  int
                
                	**range:** 1..10
                
                	**default value**\: 10
                
                

                """

                _prefix = 'subscriber-ipsub-cfg'
                _revision = '2015-11-09'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber, self).__init__()

                    self.yang_name = "ip-subscriber"
                    self.yang_parent_name = "subscriber"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"ipv4" : ("ipv4", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4), "ipv6" : ("ipv6", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6), "session-limit" : ("session_limit", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit)}
                    self._child_list_classes = {}

                    self.interface = YLeaf(YType.empty, "interface")

                    self.subscriber_templates = YLeaf(YType.uint32, "subscriber-templates")

                    self.ipv4 = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4()
                    self.ipv4.parent = self
                    self._children_name_map["ipv4"] = "ipv4"
                    self._children_yang_names.add("ipv4")

                    self.ipv6 = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6()
                    self.ipv6.parent = self
                    self._children_name_map["ipv6"] = "ipv6"
                    self._children_yang_names.add("ipv6")

                    self.session_limit = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit()
                    self.session_limit.parent = self
                    self._children_name_map["session_limit"] = "session-limit"
                    self._children_yang_names.add("session-limit")
                    self._segment_path = lambda: "ip-subscriber"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber, ['interface', 'subscriber_templates'], name, value)


                class Ipv4(Entity):
                    """
                    IPv4 subscriber
                    
                    .. attribute:: l2_connected
                    
                    	L2 connected IPv4 subscriber
                    	**type**\:   :py:class:`L2Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected>`
                    
                    .. attribute:: routed
                    
                    	Routed IPv4 subscriber
                    	**type**\:   :py:class:`Routed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed>`
                    
                    

                    """

                    _prefix = 'subscriber-ipsub-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4, self).__init__()

                        self.yang_name = "ipv4"
                        self.yang_parent_name = "ip-subscriber"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"l2-connected" : ("l2_connected", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected), "routed" : ("routed", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed)}
                        self._child_list_classes = {}

                        self.l2_connected = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected()
                        self.l2_connected.parent = self
                        self._children_name_map["l2_connected"] = "l2-connected"
                        self._children_yang_names.add("l2-connected")

                        self.routed = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed()
                        self.routed.parent = self
                        self._children_name_map["routed"] = "routed"
                        self._children_yang_names.add("routed")
                        self._segment_path = lambda: "ipv4"


                    class L2Connected(Entity):
                        """
                        L2 connected IPv4 subscriber
                        
                        .. attribute:: initiator
                        
                        	Configure IP subscriber initiator
                        	**type**\:   :py:class:`Initiator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator>`
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected, self).__init__()

                            self.yang_name = "l2-connected"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"initiator" : ("initiator", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator)}
                            self._child_list_classes = {}

                            self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator()
                            self.initiator.parent = self
                            self._children_name_map["initiator"] = "initiator"
                            self._children_yang_names.add("initiator")
                            self._segment_path = lambda: "l2-connected"


                        class Initiator(Entity):
                            """
                            Configure IP subscriber initiator
                            
                            .. attribute:: dhcp
                            
                            	Configure IP subscriber DHCP initiator
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: unclassified_source_fsol
                            
                            	Configure IP subscriber unclassified source initiator
                            	**type**\:   :py:class:`UnclassifiedSourceFsol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator.UnclassifiedSourceFsol>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'subscriber-ipsub-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator, self).__init__()

                                self.yang_name = "initiator"
                                self.yang_parent_name = "l2-connected"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"unclassified-source-fsol" : ("unclassified_source_fsol", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator.UnclassifiedSourceFsol)}
                                self._child_list_classes = {}

                                self.dhcp = YLeaf(YType.empty, "dhcp")

                                self.unclassified_source_fsol = None
                                self._children_name_map["unclassified_source_fsol"] = "unclassified-source-fsol"
                                self._children_yang_names.add("unclassified-source-fsol")
                                self._segment_path = lambda: "initiator"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator, ['dhcp'], name, value)


                            class UnclassifiedSourceFsol(Entity):
                                """
                                Configure IP subscriber unclassified source
                                initiator
                                
                                .. attribute:: address_unique
                                
                                	Check for subscriber IP uniqueness during first sign of life
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: enable
                                
                                	Enable unclassified source
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                	**mandatory**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'subscriber-ipsub-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator.UnclassifiedSourceFsol, self).__init__()

                                    self.yang_name = "unclassified-source-fsol"
                                    self.yang_parent_name = "initiator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}
                                    self.is_presence_container = True

                                    self.address_unique = YLeaf(YType.boolean, "address-unique")

                                    self.enable = YLeaf(YType.empty, "enable")
                                    self._segment_path = lambda: "unclassified-source-fsol"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.L2Connected.Initiator.UnclassifiedSourceFsol, ['address_unique', 'enable'], name, value)


                    class Routed(Entity):
                        """
                        Routed IPv4 subscriber
                        
                        .. attribute:: initiator
                        
                        	Configure IP subscriber initiator
                        	**type**\:   :py:class:`Initiator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator>`
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed, self).__init__()

                            self.yang_name = "routed"
                            self.yang_parent_name = "ipv4"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"initiator" : ("initiator", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator)}
                            self._child_list_classes = {}

                            self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator()
                            self.initiator.parent = self
                            self._children_name_map["initiator"] = "initiator"
                            self._children_yang_names.add("initiator")
                            self._segment_path = lambda: "routed"


                        class Initiator(Entity):
                            """
                            Configure IP subscriber initiator
                            
                            .. attribute:: dhcp
                            
                            	Configure IPv4 subscriber DHCP initiator
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: dhcp_snoop
                            
                            	Configure IPv4 subscriber DHCP Snoop initiator
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: unclassified_ip
                            
                            	Configure IPv4 subscriber unclassified source initiator
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            

                            """

                            _prefix = 'subscriber-ipsub-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator, self).__init__()

                                self.yang_name = "initiator"
                                self.yang_parent_name = "routed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.dhcp = YLeaf(YType.empty, "dhcp")

                                self.dhcp_snoop = YLeaf(YType.empty, "dhcp-snoop")

                                self.unclassified_ip = YLeaf(YType.empty, "unclassified-ip")
                                self._segment_path = lambda: "initiator"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv4.Routed.Initiator, ['dhcp', 'dhcp_snoop', 'unclassified_ip'], name, value)


                class Ipv6(Entity):
                    """
                    IPv6 subscriber
                    
                    .. attribute:: l2_connected
                    
                    	L2 connected IPv6 subscriber
                    	**type**\:   :py:class:`L2Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected>`
                    
                    .. attribute:: routed
                    
                    	Routed IPv6 subscriber
                    	**type**\:   :py:class:`Routed <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed>`
                    
                    

                    """

                    _prefix = 'subscriber-ipsub-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6, self).__init__()

                        self.yang_name = "ipv6"
                        self.yang_parent_name = "ip-subscriber"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"l2-connected" : ("l2_connected", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected), "routed" : ("routed", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed)}
                        self._child_list_classes = {}

                        self.l2_connected = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected()
                        self.l2_connected.parent = self
                        self._children_name_map["l2_connected"] = "l2-connected"
                        self._children_yang_names.add("l2-connected")

                        self.routed = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed()
                        self.routed.parent = self
                        self._children_name_map["routed"] = "routed"
                        self._children_yang_names.add("routed")
                        self._segment_path = lambda: "ipv6"


                    class L2Connected(Entity):
                        """
                        L2 connected IPv6 subscriber
                        
                        .. attribute:: initiator
                        
                        	Configure IPv6 subscriber initiator
                        	**type**\:   :py:class:`Initiator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator>`
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected, self).__init__()

                            self.yang_name = "l2-connected"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"initiator" : ("initiator", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator)}
                            self._child_list_classes = {}

                            self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator()
                            self.initiator.parent = self
                            self._children_name_map["initiator"] = "initiator"
                            self._children_yang_names.add("initiator")
                            self._segment_path = lambda: "l2-connected"


                        class Initiator(Entity):
                            """
                            Configure IPv6 subscriber initiator
                            
                            .. attribute:: dhcp
                            
                            	Configure IPv6 subscriber DHCP initiator
                            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                            
                            .. attribute:: unclassified_source_fsol
                            
                            	Configure IP subscriber unclassified source initiator
                            	**type**\:   :py:class:`UnclassifiedSourceFsol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator.UnclassifiedSourceFsol>`
                            
                            	**presence node**\: True
                            
                            

                            """

                            _prefix = 'subscriber-ipsub-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator, self).__init__()

                                self.yang_name = "initiator"
                                self.yang_parent_name = "l2-connected"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"unclassified-source-fsol" : ("unclassified_source_fsol", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator.UnclassifiedSourceFsol)}
                                self._child_list_classes = {}

                                self.dhcp = YLeaf(YType.empty, "dhcp")

                                self.unclassified_source_fsol = None
                                self._children_name_map["unclassified_source_fsol"] = "unclassified-source-fsol"
                                self._children_yang_names.add("unclassified-source-fsol")
                                self._segment_path = lambda: "initiator"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator, ['dhcp'], name, value)


                            class UnclassifiedSourceFsol(Entity):
                                """
                                Configure IP subscriber unclassified source
                                initiator
                                
                                .. attribute:: address_unique
                                
                                	Check for subscriber IP uniqueness during first sign of life
                                	**type**\:  bool
                                
                                	**default value**\: false
                                
                                .. attribute:: enable
                                
                                	Enable unclassified source
                                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                                
                                	**mandatory**\: True
                                
                                

                                This class is a :ref:`presence class<presence-class>`

                                """

                                _prefix = 'subscriber-ipsub-cfg'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator.UnclassifiedSourceFsol, self).__init__()

                                    self.yang_name = "unclassified-source-fsol"
                                    self.yang_parent_name = "initiator"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {}
                                    self.is_presence_container = True

                                    self.address_unique = YLeaf(YType.boolean, "address-unique")

                                    self.enable = YLeaf(YType.empty, "enable")
                                    self._segment_path = lambda: "unclassified-source-fsol"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.L2Connected.Initiator.UnclassifiedSourceFsol, ['address_unique', 'enable'], name, value)


                    class Routed(Entity):
                        """
                        Routed IPv6 subscriber
                        
                        .. attribute:: initiator
                        
                        	Configure IP subscriber initiator
                        	**type**\:   :py:class:`Initiator <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator>`
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed, self).__init__()

                            self.yang_name = "routed"
                            self.yang_parent_name = "ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"initiator" : ("initiator", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator)}
                            self._child_list_classes = {}

                            self.initiator = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator()
                            self.initiator.parent = self
                            self._children_name_map["initiator"] = "initiator"
                            self._children_yang_names.add("initiator")
                            self._segment_path = lambda: "routed"


                        class Initiator(Entity):
                            """
                            Configure IP subscriber initiator
                            
                            .. attribute:: dhcp
                            
                            	Configure IPv6 subscriber DHCP initiator
                            	**type**\:  int
                            
                            	**range:** 1..128
                            
                            	**default value**\: 128
                            
                            .. attribute:: dhcp_snoop
                            
                            	Configure IPv6 subscriber DHCP Snoop initiator
                            	**type**\:  int
                            
                            	**range:** 1..128
                            
                            	**default value**\: 128
                            
                            .. attribute:: unclassified_ip
                            
                            	Configure unclassified packets as first\-sign\-of\-life for IPv6 subscriber
                            	**type**\:  int
                            
                            	**range:** 1..128
                            
                            	**default value**\: 128
                            
                            

                            """

                            _prefix = 'subscriber-ipsub-cfg'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator, self).__init__()

                                self.yang_name = "initiator"
                                self.yang_parent_name = "routed"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.dhcp = YLeaf(YType.uint32, "dhcp")

                                self.dhcp_snoop = YLeaf(YType.uint32, "dhcp-snoop")

                                self.unclassified_ip = YLeaf(YType.uint32, "unclassified-ip")
                                self._segment_path = lambda: "initiator"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.Ipv6.Routed.Initiator, ['dhcp', 'dhcp_snoop', 'unclassified_ip'], name, value)


                class SessionLimit(Entity):
                    """
                    IP subscriber session limit
                    
                    .. attribute:: total
                    
                    	Session limit for all sources
                    	**type**\:   :py:class:`Total <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total>`
                    
                    .. attribute:: unclassified_source
                    
                    	Session limit for unclassified sources
                    	**type**\:   :py:class:`UnclassifiedSource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource>`
                    
                    

                    """

                    _prefix = 'subscriber-ipsub-cfg'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit, self).__init__()

                        self.yang_name = "session-limit"
                        self.yang_parent_name = "ip-subscriber"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"total" : ("total", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total), "unclassified-source" : ("unclassified_source", InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource)}
                        self._child_list_classes = {}

                        self.total = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total()
                        self.total.parent = self
                        self._children_name_map["total"] = "total"
                        self._children_yang_names.add("total")

                        self.unclassified_source = InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource()
                        self.unclassified_source.parent = self
                        self._children_name_map["unclassified_source"] = "unclassified-source"
                        self._children_yang_names.add("unclassified-source")
                        self._segment_path = lambda: "session-limit"


                    class Total(Entity):
                        """
                        Session limit for all sources
                        
                        .. attribute:: per_vlan
                        
                        	Configure per\-vlan session limit for all sources
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**default value**\: 0
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total, self).__init__()

                            self.yang_name = "total"
                            self.yang_parent_name = "session-limit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.per_vlan = YLeaf(YType.int32, "per-vlan")
                            self._segment_path = lambda: "total"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.Total, ['per_vlan'], name, value)


                    class UnclassifiedSource(Entity):
                        """
                        Session limit for unclassified sources
                        
                        .. attribute:: per_vlan
                        
                        	Configure per\-vlan session limit for unclassified sources
                        	**type**\:  int
                        
                        	**range:** \-2147483648..2147483647
                        
                        	**default value**\: 0
                        
                        

                        """

                        _prefix = 'subscriber-ipsub-cfg'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource, self).__init__()

                            self.yang_name = "unclassified-source"
                            self.yang_parent_name = "session-limit"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.per_vlan = YLeaf(YType.int32, "per-vlan")
                            self._segment_path = lambda: "unclassified-source"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Subscriber.IpSubscriber.SessionLimit.UnclassifiedSource, ['per_vlan'], name, value)


        class TransportProfileTunnel(Entity):
            """
            MPLS\-TP tunnel attributes
            
            .. attribute:: bfd
            
            	Configure BFD parameters
            	**type**\:   :py:class:`Bfd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd>`
            
            .. attribute:: destination
            
            	Node identifier and optional global identifier and tunnel identifier at destination
            	**type**\:   :py:class:`Destination <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination>`
            
            .. attribute:: fault
            
            	Fault management
            	**type**\:   :py:class:`Fault <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault>`
            
            .. attribute:: protect_lsp
            
            	Protect LSP
            	**type**\:   :py:class:`ProtectLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp>`
            
            .. attribute:: source
            
            	Transport profile node identifier in IPv4 address format
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: working_lsp
            
            	Working LSP
            	**type**\:   :py:class:`WorkingLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp>`
            
            

            """

            _prefix = 'mpls-te-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel, self).__init__()

                self.yang_name = "transport-profile-tunnel"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"bfd" : ("bfd", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd), "destination" : ("destination", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination), "fault" : ("fault", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault), "protect-lsp" : ("protect_lsp", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp), "working-lsp" : ("working_lsp", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp)}
                self._child_list_classes = {}

                self.source = YLeaf(YType.str, "source")

                self.bfd = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd()
                self.bfd.parent = self
                self._children_name_map["bfd"] = "bfd"
                self._children_yang_names.add("bfd")

                self.destination = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination()
                self.destination.parent = self
                self._children_name_map["destination"] = "destination"
                self._children_yang_names.add("destination")

                self.fault = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault()
                self.fault.parent = self
                self._children_name_map["fault"] = "fault"
                self._children_yang_names.add("fault")

                self.protect_lsp = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp()
                self.protect_lsp.parent = self
                self._children_name_map["protect_lsp"] = "protect-lsp"
                self._children_yang_names.add("protect-lsp")

                self.working_lsp = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp()
                self.working_lsp.parent = self
                self._children_name_map["working_lsp"] = "working-lsp"
                self._children_yang_names.add("working-lsp")
                self._segment_path = lambda: "Cisco-IOS-XR-mpls-te-cfg:transport-profile-tunnel"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel, ['source'], name, value)


            class Bfd(Entity):
                """
                Configure BFD parameters
                
                .. attribute:: detection_multiplier
                
                	Detect multiplier
                	**type**\:  int
                
                	**range:** 2..10
                
                .. attribute:: enable
                
                	Configure BFD parameters
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: min_interval
                
                	Hello interval, either in milli\-seconds or in micro\-seconds
                	**type**\:   :py:class:`MinInterval <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval>`
                
                .. attribute:: min_interval_standby
                
                	Hello interval for standby transport profile LSP, either in milli\-seconds or in micro\-seconds
                	**type**\:   :py:class:`MinIntervalStandby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby>`
                
                .. attribute:: multiplier_standby
                
                	Detect multiplier for standby transport profile LSP
                	**type**\:  int
                
                	**range:** 2..10
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd, self).__init__()

                    self.yang_name = "bfd"
                    self.yang_parent_name = "transport-profile-tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"min-interval" : ("min_interval", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval), "min-interval-standby" : ("min_interval_standby", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby)}
                    self._child_list_classes = {}

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.enable = YLeaf(YType.empty, "enable")

                    self.multiplier_standby = YLeaf(YType.uint32, "multiplier-standby")

                    self.min_interval = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval()
                    self.min_interval.parent = self
                    self._children_name_map["min_interval"] = "min-interval"
                    self._children_yang_names.add("min-interval")

                    self.min_interval_standby = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby()
                    self.min_interval_standby.parent = self
                    self._children_name_map["min_interval_standby"] = "min-interval-standby"
                    self._children_yang_names.add("min-interval-standby")
                    self._segment_path = lambda: "bfd"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd, ['detection_multiplier', 'enable', 'multiplier_standby'], name, value)


                class MinInterval(Entity):
                    """
                    Hello interval, either in milli\-seconds or in
                    micro\-seconds
                    
                    .. attribute:: interval_ms
                    
                    	Hello interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 3..5000
                    
                    .. attribute:: interval_us
                    
                    	Hello interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 3000..5000000
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval, self).__init__()

                        self.yang_name = "min-interval"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interval_ms = YLeaf(YType.uint32, "interval-ms")

                        self.interval_us = YLeaf(YType.uint32, "interval-us")
                        self._segment_path = lambda: "min-interval"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinInterval, ['interval_ms', 'interval_us'], name, value)


                class MinIntervalStandby(Entity):
                    """
                    Hello interval for standby transport profile
                    LSP, either in milli\-seconds or in
                    micro\-seconds
                    
                    .. attribute:: interval_standby_ms
                    
                    	Hello interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 3..5000
                    
                    .. attribute:: interval_standby_us
                    
                    	Hello interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 3000..5000000
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby, self).__init__()

                        self.yang_name = "min-interval-standby"
                        self.yang_parent_name = "bfd"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.interval_standby_ms = YLeaf(YType.uint32, "interval-standby-ms")

                        self.interval_standby_us = YLeaf(YType.uint32, "interval-standby-us")
                        self._segment_path = lambda: "min-interval-standby"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Bfd.MinIntervalStandby, ['interval_standby_ms', 'interval_standby_us'], name, value)


            class Destination(Entity):
                """
                Node identifier and optional global identifier
                and tunnel identifier at destination
                
                .. attribute:: global_id
                
                	Numeric global identifier
                	**type**\:  int
                
                	**range:** 1..65535
                
                .. attribute:: node_id
                
                	Node identifier in IPv4 address format
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: tunnel_id
                
                	Numeric tunnel identifier
                	**type**\:  int
                
                	**range:** 0..65535
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination, self).__init__()

                    self.yang_name = "destination"
                    self.yang_parent_name = "transport-profile-tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.global_id = YLeaf(YType.uint32, "global-id")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")
                    self._segment_path = lambda: "destination"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Destination, ['global_id', 'node_id', 'tunnel_id'], name, value)


            class Fault(Entity):
                """
                Fault management
                
                .. attribute:: enable
                
                	Enter transport profile tunnel fault configuration
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: protection_trigger
                
                	OAM events that trigger protection switching
                	**type**\:   :py:class:`ProtectionTrigger <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault, self).__init__()

                    self.yang_name = "fault"
                    self.yang_parent_name = "transport-profile-tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"protection-trigger" : ("protection_trigger", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger)}
                    self._child_list_classes = {}

                    self.enable = YLeaf(YType.empty, "enable")

                    self.protection_trigger = InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger()
                    self.protection_trigger.parent = self
                    self._children_name_map["protection_trigger"] = "protection-trigger"
                    self._children_yang_names.add("protection-trigger")
                    self._segment_path = lambda: "fault"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault, ['enable'], name, value)


                class ProtectionTrigger(Entity):
                    """
                    OAM events that trigger protection switching
                    
                    .. attribute:: ais
                    
                    	Enable protection switching due to AIS event
                    	**type**\:  bool
                    
                    .. attribute:: ldi
                    
                    	Enable protection switching due to LDI event
                    	**type**\:  bool
                    
                    .. attribute:: lkr
                    
                    	Enable protection switching due to LKR event
                    	**type**\:  bool
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger, self).__init__()

                        self.yang_name = "protection-trigger"
                        self.yang_parent_name = "fault"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.ais = YLeaf(YType.boolean, "ais")

                        self.ldi = YLeaf(YType.boolean, "ldi")

                        self.lkr = YLeaf(YType.boolean, "lkr")
                        self._segment_path = lambda: "protection-trigger"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.Fault.ProtectionTrigger, ['ais', 'ldi', 'lkr'], name, value)


            class ProtectLsp(Entity):
                """
                Protect LSP
                
                .. attribute:: in_label
                
                	Incoming MPLS label of the protect LSP
                	**type**\:  int
                
                	**range:** 16..4015
                
                .. attribute:: lockout
                
                	Enable lockout of protect LSP
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: lsp_id
                
                	LSP Identifier of the protect LSP
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**default value**\: 1
                
                .. attribute:: out_label
                
                	Outgoing MPLS label of the protect LSP
                	**type**\:   :py:class:`OutLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp.OutLabel>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp, self).__init__()

                    self.yang_name = "protect-lsp"
                    self.yang_parent_name = "transport-profile-tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"out-label" : ("out_label", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp.OutLabel)}
                    self._child_list_classes = {}

                    self.in_label = YLeaf(YType.uint32, "in-label")

                    self.lockout = YLeaf(YType.empty, "lockout")

                    self.lsp_id = YLeaf(YType.uint32, "lsp-id")

                    self.out_label = None
                    self._children_name_map["out_label"] = "out-label"
                    self._children_yang_names.add("out-label")
                    self._segment_path = lambda: "protect-lsp"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp, ['in_label', 'lockout', 'lsp_id'], name, value)


                class OutLabel(Entity):
                    """
                    Outgoing MPLS label of the protect LSP
                    
                    .. attribute:: label
                    
                    	MPLS label
                    	**type**\:  int
                    
                    	**range:** 16..1048575
                    
                    .. attribute:: link
                    
                    	Transport profile identifier of outgoing link
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp.OutLabel, self).__init__()

                        self.yang_name = "out-label"
                        self.yang_parent_name = "protect-lsp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.label = YLeaf(YType.uint32, "label")

                        self.link = YLeaf(YType.uint32, "link")
                        self._segment_path = lambda: "out-label"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.ProtectLsp.OutLabel, ['label', 'link'], name, value)


            class WorkingLsp(Entity):
                """
                Working LSP
                
                .. attribute:: in_label
                
                	Incoming MPLS label of the working LSP
                	**type**\:  int
                
                	**range:** 16..4015
                
                .. attribute:: lockout
                
                	Enable lockout of working LSP
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: lsp_id
                
                	LSP Identifier of the working LSP
                	**type**\:  int
                
                	**range:** 0..65535
                
                	**default value**\: 0
                
                .. attribute:: out_label
                
                	Outgoing MPLS label of the working LSP
                	**type**\:   :py:class:`OutLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp.OutLabel>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp, self).__init__()

                    self.yang_name = "working-lsp"
                    self.yang_parent_name = "transport-profile-tunnel"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"out-label" : ("out_label", InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp.OutLabel)}
                    self._child_list_classes = {}

                    self.in_label = YLeaf(YType.uint32, "in-label")

                    self.lockout = YLeaf(YType.empty, "lockout")

                    self.lsp_id = YLeaf(YType.uint32, "lsp-id")

                    self.out_label = None
                    self._children_name_map["out_label"] = "out-label"
                    self._children_yang_names.add("out-label")
                    self._segment_path = lambda: "working-lsp"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp, ['in_label', 'lockout', 'lsp_id'], name, value)


                class OutLabel(Entity):
                    """
                    Outgoing MPLS label of the working LSP
                    
                    .. attribute:: label
                    
                    	MPLS label
                    	**type**\:  int
                    
                    	**range:** 16..1048575
                    
                    .. attribute:: link
                    
                    	Transport profile identifier of outgoing link
                    	**type**\:  int
                    
                    	**range:** 1..65535
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp.OutLabel, self).__init__()

                        self.yang_name = "out-label"
                        self.yang_parent_name = "working-lsp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.label = YLeaf(YType.uint32, "label")

                        self.link = YLeaf(YType.uint32, "link")
                        self._segment_path = lambda: "out-label"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TransportProfileTunnel.WorkingLsp.OutLabel, ['label', 'link'], name, value)


        class TunnelIp(Entity):
            """
            IP over GRE encapsulation
            
            .. attribute:: allow_key
            
            	Enable flag bit to allow packets with GRE key
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: destination
            
            	Configure destination of tunnel
            	**type**\:   :py:class:`Destination <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination>`
            
            .. attribute:: disable
            
            	Disable DF bit (i.e. allow fragmentation)
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: keepalive
            
            	Enable keepalive packets on this tunnel
            	**type**\:   :py:class:`Keepalive <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive>`
            
            .. attribute:: key
            
            	Configure the key value for packets sent over this tunnel
            	**type**\:   :py:class:`Key <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key>`
            
            .. attribute:: mode
            
            	Tunnel encapsulation method
            	**type**\:   :py:class:`Mode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode>`
            
            .. attribute:: source
            
            	Configure source of tunnel
            	**type**\:   :py:class:`Source <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source>`
            
            .. attribute:: tos
            
            	Configure Type of Service bits for this tunnel
            	**type**\:  int
            
            	**range:** 0..255
            
            .. attribute:: ttl
            
            	Configure the time\-to\-live for packets sent over this tunnel
            	**type**\:  int
            
            	**range:** 1..255
            
            .. attribute:: tunnel_vrf
            
            	Tunnel vrf label name
            	**type**\:  str
            
            	**length:** 1..32
            
            

            """

            _prefix = 'tunnel-gre-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp, self).__init__()

                self.yang_name = "tunnel-ip"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"destination" : ("destination", InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination), "keepalive" : ("keepalive", InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive), "key" : ("key", InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key), "mode" : ("mode", InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode), "source" : ("source", InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source)}
                self._child_list_classes = {}

                self.allow_key = YLeaf(YType.empty, "allow-key")

                self.disable = YLeaf(YType.int32, "disable")

                self.tos = YLeaf(YType.uint32, "tos")

                self.ttl = YLeaf(YType.uint32, "ttl")

                self.tunnel_vrf = YLeaf(YType.str, "tunnel-vrf")

                self.destination = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination()
                self.destination.parent = self
                self._children_name_map["destination"] = "destination"
                self._children_yang_names.add("destination")

                self.keepalive = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive()
                self.keepalive.parent = self
                self._children_name_map["keepalive"] = "keepalive"
                self._children_yang_names.add("keepalive")

                self.key = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key()
                self.key.parent = self
                self._children_name_map["key"] = "key"
                self._children_yang_names.add("key")

                self.mode = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode()
                self.mode.parent = self
                self._children_name_map["mode"] = "mode"
                self._children_yang_names.add("mode")

                self.source = InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source()
                self.source.parent = self
                self._children_name_map["source"] = "source"
                self._children_yang_names.add("source")
                self._segment_path = lambda: "Cisco-IOS-XR-tunnel-gre-cfg:tunnel-ip"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelIp, ['allow_key', 'disable', 'tos', 'ttl', 'tunnel_vrf'], name, value)


            class Destination(Entity):
                """
                Configure destination of tunnel
                
                .. attribute:: address
                
                	IPV4 address of the tunnel destination
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: address_mask
                
                	IPv4 prefix length of the tunnel destination
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ipv6_address
                
                	IPV6 address of the tunnel destination
                	**type**\:  str
                
                .. attribute:: prefix_list_name
                
                	Prefix\-list to validate destination's resolving prefix
                	**type**\:  str
                
                	**length:** 1..64
                
                .. attribute:: type
                
                	1 for IPv4 Address, 2 for IPv6 Address
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination, self).__init__()

                    self.yang_name = "destination"
                    self.yang_parent_name = "tunnel-ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.address = YLeaf(YType.str, "address")

                    self.address_mask = YLeaf(YType.str, "address-mask")

                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    self.prefix_list_name = YLeaf(YType.str, "prefix-list-name")

                    self.type = YLeaf(YType.int32, "type")
                    self._segment_path = lambda: "destination"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Destination, ['address', 'address_mask', 'ipv6_address', 'prefix_list_name', 'type'], name, value)


            class Keepalive(Entity):
                """
                Enable keepalive packets on this tunnel
                
                .. attribute:: keep_alive_period
                
                	Keepalive period in seconds (default 10 seconds)
                	**type**\:  int
                
                	**range:** 1..32767
                
                .. attribute:: keep_alive_retries
                
                	Number of retries (default 3)
                	**type**\:  int
                
                	**range:** 1..255
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive, self).__init__()

                    self.yang_name = "keepalive"
                    self.yang_parent_name = "tunnel-ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.keep_alive_period = YLeaf(YType.uint32, "keep-alive-period")

                    self.keep_alive_retries = YLeaf(YType.uint32, "keep-alive-retries")
                    self._segment_path = lambda: "keepalive"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Keepalive, ['keep_alive_period', 'keep_alive_retries'], name, value)


            class Key(Entity):
                """
                Configure the key value for packets sent over
                this tunnel
                
                .. attribute:: entropy
                
                	Always set to true
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: value
                
                	Enter the KEY value
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key, self).__init__()

                    self.yang_name = "key"
                    self.yang_parent_name = "tunnel-ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.entropy = YLeaf(YType.empty, "entropy")

                    self.value = YLeaf(YType.uint32, "value")
                    self._segment_path = lambda: "key"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Key, ['entropy', 'value'], name, value)


            class Mode(Entity):
                """
                Tunnel encapsulation method
                
                .. attribute:: mode_direction
                
                	Tunnel Mode Direction
                	**type**\:   :py:class:`TunnelModeDirection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_tunnel_gre_cfg.TunnelModeDirection>`
                
                .. attribute:: value
                
                	GRE IPV4 \- 1, GRE IPV6 \- 2, MGRE IPV4 \- 3, MGRE IPV6 \-4. IPV4 \- 5, IPV6 \- 6
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode, self).__init__()

                    self.yang_name = "mode"
                    self.yang_parent_name = "tunnel-ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.mode_direction = YLeaf(YType.enumeration, "mode-direction")

                    self.value = YLeaf(YType.int32, "value")
                    self._segment_path = lambda: "mode"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Mode, ['mode_direction', 'value'], name, value)


            class Source(Entity):
                """
                Configure source of tunnel
                
                .. attribute:: address
                
                	IPV4 address of the tunnel source
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: interface_name
                
                	Name of tunnel source interface
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: ipv6_address
                
                	IPV6 address of the tunnel source
                	**type**\:  str
                
                .. attribute:: type
                
                	1 for Interface Name, 2 for IPv4 Address, 3 for IPv6 Address
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'tunnel-gre-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source, self).__init__()

                    self.yang_name = "source"
                    self.yang_parent_name = "tunnel-ip"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.address = YLeaf(YType.str, "address")

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.ipv6_address = YLeaf(YType.str, "ipv6-address")

                    self.type = YLeaf(YType.int32, "type")
                    self._segment_path = lambda: "source"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelIp.Source, ['address', 'interface_name', 'ipv6_address', 'type'], name, value)


        class TunnelTeAttributes(Entity):
            """
            MPLS tunnel attributes
            
            .. attribute:: admin_mode
            
            	Performs admin operations on the optical tunnel interface
            	**type**\:   :py:class:`AdminMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode>`
            
            .. attribute:: affinity_mask
            
            	Set the affinity flags and mask
            	**type**\:   :py:class:`AffinityMask <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AffinityMask>`
            
            	**presence node**\: True
            
            .. attribute:: auto_bandwidth
            
            	Tunnel Interface Auto\-bandwidth configuration data
            	**type**\:   :py:class:`AutoBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth>`
            
            .. attribute:: autoroute
            
            	Parameters for IGP routing over tunnel
            	**type**\:   :py:class:`Autoroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute>`
            
            .. attribute:: backup_bandwidth
            
            	Tunnel backup bandwidth requirement
            	**type**\:   :py:class:`BackupBandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth>`
            
            .. attribute:: bandwidth
            
            	Tunnel bandwidth requirement
            	**type**\:   :py:class:`Bandwidth <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bandwidth>`
            
            	**presence node**\: True
            
            .. attribute:: bfd_over_lsp
            
            	BFD over TE LSP
            	**type**\:   :py:class:`BfdOverLsp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp>`
            
            .. attribute:: bidirectional
            
            	Tunnel Interface Bidirectional configuration data
            	**type**\:   :py:class:`Bidirectional <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional>`
            
            .. attribute:: binding_segment_id_mpls
            
            	Allocate MPLS binding segment ID
            	**type**\:   :py:class:`BindingSegmentIdMpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls>`
            
            .. attribute:: destination
            
            	Set the destination of the tunnel
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fast_reroute
            
            	Specify MPLS tunnel can be fast\-rerouted
            	**type**\:   :py:class:`FastReroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.FastReroute>`
            
            	**presence node**\: True
            
            .. attribute:: forward_class
            
            	Forward class value
            	**type**\:  int
            
            	**range:** 1..7
            
            .. attribute:: forwarding_adjacency
            
            	Forwarding adjacency announcement to IGP
            	**type**\:   :py:class:`ForwardingAdjacency <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency>`
            
            .. attribute:: load_share
            
            	Tunnel loadsharing metric
            	**type**\:  int
            
            	**range:** 1..4294967295
            
            .. attribute:: logging
            
            	Log tunnel LSP messages
            	**type**\:   :py:class:`Logging <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging>`
            
            .. attribute:: new_style_affinity_affinity_types
            
            	Tunnel new style affinity attributes table
            	**type**\:   :py:class:`NewStyleAffinityAffinityTypes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes>`
            
            .. attribute:: path_option_protects
            
            	Tunnel path protection state
            	**type**\:   :py:class:`PathOptionProtects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects>`
            
            .. attribute:: path_protection
            
            	Specify MPLS tunnel to be path protected
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: path_selection_metric
            
            	Path selection metric to use in path calculation
            	**type**\:   :py:class:`MplsTePathSelectionMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathSelectionMetric>`
            
            .. attribute:: pce
            
            	PCE config
            	**type**\:   :py:class:`Pce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce>`
            
            .. attribute:: policy_classes
            
            	Policy classes for PBTS
            	**type**\:   :py:class:`PolicyClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses>`
            
            .. attribute:: priority
            
            	Tunnel Setup and Hold Priorities
            	**type**\:   :py:class:`Priority <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Priority>`
            
            	**presence node**\: True
            
            .. attribute:: record_route
            
            	Record the route used by the tunnel
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: signalled_name
            
            	The name of the tunnel to be included in signalling messages
            	**type**\:  str
            
            	**length:** 1..254
            
            .. attribute:: soft_preemption
            
            	Enable the soft\-preemption feature on the tunnel
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: switching
            
            	Specify tunnel LSPs switching capability descriptor
            	**type**\:   :py:class:`Switching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching>`
            
            .. attribute:: tunnel_path_selection
            
            	Configure path selection properties
            	**type**\:   :py:class:`TunnelPathSelection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection>`
            
            

            """

            _prefix = 'mpls-te-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes, self).__init__()

                self.yang_name = "tunnel-te-attributes"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"admin-mode" : ("admin_mode", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode), "affinity-mask" : ("affinity_mask", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AffinityMask), "auto-bandwidth" : ("auto_bandwidth", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth), "autoroute" : ("autoroute", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute), "backup-bandwidth" : ("backup_bandwidth", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth), "bandwidth" : ("bandwidth", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bandwidth), "bfd-over-lsp" : ("bfd_over_lsp", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp), "bidirectional" : ("bidirectional", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional), "binding-segment-id-mpls" : ("binding_segment_id_mpls", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls), "fast-reroute" : ("fast_reroute", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.FastReroute), "forwarding-adjacency" : ("forwarding_adjacency", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency), "logging" : ("logging", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging), "new-style-affinity-affinity-types" : ("new_style_affinity_affinity_types", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes), "path-option-protects" : ("path_option_protects", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects), "pce" : ("pce", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce), "policy-classes" : ("policy_classes", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses), "priority" : ("priority", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Priority), "switching" : ("switching", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching), "tunnel-path-selection" : ("tunnel_path_selection", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection)}
                self._child_list_classes = {}

                self.destination = YLeaf(YType.str, "destination")

                self.forward_class = YLeaf(YType.uint32, "forward-class")

                self.load_share = YLeaf(YType.uint32, "load-share")

                self.path_protection = YLeaf(YType.empty, "path-protection")

                self.path_selection_metric = YLeaf(YType.enumeration, "path-selection-metric")

                self.record_route = YLeaf(YType.empty, "record-route")

                self.signalled_name = YLeaf(YType.str, "signalled-name")

                self.soft_preemption = YLeaf(YType.empty, "soft-preemption")

                self.admin_mode = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode()
                self.admin_mode.parent = self
                self._children_name_map["admin_mode"] = "admin-mode"
                self._children_yang_names.add("admin-mode")

                self.affinity_mask = None
                self._children_name_map["affinity_mask"] = "affinity-mask"
                self._children_yang_names.add("affinity-mask")

                self.auto_bandwidth = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth()
                self.auto_bandwidth.parent = self
                self._children_name_map["auto_bandwidth"] = "auto-bandwidth"
                self._children_yang_names.add("auto-bandwidth")

                self.autoroute = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute()
                self.autoroute.parent = self
                self._children_name_map["autoroute"] = "autoroute"
                self._children_yang_names.add("autoroute")

                self.backup_bandwidth = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth()
                self.backup_bandwidth.parent = self
                self._children_name_map["backup_bandwidth"] = "backup-bandwidth"
                self._children_yang_names.add("backup-bandwidth")

                self.bandwidth = None
                self._children_name_map["bandwidth"] = "bandwidth"
                self._children_yang_names.add("bandwidth")

                self.bfd_over_lsp = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp()
                self.bfd_over_lsp.parent = self
                self._children_name_map["bfd_over_lsp"] = "bfd-over-lsp"
                self._children_yang_names.add("bfd-over-lsp")

                self.bidirectional = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional()
                self.bidirectional.parent = self
                self._children_name_map["bidirectional"] = "bidirectional"
                self._children_yang_names.add("bidirectional")

                self.binding_segment_id_mpls = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls()
                self.binding_segment_id_mpls.parent = self
                self._children_name_map["binding_segment_id_mpls"] = "binding-segment-id-mpls"
                self._children_yang_names.add("binding-segment-id-mpls")

                self.fast_reroute = None
                self._children_name_map["fast_reroute"] = "fast-reroute"
                self._children_yang_names.add("fast-reroute")

                self.forwarding_adjacency = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency()
                self.forwarding_adjacency.parent = self
                self._children_name_map["forwarding_adjacency"] = "forwarding-adjacency"
                self._children_yang_names.add("forwarding-adjacency")

                self.logging = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging()
                self.logging.parent = self
                self._children_name_map["logging"] = "logging"
                self._children_yang_names.add("logging")

                self.new_style_affinity_affinity_types = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes()
                self.new_style_affinity_affinity_types.parent = self
                self._children_name_map["new_style_affinity_affinity_types"] = "new-style-affinity-affinity-types"
                self._children_yang_names.add("new-style-affinity-affinity-types")

                self.path_option_protects = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects()
                self.path_option_protects.parent = self
                self._children_name_map["path_option_protects"] = "path-option-protects"
                self._children_yang_names.add("path-option-protects")

                self.pce = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce()
                self.pce.parent = self
                self._children_name_map["pce"] = "pce"
                self._children_yang_names.add("pce")

                self.policy_classes = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses()
                self.policy_classes.parent = self
                self._children_name_map["policy_classes"] = "policy-classes"
                self._children_yang_names.add("policy-classes")

                self.priority = None
                self._children_name_map["priority"] = "priority"
                self._children_yang_names.add("priority")

                self.switching = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching()
                self.switching.parent = self
                self._children_name_map["switching"] = "switching"
                self._children_yang_names.add("switching")

                self.tunnel_path_selection = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection()
                self.tunnel_path_selection.parent = self
                self._children_name_map["tunnel_path_selection"] = "tunnel-path-selection"
                self._children_yang_names.add("tunnel-path-selection")
                self._segment_path = lambda: "Cisco-IOS-XR-mpls-te-cfg:tunnel-te-attributes"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes, ['destination', 'forward_class', 'load_share', 'path_protection', 'path_selection_metric', 'record_route', 'signalled_name', 'soft_preemption'], name, value)


            class AdminMode(Entity):
                """
                Performs admin operations on the optical tunnel
                interface
                
                .. attribute:: deactivate_tunnel
                
                	Performs signalling operation to deactivate optical tunnel
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode, self).__init__()

                    self.yang_name = "admin-mode"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.deactivate_tunnel = YLeaf(YType.empty, "deactivate-tunnel")
                    self._segment_path = lambda: "admin-mode"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AdminMode, ['deactivate_tunnel'], name, value)


            class AffinityMask(Entity):
                """
                Set the affinity flags and mask
                
                .. attribute:: affinity
                
                	Affinity flags
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                	**mandatory**\: True
                
                .. attribute:: mask
                
                	Affinity mask
                	**type**\:  str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AffinityMask, self).__init__()

                    self.yang_name = "affinity-mask"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.affinity = YLeaf(YType.str, "affinity")

                    self.mask = YLeaf(YType.str, "mask")
                    self._segment_path = lambda: "affinity-mask"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AffinityMask, ['affinity', 'mask'], name, value)


            class AutoBandwidth(Entity):
                """
                Tunnel Interface Auto\-bandwidth configuration
                data
                
                .. attribute:: adjustment_threshold
                
                	Set the bandwidth change threshold to trigger adjustment
                	**type**\:   :py:class:`AdjustmentThreshold <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.AdjustmentThreshold>`
                
                	**presence node**\: True
                
                .. attribute:: application_frequency
                
                	Set the tunnel auto\-bw application frequency in minutes
                	**type**\:  int
                
                	**range:** 5..10080
                
                	**units**\: minute
                
                .. attribute:: bandwidth_limits
                
                	Set min/max bandwidth auto\-bw can apply on a tunnel
                	**type**\:   :py:class:`BandwidthLimits <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.BandwidthLimits>`
                
                	**presence node**\: True
                
                .. attribute:: collection_only
                
                	Enable bandwidth collection only, no auto\-bw adjustment
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: enabled
                
                	This object is only valid for tunnel interfaces and it controls whether that interface has auto\-bw enabled on it or not.The object must be set before any other auto\-bw configuration is supplied for the interface, and must be the last auto\-bw configuration object to be removed 
                	**type**\:  bool
                
                .. attribute:: overflow
                
                	Configuring the tunnel overflow detection
                	**type**\:   :py:class:`Overflow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Overflow>`
                
                	**presence node**\: True
                
                .. attribute:: overflow_enable
                
                	Enable auto bandwidth overflow detection
                	**type**\:  bool
                
                .. attribute:: underflow
                
                	Configuring the tunnel underflow detection
                	**type**\:   :py:class:`Underflow <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Underflow>`
                
                	**presence node**\: True
                
                .. attribute:: underflow_enable
                
                	Enable auto bandwidth underflow detection
                	**type**\:  bool
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth, self).__init__()

                    self.yang_name = "auto-bandwidth"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"adjustment-threshold" : ("adjustment_threshold", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.AdjustmentThreshold), "bandwidth-limits" : ("bandwidth_limits", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.BandwidthLimits), "overflow" : ("overflow", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Overflow), "underflow" : ("underflow", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Underflow)}
                    self._child_list_classes = {}

                    self.application_frequency = YLeaf(YType.uint32, "application-frequency")

                    self.collection_only = YLeaf(YType.empty, "collection-only")

                    self.enabled = YLeaf(YType.boolean, "enabled")

                    self.overflow_enable = YLeaf(YType.boolean, "overflow-enable")

                    self.underflow_enable = YLeaf(YType.boolean, "underflow-enable")

                    self.adjustment_threshold = None
                    self._children_name_map["adjustment_threshold"] = "adjustment-threshold"
                    self._children_yang_names.add("adjustment-threshold")

                    self.bandwidth_limits = None
                    self._children_name_map["bandwidth_limits"] = "bandwidth-limits"
                    self._children_yang_names.add("bandwidth-limits")

                    self.overflow = None
                    self._children_name_map["overflow"] = "overflow"
                    self._children_yang_names.add("overflow")

                    self.underflow = None
                    self._children_name_map["underflow"] = "underflow"
                    self._children_yang_names.add("underflow")
                    self._segment_path = lambda: "auto-bandwidth"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth, ['application_frequency', 'collection_only', 'enabled', 'overflow_enable', 'underflow_enable'], name, value)


                class AdjustmentThreshold(Entity):
                    """
                    Set the bandwidth change threshold to trigger
                    adjustment
                    
                    .. attribute:: adjustment_threshold_percent
                    
                    	Bandwidth change percent to trigger adjustment
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    	**mandatory**\: True
                    
                    	**units**\: percentage
                    
                    .. attribute:: adjustment_threshold_value
                    
                    	Bandwidth change value to trigger adjustment (kbps)
                    	**type**\:  int
                    
                    	**range:** 10..4294967295
                    
                    	**mandatory**\: True
                    
                    	**units**\: kbit/s
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.AdjustmentThreshold, self).__init__()

                        self.yang_name = "adjustment-threshold"
                        self.yang_parent_name = "auto-bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.adjustment_threshold_percent = YLeaf(YType.uint32, "adjustment-threshold-percent")

                        self.adjustment_threshold_value = YLeaf(YType.uint32, "adjustment-threshold-value")
                        self._segment_path = lambda: "adjustment-threshold"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.AdjustmentThreshold, ['adjustment_threshold_percent', 'adjustment_threshold_value'], name, value)


                class BandwidthLimits(Entity):
                    """
                    Set min/max bandwidth auto\-bw can apply on a
                    tunnel
                    
                    .. attribute:: bandwidth_max_limit
                    
                    	Set maximum bandwidth auto\-bw can apply on a tunnel
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**mandatory**\: True
                    
                    .. attribute:: bandwidth_min_limit
                    
                    	Set minimum bandwidth auto\-bw can apply on a tunnel
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.BandwidthLimits, self).__init__()

                        self.yang_name = "bandwidth-limits"
                        self.yang_parent_name = "auto-bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.bandwidth_max_limit = YLeaf(YType.uint32, "bandwidth-max-limit")

                        self.bandwidth_min_limit = YLeaf(YType.uint32, "bandwidth-min-limit")
                        self._segment_path = lambda: "bandwidth-limits"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.BandwidthLimits, ['bandwidth_max_limit', 'bandwidth_min_limit'], name, value)


                class Overflow(Entity):
                    """
                    Configuring the tunnel overflow detection
                    
                    .. attribute:: overflow_threshold_limit
                    
                    	Number of consecutive collections exceeding threshold
                    	**type**\:  int
                    
                    	**range:** 1..10
                    
                    	**mandatory**\: True
                    
                    .. attribute:: overflow_threshold_percent
                    
                    	Bandwidth change percent to trigger an overflow
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    	**mandatory**\: True
                    
                    	**units**\: percentage
                    
                    .. attribute:: overflow_threshold_value
                    
                    	Bandwidth change value to trigger an overflow (kbps)
                    	**type**\:  int
                    
                    	**range:** 10..4294967295
                    
                    	**mandatory**\: True
                    
                    	**units**\: kbit/s
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Overflow, self).__init__()

                        self.yang_name = "overflow"
                        self.yang_parent_name = "auto-bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.overflow_threshold_limit = YLeaf(YType.uint32, "overflow-threshold-limit")

                        self.overflow_threshold_percent = YLeaf(YType.uint32, "overflow-threshold-percent")

                        self.overflow_threshold_value = YLeaf(YType.uint32, "overflow-threshold-value")
                        self._segment_path = lambda: "overflow"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Overflow, ['overflow_threshold_limit', 'overflow_threshold_percent', 'overflow_threshold_value'], name, value)


                class Underflow(Entity):
                    """
                    Configuring the tunnel underflow detection
                    
                    .. attribute:: underflow_threshold_limit
                    
                    	Number of consecutive collections exceeding threshold
                    	**type**\:  int
                    
                    	**range:** 1..10
                    
                    	**mandatory**\: True
                    
                    .. attribute:: underflow_threshold_percent
                    
                    	Bandwidth change percent to trigger an underflow
                    	**type**\:  int
                    
                    	**range:** 1..100
                    
                    	**mandatory**\: True
                    
                    	**units**\: percentage
                    
                    .. attribute:: underflow_threshold_value
                    
                    	Bandwidth change value to trigger an underflow (kbps)
                    	**type**\:  int
                    
                    	**range:** 10..4294967295
                    
                    	**mandatory**\: True
                    
                    	**units**\: kbit/s
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Underflow, self).__init__()

                        self.yang_name = "underflow"
                        self.yang_parent_name = "auto-bandwidth"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.underflow_threshold_limit = YLeaf(YType.uint32, "underflow-threshold-limit")

                        self.underflow_threshold_percent = YLeaf(YType.uint32, "underflow-threshold-percent")

                        self.underflow_threshold_value = YLeaf(YType.uint32, "underflow-threshold-value")
                        self._segment_path = lambda: "underflow"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.AutoBandwidth.Underflow, ['underflow_threshold_limit', 'underflow_threshold_percent', 'underflow_threshold_value'], name, value)


            class Autoroute(Entity):
                """
                Parameters for IGP routing over tunnel
                
                .. attribute:: autoroute_announce
                
                	Announce tunnel to IGP
                	**type**\:   :py:class:`AutorouteAnnounce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce>`
                
                .. attribute:: destinations
                
                	Tunnel Autoroute Destination(s)
                	**type**\:   :py:class:`Destinations <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.Destinations>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute, self).__init__()

                    self.yang_name = "autoroute"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"autoroute-announce" : ("autoroute_announce", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce), "destinations" : ("destinations", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.Destinations)}
                    self._child_list_classes = {}

                    self.autoroute_announce = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce()
                    self.autoroute_announce.parent = self
                    self._children_name_map["autoroute_announce"] = "autoroute-announce"
                    self._children_yang_names.add("autoroute-announce")

                    self.destinations = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.Destinations()
                    self.destinations.parent = self
                    self._children_name_map["destinations"] = "destinations"
                    self._children_yang_names.add("destinations")
                    self._segment_path = lambda: "autoroute"


                class AutorouteAnnounce(Entity):
                    """
                    Announce tunnel to IGP
                    
                    .. attribute:: enable
                    
                    	Enable autoroute announce
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: exclude_traffic
                    
                    	Exclude traffic on autorouted tunnel
                    	**type**\:   :py:class:`ExcludeTraffic <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic>`
                    
                    .. attribute:: include_ipv6
                    
                    	Specify that the tunnel should be an IPv6 autoroute announce also
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: metric
                    
                    	Specify MPLS tunnel metric
                    	**type**\:   :py:class:`Metric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce, self).__init__()

                        self.yang_name = "autoroute-announce"
                        self.yang_parent_name = "autoroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"exclude-traffic" : ("exclude_traffic", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic), "metric" : ("metric", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric)}
                        self._child_list_classes = {}

                        self.enable = YLeaf(YType.empty, "enable")

                        self.include_ipv6 = YLeaf(YType.empty, "include-ipv6")

                        self.exclude_traffic = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic()
                        self.exclude_traffic.parent = self
                        self._children_name_map["exclude_traffic"] = "exclude-traffic"
                        self._children_yang_names.add("exclude-traffic")

                        self.metric = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric()
                        self.metric.parent = self
                        self._children_name_map["metric"] = "metric"
                        self._children_yang_names.add("metric")
                        self._segment_path = lambda: "autoroute-announce"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce, ['enable', 'include_ipv6'], name, value)


                    class ExcludeTraffic(Entity):
                        """
                        Exclude traffic on autorouted tunnel
                        
                        .. attribute:: segment_routing
                        
                        	Exclude tunnel in IGP for SR prefixes
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic, self).__init__()

                            self.yang_name = "exclude-traffic"
                            self.yang_parent_name = "autoroute-announce"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.segment_routing = YLeaf(YType.empty, "segment-routing")
                            self._segment_path = lambda: "exclude-traffic"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.ExcludeTraffic, ['segment_routing'], name, value)


                    class Metric(Entity):
                        """
                        Specify MPLS tunnel metric
                        
                        .. attribute:: absolute_metric
                        
                        	The absolute metric value
                        	**type**\:  int
                        
                        	**range:** 1..2147483647
                        
                        .. attribute:: constant_metric
                        
                        	The constant metric value
                        	**type**\:  int
                        
                        	**range:** 1..2147483647
                        
                        .. attribute:: metric_type
                        
                        	Autoroute tunnel metric type
                        	**type**\:   :py:class:`MplsTeAutorouteMetric <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeAutorouteMetric>`
                        
                        .. attribute:: relative_metric
                        
                        	The value of the adjustment
                        	**type**\:  int
                        
                        	**range:** \-10..10
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric, self).__init__()

                            self.yang_name = "metric"
                            self.yang_parent_name = "autoroute-announce"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.absolute_metric = YLeaf(YType.uint32, "absolute-metric")

                            self.constant_metric = YLeaf(YType.uint32, "constant-metric")

                            self.metric_type = YLeaf(YType.enumeration, "metric-type")

                            self.relative_metric = YLeaf(YType.int32, "relative-metric")
                            self._segment_path = lambda: "metric"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.AutorouteAnnounce.Metric, ['absolute_metric', 'constant_metric', 'metric_type', 'relative_metric'], name, value)


                class Destinations(Entity):
                    """
                    Tunnel Autoroute Destination(s)
                    
                    .. attribute:: destination
                    
                    	Destination address to add in RIB
                    	**type**\: list of    :py:class:`Destination <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.Destinations.Destination>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.Destinations, self).__init__()

                        self.yang_name = "destinations"
                        self.yang_parent_name = "autoroute"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"destination" : ("destination", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.Destinations.Destination)}

                        self.destination = YList(self)
                        self._segment_path = lambda: "destinations"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.Destinations, [], name, value)


                    class Destination(Entity):
                        """
                        Destination address to add in RIB
                        
                        .. attribute:: destination_address  <key>
                        
                        	IP address of destination
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.Destinations.Destination, self).__init__()

                            self.yang_name = "destination"
                            self.yang_parent_name = "destinations"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.destination_address = YLeaf(YType.str, "destination-address")
                            self._segment_path = lambda: "destination" + "[destination-address='" + self.destination_address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Autoroute.Destinations.Destination, ['destination_address'], name, value)


            class BackupBandwidth(Entity):
                """
                Tunnel backup bandwidth requirement
                
                .. attribute:: backup_bandwidth
                
                	Backup bandwidth requested by this tunnel in kbps. Ignored if bandwidth limit type is unlimited
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: class_type
                
                	Backup bandwidth class type, relevant only if DSTEType is StandardDSTE
                	**type**\:   :py:class:`MplsTeBackupBandwidthClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBackupBandwidthClass>`
                
                .. attribute:: dste_type
                
                	DSTE\-standard flag
                	**type**\:   :py:class:`MplsTeBandwidthDste <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBandwidthDste>`
                
                .. attribute:: limit_type
                
                	Backup bandwidth limit type
                	**type**\:   :py:class:`MplsTeBandwidthLimit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBandwidthLimit>`
                
                .. attribute:: pool_type
                
                	Backup bandwidth pool type, relevant only if DSTEType is PreStandardDSTE
                	**type**\:   :py:class:`MplsTeBackupBandwidthPool <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBackupBandwidthPool>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth, self).__init__()

                    self.yang_name = "backup-bandwidth"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.backup_bandwidth = YLeaf(YType.uint32, "backup-bandwidth")

                    self.class_type = YLeaf(YType.enumeration, "class-type")

                    self.dste_type = YLeaf(YType.enumeration, "dste-type")

                    self.limit_type = YLeaf(YType.enumeration, "limit-type")

                    self.pool_type = YLeaf(YType.enumeration, "pool-type")
                    self._segment_path = lambda: "backup-bandwidth"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BackupBandwidth, ['backup_bandwidth', 'class_type', 'dste_type', 'limit_type', 'pool_type'], name, value)


            class Bandwidth(Entity):
                """
                Tunnel bandwidth requirement
                
                .. attribute:: bandwidth
                
                	The value of the bandwidth reserved by this tunnel in kbps
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**mandatory**\: True
                
                	**units**\: kbit/s
                
                .. attribute:: class_or_pool_type
                
                	Class type for the bandwidth allocation
                	**type**\:  int
                
                	**range:** 0..1
                
                	**mandatory**\: True
                
                .. attribute:: dste_type
                
                	DSTE\-standard flag
                	**type**\:   :py:class:`MplsTeBandwidthDste <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeBandwidthDste>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bandwidth, self).__init__()

                    self.yang_name = "bandwidth"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.bandwidth = YLeaf(YType.uint32, "bandwidth")

                    self.class_or_pool_type = YLeaf(YType.uint32, "class-or-pool-type")

                    self.dste_type = YLeaf(YType.enumeration, "dste-type")
                    self._segment_path = lambda: "bandwidth"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bandwidth, ['bandwidth', 'class_or_pool_type', 'dste_type'], name, value)


            class BfdOverLsp(Entity):
                """
                BFD over TE LSP
                
                .. attribute:: bringup_timeout
                
                	Wait for session to come up in seconds (default 60)
                	**type**\:  int
                
                	**range:** 10..3600
                
                .. attribute:: dampening_initial_wait
                
                	Initial delay in milliseconds (default 16000)
                	**type**\:  int
                
                	**range:** 1..518400000
                
                .. attribute:: dampening_maximum_wait
                
                	Maximum delay in milliseconds (default 600000)
                	**type**\:  int
                
                	**range:** 1..518400000
                
                .. attribute:: dampening_secondary_wait
                
                	Secondary delay in milliseconds (default 20000)
                	**type**\:  int
                
                	**range:** 1..518400000
                
                .. attribute:: enable
                
                	Always set to true
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: encap_mode
                
                	Specify BFD Encap Mode on the tunnel
                	**type**\:  int
                
                	**range:** 0..1
                
                .. attribute:: fast_detect
                
                	Enable BFD Fast Detect On the tunnel
                	**type**\:   :py:class:`MplsTebfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTebfdSession>`
                
                .. attribute:: minimum_interval
                
                	Specify the minimum interval for BFD failure detection
                	**type**\:  int
                
                	**range:** 3..30000
                
                .. attribute:: multiplier
                
                	Specify the multiplier for BFD failure detection
                	**type**\:  int
                
                	**range:** 3..10
                
                .. attribute:: periodic_ping_disable
                
                	Disable Periodic LSP Ping for BFD over LSP
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: periodic_ping_interval
                
                	Periodic LSP Ping Interval in seconds (default 120)
                	**type**\:  int
                
                	**range:** 60..3600
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp, self).__init__()

                    self.yang_name = "bfd-over-lsp"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.bringup_timeout = YLeaf(YType.uint32, "bringup-timeout")

                    self.dampening_initial_wait = YLeaf(YType.uint32, "dampening-initial-wait")

                    self.dampening_maximum_wait = YLeaf(YType.uint32, "dampening-maximum-wait")

                    self.dampening_secondary_wait = YLeaf(YType.uint32, "dampening-secondary-wait")

                    self.enable = YLeaf(YType.empty, "enable")

                    self.encap_mode = YLeaf(YType.uint32, "encap-mode")

                    self.fast_detect = YLeaf(YType.enumeration, "fast-detect")

                    self.minimum_interval = YLeaf(YType.uint32, "minimum-interval")

                    self.multiplier = YLeaf(YType.uint32, "multiplier")

                    self.periodic_ping_disable = YLeaf(YType.empty, "periodic-ping-disable")

                    self.periodic_ping_interval = YLeaf(YType.uint32, "periodic-ping-interval")
                    self._segment_path = lambda: "bfd-over-lsp"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BfdOverLsp, ['bringup_timeout', 'dampening_initial_wait', 'dampening_maximum_wait', 'dampening_secondary_wait', 'enable', 'encap_mode', 'fast_detect', 'minimum_interval', 'multiplier', 'periodic_ping_disable', 'periodic_ping_interval'], name, value)


            class Bidirectional(Entity):
                """
                Tunnel Interface Bidirectional configuration
                data
                
                .. attribute:: association_corouted_type
                
                	Association Corouted Type
                	**type**\:   :py:class:`AssociationCoroutedType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType>`
                
                .. attribute:: association_parameters
                
                	Association ID, Source IP Address, and Global ID
                	**type**\:   :py:class:`AssociationParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationParameters>`
                
                	**presence node**\: True
                
                .. attribute:: enabled
                
                	This object is only valid for tunnel interfaces and it controls whether that interface has bidirectional enabled on it or not
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional, self).__init__()

                    self.yang_name = "bidirectional"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"association-corouted-type" : ("association_corouted_type", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType), "association-parameters" : ("association_parameters", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationParameters)}
                    self._child_list_classes = {}

                    self.enabled = YLeaf(YType.empty, "enabled")

                    self.association_corouted_type = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType()
                    self.association_corouted_type.parent = self
                    self._children_name_map["association_corouted_type"] = "association-corouted-type"
                    self._children_yang_names.add("association-corouted-type")

                    self.association_parameters = None
                    self._children_name_map["association_parameters"] = "association-parameters"
                    self._children_yang_names.add("association-parameters")
                    self._segment_path = lambda: "bidirectional"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional, ['enabled'], name, value)


                class AssociationCoroutedType(Entity):
                    """
                    Association Corouted Type
                    
                    .. attribute:: enable
                    
                    	Controls whether association type is co\-routed
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    .. attribute:: fault_oam
                    
                    	Tunnel Fault OAM
                    	**type**\:   :py:class:`FaultOam <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam>`
                    
                    .. attribute:: wrap_protection_enable
                    
                    	This object is only valid for bidirectional tunnel interfaces and it controls whether that interface has LSP Wrap protectionenabled on it or not
                    	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType, self).__init__()

                        self.yang_name = "association-corouted-type"
                        self.yang_parent_name = "bidirectional"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"fault-oam" : ("fault_oam", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam)}
                        self._child_list_classes = {}

                        self.enable = YLeaf(YType.empty, "enable")

                        self.wrap_protection_enable = YLeaf(YType.empty, "wrap-protection-enable")

                        self.fault_oam = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam()
                        self.fault_oam.parent = self
                        self._children_name_map["fault_oam"] = "fault-oam"
                        self._children_yang_names.add("fault-oam")
                        self._segment_path = lambda: "association-corouted-type"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType, ['enable', 'wrap_protection_enable'], name, value)


                    class FaultOam(Entity):
                        """
                        Tunnel Fault OAM
                        
                        .. attribute:: enable
                        
                        	This object is only valid for bidirectional tunnel interfaces and it controls whether that interface has fault OAM enabled on it or not
                        	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam, self).__init__()

                            self.yang_name = "fault-oam"
                            self.yang_parent_name = "association-corouted-type"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.enable = YLeaf(YType.empty, "enable")
                            self._segment_path = lambda: "fault-oam"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationCoroutedType.FaultOam, ['enable'], name, value)


                class AssociationParameters(Entity):
                    """
                    Association ID, Source IP Address, and Global
                    ID
                    
                    .. attribute:: association_global_id
                    
                    	Association Global ID
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: association_id
                    
                    	Association ID
                    	**type**\:  int
                    
                    	**range:** 0..65535
                    
                    	**mandatory**\: True
                    
                    .. attribute:: association_is_global_id_configured
                    
                    	Is Association Global ID Configured
                    	**type**\:  bool
                    
                    .. attribute:: association_source_address
                    
                    	Association Source IP Address
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    	**mandatory**\: True
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationParameters, self).__init__()

                        self.yang_name = "association-parameters"
                        self.yang_parent_name = "bidirectional"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.association_global_id = YLeaf(YType.uint32, "association-global-id")

                        self.association_id = YLeaf(YType.uint32, "association-id")

                        self.association_is_global_id_configured = YLeaf(YType.boolean, "association-is-global-id-configured")

                        self.association_source_address = YLeaf(YType.str, "association-source-address")
                        self._segment_path = lambda: "association-parameters"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Bidirectional.AssociationParameters, ['association_global_id', 'association_id', 'association_is_global_id_configured', 'association_source_address'], name, value)


            class BindingSegmentIdMpls(Entity):
                """
                Allocate MPLS binding segment ID
                
                .. attribute:: label_value
                
                	MPLS label
                	**type**\:  int
                
                	**range:** 16..4015
                
                .. attribute:: segment_id_type
                
                	MPLS label value type
                	**type**\:   :py:class:`BindingSegmentId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.BindingSegmentId>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls, self).__init__()

                    self.yang_name = "binding-segment-id-mpls"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.label_value = YLeaf(YType.uint32, "label-value")

                    self.segment_id_type = YLeaf(YType.enumeration, "segment-id-type")
                    self._segment_path = lambda: "binding-segment-id-mpls"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.BindingSegmentIdMpls, ['label_value', 'segment_id_type'], name, value)


            class FastReroute(Entity):
                """
                Specify MPLS tunnel can be fast\-rerouted
                
                .. attribute:: bandwidth_protection
                
                	Bandwidth Protection
                	**type**\:  int
                
                	**range:** 0..1
                
                	**mandatory**\: True
                
                .. attribute:: node_protection
                
                	Node Protection
                	**type**\:  int
                
                	**range:** 0..1
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.FastReroute, self).__init__()

                    self.yang_name = "fast-reroute"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.bandwidth_protection = YLeaf(YType.uint32, "bandwidth-protection")

                    self.node_protection = YLeaf(YType.uint32, "node-protection")
                    self._segment_path = lambda: "fast-reroute"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.FastReroute, ['bandwidth_protection', 'node_protection'], name, value)


            class ForwardingAdjacency(Entity):
                """
                Forwarding adjacency announcement to IGP
                
                .. attribute:: enable
                
                	Enable forwarding adjacency
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: hold_time
                
                	Specify the holdtime for the tunnel as forwarding adjacency
                	**type**\:  int
                
                	**range:** 0..20000
                
                .. attribute:: include_ipv6
                
                	Specify that the tunnel should be an IPv6 forwarding adjacency also
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency, self).__init__()

                    self.yang_name = "forwarding-adjacency"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.enable = YLeaf(YType.empty, "enable")

                    self.hold_time = YLeaf(YType.uint32, "hold-time")

                    self.include_ipv6 = YLeaf(YType.empty, "include-ipv6")
                    self._segment_path = lambda: "forwarding-adjacency"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.ForwardingAdjacency, ['enable', 'hold_time', 'include_ipv6'], name, value)


            class Logging(Entity):
                """
                Log tunnel LSP messages
                
                .. attribute:: all
                
                	Log all events for a tunnel
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bandwidth_change_message
                
                	Log tunnel messages for bandwidth change
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: bfd_state_message
                
                	Enable BFD session state change alarm
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: insufficient_bw_message
                
                	Log tunnel messages for insufficient bandwidth
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: lsp_switch_over_change_message
                
                	Log tunnel messages for bandwidth change
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: pcalc_failure_message
                
                	Enable logging for path\-calculation failures
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: record_route_messsage
                
                	Log tunnel record\-route messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reoptimize_attempts_message
                
                	Log tunnel reoptimization attempts messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reoptimized_message
                
                	Log tunnel reoptimized messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: reroute_messsage
                
                	Log tunnel rereoute messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: state_message
                
                	Log tunnel state messages
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging, self).__init__()

                    self.yang_name = "logging"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.all = YLeaf(YType.empty, "all")

                    self.bandwidth_change_message = YLeaf(YType.empty, "bandwidth-change-message")

                    self.bfd_state_message = YLeaf(YType.empty, "bfd-state-message")

                    self.insufficient_bw_message = YLeaf(YType.empty, "insufficient-bw-message")

                    self.lsp_switch_over_change_message = YLeaf(YType.empty, "lsp-switch-over-change-message")

                    self.pcalc_failure_message = YLeaf(YType.empty, "pcalc-failure-message")

                    self.record_route_messsage = YLeaf(YType.empty, "record-route-messsage")

                    self.reoptimize_attempts_message = YLeaf(YType.empty, "reoptimize-attempts-message")

                    self.reoptimized_message = YLeaf(YType.empty, "reoptimized-message")

                    self.reroute_messsage = YLeaf(YType.empty, "reroute-messsage")

                    self.state_message = YLeaf(YType.empty, "state-message")
                    self._segment_path = lambda: "logging"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Logging, ['all', 'bandwidth_change_message', 'bfd_state_message', 'insufficient_bw_message', 'lsp_switch_over_change_message', 'pcalc_failure_message', 'record_route_messsage', 'reoptimize_attempts_message', 'reoptimized_message', 'reroute_messsage', 'state_message'], name, value)


            class NewStyleAffinityAffinityTypes(Entity):
                """
                Tunnel new style affinity attributes table
                
                .. attribute:: new_style_affinity_affinity_type
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityType <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityType>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9>`
                
                .. attribute:: new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9_affinity10
                
                	Tunnel new style affinity attribute
                	**type**\: list of    :py:class:`NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes, self).__init__()

                    self.yang_name = "new-style-affinity-affinity-types"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"new-style-affinity-affinity-type" : ("new_style_affinity_affinity_type", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityType), "new-style-affinity-affinity-type-affinity1" : ("new_style_affinity_affinity_type_affinity1", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1), "new-style-affinity-affinity-type-affinity1-affinity2" : ("new_style_affinity_affinity_type_affinity1_affinity2", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2), "new-style-affinity-affinity-type-affinity1-affinity2-affinity3" : ("new_style_affinity_affinity_type_affinity1_affinity2_affinity3", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3), "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4" : ("new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4), "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5" : ("new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5), "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6" : ("new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6), "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7" : ("new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7), "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8" : ("new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8), "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9" : ("new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9), "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9-affinity10" : ("new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9_affinity10", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10)}

                    self.new_style_affinity_affinity_type = YList(self)
                    self.new_style_affinity_affinity_type_affinity1 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9 = YList(self)
                    self.new_style_affinity_affinity_type_affinity1_affinity2_affinity3_affinity4_affinity5_affinity6_affinity7_affinity8_affinity9_affinity10 = YList(self)
                    self._segment_path = lambda: "new-style-affinity-affinity-types"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes, [], name, value)


                class NewStyleAffinityAffinityType(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityType, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")
                        self._segment_path = lambda: "new-style-affinity-affinity-type" + "[affinity-type='" + self.affinity_type.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityType, ['affinity_type'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1, ['affinity_type', 'affinity1'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1Affinity2(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1-affinity2" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2, ['affinity_type', 'affinity1', 'affinity2'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1-affinity2-affinity3" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3, ['affinity_type', 'affinity1', 'affinity2', 'affinity3'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4, ['affinity_type', 'affinity1', 'affinity2', 'affinity3', 'affinity4'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5, ['affinity_type', 'affinity1', 'affinity2', 'affinity3', 'affinity4', 'affinity5'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6, ['affinity_type', 'affinity1', 'affinity2', 'affinity3', 'affinity4', 'affinity5', 'affinity6'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7, ['affinity_type', 'affinity1', 'affinity2', 'affinity3', 'affinity4', 'affinity5', 'affinity6', 'affinity7'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity8  <key>
                    
                    	The name of the eighth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")

                        self.affinity8 = YLeaf(YType.str, "affinity8")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']" + "[affinity8='" + self.affinity8.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8, ['affinity_type', 'affinity1', 'affinity2', 'affinity3', 'affinity4', 'affinity5', 'affinity6', 'affinity7', 'affinity8'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity8  <key>
                    
                    	The name of the eighth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity9  <key>
                    
                    	The name of the nineth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")

                        self.affinity8 = YLeaf(YType.str, "affinity8")

                        self.affinity9 = YLeaf(YType.str, "affinity9")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']" + "[affinity8='" + self.affinity8.get() + "']" + "[affinity9='" + self.affinity9.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9, ['affinity_type', 'affinity1', 'affinity2', 'affinity3', 'affinity4', 'affinity5', 'affinity6', 'affinity7', 'affinity8', 'affinity9'], name, value)


                class NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10(Entity):
                    """
                    Tunnel new style affinity attribute
                    
                    .. attribute:: affinity_type  <key>
                    
                    	The type of the affinity entry
                    	**type**\:   :py:class:`MplsTeTunnelAffinity <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeTunnelAffinity>`
                    
                    .. attribute:: affinity1  <key>
                    
                    	The name of the first affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity2  <key>
                    
                    	The name of the second affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity3  <key>
                    
                    	The name of the third affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity4  <key>
                    
                    	The name of the fourth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity5  <key>
                    
                    	The name of the fifth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity6  <key>
                    
                    	The name of the sixth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity7  <key>
                    
                    	The name of the seventh affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity8  <key>
                    
                    	The name of the eighth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity9  <key>
                    
                    	The name of the nineth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    .. attribute:: affinity10  <key>
                    
                    	The name of the tenth affinity
                    	**type**\:  str
                    
                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10, self).__init__()

                        self.yang_name = "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9-affinity10"
                        self.yang_parent_name = "new-style-affinity-affinity-types"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.affinity_type = YLeaf(YType.enumeration, "affinity-type")

                        self.affinity1 = YLeaf(YType.str, "affinity1")

                        self.affinity2 = YLeaf(YType.str, "affinity2")

                        self.affinity3 = YLeaf(YType.str, "affinity3")

                        self.affinity4 = YLeaf(YType.str, "affinity4")

                        self.affinity5 = YLeaf(YType.str, "affinity5")

                        self.affinity6 = YLeaf(YType.str, "affinity6")

                        self.affinity7 = YLeaf(YType.str, "affinity7")

                        self.affinity8 = YLeaf(YType.str, "affinity8")

                        self.affinity9 = YLeaf(YType.str, "affinity9")

                        self.affinity10 = YLeaf(YType.str, "affinity10")
                        self._segment_path = lambda: "new-style-affinity-affinity-type-affinity1-affinity2-affinity3-affinity4-affinity5-affinity6-affinity7-affinity8-affinity9-affinity10" + "[affinity-type='" + self.affinity_type.get() + "']" + "[affinity1='" + self.affinity1.get() + "']" + "[affinity2='" + self.affinity2.get() + "']" + "[affinity3='" + self.affinity3.get() + "']" + "[affinity4='" + self.affinity4.get() + "']" + "[affinity5='" + self.affinity5.get() + "']" + "[affinity6='" + self.affinity6.get() + "']" + "[affinity7='" + self.affinity7.get() + "']" + "[affinity8='" + self.affinity8.get() + "']" + "[affinity9='" + self.affinity9.get() + "']" + "[affinity10='" + self.affinity10.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.NewStyleAffinityAffinityTypes.NewStyleAffinityAffinityTypeAffinity1Affinity2Affinity3Affinity4Affinity5Affinity6Affinity7Affinity8Affinity9Affinity10, ['affinity_type', 'affinity1', 'affinity2', 'affinity3', 'affinity4', 'affinity5', 'affinity6', 'affinity7', 'affinity8', 'affinity9', 'affinity10'], name, value)


            class PathOptionProtects(Entity):
                """
                Tunnel path protection state
                
                .. attribute:: path_option_protect
                
                	Tunnel path protection
                	**type**\: list of    :py:class:`PathOptionProtect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects, self).__init__()

                    self.yang_name = "path-option-protects"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"path-option-protect" : ("path_option_protect", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect)}

                    self.path_option_protect = YList(self)
                    self._segment_path = lambda: "path-option-protects"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects, [], name, value)


                class PathOptionProtect(Entity):
                    """
                    Tunnel path protection
                    
                    .. attribute:: protection  <key>
                    
                    	Protection type for this path
                    	**type**\:   :py:class:`MplsTePathOptionProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProtection>`
                    
                    .. attribute:: path_options
                    
                    	Tunnel path options
                    	**type**\:   :py:class:`PathOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions>`
                    
                    

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect, self).__init__()

                        self.yang_name = "path-option-protect"
                        self.yang_parent_name = "path-option-protects"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"path-options" : ("path_options", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions)}
                        self._child_list_classes = {}

                        self.protection = YLeaf(YType.enumeration, "protection")

                        self.path_options = InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions()
                        self.path_options.parent = self
                        self._children_name_map["path_options"] = "path-options"
                        self._children_yang_names.add("path-options")
                        self._segment_path = lambda: "path-option-protect" + "[protection='" + self.protection.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect, ['protection'], name, value)


                    class PathOptions(Entity):
                        """
                        Tunnel path options
                        
                        .. attribute:: path_option
                        
                        	A tunnel path option
                        	**type**\: list of    :py:class:`PathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions.PathOption>`
                        
                        

                        """

                        _prefix = 'mpls-te-cfg'
                        _revision = '2017-05-01'

                        def __init__(self):
                            super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions, self).__init__()

                            self.yang_name = "path-options"
                            self.yang_parent_name = "path-option-protect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"path-option" : ("path_option", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions.PathOption)}

                            self.path_option = YList(self)
                            self._segment_path = lambda: "path-options"

                        def __setattr__(self, name, value):
                            self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions, [], name, value)


                        class PathOption(Entity):
                            """
                            A tunnel path option
                            
                            .. attribute:: preference_level  <key>
                            
                            	Preference level for this path option
                            	**type**\:  int
                            
                            	**range:** 1..1000
                            
                            .. attribute:: destination
                            
                            	Deprecated
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**default value**\: 0.0.0.0
                            
                            .. attribute:: igp_area
                            
                            	IGP area ID in integer format
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: igp_area_ip_address_id
                            
                            	IGP area ID in IP address format
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**default value**\: 0.0.0.0
                            
                            .. attribute:: igp_instance
                            
                            	IGP instance name
                            	**type**\:  str
                            
                            	**length:** 1..40
                            
                            .. attribute:: igp_type
                            
                            	IGP type
                            	**type**\:   :py:class:`MplsTeIgpProtocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeIgpProtocol>`
                            
                            	**default value**\: none
                            
                            .. attribute:: interface
                            
                            	Deprecated
                            	**type**\:  str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: lockdown
                            
                            	Lockdown properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            	**default value**\: none
                            
                            .. attribute:: output_label
                            
                            	Deprecated
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: path_id
                            
                            	The ID of the IP explicit path associated with this option
                            	**type**\:  int
                            
                            	**range:** 1..65535
                            
                            	**default value**\: 1
                            
                            .. attribute:: path_name
                            
                            	The name of the IP explicit path associated with this option
                            	**type**\:  str
                            
                            .. attribute:: path_option_attribute_set_name
                            
                            	Path option attribute set name
                            	**type**\:  str
                            
                            .. attribute:: path_property
                            
                            	Deprecated
                            	**type**\:  int
                            
                            	**range:** \-2147483648..2147483647
                            
                            	**default value**\: 0
                            
                            .. attribute:: path_type
                            
                            	The type of the path option
                            	**type**\:   :py:class:`MplsTePathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOption>`
                            
                            	**mandatory**\: True
                            
                            .. attribute:: pce
                            
                            	PCE properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            	**default value**\: none
                            
                            .. attribute:: pce_address
                            
                            	PCE address
                            	**type**\:  str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            	**default value**\: 0.0.0.0
                            
                            .. attribute:: protected_by_preference_level
                            
                            	Preference level of the protecting explicit path. Leave unset in order to not use an explicit protecting path
                            	**type**\:  int
                            
                            	**range:** 1..1000
                            
                            	**default value**\: 1
                            
                            .. attribute:: segment_routing
                            
                            	SegmentRouting properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            	**default value**\: none
                            
                            .. attribute:: verbatim
                            
                            	Verbatim properties
                            	**type**\:   :py:class:`MplsTePathOptionProperty <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathOptionProperty>`
                            
                            	**default value**\: none
                            
                            

                            """

                            _prefix = 'mpls-te-cfg'
                            _revision = '2017-05-01'

                            def __init__(self):
                                super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions.PathOption, self).__init__()

                                self.yang_name = "path-option"
                                self.yang_parent_name = "path-options"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {}

                                self.preference_level = YLeaf(YType.uint32, "preference-level")

                                self.destination = YLeaf(YType.str, "destination")

                                self.igp_area = YLeaf(YType.int32, "igp-area")

                                self.igp_area_ip_address_id = YLeaf(YType.str, "igp-area-ip-address-id")

                                self.igp_instance = YLeaf(YType.str, "igp-instance")

                                self.igp_type = YLeaf(YType.enumeration, "igp-type")

                                self.interface = YLeaf(YType.str, "interface")

                                self.lockdown = YLeaf(YType.enumeration, "lockdown")

                                self.output_label = YLeaf(YType.int32, "output-label")

                                self.path_id = YLeaf(YType.uint32, "path-id")

                                self.path_name = YLeaf(YType.str, "path-name")

                                self.path_option_attribute_set_name = YLeaf(YType.str, "path-option-attribute-set-name")

                                self.path_property = YLeaf(YType.int32, "path-property")

                                self.path_type = YLeaf(YType.enumeration, "path-type")

                                self.pce = YLeaf(YType.enumeration, "pce")

                                self.pce_address = YLeaf(YType.str, "pce-address")

                                self.protected_by_preference_level = YLeaf(YType.uint32, "protected-by-preference-level")

                                self.segment_routing = YLeaf(YType.enumeration, "segment-routing")

                                self.verbatim = YLeaf(YType.enumeration, "verbatim")
                                self._segment_path = lambda: "path-option" + "[preference-level='" + self.preference_level.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PathOptionProtects.PathOptionProtect.PathOptions.PathOption, ['preference_level', 'destination', 'igp_area', 'igp_area_ip_address_id', 'igp_instance', 'igp_type', 'interface', 'lockdown', 'output_label', 'path_id', 'path_name', 'path_option_attribute_set_name', 'path_property', 'path_type', 'pce', 'pce_address', 'protected_by_preference_level', 'segment_routing', 'verbatim'], name, value)


            class Pce(Entity):
                """
                PCE config
                
                .. attribute:: delegation
                
                	Enable PCE Delegation
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                .. attribute:: enable
                
                	Always set to true
                	**type**\:  :py:class:`Empty<ydk.types.Empty>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce, self).__init__()

                    self.yang_name = "pce"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.delegation = YLeaf(YType.empty, "delegation")

                    self.enable = YLeaf(YType.empty, "enable")
                    self._segment_path = lambda: "pce"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Pce, ['delegation', 'enable'], name, value)


            class PolicyClasses(Entity):
                """
                Policy classes for PBTS
                
                .. attribute:: policy_class
                
                	Array of Policy class
                	**type**\:  list of int
                
                	**range:** 1..8
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses, self).__init__()

                    self.yang_name = "policy-classes"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.policy_class = YLeafList(YType.uint32, "policy-class")
                    self._segment_path = lambda: "policy-classes"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.PolicyClasses, ['policy_class'], name, value)


            class Priority(Entity):
                """
                Tunnel Setup and Hold Priorities
                
                .. attribute:: hold_priority
                
                	Hold Priority
                	**type**\:  int
                
                	**range:** 0..7
                
                	**mandatory**\: True
                
                .. attribute:: setup_priority
                
                	Setup Priority
                	**type**\:  int
                
                	**range:** 0..7
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Priority, self).__init__()

                    self.yang_name = "priority"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.hold_priority = YLeaf(YType.uint32, "hold-priority")

                    self.setup_priority = YLeaf(YType.uint32, "setup-priority")
                    self._segment_path = lambda: "priority"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Priority, ['hold_priority', 'setup_priority'], name, value)


            class Switching(Entity):
                """
                Specify tunnel LSPs switching capability
                descriptor
                
                .. attribute:: endpoint
                
                	Specify end point switching descriptor parameters
                	**type**\:   :py:class:`Endpoint <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Endpoint>`
                
                	**presence node**\: True
                
                .. attribute:: transit
                
                	Specify transit switching descriptor parameters
                	**type**\:   :py:class:`Transit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Transit>`
                
                	**presence node**\: True
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching, self).__init__()

                    self.yang_name = "switching"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"endpoint" : ("endpoint", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Endpoint), "transit" : ("transit", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Transit)}
                    self._child_list_classes = {}

                    self.endpoint = None
                    self._children_name_map["endpoint"] = "endpoint"
                    self._children_yang_names.add("endpoint")

                    self.transit = None
                    self._children_name_map["transit"] = "transit"
                    self._children_yang_names.add("transit")
                    self._segment_path = lambda: "switching"


                class Endpoint(Entity):
                    """
                    Specify end point switching descriptor
                    parameters
                    
                    .. attribute:: capability
                    
                    	Switching capability
                    	**type**\:   :py:class:`MplsTeSwitchingCap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeSwitchingCap>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: encoding
                    
                    	LSP encoding
                    	**type**\:   :py:class:`MplsTeSwitchingEncode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeSwitchingEncode>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Endpoint, self).__init__()

                        self.yang_name = "endpoint"
                        self.yang_parent_name = "switching"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.capability = YLeaf(YType.enumeration, "capability")

                        self.encoding = YLeaf(YType.enumeration, "encoding")
                        self._segment_path = lambda: "endpoint"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Endpoint, ['capability', 'encoding'], name, value)


                class Transit(Entity):
                    """
                    Specify transit switching descriptor
                    parameters
                    
                    .. attribute:: capability
                    
                    	Switching capability
                    	**type**\:   :py:class:`MplsTeSwitchingCap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeSwitchingCap>`
                    
                    	**mandatory**\: True
                    
                    .. attribute:: encoding
                    
                    	LSP encoding
                    	**type**\:   :py:class:`MplsTeSwitchingEncode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTeSwitchingEncode>`
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Transit, self).__init__()

                        self.yang_name = "transit"
                        self.yang_parent_name = "switching"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.capability = YLeaf(YType.enumeration, "capability")

                        self.encoding = YLeaf(YType.enumeration, "encoding")
                        self._segment_path = lambda: "transit"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.Switching.Transit, ['capability', 'encoding'], name, value)


            class TunnelPathSelection(Entity):
                """
                Configure path selection properties
                
                .. attribute:: invalidation
                
                	Path invalidation configuration for this specific tunnel
                	**type**\:   :py:class:`Invalidation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection.Invalidation>`
                
                	**presence node**\: True
                
                .. attribute:: path_selection_cost_limit
                
                	Path selection cost limit configuration for this specific tunnel
                	**type**\:  int
                
                	**range:** 1..4294967295
                
                .. attribute:: path_selection_hop_limit
                
                	Path selection hop limit configuration for this specific tunnel
                	**type**\:  int
                
                	**range:** 1..255
                
                .. attribute:: tiebreaker
                
                	CSPF tiebreaker to use in path calculation
                	**type**\:   :py:class:`MplsTePathSelectionTiebreaker <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.MplsTePathSelectionTiebreaker>`
                
                

                """

                _prefix = 'mpls-te-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection, self).__init__()

                    self.yang_name = "tunnel-path-selection"
                    self.yang_parent_name = "tunnel-te-attributes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {"invalidation" : ("invalidation", InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection.Invalidation)}
                    self._child_list_classes = {}

                    self.path_selection_cost_limit = YLeaf(YType.uint32, "path-selection-cost-limit")

                    self.path_selection_hop_limit = YLeaf(YType.uint32, "path-selection-hop-limit")

                    self.tiebreaker = YLeaf(YType.enumeration, "tiebreaker")

                    self.invalidation = None
                    self._children_name_map["invalidation"] = "invalidation"
                    self._children_yang_names.add("invalidation")
                    self._segment_path = lambda: "tunnel-path-selection"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection, ['path_selection_cost_limit', 'path_selection_hop_limit', 'tiebreaker'], name, value)


                class Invalidation(Entity):
                    """
                    Path invalidation configuration for this
                    specific tunnel
                    
                    .. attribute:: path_invalidation_action
                    
                    	Path Invalidation Action
                    	**type**\:   :py:class:`PathInvalidationAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_mpls_te_cfg.PathInvalidationAction>`
                    
                    .. attribute:: path_invalidation_timeout
                    
                    	Path Invalidation Timeout
                    	**type**\:  int
                    
                    	**range:** 0..60000
                    
                    

                    This class is a :ref:`presence class<presence-class>`

                    """

                    _prefix = 'mpls-te-cfg'
                    _revision = '2017-05-01'

                    def __init__(self):
                        super(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection.Invalidation, self).__init__()

                        self.yang_name = "invalidation"
                        self.yang_parent_name = "tunnel-path-selection"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {}
                        self.is_presence_container = True

                        self.path_invalidation_action = YLeaf(YType.enumeration, "path-invalidation-action")

                        self.path_invalidation_timeout = YLeaf(YType.uint32, "path-invalidation-timeout")
                        self._segment_path = lambda: "invalidation"

                    def __setattr__(self, name, value):
                        self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.TunnelTeAttributes.TunnelPathSelection.Invalidation, ['path_invalidation_action', 'path_invalidation_timeout'], name, value)


        class VlanSubConfiguration(Entity):
            """
            IEEE 802.1Q VLAN subinterface configuration
            
            .. attribute:: vlan_identifier
            
            	The VLAN tag stack associated with this sub\-interface
            	**type**\:   :py:class:`VlanIdentifier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration.VlanIdentifier>`
            
            	**presence node**\: True
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration, self).__init__()

                self.yang_name = "vlan-sub-configuration"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"vlan-identifier" : ("vlan_identifier", InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration.VlanIdentifier)}
                self._child_list_classes = {}

                self.vlan_identifier = None
                self._children_name_map["vlan_identifier"] = "vlan-identifier"
                self._children_yang_names.add("vlan-identifier")
                self._segment_path = lambda: "Cisco-IOS-XR-l2-eth-infra-cfg:vlan-sub-configuration"


            class VlanIdentifier(Entity):
                """
                The VLAN tag stack associated with this
                sub\-interface.
                
                .. attribute:: first_tag
                
                	First (outermost) VLAN tag value
                	**type**\:  int
                
                	**range:** 1..4094
                
                	**mandatory**\: True
                
                .. attribute:: second_tag
                
                	Second VLAN tag value. The any value may only be used for Layer 2 subinterfaces
                	**type**\: one of the below types:
                
                	**type**\:   :py:class:`VlanTagOrNull <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.VlanTagOrNull>`
                
                
                ----
                	**type**\:  int
                
                	**range:** 0..4094
                
                
                ----
                .. attribute:: vlan_type
                
                	Whether this sub\-interface is dot1ad or dot1Q
                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Vlan>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration.VlanIdentifier, self).__init__()

                    self.yang_name = "vlan-identifier"
                    self.yang_parent_name = "vlan-sub-configuration"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.first_tag = YLeaf(YType.uint32, "first-tag")

                    self.second_tag = YLeaf(YType.str, "second-tag")

                    self.vlan_type = YLeaf(YType.enumeration, "vlan-type")
                    self._segment_path = lambda: "vlan-identifier"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.VlanSubConfiguration.VlanIdentifier, ['first_tag', 'second_tag', 'vlan_type'], name, value)


        class VlanTrunkConfiguration(Entity):
            """
            IEEE 802.1Q VLAN trunk interface configuration
            
            .. attribute:: native_vlan_identifier
            
            	The Native VLAN identifier associated with this trunk interface
            	**type**\:   :py:class:`NativeVlanIdentifier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.NativeVlanIdentifier>`
            
            	**presence node**\: True
            
            .. attribute:: tunneling_ethertype
            
            	The outer ethertype used in Q\-in\-Q frames. The default value is 0x8100
            	**type**\:   :py:class:`TunnelingEthertype <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ifmgr_cfg.InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.TunnelingEthertype>`
            
            

            """

            _prefix = 'l2-eth-infra-cfg'
            _revision = '2017-05-01'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration, self).__init__()

                self.yang_name = "vlan-trunk-configuration"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {"native-vlan-identifier" : ("native_vlan_identifier", InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.NativeVlanIdentifier)}
                self._child_list_classes = {}

                self.tunneling_ethertype = YLeaf(YType.enumeration, "tunneling-ethertype")

                self.native_vlan_identifier = None
                self._children_name_map["native_vlan_identifier"] = "native-vlan-identifier"
                self._children_yang_names.add("native-vlan-identifier")
                self._segment_path = lambda: "Cisco-IOS-XR-l2-eth-infra-cfg:vlan-trunk-configuration"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration, ['tunneling_ethertype'], name, value)

            class TunnelingEthertype(Enum):
                """
                TunnelingEthertype

                The outer ethertype used in Q\-in\-Q frames. The

                default value is 0x8100

                .. data:: Y_0x9100 = 37120

                	0x9100

                .. data:: Y_0x9200 = 37376

                	0x9200

                """

                Y_0x9100 = Enum.YLeaf(37120, "0x9100")

                Y_0x9200 = Enum.YLeaf(37376, "0x9200")



            class NativeVlanIdentifier(Entity):
                """
                The Native VLAN identifier associated with this
                trunk interface
                
                .. attribute:: vlan_identifier
                
                	VLAN identifier
                	**type**\:  int
                
                	**range:** 1..4094
                
                	**mandatory**\: True
                
                .. attribute:: vlan_type
                
                	Whether this interface is dot1ad or dot1Q
                	**type**\:   :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2_eth_infra_datatypes.Vlan>`
                
                	**mandatory**\: True
                
                

                This class is a :ref:`presence class<presence-class>`

                """

                _prefix = 'l2-eth-infra-cfg'
                _revision = '2017-05-01'

                def __init__(self):
                    super(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.NativeVlanIdentifier, self).__init__()

                    self.yang_name = "native-vlan-identifier"
                    self.yang_parent_name = "vlan-trunk-configuration"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}
                    self.is_presence_container = True

                    self.vlan_identifier = YLeaf(YType.uint32, "vlan-identifier")

                    self.vlan_type = YLeaf(YType.enumeration, "vlan-type")
                    self._segment_path = lambda: "native-vlan-identifier"

                def __setattr__(self, name, value):
                    self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.VlanTrunkConfiguration.NativeVlanIdentifier, ['vlan_identifier', 'vlan_type'], name, value)


        class Wanphy(Entity):
            """
            WANPHY port controller configuration
            
            .. attribute:: lan_mode
            
            	Configure LAN Mode
            	**type**\:   :py:class:`WanphyLanMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_wanphy_ui_cfg.WanphyLanMode>`
            
            .. attribute:: report_line_ais
            
            	Configure Line Alarm Indication Signal reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_lof
            
            	Configure Loss Of Frame reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_lop
            
            	Configure Loss Of Pointer reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_los
            
            	Configure Loss Of Signal reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_ais
            
            	Configure Path Alarm Indication Signal reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_fe_ais
            
            	Configure Path Far End Payload Label Mismatch reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_fe_plm
            
            	Configure Path Far End Payload Label Mismatch reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_lcd
            
            	Configure Path Loss Of Code\-Group Delineation reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_plm
            
            	Configure Path Payload Label Mismatch reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_path_rdi
            
            	Configure Path Remote Defect Indicator reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_rdi
            
            	Configure Remote Defect Indicator reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_sd_ber
            
            	Configure B2 BER in excess of SD threshold reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: report_sf_ber
            
            	Configure B2 BER in excess of SF threshold reporting
            	**type**\:  :py:class:`Empty<ydk.types.Empty>`
            
            .. attribute:: threshold_sd_ber
            
            	Bit error rate is 10 to the minus n, where n is threshold value
            	**type**\:  int
            
            	**range:** 3..9
            
            	**default value**\: 6
            
            .. attribute:: threshold_sf_ber
            
            	Bit error rate is 10 to the minus n, where n is threshold value
            	**type**\:  int
            
            	**range:** 3..9
            
            	**default value**\: 3
            
            .. attribute:: wan_mode
            
            	Configure WAN Mode
            	**type**\:   :py:class:`WanphyWanMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_wanphy_ui_cfg.WanphyWanMode>`
            
            

            """

            _prefix = 'wanphy-ui-cfg'
            _revision = '2015-11-09'

            def __init__(self):
                super(InterfaceConfigurations.InterfaceConfiguration.Wanphy, self).__init__()

                self.yang_name = "wanphy"
                self.yang_parent_name = "interface-configuration"
                self.is_top_level_class = False
                self.has_list_ancestor = True
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.lan_mode = YLeaf(YType.enumeration, "lan-mode")

                self.report_line_ais = YLeaf(YType.empty, "report-line-ais")

                self.report_lof = YLeaf(YType.empty, "report-lof")

                self.report_lop = YLeaf(YType.empty, "report-lop")

                self.report_los = YLeaf(YType.empty, "report-los")

                self.report_path_ais = YLeaf(YType.empty, "report-path-ais")

                self.report_path_fe_ais = YLeaf(YType.empty, "report-path-fe-ais")

                self.report_path_fe_plm = YLeaf(YType.empty, "report-path-fe-plm")

                self.report_path_lcd = YLeaf(YType.empty, "report-path-lcd")

                self.report_path_plm = YLeaf(YType.empty, "report-path-plm")

                self.report_path_rdi = YLeaf(YType.empty, "report-path-rdi")

                self.report_rdi = YLeaf(YType.empty, "report-rdi")

                self.report_sd_ber = YLeaf(YType.empty, "report-sd-ber")

                self.report_sf_ber = YLeaf(YType.empty, "report-sf-ber")

                self.threshold_sd_ber = YLeaf(YType.uint32, "threshold-sd-ber")

                self.threshold_sf_ber = YLeaf(YType.uint32, "threshold-sf-ber")

                self.wan_mode = YLeaf(YType.enumeration, "wan-mode")
                self._segment_path = lambda: "Cisco-IOS-XR-wanphy-ui-cfg:wanphy"

            def __setattr__(self, name, value):
                self._perform_setattr(InterfaceConfigurations.InterfaceConfiguration.Wanphy, ['lan_mode', 'report_line_ais', 'report_lof', 'report_lop', 'report_los', 'report_path_ais', 'report_path_fe_ais', 'report_path_fe_plm', 'report_path_lcd', 'report_path_plm', 'report_path_rdi', 'report_rdi', 'report_sd_ber', 'report_sf_ber', 'threshold_sd_ber', 'threshold_sf_ber', 'wan_mode'], name, value)

    def clone_ptr(self):
        self._top_entity = InterfaceConfigurations()
        return self._top_entity

