""" Cisco_IOS_XR_ip_bfd_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ip\-bfd package operational data.

This module contains definitions
for the following management objects\:
  bfd\: Bidirectional Forwarding Detection(BFD) operational data

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class BfdAfId(Enum):
    """
    BfdAfId

    Bfd af id

    .. data:: bfd_af_id_none = 0

    	No Address

    .. data:: bfd_af_id_ipv4 = 2

    	IPv4 AFI

    .. data:: bfd_af_id_ipv6 = 10

    	IPv6 AFI

    """

    bfd_af_id_none = Enum.YLeaf(0, "bfd-af-id-none")

    bfd_af_id_ipv4 = Enum.YLeaf(2, "bfd-af-id-ipv4")

    bfd_af_id_ipv6 = Enum.YLeaf(10, "bfd-af-id-ipv6")


class BfdMgmtPktDisplay(Enum):
    """
    BfdMgmtPktDisplay

    BFD session type

    .. data:: bfd_mgmt_pkt_display_type_none = 0

    	None

    .. data:: bfd_mgmt_pkt_display_type_bob_mbr = 1

    	Display Type Bundle RTR Member

    .. data:: bfd_mgmt_pkt_display_type_max = 2

    	Display Type Enum Max Value

    """

    bfd_mgmt_pkt_display_type_none = Enum.YLeaf(0, "bfd-mgmt-pkt-display-type-none")

    bfd_mgmt_pkt_display_type_bob_mbr = Enum.YLeaf(1, "bfd-mgmt-pkt-display-type-bob-mbr")

    bfd_mgmt_pkt_display_type_max = Enum.YLeaf(2, "bfd-mgmt-pkt-display-type-max")


class BfdMgmtSessionDiag(Enum):
    """
    BfdMgmtSessionDiag

    BFD session diagnostic

    .. data:: bfd_mgmt_session_diag_none = 0

    	No diagnostic

    .. data:: bfd_mgmt_session_diag_control_detect_expired = 1

    	Control Detection Time Expired

    .. data:: bfd_mgmt_session_diag_echo_function_failed = 2

    	Echo Function Failed

    .. data:: bfd_mgmt_session_diag_nb_or_signaled_down = 3

    	Neighbor Signaled Session Down

    .. data:: bfd_mgmt_session_diag_fwding_plane_reset = 4

    	Forwarding Plane Reset

    .. data:: bfd_mgmt_session_diag_path_down = 5

    	Path Down

    .. data:: bfd_mgmt_session_diag_conc_path_down = 6

    	Concatenated Path Down

    .. data:: bfd_mgmt_session_diag_admin_down = 7

    	Administratively Down

    .. data:: bfd_mgmt_session_diag_rev_conc_path_down = 8

    	Reverse Concatenated Path Down

    .. data:: bfd_mgmt_session_diag_num = 10

    	Unknown diagnostic state

    """

    bfd_mgmt_session_diag_none = Enum.YLeaf(0, "bfd-mgmt-session-diag-none")

    bfd_mgmt_session_diag_control_detect_expired = Enum.YLeaf(1, "bfd-mgmt-session-diag-control-detect-expired")

    bfd_mgmt_session_diag_echo_function_failed = Enum.YLeaf(2, "bfd-mgmt-session-diag-echo-function-failed")

    bfd_mgmt_session_diag_nb_or_signaled_down = Enum.YLeaf(3, "bfd-mgmt-session-diag-nb-or-signaled-down")

    bfd_mgmt_session_diag_fwding_plane_reset = Enum.YLeaf(4, "bfd-mgmt-session-diag-fwding-plane-reset")

    bfd_mgmt_session_diag_path_down = Enum.YLeaf(5, "bfd-mgmt-session-diag-path-down")

    bfd_mgmt_session_diag_conc_path_down = Enum.YLeaf(6, "bfd-mgmt-session-diag-conc-path-down")

    bfd_mgmt_session_diag_admin_down = Enum.YLeaf(7, "bfd-mgmt-session-diag-admin-down")

    bfd_mgmt_session_diag_rev_conc_path_down = Enum.YLeaf(8, "bfd-mgmt-session-diag-rev-conc-path-down")

    bfd_mgmt_session_diag_num = Enum.YLeaf(10, "bfd-mgmt-session-diag-num")


class BfdMgmtSessionState(Enum):
    """
    BfdMgmtSessionState

    BFD session states

    .. data:: bfd_mgmt_session_state_admin_down = 0

    	Session in Administratively Shutdown State

    .. data:: bfd_mgmt_session_state_down = 1

    	Session in Down State

    .. data:: bfd_mgmt_session_state_init = 2

    	Session in Initializing State

    .. data:: bfd_mgmt_session_state_up = 3

    	Session in Up State

    .. data:: bfd_mgmt_session_state_failing = 4

    	Session in Failing State

    .. data:: bfd_mgmt_session_state_unknown = 6

    	Session in Unknown State

    """

    bfd_mgmt_session_state_admin_down = Enum.YLeaf(0, "bfd-mgmt-session-state-admin-down")

    bfd_mgmt_session_state_down = Enum.YLeaf(1, "bfd-mgmt-session-state-down")

    bfd_mgmt_session_state_init = Enum.YLeaf(2, "bfd-mgmt-session-state-init")

    bfd_mgmt_session_state_up = Enum.YLeaf(3, "bfd-mgmt-session-state-up")

    bfd_mgmt_session_state_failing = Enum.YLeaf(4, "bfd-mgmt-session-state-failing")

    bfd_mgmt_session_state_unknown = Enum.YLeaf(6, "bfd-mgmt-session-state-unknown")


class BfdMpDownloadState(Enum):
    """
    BfdMpDownloadState

    Bfd mp download state

    .. data:: bfd_mp_download_none = 0

    	bfd mp download none

    .. data:: bfd_mp_download_no_lc = 1

    	bfd mp download no lc

    .. data:: bfd_mp_download_downloaded = 2

    	bfd mp download downloaded

    .. data:: bfd_mp_download_ack = 3

    	bfd mp download ack

    .. data:: bfd_mp_download_nack = 4

    	bfd mp download nack

    .. data:: bfd_mp_download_delete = 5

    	bfd mp download delete

    """

    bfd_mp_download_none = Enum.YLeaf(0, "bfd-mp-download-none")

    bfd_mp_download_no_lc = Enum.YLeaf(1, "bfd-mp-download-no-lc")

    bfd_mp_download_downloaded = Enum.YLeaf(2, "bfd-mp-download-downloaded")

    bfd_mp_download_ack = Enum.YLeaf(3, "bfd-mp-download-ack")

    bfd_mp_download_nack = Enum.YLeaf(4, "bfd-mp-download-nack")

    bfd_mp_download_delete = Enum.YLeaf(5, "bfd-mp-download-delete")


class BfdSession(Enum):
    """
    BfdSession

    BFD session type

    .. data:: undefined = 0

    	Session type is undefined

    .. data:: bundle_member = 1

    	Session type is bundle member

    .. data:: bundle_interface = 2

    	Session type is bundle interface

    .. data:: state_inheriting = 3

    	Session type is state inheriting

    .. data:: bundle_vlan = 4

    	Session type is bundle vlan

    .. data:: mpls_tp = 5

    	Session type is MPLS-TP

    .. data:: gre = 6

    	Session type is GRE tunnel

    .. data:: pseudowire_headend = 7

    	Session type is PW-HE

    .. data:: ip_single_hop = 8

    	Session type is IP single hop

    """

    undefined = Enum.YLeaf(0, "undefined")

    bundle_member = Enum.YLeaf(1, "bundle-member")

    bundle_interface = Enum.YLeaf(2, "bundle-interface")

    state_inheriting = Enum.YLeaf(3, "state-inheriting")

    bundle_vlan = Enum.YLeaf(4, "bundle-vlan")

    mpls_tp = Enum.YLeaf(5, "mpls-tp")

    gre = Enum.YLeaf(6, "gre")

    pseudowire_headend = Enum.YLeaf(7, "pseudowire-headend")

    ip_single_hop = Enum.YLeaf(8, "ip-single-hop")



class Bfd(Entity):
    """
    Bidirectional Forwarding Detection(BFD)
    operational data
    
    .. attribute:: client_briefs
    
    	Table of Brief information about BFD clients
    	**type**\:   :py:class:`ClientBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.ClientBriefs>`
    
    .. attribute:: client_details
    
    	Table of detailed information about BFD clients
    	**type**\:   :py:class:`ClientDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.ClientDetails>`
    
    .. attribute:: counters
    
    	Counters
    	**type**\:   :py:class:`Counters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Counters>`
    
    .. attribute:: generic_summaries
    
    	Generic summary information about BFD location
    	**type**\:   :py:class:`GenericSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.GenericSummaries>`
    
    .. attribute:: ipv4_multi_hop_counters
    
    	IPv4 multiple hop Counters
    	**type**\:   :py:class:`Ipv4MultiHopCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopCounters>`
    
    .. attribute:: ipv4_multi_hop_multi_paths
    
    	IPv4 multi\-hop multipath
    	**type**\:   :py:class:`Ipv4MultiHopMultiPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopMultiPaths>`
    
    .. attribute:: ipv4_multi_hop_node_location_summaries
    
    	Table of summary information about BFD IPv4 multihop sessions per location
    	**type**\:   :py:class:`Ipv4MultiHopNodeLocationSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopNodeLocationSummaries>`
    
    .. attribute:: ipv4_multi_hop_session_briefs
    
    	Table of brief information about all IPv4 multihop BFD sessions in the System
    	**type**\:   :py:class:`Ipv4MultiHopSessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionBriefs>`
    
    .. attribute:: ipv4_multi_hop_session_details
    
    	Table of detailed information about all IPv4 multihop BFD sessions in the System 
    	**type**\:   :py:class:`Ipv4MultiHopSessionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails>`
    
    .. attribute:: ipv4_multi_hop_summary
    
    	Summary information of BFD IPv4 multihop sessions
    	**type**\:   :py:class:`Ipv4MultiHopSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSummary>`
    
    .. attribute:: ipv4_single_hop_counters
    
    	IPv4 single hop Counters
    	**type**\:   :py:class:`Ipv4SingleHopCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopCounters>`
    
    .. attribute:: ipv4_single_hop_location_summaries
    
    	Table of summary information about IPv4 singlehop BFD sessions for location
    	**type**\:   :py:class:`Ipv4SingleHopLocationSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopLocationSummaries>`
    
    .. attribute:: ipv4_single_hop_multi_paths
    
    	IPv4 single hop multipath
    	**type**\:   :py:class:`Ipv4SingleHopMultiPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopMultiPaths>`
    
    .. attribute:: ipv4_single_hop_node_location_summaries
    
    	Table of summary information about BFD IPv4 singlehop sessions per location
    	**type**\:   :py:class:`Ipv4SingleHopNodeLocationSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopNodeLocationSummaries>`
    
    .. attribute:: ipv4_single_hop_session_briefs
    
    	Table of brief information about all IPv4 singlehop BFD sessions in the System
    	**type**\:   :py:class:`Ipv4SingleHopSessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionBriefs>`
    
    .. attribute:: ipv4_single_hop_session_details
    
    	Table of detailed information about all IPv4 singlehop BFD sessions in the System 
    	**type**\:   :py:class:`Ipv4SingleHopSessionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails>`
    
    .. attribute:: ipv4_single_hop_summary
    
    	Summary information of BFD IPv4 singlehop sessions
    	**type**\:   :py:class:`Ipv4SingleHopSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSummary>`
    
    .. attribute:: ipv4bf_do_mplste_head_counters
    
    	IPv4 BFD over MPLS\-TE Counters
    	**type**\:   :py:class:`Ipv4BfDoMplsteHeadCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadCounters>`
    
    .. attribute:: ipv4bf_do_mplste_head_multi_paths
    
    	IPv4 BFD over MPLS\-TE Head multipath
    	**type**\:   :py:class:`Ipv4BfDoMplsteHeadMultiPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadMultiPaths>`
    
    .. attribute:: ipv4bf_do_mplste_head_session_briefs
    
    	Table of brief information about all IPv4 BFD over MPLS\-TE Head sessions in the System
    	**type**\:   :py:class:`Ipv4BfDoMplsteHeadSessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionBriefs>`
    
    .. attribute:: ipv4bf_do_mplste_head_session_details
    
    	Table of detailed information about all IPv4 BFD over MPLS\-TE Head sessions in the System
    	**type**\:   :py:class:`Ipv4BfDoMplsteHeadSessionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails>`
    
    .. attribute:: ipv4bf_do_mplste_head_summary
    
    	Summary information of IPv4 BFD over MPLS\-TE Head
    	**type**\:   :py:class:`Ipv4BfDoMplsteHeadSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSummary>`
    
    .. attribute:: ipv4bf_do_mplste_tail_counters
    
    	IPv4 BFD over MPLS\-TE Counters
    	**type**\:   :py:class:`Ipv4BfDoMplsteTailCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailCounters>`
    
    .. attribute:: ipv4bf_do_mplste_tail_multi_paths
    
    	IPv4 BFD over MPLS\-TE Tail multipath
    	**type**\:   :py:class:`Ipv4BfDoMplsteTailMultiPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailMultiPaths>`
    
    .. attribute:: ipv4bf_do_mplste_tail_session_briefs
    
    	Table of brief information about all IPv4 BFD over MPLS\-TE Tail sessions in the System
    	**type**\:   :py:class:`Ipv4BfDoMplsteTailSessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionBriefs>`
    
    .. attribute:: ipv4bf_do_mplste_tail_session_details
    
    	Table of detailed information about all IPv4 BFD over MPLS\-TE Tail sessions in the System
    	**type**\:   :py:class:`Ipv4BfDoMplsteTailSessionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails>`
    
    .. attribute:: ipv4bf_do_mplste_tail_summary
    
    	Summary information of IPv4 BFD over MPLS\-TE Tail
    	**type**\:   :py:class:`Ipv4BfDoMplsteTailSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSummary>`
    
    .. attribute:: ipv4bfd_mplste_head_summary_nodes
    
    	Table of summary about IPv4 TE head BFD sessions for location
    	**type**\:   :py:class:`Ipv4BfdMplsteHeadSummaryNodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfdMplsteHeadSummaryNodes>`
    
    .. attribute:: ipv4bfd_mplste_tail_node_summaries
    
    	Table of summary about IPv4 TE tail BFD sessions for location
    	**type**\:   :py:class:`Ipv4BfdMplsteTailNodeSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfdMplsteTailNodeSummaries>`
    
    .. attribute:: ipv6_multi_hop_counters
    
    	IPv6 multiple hop Counters
    	**type**\:   :py:class:`Ipv6MultiHopCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopCounters>`
    
    .. attribute:: ipv6_multi_hop_multi_paths
    
    	IPv6 multi hop multipath
    	**type**\:   :py:class:`Ipv6MultiHopMultiPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopMultiPaths>`
    
    .. attribute:: ipv6_multi_hop_node_location_summaries
    
    	Table of summary information about BFD IPv6 multihop sessions per location
    	**type**\:   :py:class:`Ipv6MultiHopNodeLocationSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopNodeLocationSummaries>`
    
    .. attribute:: ipv6_multi_hop_session_briefs
    
    	Table of brief information about all IPv6 multihop BFD sessions in the System
    	**type**\:   :py:class:`Ipv6MultiHopSessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionBriefs>`
    
    .. attribute:: ipv6_multi_hop_session_details
    
    	Table of detailed information about all IPv6 multihop BFD sessions in the System 
    	**type**\:   :py:class:`Ipv6MultiHopSessionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails>`
    
    .. attribute:: ipv6_multi_hop_summary
    
    	Summary information of BFD IPv6 multihop sessions
    	**type**\:   :py:class:`Ipv6MultiHopSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSummary>`
    
    .. attribute:: ipv6_single_hop_counters
    
    	IPv6 single hop Counters
    	**type**\:   :py:class:`Ipv6SingleHopCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopCounters>`
    
    .. attribute:: ipv6_single_hop_location_summaries
    
    	Table of summary information about BFD IPv6 singlehop sessions per location
    	**type**\:   :py:class:`Ipv6SingleHopLocationSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopLocationSummaries>`
    
    .. attribute:: ipv6_single_hop_multi_paths
    
    	IPv6 single hop multipath
    	**type**\:   :py:class:`Ipv6SingleHopMultiPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopMultiPaths>`
    
    .. attribute:: ipv6_single_hop_node_location_summaries
    
    	Table of summary information about BFD IPv6 singlehop sessions per location
    	**type**\:   :py:class:`Ipv6SingleHopNodeLocationSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopNodeLocationSummaries>`
    
    .. attribute:: ipv6_single_hop_session_briefs
    
    	Table of brief information about all IPv6 singlehop BFD sessions in the System
    	**type**\:   :py:class:`Ipv6SingleHopSessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionBriefs>`
    
    .. attribute:: ipv6_single_hop_session_details
    
    	Table of detailed information about all IPv6 singlehop BFD sessions in the System 
    	**type**\:   :py:class:`Ipv6SingleHopSessionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails>`
    
    .. attribute:: ipv6_single_hop_summary
    
    	Summary information of BFD IPv6 singlehop sessions
    	**type**\:   :py:class:`Ipv6SingleHopSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSummary>`
    
    .. attribute:: label_counters
    
    	Label Counters
    	**type**\:   :py:class:`LabelCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelCounters>`
    
    .. attribute:: label_multi_paths
    
    	Label multipath
    	**type**\:   :py:class:`LabelMultiPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelMultiPaths>`
    
    .. attribute:: label_session_briefs
    
    	Table of brief information about all Label BFD sessions in the System
    	**type**\:   :py:class:`LabelSessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionBriefs>`
    
    .. attribute:: label_session_details
    
    	Table of detailed information about all Label BFD sessions in the System 
    	**type**\:   :py:class:`LabelSessionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails>`
    
    .. attribute:: label_summary
    
    	Summary information of Label BFD
    	**type**\:   :py:class:`LabelSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSummary>`
    
    .. attribute:: label_summary_nodes
    
    	Table of summary about Label BFD sessions for location
    	**type**\:   :py:class:`LabelSummaryNodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSummaryNodes>`
    
    .. attribute:: relation_briefs
    
    	Table of brief information about all BFD relations in the System
    	**type**\:   :py:class:`RelationBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.RelationBriefs>`
    
    .. attribute:: relation_details
    
    	Table of detail information about all BFD relations in the System
    	**type**\:   :py:class:`RelationDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.RelationDetails>`
    
    .. attribute:: session_briefs
    
    	Table of brief information about singlehop IPv4 BFD sessions in the System
    	**type**\:   :py:class:`SessionBriefs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionBriefs>`
    
    .. attribute:: session_details
    
    	Table of detailed information about IPv4 singlehop BFD sessions in the System 
    	**type**\:   :py:class:`SessionDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails>`
    
    .. attribute:: session_mibs
    
    	BFD session MIB database
    	**type**\:   :py:class:`SessionMibs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionMibs>`
    
    .. attribute:: summary
    
    	Summary information of BFD IPv4 singlehop sessions
    	**type**\:   :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Summary>`
    
    

    """

    _prefix = 'ip-bfd-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Bfd, self).__init__()
        self._top_entity = None

        self.yang_name = "bfd"
        self.yang_parent_name = "Cisco-IOS-XR-ip-bfd-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"client-briefs" : ("client_briefs", Bfd.ClientBriefs), "client-details" : ("client_details", Bfd.ClientDetails), "counters" : ("counters", Bfd.Counters), "generic-summaries" : ("generic_summaries", Bfd.GenericSummaries), "ipv4-multi-hop-counters" : ("ipv4_multi_hop_counters", Bfd.Ipv4MultiHopCounters), "ipv4-multi-hop-multi-paths" : ("ipv4_multi_hop_multi_paths", Bfd.Ipv4MultiHopMultiPaths), "ipv4-multi-hop-node-location-summaries" : ("ipv4_multi_hop_node_location_summaries", Bfd.Ipv4MultiHopNodeLocationSummaries), "ipv4-multi-hop-session-briefs" : ("ipv4_multi_hop_session_briefs", Bfd.Ipv4MultiHopSessionBriefs), "ipv4-multi-hop-session-details" : ("ipv4_multi_hop_session_details", Bfd.Ipv4MultiHopSessionDetails), "ipv4-multi-hop-summary" : ("ipv4_multi_hop_summary", Bfd.Ipv4MultiHopSummary), "ipv4-single-hop-counters" : ("ipv4_single_hop_counters", Bfd.Ipv4SingleHopCounters), "ipv4-single-hop-location-summaries" : ("ipv4_single_hop_location_summaries", Bfd.Ipv4SingleHopLocationSummaries), "ipv4-single-hop-multi-paths" : ("ipv4_single_hop_multi_paths", Bfd.Ipv4SingleHopMultiPaths), "ipv4-single-hop-node-location-summaries" : ("ipv4_single_hop_node_location_summaries", Bfd.Ipv4SingleHopNodeLocationSummaries), "ipv4-single-hop-session-briefs" : ("ipv4_single_hop_session_briefs", Bfd.Ipv4SingleHopSessionBriefs), "ipv4-single-hop-session-details" : ("ipv4_single_hop_session_details", Bfd.Ipv4SingleHopSessionDetails), "ipv4-single-hop-summary" : ("ipv4_single_hop_summary", Bfd.Ipv4SingleHopSummary), "ipv4bf-do-mplste-head-counters" : ("ipv4bf_do_mplste_head_counters", Bfd.Ipv4BfDoMplsteHeadCounters), "ipv4bf-do-mplste-head-multi-paths" : ("ipv4bf_do_mplste_head_multi_paths", Bfd.Ipv4BfDoMplsteHeadMultiPaths), "ipv4bf-do-mplste-head-session-briefs" : ("ipv4bf_do_mplste_head_session_briefs", Bfd.Ipv4BfDoMplsteHeadSessionBriefs), "ipv4bf-do-mplste-head-session-details" : ("ipv4bf_do_mplste_head_session_details", Bfd.Ipv4BfDoMplsteHeadSessionDetails), "ipv4bf-do-mplste-head-summary" : ("ipv4bf_do_mplste_head_summary", Bfd.Ipv4BfDoMplsteHeadSummary), "ipv4bf-do-mplste-tail-counters" : ("ipv4bf_do_mplste_tail_counters", Bfd.Ipv4BfDoMplsteTailCounters), "ipv4bf-do-mplste-tail-multi-paths" : ("ipv4bf_do_mplste_tail_multi_paths", Bfd.Ipv4BfDoMplsteTailMultiPaths), "ipv4bf-do-mplste-tail-session-briefs" : ("ipv4bf_do_mplste_tail_session_briefs", Bfd.Ipv4BfDoMplsteTailSessionBriefs), "ipv4bf-do-mplste-tail-session-details" : ("ipv4bf_do_mplste_tail_session_details", Bfd.Ipv4BfDoMplsteTailSessionDetails), "ipv4bf-do-mplste-tail-summary" : ("ipv4bf_do_mplste_tail_summary", Bfd.Ipv4BfDoMplsteTailSummary), "ipv4bfd-mplste-head-summary-nodes" : ("ipv4bfd_mplste_head_summary_nodes", Bfd.Ipv4BfdMplsteHeadSummaryNodes), "ipv4bfd-mplste-tail-node-summaries" : ("ipv4bfd_mplste_tail_node_summaries", Bfd.Ipv4BfdMplsteTailNodeSummaries), "ipv6-multi-hop-counters" : ("ipv6_multi_hop_counters", Bfd.Ipv6MultiHopCounters), "ipv6-multi-hop-multi-paths" : ("ipv6_multi_hop_multi_paths", Bfd.Ipv6MultiHopMultiPaths), "ipv6-multi-hop-node-location-summaries" : ("ipv6_multi_hop_node_location_summaries", Bfd.Ipv6MultiHopNodeLocationSummaries), "ipv6-multi-hop-session-briefs" : ("ipv6_multi_hop_session_briefs", Bfd.Ipv6MultiHopSessionBriefs), "ipv6-multi-hop-session-details" : ("ipv6_multi_hop_session_details", Bfd.Ipv6MultiHopSessionDetails), "ipv6-multi-hop-summary" : ("ipv6_multi_hop_summary", Bfd.Ipv6MultiHopSummary), "ipv6-single-hop-counters" : ("ipv6_single_hop_counters", Bfd.Ipv6SingleHopCounters), "ipv6-single-hop-location-summaries" : ("ipv6_single_hop_location_summaries", Bfd.Ipv6SingleHopLocationSummaries), "ipv6-single-hop-multi-paths" : ("ipv6_single_hop_multi_paths", Bfd.Ipv6SingleHopMultiPaths), "ipv6-single-hop-node-location-summaries" : ("ipv6_single_hop_node_location_summaries", Bfd.Ipv6SingleHopNodeLocationSummaries), "ipv6-single-hop-session-briefs" : ("ipv6_single_hop_session_briefs", Bfd.Ipv6SingleHopSessionBriefs), "ipv6-single-hop-session-details" : ("ipv6_single_hop_session_details", Bfd.Ipv6SingleHopSessionDetails), "ipv6-single-hop-summary" : ("ipv6_single_hop_summary", Bfd.Ipv6SingleHopSummary), "label-counters" : ("label_counters", Bfd.LabelCounters), "label-multi-paths" : ("label_multi_paths", Bfd.LabelMultiPaths), "label-session-briefs" : ("label_session_briefs", Bfd.LabelSessionBriefs), "label-session-details" : ("label_session_details", Bfd.LabelSessionDetails), "label-summary" : ("label_summary", Bfd.LabelSummary), "label-summary-nodes" : ("label_summary_nodes", Bfd.LabelSummaryNodes), "relation-briefs" : ("relation_briefs", Bfd.RelationBriefs), "relation-details" : ("relation_details", Bfd.RelationDetails), "session-briefs" : ("session_briefs", Bfd.SessionBriefs), "session-details" : ("session_details", Bfd.SessionDetails), "session-mibs" : ("session_mibs", Bfd.SessionMibs), "summary" : ("summary", Bfd.Summary)}
        self._child_list_classes = {}

        self.client_briefs = Bfd.ClientBriefs()
        self.client_briefs.parent = self
        self._children_name_map["client_briefs"] = "client-briefs"
        self._children_yang_names.add("client-briefs")

        self.client_details = Bfd.ClientDetails()
        self.client_details.parent = self
        self._children_name_map["client_details"] = "client-details"
        self._children_yang_names.add("client-details")

        self.counters = Bfd.Counters()
        self.counters.parent = self
        self._children_name_map["counters"] = "counters"
        self._children_yang_names.add("counters")

        self.generic_summaries = Bfd.GenericSummaries()
        self.generic_summaries.parent = self
        self._children_name_map["generic_summaries"] = "generic-summaries"
        self._children_yang_names.add("generic-summaries")

        self.ipv4_multi_hop_counters = Bfd.Ipv4MultiHopCounters()
        self.ipv4_multi_hop_counters.parent = self
        self._children_name_map["ipv4_multi_hop_counters"] = "ipv4-multi-hop-counters"
        self._children_yang_names.add("ipv4-multi-hop-counters")

        self.ipv4_multi_hop_multi_paths = Bfd.Ipv4MultiHopMultiPaths()
        self.ipv4_multi_hop_multi_paths.parent = self
        self._children_name_map["ipv4_multi_hop_multi_paths"] = "ipv4-multi-hop-multi-paths"
        self._children_yang_names.add("ipv4-multi-hop-multi-paths")

        self.ipv4_multi_hop_node_location_summaries = Bfd.Ipv4MultiHopNodeLocationSummaries()
        self.ipv4_multi_hop_node_location_summaries.parent = self
        self._children_name_map["ipv4_multi_hop_node_location_summaries"] = "ipv4-multi-hop-node-location-summaries"
        self._children_yang_names.add("ipv4-multi-hop-node-location-summaries")

        self.ipv4_multi_hop_session_briefs = Bfd.Ipv4MultiHopSessionBriefs()
        self.ipv4_multi_hop_session_briefs.parent = self
        self._children_name_map["ipv4_multi_hop_session_briefs"] = "ipv4-multi-hop-session-briefs"
        self._children_yang_names.add("ipv4-multi-hop-session-briefs")

        self.ipv4_multi_hop_session_details = Bfd.Ipv4MultiHopSessionDetails()
        self.ipv4_multi_hop_session_details.parent = self
        self._children_name_map["ipv4_multi_hop_session_details"] = "ipv4-multi-hop-session-details"
        self._children_yang_names.add("ipv4-multi-hop-session-details")

        self.ipv4_multi_hop_summary = Bfd.Ipv4MultiHopSummary()
        self.ipv4_multi_hop_summary.parent = self
        self._children_name_map["ipv4_multi_hop_summary"] = "ipv4-multi-hop-summary"
        self._children_yang_names.add("ipv4-multi-hop-summary")

        self.ipv4_single_hop_counters = Bfd.Ipv4SingleHopCounters()
        self.ipv4_single_hop_counters.parent = self
        self._children_name_map["ipv4_single_hop_counters"] = "ipv4-single-hop-counters"
        self._children_yang_names.add("ipv4-single-hop-counters")

        self.ipv4_single_hop_location_summaries = Bfd.Ipv4SingleHopLocationSummaries()
        self.ipv4_single_hop_location_summaries.parent = self
        self._children_name_map["ipv4_single_hop_location_summaries"] = "ipv4-single-hop-location-summaries"
        self._children_yang_names.add("ipv4-single-hop-location-summaries")

        self.ipv4_single_hop_multi_paths = Bfd.Ipv4SingleHopMultiPaths()
        self.ipv4_single_hop_multi_paths.parent = self
        self._children_name_map["ipv4_single_hop_multi_paths"] = "ipv4-single-hop-multi-paths"
        self._children_yang_names.add("ipv4-single-hop-multi-paths")

        self.ipv4_single_hop_node_location_summaries = Bfd.Ipv4SingleHopNodeLocationSummaries()
        self.ipv4_single_hop_node_location_summaries.parent = self
        self._children_name_map["ipv4_single_hop_node_location_summaries"] = "ipv4-single-hop-node-location-summaries"
        self._children_yang_names.add("ipv4-single-hop-node-location-summaries")

        self.ipv4_single_hop_session_briefs = Bfd.Ipv4SingleHopSessionBriefs()
        self.ipv4_single_hop_session_briefs.parent = self
        self._children_name_map["ipv4_single_hop_session_briefs"] = "ipv4-single-hop-session-briefs"
        self._children_yang_names.add("ipv4-single-hop-session-briefs")

        self.ipv4_single_hop_session_details = Bfd.Ipv4SingleHopSessionDetails()
        self.ipv4_single_hop_session_details.parent = self
        self._children_name_map["ipv4_single_hop_session_details"] = "ipv4-single-hop-session-details"
        self._children_yang_names.add("ipv4-single-hop-session-details")

        self.ipv4_single_hop_summary = Bfd.Ipv4SingleHopSummary()
        self.ipv4_single_hop_summary.parent = self
        self._children_name_map["ipv4_single_hop_summary"] = "ipv4-single-hop-summary"
        self._children_yang_names.add("ipv4-single-hop-summary")

        self.ipv4bf_do_mplste_head_counters = Bfd.Ipv4BfDoMplsteHeadCounters()
        self.ipv4bf_do_mplste_head_counters.parent = self
        self._children_name_map["ipv4bf_do_mplste_head_counters"] = "ipv4bf-do-mplste-head-counters"
        self._children_yang_names.add("ipv4bf-do-mplste-head-counters")

        self.ipv4bf_do_mplste_head_multi_paths = Bfd.Ipv4BfDoMplsteHeadMultiPaths()
        self.ipv4bf_do_mplste_head_multi_paths.parent = self
        self._children_name_map["ipv4bf_do_mplste_head_multi_paths"] = "ipv4bf-do-mplste-head-multi-paths"
        self._children_yang_names.add("ipv4bf-do-mplste-head-multi-paths")

        self.ipv4bf_do_mplste_head_session_briefs = Bfd.Ipv4BfDoMplsteHeadSessionBriefs()
        self.ipv4bf_do_mplste_head_session_briefs.parent = self
        self._children_name_map["ipv4bf_do_mplste_head_session_briefs"] = "ipv4bf-do-mplste-head-session-briefs"
        self._children_yang_names.add("ipv4bf-do-mplste-head-session-briefs")

        self.ipv4bf_do_mplste_head_session_details = Bfd.Ipv4BfDoMplsteHeadSessionDetails()
        self.ipv4bf_do_mplste_head_session_details.parent = self
        self._children_name_map["ipv4bf_do_mplste_head_session_details"] = "ipv4bf-do-mplste-head-session-details"
        self._children_yang_names.add("ipv4bf-do-mplste-head-session-details")

        self.ipv4bf_do_mplste_head_summary = Bfd.Ipv4BfDoMplsteHeadSummary()
        self.ipv4bf_do_mplste_head_summary.parent = self
        self._children_name_map["ipv4bf_do_mplste_head_summary"] = "ipv4bf-do-mplste-head-summary"
        self._children_yang_names.add("ipv4bf-do-mplste-head-summary")

        self.ipv4bf_do_mplste_tail_counters = Bfd.Ipv4BfDoMplsteTailCounters()
        self.ipv4bf_do_mplste_tail_counters.parent = self
        self._children_name_map["ipv4bf_do_mplste_tail_counters"] = "ipv4bf-do-mplste-tail-counters"
        self._children_yang_names.add("ipv4bf-do-mplste-tail-counters")

        self.ipv4bf_do_mplste_tail_multi_paths = Bfd.Ipv4BfDoMplsteTailMultiPaths()
        self.ipv4bf_do_mplste_tail_multi_paths.parent = self
        self._children_name_map["ipv4bf_do_mplste_tail_multi_paths"] = "ipv4bf-do-mplste-tail-multi-paths"
        self._children_yang_names.add("ipv4bf-do-mplste-tail-multi-paths")

        self.ipv4bf_do_mplste_tail_session_briefs = Bfd.Ipv4BfDoMplsteTailSessionBriefs()
        self.ipv4bf_do_mplste_tail_session_briefs.parent = self
        self._children_name_map["ipv4bf_do_mplste_tail_session_briefs"] = "ipv4bf-do-mplste-tail-session-briefs"
        self._children_yang_names.add("ipv4bf-do-mplste-tail-session-briefs")

        self.ipv4bf_do_mplste_tail_session_details = Bfd.Ipv4BfDoMplsteTailSessionDetails()
        self.ipv4bf_do_mplste_tail_session_details.parent = self
        self._children_name_map["ipv4bf_do_mplste_tail_session_details"] = "ipv4bf-do-mplste-tail-session-details"
        self._children_yang_names.add("ipv4bf-do-mplste-tail-session-details")

        self.ipv4bf_do_mplste_tail_summary = Bfd.Ipv4BfDoMplsteTailSummary()
        self.ipv4bf_do_mplste_tail_summary.parent = self
        self._children_name_map["ipv4bf_do_mplste_tail_summary"] = "ipv4bf-do-mplste-tail-summary"
        self._children_yang_names.add("ipv4bf-do-mplste-tail-summary")

        self.ipv4bfd_mplste_head_summary_nodes = Bfd.Ipv4BfdMplsteHeadSummaryNodes()
        self.ipv4bfd_mplste_head_summary_nodes.parent = self
        self._children_name_map["ipv4bfd_mplste_head_summary_nodes"] = "ipv4bfd-mplste-head-summary-nodes"
        self._children_yang_names.add("ipv4bfd-mplste-head-summary-nodes")

        self.ipv4bfd_mplste_tail_node_summaries = Bfd.Ipv4BfdMplsteTailNodeSummaries()
        self.ipv4bfd_mplste_tail_node_summaries.parent = self
        self._children_name_map["ipv4bfd_mplste_tail_node_summaries"] = "ipv4bfd-mplste-tail-node-summaries"
        self._children_yang_names.add("ipv4bfd-mplste-tail-node-summaries")

        self.ipv6_multi_hop_counters = Bfd.Ipv6MultiHopCounters()
        self.ipv6_multi_hop_counters.parent = self
        self._children_name_map["ipv6_multi_hop_counters"] = "ipv6-multi-hop-counters"
        self._children_yang_names.add("ipv6-multi-hop-counters")

        self.ipv6_multi_hop_multi_paths = Bfd.Ipv6MultiHopMultiPaths()
        self.ipv6_multi_hop_multi_paths.parent = self
        self._children_name_map["ipv6_multi_hop_multi_paths"] = "ipv6-multi-hop-multi-paths"
        self._children_yang_names.add("ipv6-multi-hop-multi-paths")

        self.ipv6_multi_hop_node_location_summaries = Bfd.Ipv6MultiHopNodeLocationSummaries()
        self.ipv6_multi_hop_node_location_summaries.parent = self
        self._children_name_map["ipv6_multi_hop_node_location_summaries"] = "ipv6-multi-hop-node-location-summaries"
        self._children_yang_names.add("ipv6-multi-hop-node-location-summaries")

        self.ipv6_multi_hop_session_briefs = Bfd.Ipv6MultiHopSessionBriefs()
        self.ipv6_multi_hop_session_briefs.parent = self
        self._children_name_map["ipv6_multi_hop_session_briefs"] = "ipv6-multi-hop-session-briefs"
        self._children_yang_names.add("ipv6-multi-hop-session-briefs")

        self.ipv6_multi_hop_session_details = Bfd.Ipv6MultiHopSessionDetails()
        self.ipv6_multi_hop_session_details.parent = self
        self._children_name_map["ipv6_multi_hop_session_details"] = "ipv6-multi-hop-session-details"
        self._children_yang_names.add("ipv6-multi-hop-session-details")

        self.ipv6_multi_hop_summary = Bfd.Ipv6MultiHopSummary()
        self.ipv6_multi_hop_summary.parent = self
        self._children_name_map["ipv6_multi_hop_summary"] = "ipv6-multi-hop-summary"
        self._children_yang_names.add("ipv6-multi-hop-summary")

        self.ipv6_single_hop_counters = Bfd.Ipv6SingleHopCounters()
        self.ipv6_single_hop_counters.parent = self
        self._children_name_map["ipv6_single_hop_counters"] = "ipv6-single-hop-counters"
        self._children_yang_names.add("ipv6-single-hop-counters")

        self.ipv6_single_hop_location_summaries = Bfd.Ipv6SingleHopLocationSummaries()
        self.ipv6_single_hop_location_summaries.parent = self
        self._children_name_map["ipv6_single_hop_location_summaries"] = "ipv6-single-hop-location-summaries"
        self._children_yang_names.add("ipv6-single-hop-location-summaries")

        self.ipv6_single_hop_multi_paths = Bfd.Ipv6SingleHopMultiPaths()
        self.ipv6_single_hop_multi_paths.parent = self
        self._children_name_map["ipv6_single_hop_multi_paths"] = "ipv6-single-hop-multi-paths"
        self._children_yang_names.add("ipv6-single-hop-multi-paths")

        self.ipv6_single_hop_node_location_summaries = Bfd.Ipv6SingleHopNodeLocationSummaries()
        self.ipv6_single_hop_node_location_summaries.parent = self
        self._children_name_map["ipv6_single_hop_node_location_summaries"] = "ipv6-single-hop-node-location-summaries"
        self._children_yang_names.add("ipv6-single-hop-node-location-summaries")

        self.ipv6_single_hop_session_briefs = Bfd.Ipv6SingleHopSessionBriefs()
        self.ipv6_single_hop_session_briefs.parent = self
        self._children_name_map["ipv6_single_hop_session_briefs"] = "ipv6-single-hop-session-briefs"
        self._children_yang_names.add("ipv6-single-hop-session-briefs")

        self.ipv6_single_hop_session_details = Bfd.Ipv6SingleHopSessionDetails()
        self.ipv6_single_hop_session_details.parent = self
        self._children_name_map["ipv6_single_hop_session_details"] = "ipv6-single-hop-session-details"
        self._children_yang_names.add("ipv6-single-hop-session-details")

        self.ipv6_single_hop_summary = Bfd.Ipv6SingleHopSummary()
        self.ipv6_single_hop_summary.parent = self
        self._children_name_map["ipv6_single_hop_summary"] = "ipv6-single-hop-summary"
        self._children_yang_names.add("ipv6-single-hop-summary")

        self.label_counters = Bfd.LabelCounters()
        self.label_counters.parent = self
        self._children_name_map["label_counters"] = "label-counters"
        self._children_yang_names.add("label-counters")

        self.label_multi_paths = Bfd.LabelMultiPaths()
        self.label_multi_paths.parent = self
        self._children_name_map["label_multi_paths"] = "label-multi-paths"
        self._children_yang_names.add("label-multi-paths")

        self.label_session_briefs = Bfd.LabelSessionBriefs()
        self.label_session_briefs.parent = self
        self._children_name_map["label_session_briefs"] = "label-session-briefs"
        self._children_yang_names.add("label-session-briefs")

        self.label_session_details = Bfd.LabelSessionDetails()
        self.label_session_details.parent = self
        self._children_name_map["label_session_details"] = "label-session-details"
        self._children_yang_names.add("label-session-details")

        self.label_summary = Bfd.LabelSummary()
        self.label_summary.parent = self
        self._children_name_map["label_summary"] = "label-summary"
        self._children_yang_names.add("label-summary")

        self.label_summary_nodes = Bfd.LabelSummaryNodes()
        self.label_summary_nodes.parent = self
        self._children_name_map["label_summary_nodes"] = "label-summary-nodes"
        self._children_yang_names.add("label-summary-nodes")

        self.relation_briefs = Bfd.RelationBriefs()
        self.relation_briefs.parent = self
        self._children_name_map["relation_briefs"] = "relation-briefs"
        self._children_yang_names.add("relation-briefs")

        self.relation_details = Bfd.RelationDetails()
        self.relation_details.parent = self
        self._children_name_map["relation_details"] = "relation-details"
        self._children_yang_names.add("relation-details")

        self.session_briefs = Bfd.SessionBriefs()
        self.session_briefs.parent = self
        self._children_name_map["session_briefs"] = "session-briefs"
        self._children_yang_names.add("session-briefs")

        self.session_details = Bfd.SessionDetails()
        self.session_details.parent = self
        self._children_name_map["session_details"] = "session-details"
        self._children_yang_names.add("session-details")

        self.session_mibs = Bfd.SessionMibs()
        self.session_mibs.parent = self
        self._children_name_map["session_mibs"] = "session-mibs"
        self._children_yang_names.add("session-mibs")

        self.summary = Bfd.Summary()
        self.summary.parent = self
        self._children_name_map["summary"] = "summary"
        self._children_yang_names.add("summary")
        self._segment_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd"


    class ClientBriefs(Entity):
        """
        Table of Brief information about BFD clients
        
        .. attribute:: client_brief
        
        	Brief information of client
        	**type**\: list of    :py:class:`ClientBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.ClientBriefs.ClientBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.ClientBriefs, self).__init__()

            self.yang_name = "client-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"client-brief" : ("client_brief", Bfd.ClientBriefs.ClientBrief)}

            self.client_brief = YList(self)
            self._segment_path = lambda: "client-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.ClientBriefs, [], name, value)


        class ClientBrief(Entity):
            """
            Brief information of client
            
            .. attribute:: name  <key>
            
            	Client Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: name_xr
            
            	Client process name
            	**type**\:  str
            
            	**length:** 0..257
            
            .. attribute:: node_id
            
            	Location where client resides
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_count
            
            	Number of sessions created by this client
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.ClientBriefs.ClientBrief, self).__init__()

                self.yang_name = "client-brief"
                self.yang_parent_name = "client-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.name = YLeaf(YType.str, "name")

                self.name_xr = YLeaf(YType.str, "name-xr")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_count = YLeaf(YType.uint32, "session-count")
                self._segment_path = lambda: "client-brief" + "[name='" + self.name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/client-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.ClientBriefs.ClientBrief, ['name', 'name_xr', 'node_id', 'session_count'], name, value)


    class ClientDetails(Entity):
        """
        Table of detailed information about BFD clients
        
        .. attribute:: client_detail
        
        	Detailed information of client
        	**type**\: list of    :py:class:`ClientDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.ClientDetails.ClientDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.ClientDetails, self).__init__()

            self.yang_name = "client-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"client-detail" : ("client_detail", Bfd.ClientDetails.ClientDetail)}

            self.client_detail = YList(self)
            self._segment_path = lambda: "client-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.ClientDetails, [], name, value)


        class ClientDetail(Entity):
            """
            Detailed information of client
            
            .. attribute:: client_name  <key>
            
            	Client Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: brief
            
            	Brief client information
            	**type**\:   :py:class:`Brief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.ClientDetails.ClientDetail.Brief>`
            
            .. attribute:: flags
            
            	The BFD Client Flags
            	**type**\:   :py:class:`Flags <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.ClientDetails.ClientDetail.Flags>`
            
            .. attribute:: recreate_time
            
            	Recreate Time in Seconds
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.ClientDetails.ClientDetail, self).__init__()

                self.yang_name = "client-detail"
                self.yang_parent_name = "client-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"brief" : ("brief", Bfd.ClientDetails.ClientDetail.Brief), "flags" : ("flags", Bfd.ClientDetails.ClientDetail.Flags)}
                self._child_list_classes = {}

                self.client_name = YLeaf(YType.str, "client-name")

                self.recreate_time = YLeaf(YType.uint32, "recreate-time")

                self.brief = Bfd.ClientDetails.ClientDetail.Brief()
                self.brief.parent = self
                self._children_name_map["brief"] = "brief"
                self._children_yang_names.add("brief")

                self.flags = Bfd.ClientDetails.ClientDetail.Flags()
                self.flags.parent = self
                self._children_name_map["flags"] = "flags"
                self._children_yang_names.add("flags")
                self._segment_path = lambda: "client-detail" + "[client-name='" + self.client_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/client-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.ClientDetails.ClientDetail, ['client_name', 'recreate_time'], name, value)


            class Brief(Entity):
                """
                Brief client information
                
                .. attribute:: name_xr
                
                	Client process name
                	**type**\:  str
                
                	**length:** 0..257
                
                .. attribute:: node_id
                
                	Location where client resides
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: session_count
                
                	Number of sessions created by this client
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.ClientDetails.ClientDetail.Brief, self).__init__()

                    self.yang_name = "brief"
                    self.yang_parent_name = "client-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.name_xr = YLeaf(YType.str, "name-xr")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.session_count = YLeaf(YType.uint32, "session-count")
                    self._segment_path = lambda: "brief"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.ClientDetails.ClientDetail.Brief, ['name_xr', 'node_id', 'session_count'], name, value)


            class Flags(Entity):
                """
                The BFD Client Flags
                
                .. attribute:: is_recreate_state
                
                	Client is in Recreate State
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: is_zombie_state
                
                	Client is in Zombie State
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.ClientDetails.ClientDetail.Flags, self).__init__()

                    self.yang_name = "flags"
                    self.yang_parent_name = "client-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.is_recreate_state = YLeaf(YType.int32, "is-recreate-state")

                    self.is_zombie_state = YLeaf(YType.int32, "is-zombie-state")
                    self._segment_path = lambda: "flags"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.ClientDetails.ClientDetail.Flags, ['is_recreate_state', 'is_zombie_state'], name, value)


    class Counters(Entity):
        """
        Counters
        
        .. attribute:: packet_counters
        
        	Table of Packet counters
        	**type**\:   :py:class:`PacketCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Counters.PacketCounters>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Counters, self).__init__()

            self.yang_name = "counters"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"packet-counters" : ("packet_counters", Bfd.Counters.PacketCounters)}
            self._child_list_classes = {}

            self.packet_counters = Bfd.Counters.PacketCounters()
            self.packet_counters.parent = self
            self._children_name_map["packet_counters"] = "packet-counters"
            self._children_yang_names.add("packet-counters")
            self._segment_path = lambda: "counters"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class PacketCounters(Entity):
            """
            Table of Packet counters
            
            .. attribute:: packet_counter
            
            	Interface Packet counters
            	**type**\: list of    :py:class:`PacketCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Counters.PacketCounters.PacketCounter>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Counters.PacketCounters, self).__init__()

                self.yang_name = "packet-counters"
                self.yang_parent_name = "counters"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"packet-counter" : ("packet_counter", Bfd.Counters.PacketCounters.PacketCounter)}

                self.packet_counter = YList(self)
                self._segment_path = lambda: "packet-counters"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/counters/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Counters.PacketCounters, [], name, value)


            class PacketCounter(Entity):
                """
                Interface Packet counters
                
                .. attribute:: interface_name  <key>
                
                	Interface Name
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: display_type
                
                	Packet Display Type
                	**type**\:   :py:class:`BfdMgmtPktDisplay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtPktDisplay>`
                
                .. attribute:: echo_receive_count
                
                	Number of echo packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: echo_transmit_count
                
                	Number of echo packets transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_receive_count
                
                	Number of Hellos received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_transmit_count
                
                	Number of Hellos transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Counters.PacketCounters.PacketCounter, self).__init__()

                    self.yang_name = "packet-counter"
                    self.yang_parent_name = "packet-counters"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.display_type = YLeaf(YType.enumeration, "display-type")

                    self.echo_receive_count = YLeaf(YType.uint32, "echo-receive-count")

                    self.echo_transmit_count = YLeaf(YType.uint32, "echo-transmit-count")

                    self.hello_receive_count = YLeaf(YType.uint32, "hello-receive-count")

                    self.hello_transmit_count = YLeaf(YType.uint32, "hello-transmit-count")
                    self._segment_path = lambda: "packet-counter" + "[interface-name='" + self.interface_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/counters/packet-counters/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Counters.PacketCounters.PacketCounter, ['interface_name', 'display_type', 'echo_receive_count', 'echo_transmit_count', 'hello_receive_count', 'hello_transmit_count'], name, value)


    class GenericSummaries(Entity):
        """
        Generic summary information about BFD location
        
        .. attribute:: generic_summary
        
        	Generic summary information for bfd location table
        	**type**\: list of    :py:class:`GenericSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.GenericSummaries.GenericSummary>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.GenericSummaries, self).__init__()

            self.yang_name = "generic-summaries"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"generic-summary" : ("generic_summary", Bfd.GenericSummaries.GenericSummary)}

            self.generic_summary = YList(self)
            self._segment_path = lambda: "generic-summaries"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.GenericSummaries, [], name, value)


        class GenericSummary(Entity):
            """
            Generic summary information for bfd location
            table
            
            .. attribute:: location  <key>
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: max_session_number
            
            	Max Session Number
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: mp_session_number
            
            	MP Session Number
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: node_id
            
            	Node ID
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: pps_all_percentage
            
            	All PPS percentage
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: percentage
            
            .. attribute:: pps_allocated_value
            
            	Allocated PPS value
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pps_max_value
            
            	Max PPS value
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ppsmp_allocated_value
            
            	Allocated MP PPS value
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ppsmp_max_value
            
            	Max MP PPS value
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: ppsmp_percentage
            
            	MP PPS percentage
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: percentage
            
            .. attribute:: total_session_number
            
            	Total Session Number
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.GenericSummaries.GenericSummary, self).__init__()

                self.yang_name = "generic-summary"
                self.yang_parent_name = "generic-summaries"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.location = YLeaf(YType.str, "location")

                self.max_session_number = YLeaf(YType.uint32, "max-session-number")

                self.mp_session_number = YLeaf(YType.uint32, "mp-session-number")

                self.node_id = YLeaf(YType.str, "node-id")

                self.pps_all_percentage = YLeaf(YType.uint32, "pps-all-percentage")

                self.pps_allocated_value = YLeaf(YType.uint32, "pps-allocated-value")

                self.pps_max_value = YLeaf(YType.uint32, "pps-max-value")

                self.ppsmp_allocated_value = YLeaf(YType.uint32, "ppsmp-allocated-value")

                self.ppsmp_max_value = YLeaf(YType.uint32, "ppsmp-max-value")

                self.ppsmp_percentage = YLeaf(YType.uint32, "ppsmp-percentage")

                self.total_session_number = YLeaf(YType.uint32, "total-session-number")
                self._segment_path = lambda: "generic-summary" + "[location='" + self.location.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/generic-summaries/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.GenericSummaries.GenericSummary, ['location', 'max_session_number', 'mp_session_number', 'node_id', 'pps_all_percentage', 'pps_allocated_value', 'pps_max_value', 'ppsmp_allocated_value', 'ppsmp_max_value', 'ppsmp_percentage', 'total_session_number'], name, value)


    class Ipv4BfDoMplsteHeadCounters(Entity):
        """
        IPv4 BFD over MPLS\-TE Counters
        
        .. attribute:: ipv4bf_do_mplste_head_packet_counters
        
        	Table of IPv4 BFD over MPLS\-TE Packet counters
        	**type**\:   :py:class:`Ipv4BfDoMplsteHeadPacketCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadCounters.Ipv4BfDoMplsteHeadPacketCounters>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteHeadCounters, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-head-counters"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"ipv4bf-do-mplste-head-packet-counters" : ("ipv4bf_do_mplste_head_packet_counters", Bfd.Ipv4BfDoMplsteHeadCounters.Ipv4BfDoMplsteHeadPacketCounters)}
            self._child_list_classes = {}

            self.ipv4bf_do_mplste_head_packet_counters = Bfd.Ipv4BfDoMplsteHeadCounters.Ipv4BfDoMplsteHeadPacketCounters()
            self.ipv4bf_do_mplste_head_packet_counters.parent = self
            self._children_name_map["ipv4bf_do_mplste_head_packet_counters"] = "ipv4bf-do-mplste-head-packet-counters"
            self._children_yang_names.add("ipv4bf-do-mplste-head-packet-counters")
            self._segment_path = lambda: "ipv4bf-do-mplste-head-counters"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class Ipv4BfDoMplsteHeadPacketCounters(Entity):
            """
            Table of IPv4 BFD over MPLS\-TE Packet counters
            
            .. attribute:: ipv4bf_do_mplste_head_packet_counter
            
            	Interface  IPv4 BFD over MPLS\-TE Packet counters
            	**type**\: list of    :py:class:`Ipv4BfDoMplsteHeadPacketCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadCounters.Ipv4BfDoMplsteHeadPacketCounters.Ipv4BfDoMplsteHeadPacketCounter>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteHeadCounters.Ipv4BfDoMplsteHeadPacketCounters, self).__init__()

                self.yang_name = "ipv4bf-do-mplste-head-packet-counters"
                self.yang_parent_name = "ipv4bf-do-mplste-head-counters"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"ipv4bf-do-mplste-head-packet-counter" : ("ipv4bf_do_mplste_head_packet_counter", Bfd.Ipv4BfDoMplsteHeadCounters.Ipv4BfDoMplsteHeadPacketCounters.Ipv4BfDoMplsteHeadPacketCounter)}

                self.ipv4bf_do_mplste_head_packet_counter = YList(self)
                self._segment_path = lambda: "ipv4bf-do-mplste-head-packet-counters"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-counters/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadCounters.Ipv4BfDoMplsteHeadPacketCounters, [], name, value)


            class Ipv4BfDoMplsteHeadPacketCounter(Entity):
                """
                Interface  IPv4 BFD over MPLS\-TE Packet
                counters
                
                .. attribute:: display_type
                
                	Packet Display Type
                	**type**\:   :py:class:`BfdMgmtPktDisplay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtPktDisplay>`
                
                .. attribute:: echo_receive_count
                
                	Number of echo packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: echo_transmit_count
                
                	Number of echo packets transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_receive_count
                
                	Number of Hellos received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_transmit_count
                
                	Number of Hellos transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_name
                
                	Interface Name
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: location
                
                	Location
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteHeadCounters.Ipv4BfDoMplsteHeadPacketCounters.Ipv4BfDoMplsteHeadPacketCounter, self).__init__()

                    self.yang_name = "ipv4bf-do-mplste-head-packet-counter"
                    self.yang_parent_name = "ipv4bf-do-mplste-head-packet-counters"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.display_type = YLeaf(YType.enumeration, "display-type")

                    self.echo_receive_count = YLeaf(YType.uint32, "echo-receive-count")

                    self.echo_transmit_count = YLeaf(YType.uint32, "echo-transmit-count")

                    self.hello_receive_count = YLeaf(YType.uint32, "hello-receive-count")

                    self.hello_transmit_count = YLeaf(YType.uint32, "hello-transmit-count")

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.location = YLeaf(YType.str, "location")
                    self._segment_path = lambda: "ipv4bf-do-mplste-head-packet-counter"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-counters/ipv4bf-do-mplste-head-packet-counters/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadCounters.Ipv4BfDoMplsteHeadPacketCounters.Ipv4BfDoMplsteHeadPacketCounter, ['display_type', 'echo_receive_count', 'echo_transmit_count', 'hello_receive_count', 'hello_transmit_count', 'interface_name', 'location'], name, value)


    class Ipv4BfDoMplsteHeadMultiPaths(Entity):
        """
        IPv4 BFD over MPLS\-TE Head multipath
        
        .. attribute:: ipv4bf_do_mplste_head_multi_path
        
        	Label multipath table
        	**type**\: list of    :py:class:`Ipv4BfDoMplsteHeadMultiPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadMultiPaths.Ipv4BfDoMplsteHeadMultiPath>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteHeadMultiPaths, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-head-multi-paths"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4bf-do-mplste-head-multi-path" : ("ipv4bf_do_mplste_head_multi_path", Bfd.Ipv4BfDoMplsteHeadMultiPaths.Ipv4BfDoMplsteHeadMultiPath)}

            self.ipv4bf_do_mplste_head_multi_path = YList(self)
            self._segment_path = lambda: "ipv4bf-do-mplste-head-multi-paths"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadMultiPaths, [], name, value)


        class Ipv4BfDoMplsteHeadMultiPath(Entity):
            """
            Label multipath table
            
            .. attribute:: fe_ctype
            
            	FEC Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_ctype
            
            	FEC C Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_destination
            
            	FEC Destination
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_extended_tunnel_id
            
            	FEC Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_source
            
            	FEC Source
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_subgroup_id
            
            	FEC Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_subgroup_originator
            
            	FEC Subgroup originator
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_tunnel_id
            
            	FEC Tunnel ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: feclspid
            
            	FEC LSP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fecp2mpid
            
            	FEC P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: incoming_label
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: incoming_label_xr
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: local_discriminator
            
            	Session's Local discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_interface_name
            
            	Interface name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteHeadMultiPaths.Ipv4BfDoMplsteHeadMultiPath, self).__init__()

                self.yang_name = "ipv4bf-do-mplste-head-multi-path"
                self.yang_parent_name = "ipv4bf-do-mplste-head-multi-paths"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                self.fec_ctype = YLeaf(YType.int32, "fec-ctype")

                self.fec_destination = YLeaf(YType.str, "fec-destination")

                self.fec_extended_tunnel_id = YLeaf(YType.str, "fec-extended-tunnel-id")

                self.fec_source = YLeaf(YType.str, "fec-source")

                self.fec_subgroup_id = YLeaf(YType.int32, "fec-subgroup-id")

                self.fec_subgroup_originator = YLeaf(YType.str, "fec-subgroup-originator")

                self.fec_tunnel_id = YLeaf(YType.int32, "fec-tunnel-id")

                self.feclspid = YLeaf(YType.int32, "feclspid")

                self.fecp2mpid = YLeaf(YType.int32, "fecp2mpid")

                self.incoming_label = YLeaf(YType.int32, "incoming-label")

                self.incoming_label_xr = YLeaf(YType.uint32, "incoming-label-xr")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_interface_name = YLeaf(YType.str, "session-interface-name")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.state = YLeaf(YType.enumeration, "state")

                self.vrf_name = YLeaf(YType.str, "vrf-name")
                self._segment_path = lambda: "ipv4bf-do-mplste-head-multi-path"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-multi-paths/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadMultiPaths.Ipv4BfDoMplsteHeadMultiPath, ['fe_ctype', 'fec_ctype', 'fec_destination', 'fec_extended_tunnel_id', 'fec_source', 'fec_subgroup_id', 'fec_subgroup_originator', 'fec_tunnel_id', 'feclspid', 'fecp2mpid', 'incoming_label', 'incoming_label_xr', 'interface_name', 'local_discriminator', 'location', 'node_id', 'session_interface_name', 'session_subtype', 'state', 'vrf_name'], name, value)


    class Ipv4BfDoMplsteHeadSessionBriefs(Entity):
        """
        Table of brief information about all IPv4 BFD
        over MPLS\-TE Head sessions in the System
        
        .. attribute:: ipv4bf_do_mplste_head_session_brief
        
        	Brief information for a single IPv4 BFD over MPLS\-TE Head session
        	**type**\: list of    :py:class:`Ipv4BfDoMplsteHeadSessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteHeadSessionBriefs, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-head-session-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4bf-do-mplste-head-session-brief" : ("ipv4bf_do_mplste_head_session_brief", Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief)}

            self.ipv4bf_do_mplste_head_session_brief = YList(self)
            self._segment_path = lambda: "ipv4bf-do-mplste-head-session-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionBriefs, [], name, value)


        class Ipv4BfDoMplsteHeadSessionBrief(Entity):
            """
            Brief information for a single IPv4 BFD over
            MPLS\-TE Head session
            
            .. attribute:: fe_ctype
            
            	FEC Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_ctype
            
            	FEC C Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_destination
            
            	FEC Destination
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_extended_tunnel_id
            
            	FEC Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_source
            
            	FEC Source
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_subgroup_id
            
            	FEC Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_subgroup_originator
            
            	FEC Subgroup originator
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_tunnel_id
            
            	FEC Tunnel ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: feclspid
            
            	FEC LSP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fecp2mpid
            
            	FEC P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: incoming_label
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_flags
            
            	Session Flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: session_type
            
            	Session type
            	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: status_brief_information
            
            	Brief Status Information
            	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief, self).__init__()

                self.yang_name = "ipv4bf-do-mplste-head-session-brief"
                self.yang_parent_name = "ipv4bf-do-mplste-head-session-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"status-brief-information" : ("status_brief_information", Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation)}
                self._child_list_classes = {}

                self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                self.fec_ctype = YLeaf(YType.int32, "fec-ctype")

                self.fec_destination = YLeaf(YType.str, "fec-destination")

                self.fec_extended_tunnel_id = YLeaf(YType.str, "fec-extended-tunnel-id")

                self.fec_source = YLeaf(YType.str, "fec-source")

                self.fec_subgroup_id = YLeaf(YType.int32, "fec-subgroup-id")

                self.fec_subgroup_originator = YLeaf(YType.str, "fec-subgroup-originator")

                self.fec_tunnel_id = YLeaf(YType.int32, "fec-tunnel-id")

                self.feclspid = YLeaf(YType.int32, "feclspid")

                self.fecp2mpid = YLeaf(YType.int32, "fecp2mpid")

                self.incoming_label = YLeaf(YType.int32, "incoming-label")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_flags = YLeaf(YType.uint32, "session-flags")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.state = YLeaf(YType.enumeration, "state")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.status_brief_information = Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation()
                self.status_brief_information.parent = self
                self._children_name_map["status_brief_information"] = "status-brief-information"
                self._children_yang_names.add("status-brief-information")
                self._segment_path = lambda: "ipv4bf-do-mplste-head-session-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief, ['fe_ctype', 'fec_ctype', 'fec_destination', 'fec_extended_tunnel_id', 'fec_source', 'fec_subgroup_id', 'fec_subgroup_originator', 'fec_tunnel_id', 'feclspid', 'fecp2mpid', 'incoming_label', 'interface_name', 'location', 'node_id', 'session_flags', 'session_subtype', 'session_type', 'state', 'vrf_name'], name, value)


            class StatusBriefInformation(Entity):
                """
                Brief Status Information
                
                .. attribute:: async_interval_multiplier
                
                	Async Interval and Detect Multiplier Information
                	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier>`
                
                .. attribute:: echo_interval_multiplier
                
                	Echo Interval and Detect Multiplier Information
                	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.EchoIntervalMultiplier>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation, self).__init__()

                    self.yang_name = "status-brief-information"
                    self.yang_parent_name = "ipv4bf-do-mplste-head-session-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.EchoIntervalMultiplier)}
                    self._child_list_classes = {}

                    self.async_interval_multiplier = Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier()
                    self.async_interval_multiplier.parent = self
                    self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                    self._children_yang_names.add("async-interval-multiplier")

                    self.echo_interval_multiplier = Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.EchoIntervalMultiplier()
                    self.echo_interval_multiplier.parent = self
                    self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                    self._children_yang_names.add("echo-interval-multiplier")
                    self._segment_path = lambda: "status-brief-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-briefs/ipv4bf-do-mplste-head-session-brief/%s" % self._segment_path()


                class AsyncIntervalMultiplier(Entity):
                    """
                    Async Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_local_transmit_interval
                    
                    	Negotiated local transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_remote_transmit_interval
                    
                    	Negotiated remote transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                        self.yang_name = "async-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                        self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                        self._segment_path = lambda: "async-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-briefs/ipv4bf-do-mplste-head-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                class EchoIntervalMultiplier(Entity):
                    """
                    Echo Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_transmit_interval
                    
                    	Negotiated transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                        self.yang_name = "echo-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                        self._segment_path = lambda: "echo-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-briefs/ipv4bf-do-mplste-head-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionBriefs.Ipv4BfDoMplsteHeadSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


    class Ipv4BfDoMplsteHeadSessionDetails(Entity):
        """
        Table of detailed information about all IPv4 BFD
        over MPLS\-TE Head sessions in the System
        
        .. attribute:: ipv4bf_do_mplste_head_session_detail
        
        	Detailed information for a single IPv4 BFD over MPLS\-TE head session
        	**type**\: list of    :py:class:`Ipv4BfDoMplsteHeadSessionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteHeadSessionDetails, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-head-session-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4bf-do-mplste-head-session-detail" : ("ipv4bf_do_mplste_head_session_detail", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail)}

            self.ipv4bf_do_mplste_head_session_detail = YList(self)
            self._segment_path = lambda: "ipv4bf-do-mplste-head-session-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails, [], name, value)


        class Ipv4BfDoMplsteHeadSessionDetail(Entity):
            """
            Detailed information for a single IPv4 BFD over
            MPLS\-TE head session
            
            .. attribute:: association_information
            
            	Association session information
            	**type**\: list of    :py:class:`AssociationInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation>`
            
            .. attribute:: fe_ctype
            
            	FEC Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_ctype
            
            	FEC C Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_destination
            
            	FEC Destination
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_extended_tunnel_id
            
            	FEC Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_source
            
            	FEC Source
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_subgroup_id
            
            	FEC Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_subgroup_originator
            
            	FEC Subgroup originator
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_tunnel_id
            
            	FEC Tunnel ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: feclspid
            
            	FEC LSP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fecp2mpid
            
            	FEC P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: incoming_label
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: lsp_ping_info
            
            	LSP Ping Info
            	**type**\:   :py:class:`LspPingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo>`
            
            .. attribute:: mp_download_state
            
            	MP Dowload State
            	**type**\:   :py:class:`MpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState>`
            
            .. attribute:: owner_information
            
            	Client applications owning the session
            	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.OwnerInformation>`
            
            .. attribute:: status_information
            
            	Session status information
            	**type**\:   :py:class:`StatusInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail, self).__init__()

                self.yang_name = "ipv4bf-do-mplste-head-session-detail"
                self.yang_parent_name = "ipv4bf-do-mplste-head-session-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"lsp-ping-info" : ("lsp_ping_info", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo), "mp-download-state" : ("mp_download_state", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState), "status-information" : ("status_information", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation)}
                self._child_list_classes = {"association-information" : ("association_information", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation), "owner-information" : ("owner_information", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.OwnerInformation)}

                self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                self.fec_ctype = YLeaf(YType.int32, "fec-ctype")

                self.fec_destination = YLeaf(YType.str, "fec-destination")

                self.fec_extended_tunnel_id = YLeaf(YType.str, "fec-extended-tunnel-id")

                self.fec_source = YLeaf(YType.str, "fec-source")

                self.fec_subgroup_id = YLeaf(YType.int32, "fec-subgroup-id")

                self.fec_subgroup_originator = YLeaf(YType.str, "fec-subgroup-originator")

                self.fec_tunnel_id = YLeaf(YType.int32, "fec-tunnel-id")

                self.feclspid = YLeaf(YType.int32, "feclspid")

                self.fecp2mpid = YLeaf(YType.int32, "fecp2mpid")

                self.incoming_label = YLeaf(YType.int32, "incoming-label")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.lsp_ping_info = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo()
                self.lsp_ping_info.parent = self
                self._children_name_map["lsp_ping_info"] = "lsp-ping-info"
                self._children_yang_names.add("lsp-ping-info")

                self.mp_download_state = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState()
                self.mp_download_state.parent = self
                self._children_name_map["mp_download_state"] = "mp-download-state"
                self._children_yang_names.add("mp-download-state")

                self.status_information = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation()
                self.status_information.parent = self
                self._children_name_map["status_information"] = "status-information"
                self._children_yang_names.add("status-information")

                self.association_information = YList(self)
                self.owner_information = YList(self)
                self._segment_path = lambda: "ipv4bf-do-mplste-head-session-detail"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail, ['fe_ctype', 'fec_ctype', 'fec_destination', 'fec_extended_tunnel_id', 'fec_source', 'fec_subgroup_id', 'fec_subgroup_originator', 'fec_tunnel_id', 'feclspid', 'fecp2mpid', 'incoming_label', 'interface_name', 'location', 'vrf_name'], name, value)


            class AssociationInformation(Entity):
                """
                Association session information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: ip_destination_address
                
                	IPv4/v6 dest address
                	**type**\:   :py:class:`IpDestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation.IpDestinationAddress>`
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: owner_information
                
                	Client applications owning the session
                	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation.OwnerInformation>`
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation, self).__init__()

                    self.yang_name = "association-information"
                    self.yang_parent_name = "ipv4bf-do-mplste-head-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"ip-destination-address" : ("ip_destination_address", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation.IpDestinationAddress)}
                    self._child_list_classes = {"owner-information" : ("owner_information", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation.OwnerInformation)}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.ip_destination_address = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation.IpDestinationAddress()
                    self.ip_destination_address.parent = self
                    self._children_name_map["ip_destination_address"] = "ip-destination-address"
                    self._children_yang_names.add("ip-destination-address")

                    self.owner_information = YList(self)
                    self._segment_path = lambda: "association-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation, ['interface_name', 'local_discriminator', 'sessiontype'], name, value)


                class IpDestinationAddress(Entity):
                    """
                    IPv4/v6 dest address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation.IpDestinationAddress, self).__init__()

                        self.yang_name = "ip-destination-address"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "ip-destination-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation.IpDestinationAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class OwnerInformation(Entity):
                    """
                    Client applications owning the session
                    
                    .. attribute:: adjusted_detection_multiplier
                    
                    	Adjusted detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: adjusted_interval
                    
                    	Adjusted minimum transmit interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Client specified detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interval
                    
                    	Client specified minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: name
                    
                    	Client process name
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation.OwnerInformation, self).__init__()

                        self.yang_name = "owner-information"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                        self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "owner-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.AssociationInformation.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class LspPingInfo(Entity):
                """
                LSP Ping Info
                
                .. attribute:: lsp_ping_rx_count
                
                	LSP Ping numer of times received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_code
                
                	LSP Ping Rx Last Code
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_discr
                
                	LSP Ping Rx last received discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_output
                
                	LSP Ping Rx Last Output
                	**type**\:  str
                
                .. attribute:: lsp_ping_rx_last_subcode
                
                	LSP Ping Rx Last Subcode
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_time
                
                	LSP Ping last received time
                	**type**\:   :py:class:`LspPingRxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingRxLastTime>`
                
                .. attribute:: lsp_ping_tx_count
                
                	LSP Ping Tx count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_error_count
                
                	LSP Ping Tx error count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_last_error_rc
                
                	LSP Ping Tx last error
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_error_time
                
                	LSP Ping last error time
                	**type**\:   :py:class:`LspPingTxLastErrorTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastErrorTime>`
                
                .. attribute:: lsp_ping_tx_last_rc
                
                	LSP Ping Tx last result
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_time
                
                	LSP Ping last sent time
                	**type**\:   :py:class:`LspPingTxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastTime>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo, self).__init__()

                    self.yang_name = "lsp-ping-info"
                    self.yang_parent_name = "ipv4bf-do-mplste-head-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"lsp-ping-rx-last-time" : ("lsp_ping_rx_last_time", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingRxLastTime), "lsp-ping-tx-last-error-time" : ("lsp_ping_tx_last_error_time", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastErrorTime), "lsp-ping-tx-last-time" : ("lsp_ping_tx_last_time", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastTime)}
                    self._child_list_classes = {}

                    self.lsp_ping_rx_count = YLeaf(YType.uint32, "lsp-ping-rx-count")

                    self.lsp_ping_rx_last_code = YLeaf(YType.uint8, "lsp-ping-rx-last-code")

                    self.lsp_ping_rx_last_discr = YLeaf(YType.uint32, "lsp-ping-rx-last-discr")

                    self.lsp_ping_rx_last_output = YLeaf(YType.str, "lsp-ping-rx-last-output")

                    self.lsp_ping_rx_last_subcode = YLeaf(YType.uint8, "lsp-ping-rx-last-subcode")

                    self.lsp_ping_tx_count = YLeaf(YType.uint32, "lsp-ping-tx-count")

                    self.lsp_ping_tx_error_count = YLeaf(YType.uint32, "lsp-ping-tx-error-count")

                    self.lsp_ping_tx_last_error_rc = YLeaf(YType.str, "lsp-ping-tx-last-error-rc")

                    self.lsp_ping_tx_last_rc = YLeaf(YType.str, "lsp-ping-tx-last-rc")

                    self.lsp_ping_rx_last_time = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingRxLastTime()
                    self.lsp_ping_rx_last_time.parent = self
                    self._children_name_map["lsp_ping_rx_last_time"] = "lsp-ping-rx-last-time"
                    self._children_yang_names.add("lsp-ping-rx-last-time")

                    self.lsp_ping_tx_last_error_time = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastErrorTime()
                    self.lsp_ping_tx_last_error_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_error_time"] = "lsp-ping-tx-last-error-time"
                    self._children_yang_names.add("lsp-ping-tx-last-error-time")

                    self.lsp_ping_tx_last_time = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastTime()
                    self.lsp_ping_tx_last_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_time"] = "lsp-ping-tx-last-time"
                    self._children_yang_names.add("lsp-ping-tx-last-time")
                    self._segment_path = lambda: "lsp-ping-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo, ['lsp_ping_rx_count', 'lsp_ping_rx_last_code', 'lsp_ping_rx_last_discr', 'lsp_ping_rx_last_output', 'lsp_ping_rx_last_subcode', 'lsp_ping_tx_count', 'lsp_ping_tx_error_count', 'lsp_ping_tx_last_error_rc', 'lsp_ping_tx_last_rc'], name, value)


                class LspPingRxLastTime(Entity):
                    """
                    LSP Ping last received time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingRxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-rx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-rx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingRxLastTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastErrorTime(Entity):
                    """
                    LSP Ping last error time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastErrorTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-error-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-error-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastErrorTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastTime(Entity):
                    """
                    LSP Ping last sent time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.LspPingInfo.LspPingTxLastTime, ['nanoseconds', 'seconds'], name, value)


            class MpDownloadState(Entity):
                """
                MP Dowload State
                
                .. attribute:: change_time
                
                	Change time
                	**type**\:   :py:class:`ChangeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState.ChangeTime>`
                
                .. attribute:: mp_download_state
                
                	MP Download State
                	**type**\:   :py:class:`BfdMpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMpDownloadState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState, self).__init__()

                    self.yang_name = "mp-download-state"
                    self.yang_parent_name = "ipv4bf-do-mplste-head-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"change-time" : ("change_time", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState.ChangeTime)}
                    self._child_list_classes = {}

                    self.mp_download_state = YLeaf(YType.enumeration, "mp-download-state")

                    self.change_time = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState.ChangeTime()
                    self.change_time.parent = self
                    self._children_name_map["change_time"] = "change-time"
                    self._children_yang_names.add("change-time")
                    self._segment_path = lambda: "mp-download-state"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState, ['mp_download_state'], name, value)


                class ChangeTime(Entity):
                    """
                    Change time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState.ChangeTime, self).__init__()

                        self.yang_name = "change-time"
                        self.yang_parent_name = "mp-download-state"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "change-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/mp-download-state/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.MpDownloadState.ChangeTime, ['nanoseconds', 'seconds'], name, value)


            class OwnerInformation(Entity):
                """
                Client applications owning the session
                
                .. attribute:: adjusted_detection_multiplier
                
                	Adjusted detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adjusted_interval
                
                	Adjusted minimum transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: detection_multiplier
                
                	Client specified detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interval
                
                	Client specified minimum transmit interval in micro\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: name
                
                	Client process name
                	**type**\:  str
                
                	**length:** 0..257
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.OwnerInformation, self).__init__()

                    self.yang_name = "owner-information"
                    self.yang_parent_name = "ipv4bf-do-mplste-head-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                    self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.interval = YLeaf(YType.uint32, "interval")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "owner-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class StatusInformation(Entity):
                """
                Session status information
                
                .. attribute:: async_receive_statistics
                
                	Statistics of Interval between Async Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`AsyncReceiveStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncReceiveStatistics>`
                
                .. attribute:: async_transmit_statistics
                
                	Statistics of Interval between Async Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`AsyncTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncTransmitStatistics>`
                
                .. attribute:: desired_minimum_echo_transmit_interval
                
                	Desired minimum echo transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: echo_received_statistics
                
                	Statistics of Interval between Echo Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`EchoReceivedStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoReceivedStatistics>`
                
                .. attribute:: echo_transmit_statistics
                
                	Statistics of Interval between Echo Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`EchoTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoTransmitStatistics>`
                
                .. attribute:: internal_label
                
                	Internal Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_state_change
                
                	Time since last state change
                	**type**\:   :py:class:`LastStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.LastStateChange>`
                
                .. attribute:: latency_average
                
                	Average value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_maximum
                
                	Maximum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_minimum
                
                	Minimum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_number
                
                	Number of Latency Samples. Time between Transmit and Receive
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: node_id
                
                	Location where session is housed
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: receive_packet
                
                	Receive Packet
                	**type**\:   :py:class:`ReceivePacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.ReceivePacket>`
                
                .. attribute:: remote_discriminator
                
                	Session's Remote discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_negotiated_interval
                
                	Remote Negotiated Interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: session_subtype
                
                	Session subtype
                	**type**\:  str
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                .. attribute:: source_address
                
                	Source address
                	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.SourceAddress>`
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                .. attribute:: status_brief_information
                
                	Brief Status Information
                	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation>`
                
                .. attribute:: to_up_state_count
                
                	Number of times session state went to UP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmit_packet
                
                	Transmit Packet
                	**type**\:   :py:class:`TransmitPacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.TransmitPacket>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation, self).__init__()

                    self.yang_name = "status-information"
                    self.yang_parent_name = "ipv4bf-do-mplste-head-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-receive-statistics" : ("async_receive_statistics", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncReceiveStatistics), "async-transmit-statistics" : ("async_transmit_statistics", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncTransmitStatistics), "echo-received-statistics" : ("echo_received_statistics", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoReceivedStatistics), "echo-transmit-statistics" : ("echo_transmit_statistics", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoTransmitStatistics), "last-state-change" : ("last_state_change", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.LastStateChange), "receive-packet" : ("receive_packet", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.ReceivePacket), "source-address" : ("source_address", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.SourceAddress), "status-brief-information" : ("status_brief_information", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation), "transmit-packet" : ("transmit_packet", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.TransmitPacket)}
                    self._child_list_classes = {}

                    self.desired_minimum_echo_transmit_interval = YLeaf(YType.uint32, "desired-minimum-echo-transmit-interval")

                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                    self.latency_average = YLeaf(YType.uint32, "latency-average")

                    self.latency_maximum = YLeaf(YType.uint32, "latency-maximum")

                    self.latency_minimum = YLeaf(YType.uint32, "latency-minimum")

                    self.latency_number = YLeaf(YType.uint32, "latency-number")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.remote_discriminator = YLeaf(YType.uint32, "remote-discriminator")

                    self.remote_negotiated_interval = YLeaf(YType.uint32, "remote-negotiated-interval")

                    self.session_subtype = YLeaf(YType.str, "session-subtype")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.to_up_state_count = YLeaf(YType.uint32, "to-up-state-count")

                    self.async_receive_statistics = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncReceiveStatistics()
                    self.async_receive_statistics.parent = self
                    self._children_name_map["async_receive_statistics"] = "async-receive-statistics"
                    self._children_yang_names.add("async-receive-statistics")

                    self.async_transmit_statistics = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncTransmitStatistics()
                    self.async_transmit_statistics.parent = self
                    self._children_name_map["async_transmit_statistics"] = "async-transmit-statistics"
                    self._children_yang_names.add("async-transmit-statistics")

                    self.echo_received_statistics = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoReceivedStatistics()
                    self.echo_received_statistics.parent = self
                    self._children_name_map["echo_received_statistics"] = "echo-received-statistics"
                    self._children_yang_names.add("echo-received-statistics")

                    self.echo_transmit_statistics = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoTransmitStatistics()
                    self.echo_transmit_statistics.parent = self
                    self._children_name_map["echo_transmit_statistics"] = "echo-transmit-statistics"
                    self._children_yang_names.add("echo-transmit-statistics")

                    self.last_state_change = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.LastStateChange()
                    self.last_state_change.parent = self
                    self._children_name_map["last_state_change"] = "last-state-change"
                    self._children_yang_names.add("last-state-change")

                    self.receive_packet = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.ReceivePacket()
                    self.receive_packet.parent = self
                    self._children_name_map["receive_packet"] = "receive-packet"
                    self._children_yang_names.add("receive-packet")

                    self.source_address = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.SourceAddress()
                    self.source_address.parent = self
                    self._children_name_map["source_address"] = "source-address"
                    self._children_yang_names.add("source-address")

                    self.status_brief_information = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation()
                    self.status_brief_information.parent = self
                    self._children_name_map["status_brief_information"] = "status-brief-information"
                    self._children_yang_names.add("status-brief-information")

                    self.transmit_packet = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.TransmitPacket()
                    self.transmit_packet.parent = self
                    self._children_name_map["transmit_packet"] = "transmit-packet"
                    self._children_yang_names.add("transmit-packet")
                    self._segment_path = lambda: "status-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation, ['desired_minimum_echo_transmit_interval', 'internal_label', 'latency_average', 'latency_maximum', 'latency_minimum', 'latency_number', 'local_discriminator', 'node_id', 'remote_discriminator', 'remote_negotiated_interval', 'session_subtype', 'sessiontype', 'state', 'to_up_state_count'], name, value)


                class AsyncReceiveStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncReceiveStatistics, self).__init__()

                        self.yang_name = "async-receive-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-receive-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncReceiveStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class AsyncTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncTransmitStatistics, self).__init__()

                        self.yang_name = "async-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.AsyncTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoReceivedStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoReceivedStatistics, self).__init__()

                        self.yang_name = "echo-received-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-received-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoReceivedStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoTransmitStatistics, self).__init__()

                        self.yang_name = "echo-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.EchoTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class LastStateChange(Entity):
                    """
                    Time since last state change
                    
                    .. attribute:: days
                    
                    	Number of days since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: day
                    
                    .. attribute:: hours
                    
                    	Number of hours since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: hour
                    
                    .. attribute:: minutes
                    
                    	Number of mins since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: minute
                    
                    .. attribute:: seconds
                    
                    	Number of seconds since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.LastStateChange, self).__init__()

                        self.yang_name = "last-state-change"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.days = YLeaf(YType.uint32, "days")

                        self.hours = YLeaf(YType.uint8, "hours")

                        self.minutes = YLeaf(YType.uint8, "minutes")

                        self.seconds = YLeaf(YType.uint8, "seconds")
                        self._segment_path = lambda: "last-state-change"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.LastStateChange, ['days', 'hours', 'minutes', 'seconds'], name, value)


                class ReceivePacket(Entity):
                    """
                    Receive Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.ReceivePacket, self).__init__()

                        self.yang_name = "receive-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "receive-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.ReceivePacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


                class SourceAddress(Entity):
                    """
                    Source address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.SourceAddress, self).__init__()

                        self.yang_name = "source-address"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "source-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.SourceAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class StatusBriefInformation(Entity):
                    """
                    Brief Status Information
                    
                    .. attribute:: async_interval_multiplier
                    
                    	Async Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier>`
                    
                    .. attribute:: echo_interval_multiplier
                    
                    	Echo Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier>`
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation, self).__init__()

                        self.yang_name = "status-brief-information"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier)}
                        self._child_list_classes = {}

                        self.async_interval_multiplier = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier()
                        self.async_interval_multiplier.parent = self
                        self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                        self._children_yang_names.add("async-interval-multiplier")

                        self.echo_interval_multiplier = Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier()
                        self.echo_interval_multiplier.parent = self
                        self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                        self._children_yang_names.add("echo-interval-multiplier")
                        self._segment_path = lambda: "status-brief-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/%s" % self._segment_path()


                    class AsyncIntervalMultiplier(Entity):
                        """
                        Async Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_local_transmit_interval
                        
                        	Negotiated local transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_remote_transmit_interval
                        
                        	Negotiated remote transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                            self.yang_name = "async-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                            self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                            self._segment_path = lambda: "async-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                    class EchoIntervalMultiplier(Entity):
                        """
                        Echo Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_transmit_interval
                        
                        	Negotiated transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                            self.yang_name = "echo-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                            self._segment_path = lambda: "echo-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


                class TransmitPacket(Entity):
                    """
                    Transmit Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.TransmitPacket, self).__init__()

                        self.yang_name = "transmit-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "transmit-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-session-details/ipv4bf-do-mplste-head-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSessionDetails.Ipv4BfDoMplsteHeadSessionDetail.StatusInformation.TransmitPacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


    class Ipv4BfDoMplsteHeadSummary(Entity):
        """
        Summary information of IPv4 BFD over MPLS\-TE
        Head
        
        .. attribute:: session_state
        
        	Statistics of states for sessions
        	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteHeadSummary.SessionState>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteHeadSummary, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-head-summary"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv4BfDoMplsteHeadSummary.SessionState)}
            self._child_list_classes = {}

            self.session_state = Bfd.Ipv4BfDoMplsteHeadSummary.SessionState()
            self.session_state.parent = self
            self._children_name_map["session_state"] = "session-state"
            self._children_yang_names.add("session-state")
            self._segment_path = lambda: "ipv4bf-do-mplste-head-summary"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class SessionState(Entity):
            """
            Statistics of states for sessions
            
            .. attribute:: down_count
            
            	Number of sessions in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_count
            
            	Number of sessions in database
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_count
            
            	Number of sessions in unknown state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of sessions in up state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteHeadSummary.SessionState, self).__init__()

                self.yang_name = "session-state"
                self.yang_parent_name = "ipv4bf-do-mplste-head-summary"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.down_count = YLeaf(YType.uint32, "down-count")

                self.total_count = YLeaf(YType.uint32, "total-count")

                self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                self.up_count = YLeaf(YType.uint32, "up-count")
                self._segment_path = lambda: "session-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-head-summary/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteHeadSummary.SessionState, ['down_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv4BfDoMplsteTailCounters(Entity):
        """
        IPv4 BFD over MPLS\-TE Counters
        
        .. attribute:: ipv4bf_do_mplste_tail_packet_counters
        
        	Table of IPv4 BFD over MPLS\-TE Packet counters
        	**type**\:   :py:class:`Ipv4BfDoMplsteTailPacketCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailCounters.Ipv4BfDoMplsteTailPacketCounters>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteTailCounters, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-tail-counters"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"ipv4bf-do-mplste-tail-packet-counters" : ("ipv4bf_do_mplste_tail_packet_counters", Bfd.Ipv4BfDoMplsteTailCounters.Ipv4BfDoMplsteTailPacketCounters)}
            self._child_list_classes = {}

            self.ipv4bf_do_mplste_tail_packet_counters = Bfd.Ipv4BfDoMplsteTailCounters.Ipv4BfDoMplsteTailPacketCounters()
            self.ipv4bf_do_mplste_tail_packet_counters.parent = self
            self._children_name_map["ipv4bf_do_mplste_tail_packet_counters"] = "ipv4bf-do-mplste-tail-packet-counters"
            self._children_yang_names.add("ipv4bf-do-mplste-tail-packet-counters")
            self._segment_path = lambda: "ipv4bf-do-mplste-tail-counters"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class Ipv4BfDoMplsteTailPacketCounters(Entity):
            """
            Table of IPv4 BFD over MPLS\-TE Packet counters
            
            .. attribute:: ipv4bf_do_mplste_tail_packet_counter
            
            	Interface  IPv4 BFD over MPLS\-TE Packet counters
            	**type**\: list of    :py:class:`Ipv4BfDoMplsteTailPacketCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailCounters.Ipv4BfDoMplsteTailPacketCounters.Ipv4BfDoMplsteTailPacketCounter>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteTailCounters.Ipv4BfDoMplsteTailPacketCounters, self).__init__()

                self.yang_name = "ipv4bf-do-mplste-tail-packet-counters"
                self.yang_parent_name = "ipv4bf-do-mplste-tail-counters"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"ipv4bf-do-mplste-tail-packet-counter" : ("ipv4bf_do_mplste_tail_packet_counter", Bfd.Ipv4BfDoMplsteTailCounters.Ipv4BfDoMplsteTailPacketCounters.Ipv4BfDoMplsteTailPacketCounter)}

                self.ipv4bf_do_mplste_tail_packet_counter = YList(self)
                self._segment_path = lambda: "ipv4bf-do-mplste-tail-packet-counters"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-counters/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteTailCounters.Ipv4BfDoMplsteTailPacketCounters, [], name, value)


            class Ipv4BfDoMplsteTailPacketCounter(Entity):
                """
                Interface  IPv4 BFD over MPLS\-TE Packet
                counters
                
                .. attribute:: display_type
                
                	Packet Display Type
                	**type**\:   :py:class:`BfdMgmtPktDisplay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtPktDisplay>`
                
                .. attribute:: echo_receive_count
                
                	Number of echo packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: echo_transmit_count
                
                	Number of echo packets transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: fe_ctype
                
                	FEC Type
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: fec_ctype
                
                	FEC C Type
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: fec_destination
                
                	FEC Destination
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: fec_extended_tunnel_id
                
                	FEC Extended Tunnel ID
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: fec_source
                
                	FEC Source
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: fec_subgroup_id
                
                	FEC Subgroup ID
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: fec_subgroup_originator
                
                	FEC Subgroup originator
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: fec_tunnel_id
                
                	FEC Tunnel ID
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: feclspid
                
                	FEC LSP ID
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: fecp2mpid
                
                	FEC P2MP ID
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: hello_receive_count
                
                	Number of Hellos received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_transmit_count
                
                	Number of Hellos transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: incoming_label
                
                	Incoming Label
                	**type**\:  int
                
                	**range:** \-2147483648..2147483647
                
                .. attribute:: location
                
                	Location
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: vrf_name
                
                	VRF name
                	**type**\:  str
                
                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteTailCounters.Ipv4BfDoMplsteTailPacketCounters.Ipv4BfDoMplsteTailPacketCounter, self).__init__()

                    self.yang_name = "ipv4bf-do-mplste-tail-packet-counter"
                    self.yang_parent_name = "ipv4bf-do-mplste-tail-packet-counters"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.display_type = YLeaf(YType.enumeration, "display-type")

                    self.echo_receive_count = YLeaf(YType.uint32, "echo-receive-count")

                    self.echo_transmit_count = YLeaf(YType.uint32, "echo-transmit-count")

                    self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                    self.fec_ctype = YLeaf(YType.int32, "fec-ctype")

                    self.fec_destination = YLeaf(YType.str, "fec-destination")

                    self.fec_extended_tunnel_id = YLeaf(YType.str, "fec-extended-tunnel-id")

                    self.fec_source = YLeaf(YType.str, "fec-source")

                    self.fec_subgroup_id = YLeaf(YType.int32, "fec-subgroup-id")

                    self.fec_subgroup_originator = YLeaf(YType.str, "fec-subgroup-originator")

                    self.fec_tunnel_id = YLeaf(YType.int32, "fec-tunnel-id")

                    self.feclspid = YLeaf(YType.int32, "feclspid")

                    self.fecp2mpid = YLeaf(YType.int32, "fecp2mpid")

                    self.hello_receive_count = YLeaf(YType.uint32, "hello-receive-count")

                    self.hello_transmit_count = YLeaf(YType.uint32, "hello-transmit-count")

                    self.incoming_label = YLeaf(YType.int32, "incoming-label")

                    self.location = YLeaf(YType.str, "location")

                    self.vrf_name = YLeaf(YType.str, "vrf-name")
                    self._segment_path = lambda: "ipv4bf-do-mplste-tail-packet-counter"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-counters/ipv4bf-do-mplste-tail-packet-counters/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteTailCounters.Ipv4BfDoMplsteTailPacketCounters.Ipv4BfDoMplsteTailPacketCounter, ['display_type', 'echo_receive_count', 'echo_transmit_count', 'fe_ctype', 'fec_ctype', 'fec_destination', 'fec_extended_tunnel_id', 'fec_source', 'fec_subgroup_id', 'fec_subgroup_originator', 'fec_tunnel_id', 'feclspid', 'fecp2mpid', 'hello_receive_count', 'hello_transmit_count', 'incoming_label', 'location', 'vrf_name'], name, value)


    class Ipv4BfDoMplsteTailMultiPaths(Entity):
        """
        IPv4 BFD over MPLS\-TE Tail multipath
        
        .. attribute:: ipv4bf_do_mplste_tail_multi_path
        
        	Label multipath table
        	**type**\: list of    :py:class:`Ipv4BfDoMplsteTailMultiPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailMultiPaths.Ipv4BfDoMplsteTailMultiPath>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteTailMultiPaths, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-tail-multi-paths"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4bf-do-mplste-tail-multi-path" : ("ipv4bf_do_mplste_tail_multi_path", Bfd.Ipv4BfDoMplsteTailMultiPaths.Ipv4BfDoMplsteTailMultiPath)}

            self.ipv4bf_do_mplste_tail_multi_path = YList(self)
            self._segment_path = lambda: "ipv4bf-do-mplste-tail-multi-paths"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4BfDoMplsteTailMultiPaths, [], name, value)


        class Ipv4BfDoMplsteTailMultiPath(Entity):
            """
            Label multipath table
            
            .. attribute:: fe_ctype
            
            	FEC Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_ctype
            
            	FEC C Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_destination
            
            	FEC Destination
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_extended_tunnel_id
            
            	FEC Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_source
            
            	FEC Source
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_subgroup_id
            
            	FEC Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_subgroup_originator
            
            	FEC Subgroup originator
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_tunnel_id
            
            	FEC Tunnel ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: feclspid
            
            	FEC LSP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fecp2mpid
            
            	FEC P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: incoming_label
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: incoming_label_xr
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: local_discriminator
            
            	Session's Local discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_interface_name
            
            	Interface name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteTailMultiPaths.Ipv4BfDoMplsteTailMultiPath, self).__init__()

                self.yang_name = "ipv4bf-do-mplste-tail-multi-path"
                self.yang_parent_name = "ipv4bf-do-mplste-tail-multi-paths"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                self.fec_ctype = YLeaf(YType.int32, "fec-ctype")

                self.fec_destination = YLeaf(YType.str, "fec-destination")

                self.fec_extended_tunnel_id = YLeaf(YType.str, "fec-extended-tunnel-id")

                self.fec_source = YLeaf(YType.str, "fec-source")

                self.fec_subgroup_id = YLeaf(YType.int32, "fec-subgroup-id")

                self.fec_subgroup_originator = YLeaf(YType.str, "fec-subgroup-originator")

                self.fec_tunnel_id = YLeaf(YType.int32, "fec-tunnel-id")

                self.feclspid = YLeaf(YType.int32, "feclspid")

                self.fecp2mpid = YLeaf(YType.int32, "fecp2mpid")

                self.incoming_label = YLeaf(YType.int32, "incoming-label")

                self.incoming_label_xr = YLeaf(YType.uint32, "incoming-label-xr")

                self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_interface_name = YLeaf(YType.str, "session-interface-name")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.state = YLeaf(YType.enumeration, "state")

                self.vrf_name = YLeaf(YType.str, "vrf-name")
                self._segment_path = lambda: "ipv4bf-do-mplste-tail-multi-path"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-multi-paths/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteTailMultiPaths.Ipv4BfDoMplsteTailMultiPath, ['fe_ctype', 'fec_ctype', 'fec_destination', 'fec_extended_tunnel_id', 'fec_source', 'fec_subgroup_id', 'fec_subgroup_originator', 'fec_tunnel_id', 'feclspid', 'fecp2mpid', 'incoming_label', 'incoming_label_xr', 'local_discriminator', 'location', 'node_id', 'session_interface_name', 'session_subtype', 'state', 'vrf_name'], name, value)


    class Ipv4BfDoMplsteTailSessionBriefs(Entity):
        """
        Table of brief information about all IPv4 BFD
        over MPLS\-TE Tail sessions in the System
        
        .. attribute:: ipv4bf_do_mplste_tail_session_brief
        
        	Brief information for a single IPv4 BFD over MPLS\-TE session
        	**type**\: list of    :py:class:`Ipv4BfDoMplsteTailSessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteTailSessionBriefs, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-tail-session-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4bf-do-mplste-tail-session-brief" : ("ipv4bf_do_mplste_tail_session_brief", Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief)}

            self.ipv4bf_do_mplste_tail_session_brief = YList(self)
            self._segment_path = lambda: "ipv4bf-do-mplste-tail-session-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionBriefs, [], name, value)


        class Ipv4BfDoMplsteTailSessionBrief(Entity):
            """
            Brief information for a single IPv4 BFD over
            MPLS\-TE session
            
            .. attribute:: fe_ctype
            
            	FEC Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_ctype
            
            	FEC C Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_destination
            
            	FEC Destination
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_extended_tunnel_id
            
            	FEC Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_source
            
            	FEC Source
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_subgroup_id
            
            	FEC Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_subgroup_originator
            
            	FEC Subgroup originator
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_tunnel_id
            
            	FEC Tunnel ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: feclspid
            
            	FEC LSP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fecp2mpid
            
            	FEC P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: incoming_label
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_flags
            
            	Session Flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: session_type
            
            	Session type
            	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: status_brief_information
            
            	Brief Status Information
            	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief, self).__init__()

                self.yang_name = "ipv4bf-do-mplste-tail-session-brief"
                self.yang_parent_name = "ipv4bf-do-mplste-tail-session-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"status-brief-information" : ("status_brief_information", Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation)}
                self._child_list_classes = {}

                self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                self.fec_ctype = YLeaf(YType.int32, "fec-ctype")

                self.fec_destination = YLeaf(YType.str, "fec-destination")

                self.fec_extended_tunnel_id = YLeaf(YType.str, "fec-extended-tunnel-id")

                self.fec_source = YLeaf(YType.str, "fec-source")

                self.fec_subgroup_id = YLeaf(YType.int32, "fec-subgroup-id")

                self.fec_subgroup_originator = YLeaf(YType.str, "fec-subgroup-originator")

                self.fec_tunnel_id = YLeaf(YType.int32, "fec-tunnel-id")

                self.feclspid = YLeaf(YType.int32, "feclspid")

                self.fecp2mpid = YLeaf(YType.int32, "fecp2mpid")

                self.incoming_label = YLeaf(YType.int32, "incoming-label")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_flags = YLeaf(YType.uint32, "session-flags")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.state = YLeaf(YType.enumeration, "state")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.status_brief_information = Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation()
                self.status_brief_information.parent = self
                self._children_name_map["status_brief_information"] = "status-brief-information"
                self._children_yang_names.add("status-brief-information")
                self._segment_path = lambda: "ipv4bf-do-mplste-tail-session-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief, ['fe_ctype', 'fec_ctype', 'fec_destination', 'fec_extended_tunnel_id', 'fec_source', 'fec_subgroup_id', 'fec_subgroup_originator', 'fec_tunnel_id', 'feclspid', 'fecp2mpid', 'incoming_label', 'location', 'node_id', 'session_flags', 'session_subtype', 'session_type', 'state', 'vrf_name'], name, value)


            class StatusBriefInformation(Entity):
                """
                Brief Status Information
                
                .. attribute:: async_interval_multiplier
                
                	Async Interval and Detect Multiplier Information
                	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier>`
                
                .. attribute:: echo_interval_multiplier
                
                	Echo Interval and Detect Multiplier Information
                	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.EchoIntervalMultiplier>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation, self).__init__()

                    self.yang_name = "status-brief-information"
                    self.yang_parent_name = "ipv4bf-do-mplste-tail-session-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.EchoIntervalMultiplier)}
                    self._child_list_classes = {}

                    self.async_interval_multiplier = Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier()
                    self.async_interval_multiplier.parent = self
                    self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                    self._children_yang_names.add("async-interval-multiplier")

                    self.echo_interval_multiplier = Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.EchoIntervalMultiplier()
                    self.echo_interval_multiplier.parent = self
                    self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                    self._children_yang_names.add("echo-interval-multiplier")
                    self._segment_path = lambda: "status-brief-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-briefs/ipv4bf-do-mplste-tail-session-brief/%s" % self._segment_path()


                class AsyncIntervalMultiplier(Entity):
                    """
                    Async Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_local_transmit_interval
                    
                    	Negotiated local transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_remote_transmit_interval
                    
                    	Negotiated remote transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                        self.yang_name = "async-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                        self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                        self._segment_path = lambda: "async-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-briefs/ipv4bf-do-mplste-tail-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                class EchoIntervalMultiplier(Entity):
                    """
                    Echo Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_transmit_interval
                    
                    	Negotiated transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                        self.yang_name = "echo-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                        self._segment_path = lambda: "echo-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-briefs/ipv4bf-do-mplste-tail-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionBriefs.Ipv4BfDoMplsteTailSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


    class Ipv4BfDoMplsteTailSessionDetails(Entity):
        """
        Table of detailed information about all IPv4 BFD
        over MPLS\-TE Tail sessions in the System
        
        .. attribute:: ipv4bf_do_mplste_tail_session_detail
        
        	Detailed information for a single IPv4 BFD over MPLS\-TE Tail session
        	**type**\: list of    :py:class:`Ipv4BfDoMplsteTailSessionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteTailSessionDetails, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-tail-session-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4bf-do-mplste-tail-session-detail" : ("ipv4bf_do_mplste_tail_session_detail", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail)}

            self.ipv4bf_do_mplste_tail_session_detail = YList(self)
            self._segment_path = lambda: "ipv4bf-do-mplste-tail-session-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails, [], name, value)


        class Ipv4BfDoMplsteTailSessionDetail(Entity):
            """
            Detailed information for a single IPv4 BFD over
            MPLS\-TE Tail session
            
            .. attribute:: association_information
            
            	Association session information
            	**type**\: list of    :py:class:`AssociationInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation>`
            
            .. attribute:: fe_ctype
            
            	FEC Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_ctype
            
            	FEC C Type
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_destination
            
            	FEC Destination
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_extended_tunnel_id
            
            	FEC Extended Tunnel ID
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_source
            
            	FEC Source
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_subgroup_id
            
            	FEC Subgroup ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fec_subgroup_originator
            
            	FEC Subgroup originator
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: fec_tunnel_id
            
            	FEC Tunnel ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: feclspid
            
            	FEC LSP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: fecp2mpid
            
            	FEC P2MP ID
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: incoming_label
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: lsp_ping_info
            
            	LSP Ping Info
            	**type**\:   :py:class:`LspPingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo>`
            
            .. attribute:: mp_download_state
            
            	MP Dowload State
            	**type**\:   :py:class:`MpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState>`
            
            .. attribute:: owner_information
            
            	Client applications owning the session
            	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.OwnerInformation>`
            
            .. attribute:: status_information
            
            	Session status information
            	**type**\:   :py:class:`StatusInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail, self).__init__()

                self.yang_name = "ipv4bf-do-mplste-tail-session-detail"
                self.yang_parent_name = "ipv4bf-do-mplste-tail-session-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"lsp-ping-info" : ("lsp_ping_info", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo), "mp-download-state" : ("mp_download_state", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState), "status-information" : ("status_information", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation)}
                self._child_list_classes = {"association-information" : ("association_information", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation), "owner-information" : ("owner_information", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.OwnerInformation)}

                self.fe_ctype = YLeaf(YType.int32, "fe-ctype")

                self.fec_ctype = YLeaf(YType.int32, "fec-ctype")

                self.fec_destination = YLeaf(YType.str, "fec-destination")

                self.fec_extended_tunnel_id = YLeaf(YType.str, "fec-extended-tunnel-id")

                self.fec_source = YLeaf(YType.str, "fec-source")

                self.fec_subgroup_id = YLeaf(YType.int32, "fec-subgroup-id")

                self.fec_subgroup_originator = YLeaf(YType.str, "fec-subgroup-originator")

                self.fec_tunnel_id = YLeaf(YType.int32, "fec-tunnel-id")

                self.feclspid = YLeaf(YType.int32, "feclspid")

                self.fecp2mpid = YLeaf(YType.int32, "fecp2mpid")

                self.incoming_label = YLeaf(YType.int32, "incoming-label")

                self.location = YLeaf(YType.str, "location")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.lsp_ping_info = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo()
                self.lsp_ping_info.parent = self
                self._children_name_map["lsp_ping_info"] = "lsp-ping-info"
                self._children_yang_names.add("lsp-ping-info")

                self.mp_download_state = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState()
                self.mp_download_state.parent = self
                self._children_name_map["mp_download_state"] = "mp-download-state"
                self._children_yang_names.add("mp-download-state")

                self.status_information = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation()
                self.status_information.parent = self
                self._children_name_map["status_information"] = "status-information"
                self._children_yang_names.add("status-information")

                self.association_information = YList(self)
                self.owner_information = YList(self)
                self._segment_path = lambda: "ipv4bf-do-mplste-tail-session-detail"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail, ['fe_ctype', 'fec_ctype', 'fec_destination', 'fec_extended_tunnel_id', 'fec_source', 'fec_subgroup_id', 'fec_subgroup_originator', 'fec_tunnel_id', 'feclspid', 'fecp2mpid', 'incoming_label', 'location', 'vrf_name'], name, value)


            class AssociationInformation(Entity):
                """
                Association session information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: ip_destination_address
                
                	IPv4/v6 dest address
                	**type**\:   :py:class:`IpDestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation.IpDestinationAddress>`
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: owner_information
                
                	Client applications owning the session
                	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation.OwnerInformation>`
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation, self).__init__()

                    self.yang_name = "association-information"
                    self.yang_parent_name = "ipv4bf-do-mplste-tail-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"ip-destination-address" : ("ip_destination_address", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation.IpDestinationAddress)}
                    self._child_list_classes = {"owner-information" : ("owner_information", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation.OwnerInformation)}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.ip_destination_address = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation.IpDestinationAddress()
                    self.ip_destination_address.parent = self
                    self._children_name_map["ip_destination_address"] = "ip-destination-address"
                    self._children_yang_names.add("ip-destination-address")

                    self.owner_information = YList(self)
                    self._segment_path = lambda: "association-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation, ['interface_name', 'local_discriminator', 'sessiontype'], name, value)


                class IpDestinationAddress(Entity):
                    """
                    IPv4/v6 dest address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation.IpDestinationAddress, self).__init__()

                        self.yang_name = "ip-destination-address"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "ip-destination-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation.IpDestinationAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class OwnerInformation(Entity):
                    """
                    Client applications owning the session
                    
                    .. attribute:: adjusted_detection_multiplier
                    
                    	Adjusted detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: adjusted_interval
                    
                    	Adjusted minimum transmit interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Client specified detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interval
                    
                    	Client specified minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: name
                    
                    	Client process name
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation.OwnerInformation, self).__init__()

                        self.yang_name = "owner-information"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                        self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "owner-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.AssociationInformation.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class LspPingInfo(Entity):
                """
                LSP Ping Info
                
                .. attribute:: lsp_ping_rx_count
                
                	LSP Ping numer of times received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_code
                
                	LSP Ping Rx Last Code
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_discr
                
                	LSP Ping Rx last received discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_output
                
                	LSP Ping Rx Last Output
                	**type**\:  str
                
                .. attribute:: lsp_ping_rx_last_subcode
                
                	LSP Ping Rx Last Subcode
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_time
                
                	LSP Ping last received time
                	**type**\:   :py:class:`LspPingRxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingRxLastTime>`
                
                .. attribute:: lsp_ping_tx_count
                
                	LSP Ping Tx count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_error_count
                
                	LSP Ping Tx error count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_last_error_rc
                
                	LSP Ping Tx last error
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_error_time
                
                	LSP Ping last error time
                	**type**\:   :py:class:`LspPingTxLastErrorTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastErrorTime>`
                
                .. attribute:: lsp_ping_tx_last_rc
                
                	LSP Ping Tx last result
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_time
                
                	LSP Ping last sent time
                	**type**\:   :py:class:`LspPingTxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastTime>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo, self).__init__()

                    self.yang_name = "lsp-ping-info"
                    self.yang_parent_name = "ipv4bf-do-mplste-tail-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"lsp-ping-rx-last-time" : ("lsp_ping_rx_last_time", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingRxLastTime), "lsp-ping-tx-last-error-time" : ("lsp_ping_tx_last_error_time", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastErrorTime), "lsp-ping-tx-last-time" : ("lsp_ping_tx_last_time", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastTime)}
                    self._child_list_classes = {}

                    self.lsp_ping_rx_count = YLeaf(YType.uint32, "lsp-ping-rx-count")

                    self.lsp_ping_rx_last_code = YLeaf(YType.uint8, "lsp-ping-rx-last-code")

                    self.lsp_ping_rx_last_discr = YLeaf(YType.uint32, "lsp-ping-rx-last-discr")

                    self.lsp_ping_rx_last_output = YLeaf(YType.str, "lsp-ping-rx-last-output")

                    self.lsp_ping_rx_last_subcode = YLeaf(YType.uint8, "lsp-ping-rx-last-subcode")

                    self.lsp_ping_tx_count = YLeaf(YType.uint32, "lsp-ping-tx-count")

                    self.lsp_ping_tx_error_count = YLeaf(YType.uint32, "lsp-ping-tx-error-count")

                    self.lsp_ping_tx_last_error_rc = YLeaf(YType.str, "lsp-ping-tx-last-error-rc")

                    self.lsp_ping_tx_last_rc = YLeaf(YType.str, "lsp-ping-tx-last-rc")

                    self.lsp_ping_rx_last_time = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingRxLastTime()
                    self.lsp_ping_rx_last_time.parent = self
                    self._children_name_map["lsp_ping_rx_last_time"] = "lsp-ping-rx-last-time"
                    self._children_yang_names.add("lsp-ping-rx-last-time")

                    self.lsp_ping_tx_last_error_time = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastErrorTime()
                    self.lsp_ping_tx_last_error_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_error_time"] = "lsp-ping-tx-last-error-time"
                    self._children_yang_names.add("lsp-ping-tx-last-error-time")

                    self.lsp_ping_tx_last_time = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastTime()
                    self.lsp_ping_tx_last_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_time"] = "lsp-ping-tx-last-time"
                    self._children_yang_names.add("lsp-ping-tx-last-time")
                    self._segment_path = lambda: "lsp-ping-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo, ['lsp_ping_rx_count', 'lsp_ping_rx_last_code', 'lsp_ping_rx_last_discr', 'lsp_ping_rx_last_output', 'lsp_ping_rx_last_subcode', 'lsp_ping_tx_count', 'lsp_ping_tx_error_count', 'lsp_ping_tx_last_error_rc', 'lsp_ping_tx_last_rc'], name, value)


                class LspPingRxLastTime(Entity):
                    """
                    LSP Ping last received time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingRxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-rx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-rx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingRxLastTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastErrorTime(Entity):
                    """
                    LSP Ping last error time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastErrorTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-error-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-error-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastErrorTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastTime(Entity):
                    """
                    LSP Ping last sent time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.LspPingInfo.LspPingTxLastTime, ['nanoseconds', 'seconds'], name, value)


            class MpDownloadState(Entity):
                """
                MP Dowload State
                
                .. attribute:: change_time
                
                	Change time
                	**type**\:   :py:class:`ChangeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState.ChangeTime>`
                
                .. attribute:: mp_download_state
                
                	MP Download State
                	**type**\:   :py:class:`BfdMpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMpDownloadState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState, self).__init__()

                    self.yang_name = "mp-download-state"
                    self.yang_parent_name = "ipv4bf-do-mplste-tail-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"change-time" : ("change_time", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState.ChangeTime)}
                    self._child_list_classes = {}

                    self.mp_download_state = YLeaf(YType.enumeration, "mp-download-state")

                    self.change_time = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState.ChangeTime()
                    self.change_time.parent = self
                    self._children_name_map["change_time"] = "change-time"
                    self._children_yang_names.add("change-time")
                    self._segment_path = lambda: "mp-download-state"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState, ['mp_download_state'], name, value)


                class ChangeTime(Entity):
                    """
                    Change time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState.ChangeTime, self).__init__()

                        self.yang_name = "change-time"
                        self.yang_parent_name = "mp-download-state"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "change-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/mp-download-state/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.MpDownloadState.ChangeTime, ['nanoseconds', 'seconds'], name, value)


            class OwnerInformation(Entity):
                """
                Client applications owning the session
                
                .. attribute:: adjusted_detection_multiplier
                
                	Adjusted detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adjusted_interval
                
                	Adjusted minimum transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: detection_multiplier
                
                	Client specified detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interval
                
                	Client specified minimum transmit interval in micro\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: name
                
                	Client process name
                	**type**\:  str
                
                	**length:** 0..257
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.OwnerInformation, self).__init__()

                    self.yang_name = "owner-information"
                    self.yang_parent_name = "ipv4bf-do-mplste-tail-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                    self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.interval = YLeaf(YType.uint32, "interval")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "owner-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class StatusInformation(Entity):
                """
                Session status information
                
                .. attribute:: async_receive_statistics
                
                	Statistics of Interval between Async Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`AsyncReceiveStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncReceiveStatistics>`
                
                .. attribute:: async_transmit_statistics
                
                	Statistics of Interval between Async Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`AsyncTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncTransmitStatistics>`
                
                .. attribute:: desired_minimum_echo_transmit_interval
                
                	Desired minimum echo transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: echo_received_statistics
                
                	Statistics of Interval between Echo Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`EchoReceivedStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoReceivedStatistics>`
                
                .. attribute:: echo_transmit_statistics
                
                	Statistics of Interval between Echo Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`EchoTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoTransmitStatistics>`
                
                .. attribute:: internal_label
                
                	Internal Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_state_change
                
                	Time since last state change
                	**type**\:   :py:class:`LastStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.LastStateChange>`
                
                .. attribute:: latency_average
                
                	Average value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_maximum
                
                	Maximum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_minimum
                
                	Minimum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_number
                
                	Number of Latency Samples. Time between Transmit and Receive
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: node_id
                
                	Location where session is housed
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: receive_packet
                
                	Receive Packet
                	**type**\:   :py:class:`ReceivePacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.ReceivePacket>`
                
                .. attribute:: remote_discriminator
                
                	Session's Remote discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_negotiated_interval
                
                	Remote Negotiated Interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: session_subtype
                
                	Session subtype
                	**type**\:  str
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                .. attribute:: source_address
                
                	Source address
                	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.SourceAddress>`
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                .. attribute:: status_brief_information
                
                	Brief Status Information
                	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation>`
                
                .. attribute:: to_up_state_count
                
                	Number of times session state went to UP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmit_packet
                
                	Transmit Packet
                	**type**\:   :py:class:`TransmitPacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.TransmitPacket>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation, self).__init__()

                    self.yang_name = "status-information"
                    self.yang_parent_name = "ipv4bf-do-mplste-tail-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-receive-statistics" : ("async_receive_statistics", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncReceiveStatistics), "async-transmit-statistics" : ("async_transmit_statistics", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncTransmitStatistics), "echo-received-statistics" : ("echo_received_statistics", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoReceivedStatistics), "echo-transmit-statistics" : ("echo_transmit_statistics", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoTransmitStatistics), "last-state-change" : ("last_state_change", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.LastStateChange), "receive-packet" : ("receive_packet", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.ReceivePacket), "source-address" : ("source_address", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.SourceAddress), "status-brief-information" : ("status_brief_information", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation), "transmit-packet" : ("transmit_packet", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.TransmitPacket)}
                    self._child_list_classes = {}

                    self.desired_minimum_echo_transmit_interval = YLeaf(YType.uint32, "desired-minimum-echo-transmit-interval")

                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                    self.latency_average = YLeaf(YType.uint32, "latency-average")

                    self.latency_maximum = YLeaf(YType.uint32, "latency-maximum")

                    self.latency_minimum = YLeaf(YType.uint32, "latency-minimum")

                    self.latency_number = YLeaf(YType.uint32, "latency-number")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.remote_discriminator = YLeaf(YType.uint32, "remote-discriminator")

                    self.remote_negotiated_interval = YLeaf(YType.uint32, "remote-negotiated-interval")

                    self.session_subtype = YLeaf(YType.str, "session-subtype")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.to_up_state_count = YLeaf(YType.uint32, "to-up-state-count")

                    self.async_receive_statistics = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncReceiveStatistics()
                    self.async_receive_statistics.parent = self
                    self._children_name_map["async_receive_statistics"] = "async-receive-statistics"
                    self._children_yang_names.add("async-receive-statistics")

                    self.async_transmit_statistics = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncTransmitStatistics()
                    self.async_transmit_statistics.parent = self
                    self._children_name_map["async_transmit_statistics"] = "async-transmit-statistics"
                    self._children_yang_names.add("async-transmit-statistics")

                    self.echo_received_statistics = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoReceivedStatistics()
                    self.echo_received_statistics.parent = self
                    self._children_name_map["echo_received_statistics"] = "echo-received-statistics"
                    self._children_yang_names.add("echo-received-statistics")

                    self.echo_transmit_statistics = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoTransmitStatistics()
                    self.echo_transmit_statistics.parent = self
                    self._children_name_map["echo_transmit_statistics"] = "echo-transmit-statistics"
                    self._children_yang_names.add("echo-transmit-statistics")

                    self.last_state_change = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.LastStateChange()
                    self.last_state_change.parent = self
                    self._children_name_map["last_state_change"] = "last-state-change"
                    self._children_yang_names.add("last-state-change")

                    self.receive_packet = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.ReceivePacket()
                    self.receive_packet.parent = self
                    self._children_name_map["receive_packet"] = "receive-packet"
                    self._children_yang_names.add("receive-packet")

                    self.source_address = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.SourceAddress()
                    self.source_address.parent = self
                    self._children_name_map["source_address"] = "source-address"
                    self._children_yang_names.add("source-address")

                    self.status_brief_information = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation()
                    self.status_brief_information.parent = self
                    self._children_name_map["status_brief_information"] = "status-brief-information"
                    self._children_yang_names.add("status-brief-information")

                    self.transmit_packet = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.TransmitPacket()
                    self.transmit_packet.parent = self
                    self._children_name_map["transmit_packet"] = "transmit-packet"
                    self._children_yang_names.add("transmit-packet")
                    self._segment_path = lambda: "status-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation, ['desired_minimum_echo_transmit_interval', 'internal_label', 'latency_average', 'latency_maximum', 'latency_minimum', 'latency_number', 'local_discriminator', 'node_id', 'remote_discriminator', 'remote_negotiated_interval', 'session_subtype', 'sessiontype', 'state', 'to_up_state_count'], name, value)


                class AsyncReceiveStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncReceiveStatistics, self).__init__()

                        self.yang_name = "async-receive-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-receive-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncReceiveStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class AsyncTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncTransmitStatistics, self).__init__()

                        self.yang_name = "async-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.AsyncTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoReceivedStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoReceivedStatistics, self).__init__()

                        self.yang_name = "echo-received-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-received-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoReceivedStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoTransmitStatistics, self).__init__()

                        self.yang_name = "echo-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.EchoTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class LastStateChange(Entity):
                    """
                    Time since last state change
                    
                    .. attribute:: days
                    
                    	Number of days since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: day
                    
                    .. attribute:: hours
                    
                    	Number of hours since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: hour
                    
                    .. attribute:: minutes
                    
                    	Number of mins since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: minute
                    
                    .. attribute:: seconds
                    
                    	Number of seconds since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.LastStateChange, self).__init__()

                        self.yang_name = "last-state-change"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.days = YLeaf(YType.uint32, "days")

                        self.hours = YLeaf(YType.uint8, "hours")

                        self.minutes = YLeaf(YType.uint8, "minutes")

                        self.seconds = YLeaf(YType.uint8, "seconds")
                        self._segment_path = lambda: "last-state-change"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.LastStateChange, ['days', 'hours', 'minutes', 'seconds'], name, value)


                class ReceivePacket(Entity):
                    """
                    Receive Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.ReceivePacket, self).__init__()

                        self.yang_name = "receive-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "receive-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.ReceivePacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


                class SourceAddress(Entity):
                    """
                    Source address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.SourceAddress, self).__init__()

                        self.yang_name = "source-address"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "source-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.SourceAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class StatusBriefInformation(Entity):
                    """
                    Brief Status Information
                    
                    .. attribute:: async_interval_multiplier
                    
                    	Async Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier>`
                    
                    .. attribute:: echo_interval_multiplier
                    
                    	Echo Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier>`
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation, self).__init__()

                        self.yang_name = "status-brief-information"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier)}
                        self._child_list_classes = {}

                        self.async_interval_multiplier = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier()
                        self.async_interval_multiplier.parent = self
                        self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                        self._children_yang_names.add("async-interval-multiplier")

                        self.echo_interval_multiplier = Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier()
                        self.echo_interval_multiplier.parent = self
                        self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                        self._children_yang_names.add("echo-interval-multiplier")
                        self._segment_path = lambda: "status-brief-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/%s" % self._segment_path()


                    class AsyncIntervalMultiplier(Entity):
                        """
                        Async Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_local_transmit_interval
                        
                        	Negotiated local transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_remote_transmit_interval
                        
                        	Negotiated remote transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                            self.yang_name = "async-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                            self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                            self._segment_path = lambda: "async-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                    class EchoIntervalMultiplier(Entity):
                        """
                        Echo Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_transmit_interval
                        
                        	Negotiated transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                            self.yang_name = "echo-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                            self._segment_path = lambda: "echo-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


                class TransmitPacket(Entity):
                    """
                    Transmit Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.TransmitPacket, self).__init__()

                        self.yang_name = "transmit-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "transmit-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-session-details/ipv4bf-do-mplste-tail-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSessionDetails.Ipv4BfDoMplsteTailSessionDetail.StatusInformation.TransmitPacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


    class Ipv4BfDoMplsteTailSummary(Entity):
        """
        Summary information of IPv4 BFD over MPLS\-TE
        Tail
        
        .. attribute:: session_state
        
        	Statistics of states for sessions
        	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfDoMplsteTailSummary.SessionState>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfDoMplsteTailSummary, self).__init__()

            self.yang_name = "ipv4bf-do-mplste-tail-summary"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv4BfDoMplsteTailSummary.SessionState)}
            self._child_list_classes = {}

            self.session_state = Bfd.Ipv4BfDoMplsteTailSummary.SessionState()
            self.session_state.parent = self
            self._children_name_map["session_state"] = "session-state"
            self._children_yang_names.add("session-state")
            self._segment_path = lambda: "ipv4bf-do-mplste-tail-summary"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class SessionState(Entity):
            """
            Statistics of states for sessions
            
            .. attribute:: down_count
            
            	Number of sessions in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_count
            
            	Number of sessions in database
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_count
            
            	Number of sessions in unknown state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of sessions in up state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfDoMplsteTailSummary.SessionState, self).__init__()

                self.yang_name = "session-state"
                self.yang_parent_name = "ipv4bf-do-mplste-tail-summary"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.down_count = YLeaf(YType.uint32, "down-count")

                self.total_count = YLeaf(YType.uint32, "total-count")

                self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                self.up_count = YLeaf(YType.uint32, "up-count")
                self._segment_path = lambda: "session-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bf-do-mplste-tail-summary/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfDoMplsteTailSummary.SessionState, ['down_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv4BfdMplsteHeadSummaryNodes(Entity):
        """
        Table of summary about IPv4 TE head BFD sessions
        for location
        
        .. attribute:: ipv4bfd_mplste_head_summary_node
        
        	Summary of IPv4 BFD over MPLS\-TE head
        	**type**\: list of    :py:class:`Ipv4BfdMplsteHeadSummaryNode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfdMplsteHeadSummaryNodes.Ipv4BfdMplsteHeadSummaryNode>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfdMplsteHeadSummaryNodes, self).__init__()

            self.yang_name = "ipv4bfd-mplste-head-summary-nodes"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4bfd-mplste-head-summary-node" : ("ipv4bfd_mplste_head_summary_node", Bfd.Ipv4BfdMplsteHeadSummaryNodes.Ipv4BfdMplsteHeadSummaryNode)}

            self.ipv4bfd_mplste_head_summary_node = YList(self)
            self._segment_path = lambda: "ipv4bfd-mplste-head-summary-nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4BfdMplsteHeadSummaryNodes, [], name, value)


        class Ipv4BfdMplsteHeadSummaryNode(Entity):
            """
            Summary of IPv4 BFD over MPLS\-TE head
            
            .. attribute:: location_name  <key>
            
            	Location name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: session_state
            
            	Statistics of states for sessions
            	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfdMplsteHeadSummaryNodes.Ipv4BfdMplsteHeadSummaryNode.SessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfdMplsteHeadSummaryNodes.Ipv4BfdMplsteHeadSummaryNode, self).__init__()

                self.yang_name = "ipv4bfd-mplste-head-summary-node"
                self.yang_parent_name = "ipv4bfd-mplste-head-summary-nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv4BfdMplsteHeadSummaryNodes.Ipv4BfdMplsteHeadSummaryNode.SessionState)}
                self._child_list_classes = {}

                self.location_name = YLeaf(YType.str, "location-name")

                self.session_state = Bfd.Ipv4BfdMplsteHeadSummaryNodes.Ipv4BfdMplsteHeadSummaryNode.SessionState()
                self.session_state.parent = self
                self._children_name_map["session_state"] = "session-state"
                self._children_yang_names.add("session-state")
                self._segment_path = lambda: "ipv4bfd-mplste-head-summary-node" + "[location-name='" + self.location_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bfd-mplste-head-summary-nodes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfdMplsteHeadSummaryNodes.Ipv4BfdMplsteHeadSummaryNode, ['location_name'], name, value)


            class SessionState(Entity):
                """
                Statistics of states for sessions
                
                .. attribute:: down_count
                
                	Number of sessions in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retry_count
                
                	Number of sessions in retry state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_count
                
                	Number of sessions in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_count
                
                	Number of sessions in database
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_count
                
                	Number of sessions in unknown state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of sessions in up state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfdMplsteHeadSummaryNodes.Ipv4BfdMplsteHeadSummaryNode.SessionState, self).__init__()

                    self.yang_name = "session-state"
                    self.yang_parent_name = "ipv4bfd-mplste-head-summary-node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.down_count = YLeaf(YType.uint32, "down-count")

                    self.retry_count = YLeaf(YType.uint32, "retry-count")

                    self.standby_count = YLeaf(YType.uint32, "standby-count")

                    self.total_count = YLeaf(YType.uint32, "total-count")

                    self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                    self.up_count = YLeaf(YType.uint32, "up-count")
                    self._segment_path = lambda: "session-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfdMplsteHeadSummaryNodes.Ipv4BfdMplsteHeadSummaryNode.SessionState, ['down_count', 'retry_count', 'standby_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv4BfdMplsteTailNodeSummaries(Entity):
        """
        Table of summary about IPv4 TE tail BFD sessions
        for location
        
        .. attribute:: ipv4bfd_mplste_tail_node_summary
        
        	Summary of IPv4 BFD over MPLS\-TE tail
        	**type**\: list of    :py:class:`Ipv4BfdMplsteTailNodeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfdMplsteTailNodeSummaries.Ipv4BfdMplsteTailNodeSummary>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4BfdMplsteTailNodeSummaries, self).__init__()

            self.yang_name = "ipv4bfd-mplste-tail-node-summaries"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4bfd-mplste-tail-node-summary" : ("ipv4bfd_mplste_tail_node_summary", Bfd.Ipv4BfdMplsteTailNodeSummaries.Ipv4BfdMplsteTailNodeSummary)}

            self.ipv4bfd_mplste_tail_node_summary = YList(self)
            self._segment_path = lambda: "ipv4bfd-mplste-tail-node-summaries"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4BfdMplsteTailNodeSummaries, [], name, value)


        class Ipv4BfdMplsteTailNodeSummary(Entity):
            """
            Summary of IPv4 BFD over MPLS\-TE tail
            
            .. attribute:: location_name  <key>
            
            	Location name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: session_state
            
            	Statistics of states for sessions
            	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4BfdMplsteTailNodeSummaries.Ipv4BfdMplsteTailNodeSummary.SessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4BfdMplsteTailNodeSummaries.Ipv4BfdMplsteTailNodeSummary, self).__init__()

                self.yang_name = "ipv4bfd-mplste-tail-node-summary"
                self.yang_parent_name = "ipv4bfd-mplste-tail-node-summaries"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv4BfdMplsteTailNodeSummaries.Ipv4BfdMplsteTailNodeSummary.SessionState)}
                self._child_list_classes = {}

                self.location_name = YLeaf(YType.str, "location-name")

                self.session_state = Bfd.Ipv4BfdMplsteTailNodeSummaries.Ipv4BfdMplsteTailNodeSummary.SessionState()
                self.session_state.parent = self
                self._children_name_map["session_state"] = "session-state"
                self._children_yang_names.add("session-state")
                self._segment_path = lambda: "ipv4bfd-mplste-tail-node-summary" + "[location-name='" + self.location_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4bfd-mplste-tail-node-summaries/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4BfdMplsteTailNodeSummaries.Ipv4BfdMplsteTailNodeSummary, ['location_name'], name, value)


            class SessionState(Entity):
                """
                Statistics of states for sessions
                
                .. attribute:: down_count
                
                	Number of sessions in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retry_count
                
                	Number of sessions in retry state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_count
                
                	Number of sessions in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_count
                
                	Number of sessions in database
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_count
                
                	Number of sessions in unknown state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of sessions in up state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4BfdMplsteTailNodeSummaries.Ipv4BfdMplsteTailNodeSummary.SessionState, self).__init__()

                    self.yang_name = "session-state"
                    self.yang_parent_name = "ipv4bfd-mplste-tail-node-summary"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.down_count = YLeaf(YType.uint32, "down-count")

                    self.retry_count = YLeaf(YType.uint32, "retry-count")

                    self.standby_count = YLeaf(YType.uint32, "standby-count")

                    self.total_count = YLeaf(YType.uint32, "total-count")

                    self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                    self.up_count = YLeaf(YType.uint32, "up-count")
                    self._segment_path = lambda: "session-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4BfdMplsteTailNodeSummaries.Ipv4BfdMplsteTailNodeSummary.SessionState, ['down_count', 'retry_count', 'standby_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv4MultiHopCounters(Entity):
        """
        IPv4 multiple hop Counters
        
        .. attribute:: ipv4_multi_hop_packet_counters
        
        	Table of IPv4 multiple hop Packet counters
        	**type**\:   :py:class:`Ipv4MultiHopPacketCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopCounters.Ipv4MultiHopPacketCounters>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4MultiHopCounters, self).__init__()

            self.yang_name = "ipv4-multi-hop-counters"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"ipv4-multi-hop-packet-counters" : ("ipv4_multi_hop_packet_counters", Bfd.Ipv4MultiHopCounters.Ipv4MultiHopPacketCounters)}
            self._child_list_classes = {}

            self.ipv4_multi_hop_packet_counters = Bfd.Ipv4MultiHopCounters.Ipv4MultiHopPacketCounters()
            self.ipv4_multi_hop_packet_counters.parent = self
            self._children_name_map["ipv4_multi_hop_packet_counters"] = "ipv4-multi-hop-packet-counters"
            self._children_yang_names.add("ipv4-multi-hop-packet-counters")
            self._segment_path = lambda: "ipv4-multi-hop-counters"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class Ipv4MultiHopPacketCounters(Entity):
            """
            Table of IPv4 multiple hop Packet counters
            
            .. attribute:: ipv4_multi_hop_packet_counter
            
            	IPv4 multiple hop Packet counters
            	**type**\: list of    :py:class:`Ipv4MultiHopPacketCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopCounters.Ipv4MultiHopPacketCounters.Ipv4MultiHopPacketCounter>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4MultiHopCounters.Ipv4MultiHopPacketCounters, self).__init__()

                self.yang_name = "ipv4-multi-hop-packet-counters"
                self.yang_parent_name = "ipv4-multi-hop-counters"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"ipv4-multi-hop-packet-counter" : ("ipv4_multi_hop_packet_counter", Bfd.Ipv4MultiHopCounters.Ipv4MultiHopPacketCounters.Ipv4MultiHopPacketCounter)}

                self.ipv4_multi_hop_packet_counter = YList(self)
                self._segment_path = lambda: "ipv4-multi-hop-packet-counters"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-counters/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4MultiHopCounters.Ipv4MultiHopPacketCounters, [], name, value)


            class Ipv4MultiHopPacketCounter(Entity):
                """
                IPv4 multiple hop Packet counters
                
                .. attribute:: destination_address
                
                	Destination Address
                	**type**\: one of the below types:
                
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                
                ----
                	**type**\:  str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                
                ----
                .. attribute:: display_type
                
                	Packet Display Type
                	**type**\:   :py:class:`BfdMgmtPktDisplay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtPktDisplay>`
                
                .. attribute:: echo_receive_count
                
                	Number of echo packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: echo_transmit_count
                
                	Number of echo packets transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_receive_count
                
                	Number of Hellos received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_transmit_count
                
                	Number of Hellos transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: location
                
                	Location
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: source_address
                
                	Source Address
                	**type**\: one of the below types:
                
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                
                ----
                	**type**\:  str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                
                ----
                .. attribute:: vrf_name
                
                	VRF name
                	**type**\:  str
                
                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4MultiHopCounters.Ipv4MultiHopPacketCounters.Ipv4MultiHopPacketCounter, self).__init__()

                    self.yang_name = "ipv4-multi-hop-packet-counter"
                    self.yang_parent_name = "ipv4-multi-hop-packet-counters"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.destination_address = YLeaf(YType.str, "destination-address")

                    self.display_type = YLeaf(YType.enumeration, "display-type")

                    self.echo_receive_count = YLeaf(YType.uint32, "echo-receive-count")

                    self.echo_transmit_count = YLeaf(YType.uint32, "echo-transmit-count")

                    self.hello_receive_count = YLeaf(YType.uint32, "hello-receive-count")

                    self.hello_transmit_count = YLeaf(YType.uint32, "hello-transmit-count")

                    self.location = YLeaf(YType.str, "location")

                    self.source_address = YLeaf(YType.str, "source-address")

                    self.vrf_name = YLeaf(YType.str, "vrf-name")
                    self._segment_path = lambda: "ipv4-multi-hop-packet-counter"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-counters/ipv4-multi-hop-packet-counters/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4MultiHopCounters.Ipv4MultiHopPacketCounters.Ipv4MultiHopPacketCounter, ['destination_address', 'display_type', 'echo_receive_count', 'echo_transmit_count', 'hello_receive_count', 'hello_transmit_count', 'location', 'source_address', 'vrf_name'], name, value)


    class Ipv4MultiHopMultiPaths(Entity):
        """
        IPv4 multi\-hop multipath
        
        .. attribute:: ipv4_multi_hop_multi_path
        
        	IPv4 multi hop multipath table
        	**type**\: list of    :py:class:`Ipv4MultiHopMultiPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopMultiPaths.Ipv4MultiHopMultiPath>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4MultiHopMultiPaths, self).__init__()

            self.yang_name = "ipv4-multi-hop-multi-paths"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4-multi-hop-multi-path" : ("ipv4_multi_hop_multi_path", Bfd.Ipv4MultiHopMultiPaths.Ipv4MultiHopMultiPath)}

            self.ipv4_multi_hop_multi_path = YList(self)
            self._segment_path = lambda: "ipv4-multi-hop-multi-paths"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4MultiHopMultiPaths, [], name, value)


        class Ipv4MultiHopMultiPath(Entity):
            """
            IPv4 multi hop multipath table
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: incoming_label_xr
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: local_discriminator
            
            	Session's Local discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_interface_name
            
            	Interface name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4MultiHopMultiPaths.Ipv4MultiHopMultiPath, self).__init__()

                self.yang_name = "ipv4-multi-hop-multi-path"
                self.yang_parent_name = "ipv4-multi-hop-multi-paths"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.incoming_label_xr = YLeaf(YType.uint32, "incoming-label-xr")

                self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_interface_name = YLeaf(YType.str, "session-interface-name")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.source_address = YLeaf(YType.str, "source-address")

                self.state = YLeaf(YType.enumeration, "state")

                self.vrf_name = YLeaf(YType.str, "vrf-name")
                self._segment_path = lambda: "ipv4-multi-hop-multi-path"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-multi-paths/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4MultiHopMultiPaths.Ipv4MultiHopMultiPath, ['destination_address', 'incoming_label_xr', 'local_discriminator', 'location', 'node_id', 'session_interface_name', 'session_subtype', 'source_address', 'state', 'vrf_name'], name, value)


    class Ipv4MultiHopNodeLocationSummaries(Entity):
        """
        Table of summary information about BFD IPv4
        multihop sessions per location
        
        .. attribute:: ipv4_multi_hop_node_location_summary
        
        	Summary information for BFD IPv4 multihop sessions for location
        	**type**\: list of    :py:class:`Ipv4MultiHopNodeLocationSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopNodeLocationSummaries.Ipv4MultiHopNodeLocationSummary>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4MultiHopNodeLocationSummaries, self).__init__()

            self.yang_name = "ipv4-multi-hop-node-location-summaries"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4-multi-hop-node-location-summary" : ("ipv4_multi_hop_node_location_summary", Bfd.Ipv4MultiHopNodeLocationSummaries.Ipv4MultiHopNodeLocationSummary)}

            self.ipv4_multi_hop_node_location_summary = YList(self)
            self._segment_path = lambda: "ipv4-multi-hop-node-location-summaries"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4MultiHopNodeLocationSummaries, [], name, value)


        class Ipv4MultiHopNodeLocationSummary(Entity):
            """
            Summary information for BFD IPv4 multihop
            sessions for location
            
            .. attribute:: location  <key>
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_state
            
            	Statistics of states for sessions
            	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopNodeLocationSummaries.Ipv4MultiHopNodeLocationSummary.SessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4MultiHopNodeLocationSummaries.Ipv4MultiHopNodeLocationSummary, self).__init__()

                self.yang_name = "ipv4-multi-hop-node-location-summary"
                self.yang_parent_name = "ipv4-multi-hop-node-location-summaries"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv4MultiHopNodeLocationSummaries.Ipv4MultiHopNodeLocationSummary.SessionState)}
                self._child_list_classes = {}

                self.location = YLeaf(YType.str, "location")

                self.session_state = Bfd.Ipv4MultiHopNodeLocationSummaries.Ipv4MultiHopNodeLocationSummary.SessionState()
                self.session_state.parent = self
                self._children_name_map["session_state"] = "session-state"
                self._children_yang_names.add("session-state")
                self._segment_path = lambda: "ipv4-multi-hop-node-location-summary" + "[location='" + self.location.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-node-location-summaries/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4MultiHopNodeLocationSummaries.Ipv4MultiHopNodeLocationSummary, ['location'], name, value)


            class SessionState(Entity):
                """
                Statistics of states for sessions
                
                .. attribute:: down_count
                
                	Number of sessions in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retry_count
                
                	Number of sessions in retry state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_count
                
                	Number of sessions in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_count
                
                	Number of sessions in database
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_count
                
                	Number of sessions in unknown state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of sessions in up state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4MultiHopNodeLocationSummaries.Ipv4MultiHopNodeLocationSummary.SessionState, self).__init__()

                    self.yang_name = "session-state"
                    self.yang_parent_name = "ipv4-multi-hop-node-location-summary"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.down_count = YLeaf(YType.uint32, "down-count")

                    self.retry_count = YLeaf(YType.uint32, "retry-count")

                    self.standby_count = YLeaf(YType.uint32, "standby-count")

                    self.total_count = YLeaf(YType.uint32, "total-count")

                    self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                    self.up_count = YLeaf(YType.uint32, "up-count")
                    self._segment_path = lambda: "session-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4MultiHopNodeLocationSummaries.Ipv4MultiHopNodeLocationSummary.SessionState, ['down_count', 'retry_count', 'standby_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv4MultiHopSessionBriefs(Entity):
        """
        Table of brief information about all IPv4
        multihop BFD sessions in the System
        
        .. attribute:: ipv4_multi_hop_session_brief
        
        	Brief information for a single IPv4 multihop BFD session
        	**type**\: list of    :py:class:`Ipv4MultiHopSessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4MultiHopSessionBriefs, self).__init__()

            self.yang_name = "ipv4-multi-hop-session-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4-multi-hop-session-brief" : ("ipv4_multi_hop_session_brief", Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief)}

            self.ipv4_multi_hop_session_brief = YList(self)
            self._segment_path = lambda: "ipv4-multi-hop-session-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4MultiHopSessionBriefs, [], name, value)


        class Ipv4MultiHopSessionBrief(Entity):
            """
            Brief information for a single IPv4 multihop
            BFD session
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_flags
            
            	Session Flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: session_type
            
            	Session type
            	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: status_brief_information
            
            	Brief Status Information
            	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief, self).__init__()

                self.yang_name = "ipv4-multi-hop-session-brief"
                self.yang_parent_name = "ipv4-multi-hop-session-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"status-brief-information" : ("status_brief_information", Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation)}
                self._child_list_classes = {}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_flags = YLeaf(YType.uint32, "session-flags")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.state = YLeaf(YType.enumeration, "state")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.status_brief_information = Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation()
                self.status_brief_information.parent = self
                self._children_name_map["status_brief_information"] = "status-brief-information"
                self._children_yang_names.add("status-brief-information")
                self._segment_path = lambda: "ipv4-multi-hop-session-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief, ['destination_address', 'location', 'node_id', 'session_flags', 'session_subtype', 'session_type', 'source_address', 'state', 'vrf_name'], name, value)


            class StatusBriefInformation(Entity):
                """
                Brief Status Information
                
                .. attribute:: async_interval_multiplier
                
                	Async Interval and Detect Multiplier Information
                	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier>`
                
                .. attribute:: echo_interval_multiplier
                
                	Echo Interval and Detect Multiplier Information
                	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation, self).__init__()

                    self.yang_name = "status-brief-information"
                    self.yang_parent_name = "ipv4-multi-hop-session-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier)}
                    self._child_list_classes = {}

                    self.async_interval_multiplier = Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier()
                    self.async_interval_multiplier.parent = self
                    self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                    self._children_yang_names.add("async-interval-multiplier")

                    self.echo_interval_multiplier = Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier()
                    self.echo_interval_multiplier.parent = self
                    self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                    self._children_yang_names.add("echo-interval-multiplier")
                    self._segment_path = lambda: "status-brief-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-briefs/ipv4-multi-hop-session-brief/%s" % self._segment_path()


                class AsyncIntervalMultiplier(Entity):
                    """
                    Async Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_local_transmit_interval
                    
                    	Negotiated local transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_remote_transmit_interval
                    
                    	Negotiated remote transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                        self.yang_name = "async-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                        self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                        self._segment_path = lambda: "async-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-briefs/ipv4-multi-hop-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                class EchoIntervalMultiplier(Entity):
                    """
                    Echo Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_transmit_interval
                    
                    	Negotiated transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                        self.yang_name = "echo-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                        self._segment_path = lambda: "echo-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-briefs/ipv4-multi-hop-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionBriefs.Ipv4MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


    class Ipv4MultiHopSessionDetails(Entity):
        """
        Table of detailed information about all IPv4
        multihop BFD sessions in the System 
        
        .. attribute:: ipv4_multi_hop_session_detail
        
        	Detailed information for a single IPv4 multihop BFD session
        	**type**\: list of    :py:class:`Ipv4MultiHopSessionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4MultiHopSessionDetails, self).__init__()

            self.yang_name = "ipv4-multi-hop-session-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4-multi-hop-session-detail" : ("ipv4_multi_hop_session_detail", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail)}

            self.ipv4_multi_hop_session_detail = YList(self)
            self._segment_path = lambda: "ipv4-multi-hop-session-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails, [], name, value)


        class Ipv4MultiHopSessionDetail(Entity):
            """
            Detailed information for a single IPv4 multihop
            BFD session
            
            .. attribute:: association_information
            
            	Association session information
            	**type**\: list of    :py:class:`AssociationInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: lsp_ping_info
            
            	LSP Ping Info
            	**type**\:   :py:class:`LspPingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo>`
            
            .. attribute:: mp_download_state
            
            	MP Dowload State
            	**type**\:   :py:class:`MpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState>`
            
            .. attribute:: owner_information
            
            	Client applications owning the session
            	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.OwnerInformation>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: status_information
            
            	Session status information
            	**type**\:   :py:class:`StatusInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail, self).__init__()

                self.yang_name = "ipv4-multi-hop-session-detail"
                self.yang_parent_name = "ipv4-multi-hop-session-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"lsp-ping-info" : ("lsp_ping_info", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo), "mp-download-state" : ("mp_download_state", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState), "status-information" : ("status_information", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation)}
                self._child_list_classes = {"association-information" : ("association_information", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation), "owner-information" : ("owner_information", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.OwnerInformation)}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.location = YLeaf(YType.str, "location")

                self.source_address = YLeaf(YType.str, "source-address")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.lsp_ping_info = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo()
                self.lsp_ping_info.parent = self
                self._children_name_map["lsp_ping_info"] = "lsp-ping-info"
                self._children_yang_names.add("lsp-ping-info")

                self.mp_download_state = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState()
                self.mp_download_state.parent = self
                self._children_name_map["mp_download_state"] = "mp-download-state"
                self._children_yang_names.add("mp-download-state")

                self.status_information = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation()
                self.status_information.parent = self
                self._children_name_map["status_information"] = "status-information"
                self._children_yang_names.add("status-information")

                self.association_information = YList(self)
                self.owner_information = YList(self)
                self._segment_path = lambda: "ipv4-multi-hop-session-detail"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail, ['destination_address', 'location', 'source_address', 'vrf_name'], name, value)


            class AssociationInformation(Entity):
                """
                Association session information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: ip_destination_address
                
                	IPv4/v6 dest address
                	**type**\:   :py:class:`IpDestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation.IpDestinationAddress>`
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: owner_information
                
                	Client applications owning the session
                	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation.OwnerInformation>`
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation, self).__init__()

                    self.yang_name = "association-information"
                    self.yang_parent_name = "ipv4-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"ip-destination-address" : ("ip_destination_address", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation.IpDestinationAddress)}
                    self._child_list_classes = {"owner-information" : ("owner_information", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation.OwnerInformation)}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.ip_destination_address = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation.IpDestinationAddress()
                    self.ip_destination_address.parent = self
                    self._children_name_map["ip_destination_address"] = "ip-destination-address"
                    self._children_yang_names.add("ip-destination-address")

                    self.owner_information = YList(self)
                    self._segment_path = lambda: "association-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation, ['interface_name', 'local_discriminator', 'sessiontype'], name, value)


                class IpDestinationAddress(Entity):
                    """
                    IPv4/v6 dest address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation.IpDestinationAddress, self).__init__()

                        self.yang_name = "ip-destination-address"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "ip-destination-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation.IpDestinationAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class OwnerInformation(Entity):
                    """
                    Client applications owning the session
                    
                    .. attribute:: adjusted_detection_multiplier
                    
                    	Adjusted detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: adjusted_interval
                    
                    	Adjusted minimum transmit interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Client specified detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interval
                    
                    	Client specified minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: name
                    
                    	Client process name
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation.OwnerInformation, self).__init__()

                        self.yang_name = "owner-information"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                        self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "owner-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.AssociationInformation.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class LspPingInfo(Entity):
                """
                LSP Ping Info
                
                .. attribute:: lsp_ping_rx_count
                
                	LSP Ping numer of times received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_code
                
                	LSP Ping Rx Last Code
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_discr
                
                	LSP Ping Rx last received discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_output
                
                	LSP Ping Rx Last Output
                	**type**\:  str
                
                .. attribute:: lsp_ping_rx_last_subcode
                
                	LSP Ping Rx Last Subcode
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_time
                
                	LSP Ping last received time
                	**type**\:   :py:class:`LspPingRxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime>`
                
                .. attribute:: lsp_ping_tx_count
                
                	LSP Ping Tx count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_error_count
                
                	LSP Ping Tx error count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_last_error_rc
                
                	LSP Ping Tx last error
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_error_time
                
                	LSP Ping last error time
                	**type**\:   :py:class:`LspPingTxLastErrorTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime>`
                
                .. attribute:: lsp_ping_tx_last_rc
                
                	LSP Ping Tx last result
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_time
                
                	LSP Ping last sent time
                	**type**\:   :py:class:`LspPingTxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo, self).__init__()

                    self.yang_name = "lsp-ping-info"
                    self.yang_parent_name = "ipv4-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"lsp-ping-rx-last-time" : ("lsp_ping_rx_last_time", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime), "lsp-ping-tx-last-error-time" : ("lsp_ping_tx_last_error_time", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime), "lsp-ping-tx-last-time" : ("lsp_ping_tx_last_time", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime)}
                    self._child_list_classes = {}

                    self.lsp_ping_rx_count = YLeaf(YType.uint32, "lsp-ping-rx-count")

                    self.lsp_ping_rx_last_code = YLeaf(YType.uint8, "lsp-ping-rx-last-code")

                    self.lsp_ping_rx_last_discr = YLeaf(YType.uint32, "lsp-ping-rx-last-discr")

                    self.lsp_ping_rx_last_output = YLeaf(YType.str, "lsp-ping-rx-last-output")

                    self.lsp_ping_rx_last_subcode = YLeaf(YType.uint8, "lsp-ping-rx-last-subcode")

                    self.lsp_ping_tx_count = YLeaf(YType.uint32, "lsp-ping-tx-count")

                    self.lsp_ping_tx_error_count = YLeaf(YType.uint32, "lsp-ping-tx-error-count")

                    self.lsp_ping_tx_last_error_rc = YLeaf(YType.str, "lsp-ping-tx-last-error-rc")

                    self.lsp_ping_tx_last_rc = YLeaf(YType.str, "lsp-ping-tx-last-rc")

                    self.lsp_ping_rx_last_time = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime()
                    self.lsp_ping_rx_last_time.parent = self
                    self._children_name_map["lsp_ping_rx_last_time"] = "lsp-ping-rx-last-time"
                    self._children_yang_names.add("lsp-ping-rx-last-time")

                    self.lsp_ping_tx_last_error_time = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime()
                    self.lsp_ping_tx_last_error_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_error_time"] = "lsp-ping-tx-last-error-time"
                    self._children_yang_names.add("lsp-ping-tx-last-error-time")

                    self.lsp_ping_tx_last_time = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime()
                    self.lsp_ping_tx_last_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_time"] = "lsp-ping-tx-last-time"
                    self._children_yang_names.add("lsp-ping-tx-last-time")
                    self._segment_path = lambda: "lsp-ping-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo, ['lsp_ping_rx_count', 'lsp_ping_rx_last_code', 'lsp_ping_rx_last_discr', 'lsp_ping_rx_last_output', 'lsp_ping_rx_last_subcode', 'lsp_ping_tx_count', 'lsp_ping_tx_error_count', 'lsp_ping_tx_last_error_rc', 'lsp_ping_tx_last_rc'], name, value)


                class LspPingRxLastTime(Entity):
                    """
                    LSP Ping last received time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-rx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-rx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastErrorTime(Entity):
                    """
                    LSP Ping last error time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-error-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-error-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastTime(Entity):
                    """
                    LSP Ping last sent time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime, ['nanoseconds', 'seconds'], name, value)


            class MpDownloadState(Entity):
                """
                MP Dowload State
                
                .. attribute:: change_time
                
                	Change time
                	**type**\:   :py:class:`ChangeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState.ChangeTime>`
                
                .. attribute:: mp_download_state
                
                	MP Download State
                	**type**\:   :py:class:`BfdMpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMpDownloadState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState, self).__init__()

                    self.yang_name = "mp-download-state"
                    self.yang_parent_name = "ipv4-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"change-time" : ("change_time", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState.ChangeTime)}
                    self._child_list_classes = {}

                    self.mp_download_state = YLeaf(YType.enumeration, "mp-download-state")

                    self.change_time = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState.ChangeTime()
                    self.change_time.parent = self
                    self._children_name_map["change_time"] = "change-time"
                    self._children_yang_names.add("change-time")
                    self._segment_path = lambda: "mp-download-state"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState, ['mp_download_state'], name, value)


                class ChangeTime(Entity):
                    """
                    Change time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState.ChangeTime, self).__init__()

                        self.yang_name = "change-time"
                        self.yang_parent_name = "mp-download-state"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "change-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/mp-download-state/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.MpDownloadState.ChangeTime, ['nanoseconds', 'seconds'], name, value)


            class OwnerInformation(Entity):
                """
                Client applications owning the session
                
                .. attribute:: adjusted_detection_multiplier
                
                	Adjusted detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adjusted_interval
                
                	Adjusted minimum transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: detection_multiplier
                
                	Client specified detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interval
                
                	Client specified minimum transmit interval in micro\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: name
                
                	Client process name
                	**type**\:  str
                
                	**length:** 0..257
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.OwnerInformation, self).__init__()

                    self.yang_name = "owner-information"
                    self.yang_parent_name = "ipv4-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                    self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.interval = YLeaf(YType.uint32, "interval")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "owner-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class StatusInformation(Entity):
                """
                Session status information
                
                .. attribute:: async_receive_statistics
                
                	Statistics of Interval between Async Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`AsyncReceiveStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics>`
                
                .. attribute:: async_transmit_statistics
                
                	Statistics of Interval between Async Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`AsyncTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics>`
                
                .. attribute:: desired_minimum_echo_transmit_interval
                
                	Desired minimum echo transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: echo_received_statistics
                
                	Statistics of Interval between Echo Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`EchoReceivedStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics>`
                
                .. attribute:: echo_transmit_statistics
                
                	Statistics of Interval between Echo Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`EchoTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics>`
                
                .. attribute:: internal_label
                
                	Internal Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_state_change
                
                	Time since last state change
                	**type**\:   :py:class:`LastStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.LastStateChange>`
                
                .. attribute:: latency_average
                
                	Average value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_maximum
                
                	Maximum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_minimum
                
                	Minimum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_number
                
                	Number of Latency Samples. Time between Transmit and Receive
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: node_id
                
                	Location where session is housed
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: receive_packet
                
                	Receive Packet
                	**type**\:   :py:class:`ReceivePacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.ReceivePacket>`
                
                .. attribute:: remote_discriminator
                
                	Session's Remote discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_negotiated_interval
                
                	Remote Negotiated Interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: session_subtype
                
                	Session subtype
                	**type**\:  str
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                .. attribute:: source_address
                
                	Source address
                	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.SourceAddress>`
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                .. attribute:: status_brief_information
                
                	Brief Status Information
                	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation>`
                
                .. attribute:: to_up_state_count
                
                	Number of times session state went to UP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmit_packet
                
                	Transmit Packet
                	**type**\:   :py:class:`TransmitPacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.TransmitPacket>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation, self).__init__()

                    self.yang_name = "status-information"
                    self.yang_parent_name = "ipv4-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-receive-statistics" : ("async_receive_statistics", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics), "async-transmit-statistics" : ("async_transmit_statistics", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics), "echo-received-statistics" : ("echo_received_statistics", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics), "echo-transmit-statistics" : ("echo_transmit_statistics", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics), "last-state-change" : ("last_state_change", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.LastStateChange), "receive-packet" : ("receive_packet", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.ReceivePacket), "source-address" : ("source_address", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.SourceAddress), "status-brief-information" : ("status_brief_information", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation), "transmit-packet" : ("transmit_packet", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.TransmitPacket)}
                    self._child_list_classes = {}

                    self.desired_minimum_echo_transmit_interval = YLeaf(YType.uint32, "desired-minimum-echo-transmit-interval")

                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                    self.latency_average = YLeaf(YType.uint32, "latency-average")

                    self.latency_maximum = YLeaf(YType.uint32, "latency-maximum")

                    self.latency_minimum = YLeaf(YType.uint32, "latency-minimum")

                    self.latency_number = YLeaf(YType.uint32, "latency-number")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.remote_discriminator = YLeaf(YType.uint32, "remote-discriminator")

                    self.remote_negotiated_interval = YLeaf(YType.uint32, "remote-negotiated-interval")

                    self.session_subtype = YLeaf(YType.str, "session-subtype")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.to_up_state_count = YLeaf(YType.uint32, "to-up-state-count")

                    self.async_receive_statistics = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics()
                    self.async_receive_statistics.parent = self
                    self._children_name_map["async_receive_statistics"] = "async-receive-statistics"
                    self._children_yang_names.add("async-receive-statistics")

                    self.async_transmit_statistics = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics()
                    self.async_transmit_statistics.parent = self
                    self._children_name_map["async_transmit_statistics"] = "async-transmit-statistics"
                    self._children_yang_names.add("async-transmit-statistics")

                    self.echo_received_statistics = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics()
                    self.echo_received_statistics.parent = self
                    self._children_name_map["echo_received_statistics"] = "echo-received-statistics"
                    self._children_yang_names.add("echo-received-statistics")

                    self.echo_transmit_statistics = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics()
                    self.echo_transmit_statistics.parent = self
                    self._children_name_map["echo_transmit_statistics"] = "echo-transmit-statistics"
                    self._children_yang_names.add("echo-transmit-statistics")

                    self.last_state_change = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.LastStateChange()
                    self.last_state_change.parent = self
                    self._children_name_map["last_state_change"] = "last-state-change"
                    self._children_yang_names.add("last-state-change")

                    self.receive_packet = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.ReceivePacket()
                    self.receive_packet.parent = self
                    self._children_name_map["receive_packet"] = "receive-packet"
                    self._children_yang_names.add("receive-packet")

                    self.source_address = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.SourceAddress()
                    self.source_address.parent = self
                    self._children_name_map["source_address"] = "source-address"
                    self._children_yang_names.add("source-address")

                    self.status_brief_information = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation()
                    self.status_brief_information.parent = self
                    self._children_name_map["status_brief_information"] = "status-brief-information"
                    self._children_yang_names.add("status-brief-information")

                    self.transmit_packet = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.TransmitPacket()
                    self.transmit_packet.parent = self
                    self._children_name_map["transmit_packet"] = "transmit-packet"
                    self._children_yang_names.add("transmit-packet")
                    self._segment_path = lambda: "status-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation, ['desired_minimum_echo_transmit_interval', 'internal_label', 'latency_average', 'latency_maximum', 'latency_minimum', 'latency_number', 'local_discriminator', 'node_id', 'remote_discriminator', 'remote_negotiated_interval', 'session_subtype', 'sessiontype', 'state', 'to_up_state_count'], name, value)


                class AsyncReceiveStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics, self).__init__()

                        self.yang_name = "async-receive-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-receive-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class AsyncTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics, self).__init__()

                        self.yang_name = "async-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoReceivedStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics, self).__init__()

                        self.yang_name = "echo-received-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-received-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics, self).__init__()

                        self.yang_name = "echo-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class LastStateChange(Entity):
                    """
                    Time since last state change
                    
                    .. attribute:: days
                    
                    	Number of days since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: day
                    
                    .. attribute:: hours
                    
                    	Number of hours since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: hour
                    
                    .. attribute:: minutes
                    
                    	Number of mins since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: minute
                    
                    .. attribute:: seconds
                    
                    	Number of seconds since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.LastStateChange, self).__init__()

                        self.yang_name = "last-state-change"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.days = YLeaf(YType.uint32, "days")

                        self.hours = YLeaf(YType.uint8, "hours")

                        self.minutes = YLeaf(YType.uint8, "minutes")

                        self.seconds = YLeaf(YType.uint8, "seconds")
                        self._segment_path = lambda: "last-state-change"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.LastStateChange, ['days', 'hours', 'minutes', 'seconds'], name, value)


                class ReceivePacket(Entity):
                    """
                    Receive Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.ReceivePacket, self).__init__()

                        self.yang_name = "receive-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "receive-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.ReceivePacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


                class SourceAddress(Entity):
                    """
                    Source address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.SourceAddress, self).__init__()

                        self.yang_name = "source-address"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "source-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.SourceAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class StatusBriefInformation(Entity):
                    """
                    Brief Status Information
                    
                    .. attribute:: async_interval_multiplier
                    
                    	Async Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier>`
                    
                    .. attribute:: echo_interval_multiplier
                    
                    	Echo Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier>`
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation, self).__init__()

                        self.yang_name = "status-brief-information"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier)}
                        self._child_list_classes = {}

                        self.async_interval_multiplier = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier()
                        self.async_interval_multiplier.parent = self
                        self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                        self._children_yang_names.add("async-interval-multiplier")

                        self.echo_interval_multiplier = Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier()
                        self.echo_interval_multiplier.parent = self
                        self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                        self._children_yang_names.add("echo-interval-multiplier")
                        self._segment_path = lambda: "status-brief-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/%s" % self._segment_path()


                    class AsyncIntervalMultiplier(Entity):
                        """
                        Async Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_local_transmit_interval
                        
                        	Negotiated local transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_remote_transmit_interval
                        
                        	Negotiated remote transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                            self.yang_name = "async-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                            self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                            self._segment_path = lambda: "async-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                    class EchoIntervalMultiplier(Entity):
                        """
                        Echo Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_transmit_interval
                        
                        	Negotiated transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                            self.yang_name = "echo-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                            self._segment_path = lambda: "echo-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


                class TransmitPacket(Entity):
                    """
                    Transmit Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.TransmitPacket, self).__init__()

                        self.yang_name = "transmit-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "transmit-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-session-details/ipv4-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4MultiHopSessionDetails.Ipv4MultiHopSessionDetail.StatusInformation.TransmitPacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


    class Ipv4MultiHopSummary(Entity):
        """
        Summary information of BFD IPv4 multihop
        sessions
        
        .. attribute:: session_state
        
        	Statistics of states for sessions
        	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4MultiHopSummary.SessionState>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4MultiHopSummary, self).__init__()

            self.yang_name = "ipv4-multi-hop-summary"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv4MultiHopSummary.SessionState)}
            self._child_list_classes = {}

            self.session_state = Bfd.Ipv4MultiHopSummary.SessionState()
            self.session_state.parent = self
            self._children_name_map["session_state"] = "session-state"
            self._children_yang_names.add("session-state")
            self._segment_path = lambda: "ipv4-multi-hop-summary"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class SessionState(Entity):
            """
            Statistics of states for sessions
            
            .. attribute:: down_count
            
            	Number of sessions in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_count
            
            	Number of sessions in database
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_count
            
            	Number of sessions in unknown state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of sessions in up state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4MultiHopSummary.SessionState, self).__init__()

                self.yang_name = "session-state"
                self.yang_parent_name = "ipv4-multi-hop-summary"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.down_count = YLeaf(YType.uint32, "down-count")

                self.total_count = YLeaf(YType.uint32, "total-count")

                self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                self.up_count = YLeaf(YType.uint32, "up-count")
                self._segment_path = lambda: "session-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-multi-hop-summary/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4MultiHopSummary.SessionState, ['down_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv4SingleHopCounters(Entity):
        """
        IPv4 single hop Counters
        
        .. attribute:: ipv4_single_hop_packet_counters
        
        	Table of IPv4 single hop Packet counters
        	**type**\:   :py:class:`Ipv4SingleHopPacketCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopCounters.Ipv4SingleHopPacketCounters>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4SingleHopCounters, self).__init__()

            self.yang_name = "ipv4-single-hop-counters"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"ipv4-single-hop-packet-counters" : ("ipv4_single_hop_packet_counters", Bfd.Ipv4SingleHopCounters.Ipv4SingleHopPacketCounters)}
            self._child_list_classes = {}

            self.ipv4_single_hop_packet_counters = Bfd.Ipv4SingleHopCounters.Ipv4SingleHopPacketCounters()
            self.ipv4_single_hop_packet_counters.parent = self
            self._children_name_map["ipv4_single_hop_packet_counters"] = "ipv4-single-hop-packet-counters"
            self._children_yang_names.add("ipv4-single-hop-packet-counters")
            self._segment_path = lambda: "ipv4-single-hop-counters"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class Ipv4SingleHopPacketCounters(Entity):
            """
            Table of IPv4 single hop Packet counters
            
            .. attribute:: ipv4_single_hop_packet_counter
            
            	Interface IPv4 single hop Packet counters
            	**type**\: list of    :py:class:`Ipv4SingleHopPacketCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopCounters.Ipv4SingleHopPacketCounters.Ipv4SingleHopPacketCounter>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4SingleHopCounters.Ipv4SingleHopPacketCounters, self).__init__()

                self.yang_name = "ipv4-single-hop-packet-counters"
                self.yang_parent_name = "ipv4-single-hop-counters"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"ipv4-single-hop-packet-counter" : ("ipv4_single_hop_packet_counter", Bfd.Ipv4SingleHopCounters.Ipv4SingleHopPacketCounters.Ipv4SingleHopPacketCounter)}

                self.ipv4_single_hop_packet_counter = YList(self)
                self._segment_path = lambda: "ipv4-single-hop-packet-counters"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-counters/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4SingleHopCounters.Ipv4SingleHopPacketCounters, [], name, value)


            class Ipv4SingleHopPacketCounter(Entity):
                """
                Interface IPv4 single hop Packet counters
                
                .. attribute:: interface_name  <key>
                
                	Interface Name
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: display_type
                
                	Packet Display Type
                	**type**\:   :py:class:`BfdMgmtPktDisplay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtPktDisplay>`
                
                .. attribute:: echo_receive_count
                
                	Number of echo packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: echo_transmit_count
                
                	Number of echo packets transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_receive_count
                
                	Number of Hellos received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_transmit_count
                
                	Number of Hellos transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4SingleHopCounters.Ipv4SingleHopPacketCounters.Ipv4SingleHopPacketCounter, self).__init__()

                    self.yang_name = "ipv4-single-hop-packet-counter"
                    self.yang_parent_name = "ipv4-single-hop-packet-counters"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.display_type = YLeaf(YType.enumeration, "display-type")

                    self.echo_receive_count = YLeaf(YType.uint32, "echo-receive-count")

                    self.echo_transmit_count = YLeaf(YType.uint32, "echo-transmit-count")

                    self.hello_receive_count = YLeaf(YType.uint32, "hello-receive-count")

                    self.hello_transmit_count = YLeaf(YType.uint32, "hello-transmit-count")
                    self._segment_path = lambda: "ipv4-single-hop-packet-counter" + "[interface-name='" + self.interface_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-counters/ipv4-single-hop-packet-counters/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4SingleHopCounters.Ipv4SingleHopPacketCounters.Ipv4SingleHopPacketCounter, ['interface_name', 'display_type', 'echo_receive_count', 'echo_transmit_count', 'hello_receive_count', 'hello_transmit_count'], name, value)


    class Ipv4SingleHopLocationSummaries(Entity):
        """
        Table of summary information about IPv4
        singlehop BFD sessions for location
        
        .. attribute:: ipv4_single_hop_location_summary
        
        	Summary information for BFD IPv4 singlehop sessions for location
        	**type**\: list of    :py:class:`Ipv4SingleHopLocationSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopLocationSummaries.Ipv4SingleHopLocationSummary>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4SingleHopLocationSummaries, self).__init__()

            self.yang_name = "ipv4-single-hop-location-summaries"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4-single-hop-location-summary" : ("ipv4_single_hop_location_summary", Bfd.Ipv4SingleHopLocationSummaries.Ipv4SingleHopLocationSummary)}

            self.ipv4_single_hop_location_summary = YList(self)
            self._segment_path = lambda: "ipv4-single-hop-location-summaries"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4SingleHopLocationSummaries, [], name, value)


        class Ipv4SingleHopLocationSummary(Entity):
            """
            Summary information for BFD IPv4 singlehop
            sessions for location
            
            .. attribute:: location_name  <key>
            
            	Location Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: session_state
            
            	Statistics of states for sessions
            	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopLocationSummaries.Ipv4SingleHopLocationSummary.SessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4SingleHopLocationSummaries.Ipv4SingleHopLocationSummary, self).__init__()

                self.yang_name = "ipv4-single-hop-location-summary"
                self.yang_parent_name = "ipv4-single-hop-location-summaries"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv4SingleHopLocationSummaries.Ipv4SingleHopLocationSummary.SessionState)}
                self._child_list_classes = {}

                self.location_name = YLeaf(YType.str, "location-name")

                self.session_state = Bfd.Ipv4SingleHopLocationSummaries.Ipv4SingleHopLocationSummary.SessionState()
                self.session_state.parent = self
                self._children_name_map["session_state"] = "session-state"
                self._children_yang_names.add("session-state")
                self._segment_path = lambda: "ipv4-single-hop-location-summary" + "[location-name='" + self.location_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-location-summaries/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4SingleHopLocationSummaries.Ipv4SingleHopLocationSummary, ['location_name'], name, value)


            class SessionState(Entity):
                """
                Statistics of states for sessions
                
                .. attribute:: down_count
                
                	Number of sessions in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retry_count
                
                	Number of sessions in retry state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_count
                
                	Number of sessions in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_count
                
                	Number of sessions in database
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_count
                
                	Number of sessions in unknown state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of sessions in up state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4SingleHopLocationSummaries.Ipv4SingleHopLocationSummary.SessionState, self).__init__()

                    self.yang_name = "session-state"
                    self.yang_parent_name = "ipv4-single-hop-location-summary"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.down_count = YLeaf(YType.uint32, "down-count")

                    self.retry_count = YLeaf(YType.uint32, "retry-count")

                    self.standby_count = YLeaf(YType.uint32, "standby-count")

                    self.total_count = YLeaf(YType.uint32, "total-count")

                    self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                    self.up_count = YLeaf(YType.uint32, "up-count")
                    self._segment_path = lambda: "session-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4SingleHopLocationSummaries.Ipv4SingleHopLocationSummary.SessionState, ['down_count', 'retry_count', 'standby_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv4SingleHopMultiPaths(Entity):
        """
        IPv4 single hop multipath
        
        .. attribute:: ipv4_single_hop_multi_path
        
        	IPv4 single hop multipath table
        	**type**\: list of    :py:class:`Ipv4SingleHopMultiPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopMultiPaths.Ipv4SingleHopMultiPath>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4SingleHopMultiPaths, self).__init__()

            self.yang_name = "ipv4-single-hop-multi-paths"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4-single-hop-multi-path" : ("ipv4_single_hop_multi_path", Bfd.Ipv4SingleHopMultiPaths.Ipv4SingleHopMultiPath)}

            self.ipv4_single_hop_multi_path = YList(self)
            self._segment_path = lambda: "ipv4-single-hop-multi-paths"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4SingleHopMultiPaths, [], name, value)


        class Ipv4SingleHopMultiPath(Entity):
            """
            IPv4 single hop multipath table
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: incoming_label_xr
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: local_discriminator
            
            	Session's Local discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_interface_name
            
            	Interface name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4SingleHopMultiPaths.Ipv4SingleHopMultiPath, self).__init__()

                self.yang_name = "ipv4-single-hop-multi-path"
                self.yang_parent_name = "ipv4-single-hop-multi-paths"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.incoming_label_xr = YLeaf(YType.uint32, "incoming-label-xr")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_interface_name = YLeaf(YType.str, "session-interface-name")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.state = YLeaf(YType.enumeration, "state")
                self._segment_path = lambda: "ipv4-single-hop-multi-path"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-multi-paths/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4SingleHopMultiPaths.Ipv4SingleHopMultiPath, ['destination_address', 'incoming_label_xr', 'interface_name', 'local_discriminator', 'location', 'node_id', 'session_interface_name', 'session_subtype', 'state'], name, value)


    class Ipv4SingleHopNodeLocationSummaries(Entity):
        """
        Table of summary information about BFD IPv4
        singlehop sessions per location
        
        .. attribute:: ipv4_single_hop_node_location_summary
        
        	Summary information for BFD IPv4 singlehop sessions for location
        	**type**\: list of    :py:class:`Ipv4SingleHopNodeLocationSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopNodeLocationSummaries.Ipv4SingleHopNodeLocationSummary>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4SingleHopNodeLocationSummaries, self).__init__()

            self.yang_name = "ipv4-single-hop-node-location-summaries"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4-single-hop-node-location-summary" : ("ipv4_single_hop_node_location_summary", Bfd.Ipv4SingleHopNodeLocationSummaries.Ipv4SingleHopNodeLocationSummary)}

            self.ipv4_single_hop_node_location_summary = YList(self)
            self._segment_path = lambda: "ipv4-single-hop-node-location-summaries"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4SingleHopNodeLocationSummaries, [], name, value)


        class Ipv4SingleHopNodeLocationSummary(Entity):
            """
            Summary information for BFD IPv4 singlehop
            sessions for location
            
            .. attribute:: location  <key>
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_state
            
            	Statistics of states for sessions
            	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopNodeLocationSummaries.Ipv4SingleHopNodeLocationSummary.SessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4SingleHopNodeLocationSummaries.Ipv4SingleHopNodeLocationSummary, self).__init__()

                self.yang_name = "ipv4-single-hop-node-location-summary"
                self.yang_parent_name = "ipv4-single-hop-node-location-summaries"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv4SingleHopNodeLocationSummaries.Ipv4SingleHopNodeLocationSummary.SessionState)}
                self._child_list_classes = {}

                self.location = YLeaf(YType.str, "location")

                self.session_state = Bfd.Ipv4SingleHopNodeLocationSummaries.Ipv4SingleHopNodeLocationSummary.SessionState()
                self.session_state.parent = self
                self._children_name_map["session_state"] = "session-state"
                self._children_yang_names.add("session-state")
                self._segment_path = lambda: "ipv4-single-hop-node-location-summary" + "[location='" + self.location.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-node-location-summaries/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4SingleHopNodeLocationSummaries.Ipv4SingleHopNodeLocationSummary, ['location'], name, value)


            class SessionState(Entity):
                """
                Statistics of states for sessions
                
                .. attribute:: down_count
                
                	Number of sessions in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retry_count
                
                	Number of sessions in retry state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_count
                
                	Number of sessions in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_count
                
                	Number of sessions in database
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_count
                
                	Number of sessions in unknown state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of sessions in up state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4SingleHopNodeLocationSummaries.Ipv4SingleHopNodeLocationSummary.SessionState, self).__init__()

                    self.yang_name = "session-state"
                    self.yang_parent_name = "ipv4-single-hop-node-location-summary"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.down_count = YLeaf(YType.uint32, "down-count")

                    self.retry_count = YLeaf(YType.uint32, "retry-count")

                    self.standby_count = YLeaf(YType.uint32, "standby-count")

                    self.total_count = YLeaf(YType.uint32, "total-count")

                    self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                    self.up_count = YLeaf(YType.uint32, "up-count")
                    self._segment_path = lambda: "session-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4SingleHopNodeLocationSummaries.Ipv4SingleHopNodeLocationSummary.SessionState, ['down_count', 'retry_count', 'standby_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv4SingleHopSessionBriefs(Entity):
        """
        Table of brief information about all IPv4
        singlehop BFD sessions in the System
        
        .. attribute:: ipv4_single_hop_session_brief
        
        	Brief information for a single IPv4 singlehop BFD session
        	**type**\: list of    :py:class:`Ipv4SingleHopSessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4SingleHopSessionBriefs, self).__init__()

            self.yang_name = "ipv4-single-hop-session-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4-single-hop-session-brief" : ("ipv4_single_hop_session_brief", Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief)}

            self.ipv4_single_hop_session_brief = YList(self)
            self._segment_path = lambda: "ipv4-single-hop-session-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4SingleHopSessionBriefs, [], name, value)


        class Ipv4SingleHopSessionBrief(Entity):
            """
            Brief information for a single IPv4 singlehop
            BFD session
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_flags
            
            	Session Flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: session_type
            
            	Session type
            	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: status_brief_information
            
            	Brief Status Information
            	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief, self).__init__()

                self.yang_name = "ipv4-single-hop-session-brief"
                self.yang_parent_name = "ipv4-single-hop-session-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"status-brief-information" : ("status_brief_information", Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation)}
                self._child_list_classes = {}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_flags = YLeaf(YType.uint32, "session-flags")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.state = YLeaf(YType.enumeration, "state")

                self.status_brief_information = Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation()
                self.status_brief_information.parent = self
                self._children_name_map["status_brief_information"] = "status-brief-information"
                self._children_yang_names.add("status-brief-information")
                self._segment_path = lambda: "ipv4-single-hop-session-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief, ['destination_address', 'interface_name', 'location', 'node_id', 'session_flags', 'session_subtype', 'session_type', 'state'], name, value)


            class StatusBriefInformation(Entity):
                """
                Brief Status Information
                
                .. attribute:: async_interval_multiplier
                
                	Async Interval and Detect Multiplier Information
                	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier>`
                
                .. attribute:: echo_interval_multiplier
                
                	Echo Interval and Detect Multiplier Information
                	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation, self).__init__()

                    self.yang_name = "status-brief-information"
                    self.yang_parent_name = "ipv4-single-hop-session-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier)}
                    self._child_list_classes = {}

                    self.async_interval_multiplier = Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier()
                    self.async_interval_multiplier.parent = self
                    self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                    self._children_yang_names.add("async-interval-multiplier")

                    self.echo_interval_multiplier = Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier()
                    self.echo_interval_multiplier.parent = self
                    self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                    self._children_yang_names.add("echo-interval-multiplier")
                    self._segment_path = lambda: "status-brief-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-briefs/ipv4-single-hop-session-brief/%s" % self._segment_path()


                class AsyncIntervalMultiplier(Entity):
                    """
                    Async Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_local_transmit_interval
                    
                    	Negotiated local transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_remote_transmit_interval
                    
                    	Negotiated remote transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                        self.yang_name = "async-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                        self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                        self._segment_path = lambda: "async-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-briefs/ipv4-single-hop-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                class EchoIntervalMultiplier(Entity):
                    """
                    Echo Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_transmit_interval
                    
                    	Negotiated transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                        self.yang_name = "echo-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                        self._segment_path = lambda: "echo-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-briefs/ipv4-single-hop-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionBriefs.Ipv4SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


    class Ipv4SingleHopSessionDetails(Entity):
        """
        Table of detailed information about all IPv4
        singlehop BFD sessions in the System 
        
        .. attribute:: ipv4_single_hop_session_detail
        
        	Detailed information for a single IPv4 singlehop BFD session
        	**type**\: list of    :py:class:`Ipv4SingleHopSessionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4SingleHopSessionDetails, self).__init__()

            self.yang_name = "ipv4-single-hop-session-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv4-single-hop-session-detail" : ("ipv4_single_hop_session_detail", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail)}

            self.ipv4_single_hop_session_detail = YList(self)
            self._segment_path = lambda: "ipv4-single-hop-session-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails, [], name, value)


        class Ipv4SingleHopSessionDetail(Entity):
            """
            Detailed information for a single IPv4
            singlehop BFD session
            
            .. attribute:: association_information
            
            	Association session information
            	**type**\: list of    :py:class:`AssociationInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: lsp_ping_info
            
            	LSP Ping Info
            	**type**\:   :py:class:`LspPingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo>`
            
            .. attribute:: mp_download_state
            
            	MP Dowload State
            	**type**\:   :py:class:`MpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState>`
            
            .. attribute:: owner_information
            
            	Client applications owning the session
            	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.OwnerInformation>`
            
            .. attribute:: status_information
            
            	Session status information
            	**type**\:   :py:class:`StatusInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail, self).__init__()

                self.yang_name = "ipv4-single-hop-session-detail"
                self.yang_parent_name = "ipv4-single-hop-session-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"lsp-ping-info" : ("lsp_ping_info", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo), "mp-download-state" : ("mp_download_state", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState), "status-information" : ("status_information", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation)}
                self._child_list_classes = {"association-information" : ("association_information", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation), "owner-information" : ("owner_information", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.OwnerInformation)}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.lsp_ping_info = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo()
                self.lsp_ping_info.parent = self
                self._children_name_map["lsp_ping_info"] = "lsp-ping-info"
                self._children_yang_names.add("lsp-ping-info")

                self.mp_download_state = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState()
                self.mp_download_state.parent = self
                self._children_name_map["mp_download_state"] = "mp-download-state"
                self._children_yang_names.add("mp-download-state")

                self.status_information = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation()
                self.status_information.parent = self
                self._children_name_map["status_information"] = "status-information"
                self._children_yang_names.add("status-information")

                self.association_information = YList(self)
                self.owner_information = YList(self)
                self._segment_path = lambda: "ipv4-single-hop-session-detail"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail, ['destination_address', 'interface_name', 'location'], name, value)


            class AssociationInformation(Entity):
                """
                Association session information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: ip_destination_address
                
                	IPv4/v6 dest address
                	**type**\:   :py:class:`IpDestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation.IpDestinationAddress>`
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: owner_information
                
                	Client applications owning the session
                	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation.OwnerInformation>`
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation, self).__init__()

                    self.yang_name = "association-information"
                    self.yang_parent_name = "ipv4-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"ip-destination-address" : ("ip_destination_address", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation.IpDestinationAddress)}
                    self._child_list_classes = {"owner-information" : ("owner_information", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation.OwnerInformation)}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.ip_destination_address = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation.IpDestinationAddress()
                    self.ip_destination_address.parent = self
                    self._children_name_map["ip_destination_address"] = "ip-destination-address"
                    self._children_yang_names.add("ip-destination-address")

                    self.owner_information = YList(self)
                    self._segment_path = lambda: "association-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation, ['interface_name', 'local_discriminator', 'sessiontype'], name, value)


                class IpDestinationAddress(Entity):
                    """
                    IPv4/v6 dest address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation.IpDestinationAddress, self).__init__()

                        self.yang_name = "ip-destination-address"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "ip-destination-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation.IpDestinationAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class OwnerInformation(Entity):
                    """
                    Client applications owning the session
                    
                    .. attribute:: adjusted_detection_multiplier
                    
                    	Adjusted detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: adjusted_interval
                    
                    	Adjusted minimum transmit interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Client specified detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interval
                    
                    	Client specified minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: name
                    
                    	Client process name
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation.OwnerInformation, self).__init__()

                        self.yang_name = "owner-information"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                        self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "owner-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.AssociationInformation.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class LspPingInfo(Entity):
                """
                LSP Ping Info
                
                .. attribute:: lsp_ping_rx_count
                
                	LSP Ping numer of times received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_code
                
                	LSP Ping Rx Last Code
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_discr
                
                	LSP Ping Rx last received discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_output
                
                	LSP Ping Rx Last Output
                	**type**\:  str
                
                .. attribute:: lsp_ping_rx_last_subcode
                
                	LSP Ping Rx Last Subcode
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_time
                
                	LSP Ping last received time
                	**type**\:   :py:class:`LspPingRxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime>`
                
                .. attribute:: lsp_ping_tx_count
                
                	LSP Ping Tx count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_error_count
                
                	LSP Ping Tx error count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_last_error_rc
                
                	LSP Ping Tx last error
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_error_time
                
                	LSP Ping last error time
                	**type**\:   :py:class:`LspPingTxLastErrorTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime>`
                
                .. attribute:: lsp_ping_tx_last_rc
                
                	LSP Ping Tx last result
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_time
                
                	LSP Ping last sent time
                	**type**\:   :py:class:`LspPingTxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo, self).__init__()

                    self.yang_name = "lsp-ping-info"
                    self.yang_parent_name = "ipv4-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"lsp-ping-rx-last-time" : ("lsp_ping_rx_last_time", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime), "lsp-ping-tx-last-error-time" : ("lsp_ping_tx_last_error_time", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime), "lsp-ping-tx-last-time" : ("lsp_ping_tx_last_time", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime)}
                    self._child_list_classes = {}

                    self.lsp_ping_rx_count = YLeaf(YType.uint32, "lsp-ping-rx-count")

                    self.lsp_ping_rx_last_code = YLeaf(YType.uint8, "lsp-ping-rx-last-code")

                    self.lsp_ping_rx_last_discr = YLeaf(YType.uint32, "lsp-ping-rx-last-discr")

                    self.lsp_ping_rx_last_output = YLeaf(YType.str, "lsp-ping-rx-last-output")

                    self.lsp_ping_rx_last_subcode = YLeaf(YType.uint8, "lsp-ping-rx-last-subcode")

                    self.lsp_ping_tx_count = YLeaf(YType.uint32, "lsp-ping-tx-count")

                    self.lsp_ping_tx_error_count = YLeaf(YType.uint32, "lsp-ping-tx-error-count")

                    self.lsp_ping_tx_last_error_rc = YLeaf(YType.str, "lsp-ping-tx-last-error-rc")

                    self.lsp_ping_tx_last_rc = YLeaf(YType.str, "lsp-ping-tx-last-rc")

                    self.lsp_ping_rx_last_time = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime()
                    self.lsp_ping_rx_last_time.parent = self
                    self._children_name_map["lsp_ping_rx_last_time"] = "lsp-ping-rx-last-time"
                    self._children_yang_names.add("lsp-ping-rx-last-time")

                    self.lsp_ping_tx_last_error_time = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime()
                    self.lsp_ping_tx_last_error_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_error_time"] = "lsp-ping-tx-last-error-time"
                    self._children_yang_names.add("lsp-ping-tx-last-error-time")

                    self.lsp_ping_tx_last_time = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime()
                    self.lsp_ping_tx_last_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_time"] = "lsp-ping-tx-last-time"
                    self._children_yang_names.add("lsp-ping-tx-last-time")
                    self._segment_path = lambda: "lsp-ping-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo, ['lsp_ping_rx_count', 'lsp_ping_rx_last_code', 'lsp_ping_rx_last_discr', 'lsp_ping_rx_last_output', 'lsp_ping_rx_last_subcode', 'lsp_ping_tx_count', 'lsp_ping_tx_error_count', 'lsp_ping_tx_last_error_rc', 'lsp_ping_tx_last_rc'], name, value)


                class LspPingRxLastTime(Entity):
                    """
                    LSP Ping last received time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-rx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-rx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastErrorTime(Entity):
                    """
                    LSP Ping last error time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-error-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-error-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastTime(Entity):
                    """
                    LSP Ping last sent time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime, ['nanoseconds', 'seconds'], name, value)


            class MpDownloadState(Entity):
                """
                MP Dowload State
                
                .. attribute:: change_time
                
                	Change time
                	**type**\:   :py:class:`ChangeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState.ChangeTime>`
                
                .. attribute:: mp_download_state
                
                	MP Download State
                	**type**\:   :py:class:`BfdMpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMpDownloadState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState, self).__init__()

                    self.yang_name = "mp-download-state"
                    self.yang_parent_name = "ipv4-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"change-time" : ("change_time", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState.ChangeTime)}
                    self._child_list_classes = {}

                    self.mp_download_state = YLeaf(YType.enumeration, "mp-download-state")

                    self.change_time = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState.ChangeTime()
                    self.change_time.parent = self
                    self._children_name_map["change_time"] = "change-time"
                    self._children_yang_names.add("change-time")
                    self._segment_path = lambda: "mp-download-state"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState, ['mp_download_state'], name, value)


                class ChangeTime(Entity):
                    """
                    Change time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState.ChangeTime, self).__init__()

                        self.yang_name = "change-time"
                        self.yang_parent_name = "mp-download-state"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "change-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/mp-download-state/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.MpDownloadState.ChangeTime, ['nanoseconds', 'seconds'], name, value)


            class OwnerInformation(Entity):
                """
                Client applications owning the session
                
                .. attribute:: adjusted_detection_multiplier
                
                	Adjusted detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adjusted_interval
                
                	Adjusted minimum transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: detection_multiplier
                
                	Client specified detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interval
                
                	Client specified minimum transmit interval in micro\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: name
                
                	Client process name
                	**type**\:  str
                
                	**length:** 0..257
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.OwnerInformation, self).__init__()

                    self.yang_name = "owner-information"
                    self.yang_parent_name = "ipv4-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                    self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.interval = YLeaf(YType.uint32, "interval")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "owner-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class StatusInformation(Entity):
                """
                Session status information
                
                .. attribute:: async_receive_statistics
                
                	Statistics of Interval between Async Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`AsyncReceiveStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics>`
                
                .. attribute:: async_transmit_statistics
                
                	Statistics of Interval between Async Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`AsyncTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics>`
                
                .. attribute:: desired_minimum_echo_transmit_interval
                
                	Desired minimum echo transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: echo_received_statistics
                
                	Statistics of Interval between Echo Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`EchoReceivedStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics>`
                
                .. attribute:: echo_transmit_statistics
                
                	Statistics of Interval between Echo Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`EchoTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics>`
                
                .. attribute:: internal_label
                
                	Internal Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_state_change
                
                	Time since last state change
                	**type**\:   :py:class:`LastStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.LastStateChange>`
                
                .. attribute:: latency_average
                
                	Average value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_maximum
                
                	Maximum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_minimum
                
                	Minimum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_number
                
                	Number of Latency Samples. Time between Transmit and Receive
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: node_id
                
                	Location where session is housed
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: receive_packet
                
                	Receive Packet
                	**type**\:   :py:class:`ReceivePacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.ReceivePacket>`
                
                .. attribute:: remote_discriminator
                
                	Session's Remote discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_negotiated_interval
                
                	Remote Negotiated Interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: session_subtype
                
                	Session subtype
                	**type**\:  str
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                .. attribute:: source_address
                
                	Source address
                	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.SourceAddress>`
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                .. attribute:: status_brief_information
                
                	Brief Status Information
                	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation>`
                
                .. attribute:: to_up_state_count
                
                	Number of times session state went to UP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmit_packet
                
                	Transmit Packet
                	**type**\:   :py:class:`TransmitPacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.TransmitPacket>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation, self).__init__()

                    self.yang_name = "status-information"
                    self.yang_parent_name = "ipv4-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-receive-statistics" : ("async_receive_statistics", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics), "async-transmit-statistics" : ("async_transmit_statistics", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics), "echo-received-statistics" : ("echo_received_statistics", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics), "echo-transmit-statistics" : ("echo_transmit_statistics", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics), "last-state-change" : ("last_state_change", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.LastStateChange), "receive-packet" : ("receive_packet", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.ReceivePacket), "source-address" : ("source_address", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.SourceAddress), "status-brief-information" : ("status_brief_information", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation), "transmit-packet" : ("transmit_packet", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.TransmitPacket)}
                    self._child_list_classes = {}

                    self.desired_minimum_echo_transmit_interval = YLeaf(YType.uint32, "desired-minimum-echo-transmit-interval")

                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                    self.latency_average = YLeaf(YType.uint32, "latency-average")

                    self.latency_maximum = YLeaf(YType.uint32, "latency-maximum")

                    self.latency_minimum = YLeaf(YType.uint32, "latency-minimum")

                    self.latency_number = YLeaf(YType.uint32, "latency-number")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.remote_discriminator = YLeaf(YType.uint32, "remote-discriminator")

                    self.remote_negotiated_interval = YLeaf(YType.uint32, "remote-negotiated-interval")

                    self.session_subtype = YLeaf(YType.str, "session-subtype")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.to_up_state_count = YLeaf(YType.uint32, "to-up-state-count")

                    self.async_receive_statistics = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics()
                    self.async_receive_statistics.parent = self
                    self._children_name_map["async_receive_statistics"] = "async-receive-statistics"
                    self._children_yang_names.add("async-receive-statistics")

                    self.async_transmit_statistics = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics()
                    self.async_transmit_statistics.parent = self
                    self._children_name_map["async_transmit_statistics"] = "async-transmit-statistics"
                    self._children_yang_names.add("async-transmit-statistics")

                    self.echo_received_statistics = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics()
                    self.echo_received_statistics.parent = self
                    self._children_name_map["echo_received_statistics"] = "echo-received-statistics"
                    self._children_yang_names.add("echo-received-statistics")

                    self.echo_transmit_statistics = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics()
                    self.echo_transmit_statistics.parent = self
                    self._children_name_map["echo_transmit_statistics"] = "echo-transmit-statistics"
                    self._children_yang_names.add("echo-transmit-statistics")

                    self.last_state_change = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.LastStateChange()
                    self.last_state_change.parent = self
                    self._children_name_map["last_state_change"] = "last-state-change"
                    self._children_yang_names.add("last-state-change")

                    self.receive_packet = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.ReceivePacket()
                    self.receive_packet.parent = self
                    self._children_name_map["receive_packet"] = "receive-packet"
                    self._children_yang_names.add("receive-packet")

                    self.source_address = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.SourceAddress()
                    self.source_address.parent = self
                    self._children_name_map["source_address"] = "source-address"
                    self._children_yang_names.add("source-address")

                    self.status_brief_information = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation()
                    self.status_brief_information.parent = self
                    self._children_name_map["status_brief_information"] = "status-brief-information"
                    self._children_yang_names.add("status-brief-information")

                    self.transmit_packet = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.TransmitPacket()
                    self.transmit_packet.parent = self
                    self._children_name_map["transmit_packet"] = "transmit-packet"
                    self._children_yang_names.add("transmit-packet")
                    self._segment_path = lambda: "status-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation, ['desired_minimum_echo_transmit_interval', 'internal_label', 'latency_average', 'latency_maximum', 'latency_minimum', 'latency_number', 'local_discriminator', 'node_id', 'remote_discriminator', 'remote_negotiated_interval', 'session_subtype', 'sessiontype', 'state', 'to_up_state_count'], name, value)


                class AsyncReceiveStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics, self).__init__()

                        self.yang_name = "async-receive-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-receive-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class AsyncTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics, self).__init__()

                        self.yang_name = "async-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoReceivedStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics, self).__init__()

                        self.yang_name = "echo-received-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-received-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics, self).__init__()

                        self.yang_name = "echo-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class LastStateChange(Entity):
                    """
                    Time since last state change
                    
                    .. attribute:: days
                    
                    	Number of days since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: day
                    
                    .. attribute:: hours
                    
                    	Number of hours since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: hour
                    
                    .. attribute:: minutes
                    
                    	Number of mins since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: minute
                    
                    .. attribute:: seconds
                    
                    	Number of seconds since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.LastStateChange, self).__init__()

                        self.yang_name = "last-state-change"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.days = YLeaf(YType.uint32, "days")

                        self.hours = YLeaf(YType.uint8, "hours")

                        self.minutes = YLeaf(YType.uint8, "minutes")

                        self.seconds = YLeaf(YType.uint8, "seconds")
                        self._segment_path = lambda: "last-state-change"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.LastStateChange, ['days', 'hours', 'minutes', 'seconds'], name, value)


                class ReceivePacket(Entity):
                    """
                    Receive Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.ReceivePacket, self).__init__()

                        self.yang_name = "receive-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "receive-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.ReceivePacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


                class SourceAddress(Entity):
                    """
                    Source address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.SourceAddress, self).__init__()

                        self.yang_name = "source-address"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "source-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.SourceAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class StatusBriefInformation(Entity):
                    """
                    Brief Status Information
                    
                    .. attribute:: async_interval_multiplier
                    
                    	Async Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier>`
                    
                    .. attribute:: echo_interval_multiplier
                    
                    	Echo Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier>`
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation, self).__init__()

                        self.yang_name = "status-brief-information"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier)}
                        self._child_list_classes = {}

                        self.async_interval_multiplier = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier()
                        self.async_interval_multiplier.parent = self
                        self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                        self._children_yang_names.add("async-interval-multiplier")

                        self.echo_interval_multiplier = Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier()
                        self.echo_interval_multiplier.parent = self
                        self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                        self._children_yang_names.add("echo-interval-multiplier")
                        self._segment_path = lambda: "status-brief-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/%s" % self._segment_path()


                    class AsyncIntervalMultiplier(Entity):
                        """
                        Async Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_local_transmit_interval
                        
                        	Negotiated local transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_remote_transmit_interval
                        
                        	Negotiated remote transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                            self.yang_name = "async-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                            self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                            self._segment_path = lambda: "async-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                    class EchoIntervalMultiplier(Entity):
                        """
                        Echo Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_transmit_interval
                        
                        	Negotiated transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                            self.yang_name = "echo-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                            self._segment_path = lambda: "echo-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


                class TransmitPacket(Entity):
                    """
                    Transmit Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.TransmitPacket, self).__init__()

                        self.yang_name = "transmit-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "transmit-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-session-details/ipv4-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv4SingleHopSessionDetails.Ipv4SingleHopSessionDetail.StatusInformation.TransmitPacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


    class Ipv4SingleHopSummary(Entity):
        """
        Summary information of BFD IPv4 singlehop
        sessions
        
        .. attribute:: session_state
        
        	Statistics of states for sessions
        	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv4SingleHopSummary.SessionState>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv4SingleHopSummary, self).__init__()

            self.yang_name = "ipv4-single-hop-summary"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv4SingleHopSummary.SessionState)}
            self._child_list_classes = {}

            self.session_state = Bfd.Ipv4SingleHopSummary.SessionState()
            self.session_state.parent = self
            self._children_name_map["session_state"] = "session-state"
            self._children_yang_names.add("session-state")
            self._segment_path = lambda: "ipv4-single-hop-summary"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class SessionState(Entity):
            """
            Statistics of states for sessions
            
            .. attribute:: down_count
            
            	Number of sessions in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_count
            
            	Number of sessions in database
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_count
            
            	Number of sessions in unknown state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of sessions in up state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv4SingleHopSummary.SessionState, self).__init__()

                self.yang_name = "session-state"
                self.yang_parent_name = "ipv4-single-hop-summary"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.down_count = YLeaf(YType.uint32, "down-count")

                self.total_count = YLeaf(YType.uint32, "total-count")

                self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                self.up_count = YLeaf(YType.uint32, "up-count")
                self._segment_path = lambda: "session-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv4-single-hop-summary/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv4SingleHopSummary.SessionState, ['down_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv6MultiHopCounters(Entity):
        """
        IPv6 multiple hop Counters
        
        .. attribute:: ipv6_multi_hop_packet_counters
        
        	Table of IPv6 multiple hop Packet counters
        	**type**\:   :py:class:`Ipv6MultiHopPacketCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopCounters.Ipv6MultiHopPacketCounters>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6MultiHopCounters, self).__init__()

            self.yang_name = "ipv6-multi-hop-counters"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"ipv6-multi-hop-packet-counters" : ("ipv6_multi_hop_packet_counters", Bfd.Ipv6MultiHopCounters.Ipv6MultiHopPacketCounters)}
            self._child_list_classes = {}

            self.ipv6_multi_hop_packet_counters = Bfd.Ipv6MultiHopCounters.Ipv6MultiHopPacketCounters()
            self.ipv6_multi_hop_packet_counters.parent = self
            self._children_name_map["ipv6_multi_hop_packet_counters"] = "ipv6-multi-hop-packet-counters"
            self._children_yang_names.add("ipv6-multi-hop-packet-counters")
            self._segment_path = lambda: "ipv6-multi-hop-counters"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class Ipv6MultiHopPacketCounters(Entity):
            """
            Table of IPv6 multiple hop Packet counters
            
            .. attribute:: ipv6_multi_hop_packet_counter
            
            	IPv4 multiple hop Packet counters
            	**type**\: list of    :py:class:`Ipv6MultiHopPacketCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopCounters.Ipv6MultiHopPacketCounters.Ipv6MultiHopPacketCounter>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6MultiHopCounters.Ipv6MultiHopPacketCounters, self).__init__()

                self.yang_name = "ipv6-multi-hop-packet-counters"
                self.yang_parent_name = "ipv6-multi-hop-counters"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"ipv6-multi-hop-packet-counter" : ("ipv6_multi_hop_packet_counter", Bfd.Ipv6MultiHopCounters.Ipv6MultiHopPacketCounters.Ipv6MultiHopPacketCounter)}

                self.ipv6_multi_hop_packet_counter = YList(self)
                self._segment_path = lambda: "ipv6-multi-hop-packet-counters"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-counters/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6MultiHopCounters.Ipv6MultiHopPacketCounters, [], name, value)


            class Ipv6MultiHopPacketCounter(Entity):
                """
                IPv4 multiple hop Packet counters
                
                .. attribute:: destination_address
                
                	Destination Address
                	**type**\: one of the below types:
                
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                
                ----
                	**type**\:  str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                
                ----
                .. attribute:: display_type
                
                	Packet Display Type
                	**type**\:   :py:class:`BfdMgmtPktDisplay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtPktDisplay>`
                
                .. attribute:: echo_receive_count
                
                	Number of echo packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: echo_transmit_count
                
                	Number of echo packets transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_receive_count
                
                	Number of Hellos received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_transmit_count
                
                	Number of Hellos transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: location
                
                	Location
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: source_address
                
                	Source Address
                	**type**\: one of the below types:
                
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                
                ----
                	**type**\:  str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                
                ----
                .. attribute:: vrf_name
                
                	VRF name
                	**type**\:  str
                
                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6MultiHopCounters.Ipv6MultiHopPacketCounters.Ipv6MultiHopPacketCounter, self).__init__()

                    self.yang_name = "ipv6-multi-hop-packet-counter"
                    self.yang_parent_name = "ipv6-multi-hop-packet-counters"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.destination_address = YLeaf(YType.str, "destination-address")

                    self.display_type = YLeaf(YType.enumeration, "display-type")

                    self.echo_receive_count = YLeaf(YType.uint32, "echo-receive-count")

                    self.echo_transmit_count = YLeaf(YType.uint32, "echo-transmit-count")

                    self.hello_receive_count = YLeaf(YType.uint32, "hello-receive-count")

                    self.hello_transmit_count = YLeaf(YType.uint32, "hello-transmit-count")

                    self.location = YLeaf(YType.str, "location")

                    self.source_address = YLeaf(YType.str, "source-address")

                    self.vrf_name = YLeaf(YType.str, "vrf-name")
                    self._segment_path = lambda: "ipv6-multi-hop-packet-counter"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-counters/ipv6-multi-hop-packet-counters/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6MultiHopCounters.Ipv6MultiHopPacketCounters.Ipv6MultiHopPacketCounter, ['destination_address', 'display_type', 'echo_receive_count', 'echo_transmit_count', 'hello_receive_count', 'hello_transmit_count', 'location', 'source_address', 'vrf_name'], name, value)


    class Ipv6MultiHopMultiPaths(Entity):
        """
        IPv6 multi hop multipath
        
        .. attribute:: ipv6_multi_hop_multi_path
        
        	IPv6 multihop multipath table
        	**type**\: list of    :py:class:`Ipv6MultiHopMultiPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopMultiPaths.Ipv6MultiHopMultiPath>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6MultiHopMultiPaths, self).__init__()

            self.yang_name = "ipv6-multi-hop-multi-paths"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv6-multi-hop-multi-path" : ("ipv6_multi_hop_multi_path", Bfd.Ipv6MultiHopMultiPaths.Ipv6MultiHopMultiPath)}

            self.ipv6_multi_hop_multi_path = YList(self)
            self._segment_path = lambda: "ipv6-multi-hop-multi-paths"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv6MultiHopMultiPaths, [], name, value)


        class Ipv6MultiHopMultiPath(Entity):
            """
            IPv6 multihop multipath table
            
            .. attribute:: destination_address
            
            	Destination address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: incoming_label_xr
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: local_discriminator
            
            	Session's Local discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_interface_name
            
            	Interface name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: source_address
            
            	Source address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6MultiHopMultiPaths.Ipv6MultiHopMultiPath, self).__init__()

                self.yang_name = "ipv6-multi-hop-multi-path"
                self.yang_parent_name = "ipv6-multi-hop-multi-paths"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.incoming_label_xr = YLeaf(YType.uint32, "incoming-label-xr")

                self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_interface_name = YLeaf(YType.str, "session-interface-name")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.source_address = YLeaf(YType.str, "source-address")

                self.state = YLeaf(YType.enumeration, "state")

                self.vrf_name = YLeaf(YType.str, "vrf-name")
                self._segment_path = lambda: "ipv6-multi-hop-multi-path"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-multi-paths/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6MultiHopMultiPaths.Ipv6MultiHopMultiPath, ['destination_address', 'incoming_label_xr', 'local_discriminator', 'location', 'node_id', 'session_interface_name', 'session_subtype', 'source_address', 'state', 'vrf_name'], name, value)


    class Ipv6MultiHopNodeLocationSummaries(Entity):
        """
        Table of summary information about BFD IPv6
        multihop sessions per location
        
        .. attribute:: ipv6_multi_hop_node_location_summary
        
        	Summary information for BFD IPv6 multihop sessions for location
        	**type**\: list of    :py:class:`Ipv6MultiHopNodeLocationSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopNodeLocationSummaries.Ipv6MultiHopNodeLocationSummary>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6MultiHopNodeLocationSummaries, self).__init__()

            self.yang_name = "ipv6-multi-hop-node-location-summaries"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv6-multi-hop-node-location-summary" : ("ipv6_multi_hop_node_location_summary", Bfd.Ipv6MultiHopNodeLocationSummaries.Ipv6MultiHopNodeLocationSummary)}

            self.ipv6_multi_hop_node_location_summary = YList(self)
            self._segment_path = lambda: "ipv6-multi-hop-node-location-summaries"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv6MultiHopNodeLocationSummaries, [], name, value)


        class Ipv6MultiHopNodeLocationSummary(Entity):
            """
            Summary information for BFD IPv6 multihop
            sessions for location
            
            .. attribute:: location  <key>
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_state
            
            	Statistics of states for sessions
            	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopNodeLocationSummaries.Ipv6MultiHopNodeLocationSummary.SessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6MultiHopNodeLocationSummaries.Ipv6MultiHopNodeLocationSummary, self).__init__()

                self.yang_name = "ipv6-multi-hop-node-location-summary"
                self.yang_parent_name = "ipv6-multi-hop-node-location-summaries"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv6MultiHopNodeLocationSummaries.Ipv6MultiHopNodeLocationSummary.SessionState)}
                self._child_list_classes = {}

                self.location = YLeaf(YType.str, "location")

                self.session_state = Bfd.Ipv6MultiHopNodeLocationSummaries.Ipv6MultiHopNodeLocationSummary.SessionState()
                self.session_state.parent = self
                self._children_name_map["session_state"] = "session-state"
                self._children_yang_names.add("session-state")
                self._segment_path = lambda: "ipv6-multi-hop-node-location-summary" + "[location='" + self.location.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-node-location-summaries/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6MultiHopNodeLocationSummaries.Ipv6MultiHopNodeLocationSummary, ['location'], name, value)


            class SessionState(Entity):
                """
                Statistics of states for sessions
                
                .. attribute:: down_count
                
                	Number of sessions in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retry_count
                
                	Number of sessions in retry state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_count
                
                	Number of sessions in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_count
                
                	Number of sessions in database
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_count
                
                	Number of sessions in unknown state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of sessions in up state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6MultiHopNodeLocationSummaries.Ipv6MultiHopNodeLocationSummary.SessionState, self).__init__()

                    self.yang_name = "session-state"
                    self.yang_parent_name = "ipv6-multi-hop-node-location-summary"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.down_count = YLeaf(YType.uint32, "down-count")

                    self.retry_count = YLeaf(YType.uint32, "retry-count")

                    self.standby_count = YLeaf(YType.uint32, "standby-count")

                    self.total_count = YLeaf(YType.uint32, "total-count")

                    self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                    self.up_count = YLeaf(YType.uint32, "up-count")
                    self._segment_path = lambda: "session-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6MultiHopNodeLocationSummaries.Ipv6MultiHopNodeLocationSummary.SessionState, ['down_count', 'retry_count', 'standby_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv6MultiHopSessionBriefs(Entity):
        """
        Table of brief information about all IPv6
        multihop BFD sessions in the System
        
        .. attribute:: ipv6_multi_hop_session_brief
        
        	Brief information for a single IPv6 multihop BFD session
        	**type**\: list of    :py:class:`Ipv6MultiHopSessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6MultiHopSessionBriefs, self).__init__()

            self.yang_name = "ipv6-multi-hop-session-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv6-multi-hop-session-brief" : ("ipv6_multi_hop_session_brief", Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief)}

            self.ipv6_multi_hop_session_brief = YList(self)
            self._segment_path = lambda: "ipv6-multi-hop-session-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv6MultiHopSessionBriefs, [], name, value)


        class Ipv6MultiHopSessionBrief(Entity):
            """
            Brief information for a single IPv6 multihop
            BFD session
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_flags
            
            	Session Flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: session_type
            
            	Session type
            	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: status_brief_information
            
            	Brief Status Information
            	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief, self).__init__()

                self.yang_name = "ipv6-multi-hop-session-brief"
                self.yang_parent_name = "ipv6-multi-hop-session-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"status-brief-information" : ("status_brief_information", Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation)}
                self._child_list_classes = {}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_flags = YLeaf(YType.uint32, "session-flags")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.source_address = YLeaf(YType.str, "source-address")

                self.state = YLeaf(YType.enumeration, "state")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.status_brief_information = Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation()
                self.status_brief_information.parent = self
                self._children_name_map["status_brief_information"] = "status-brief-information"
                self._children_yang_names.add("status-brief-information")
                self._segment_path = lambda: "ipv6-multi-hop-session-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief, ['destination_address', 'location', 'node_id', 'session_flags', 'session_subtype', 'session_type', 'source_address', 'state', 'vrf_name'], name, value)


            class StatusBriefInformation(Entity):
                """
                Brief Status Information
                
                .. attribute:: async_interval_multiplier
                
                	Async Interval and Detect Multiplier Information
                	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier>`
                
                .. attribute:: echo_interval_multiplier
                
                	Echo Interval and Detect Multiplier Information
                	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation, self).__init__()

                    self.yang_name = "status-brief-information"
                    self.yang_parent_name = "ipv6-multi-hop-session-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier)}
                    self._child_list_classes = {}

                    self.async_interval_multiplier = Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier()
                    self.async_interval_multiplier.parent = self
                    self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                    self._children_yang_names.add("async-interval-multiplier")

                    self.echo_interval_multiplier = Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier()
                    self.echo_interval_multiplier.parent = self
                    self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                    self._children_yang_names.add("echo-interval-multiplier")
                    self._segment_path = lambda: "status-brief-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-briefs/ipv6-multi-hop-session-brief/%s" % self._segment_path()


                class AsyncIntervalMultiplier(Entity):
                    """
                    Async Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_local_transmit_interval
                    
                    	Negotiated local transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_remote_transmit_interval
                    
                    	Negotiated remote transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                        self.yang_name = "async-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                        self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                        self._segment_path = lambda: "async-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-briefs/ipv6-multi-hop-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                class EchoIntervalMultiplier(Entity):
                    """
                    Echo Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_transmit_interval
                    
                    	Negotiated transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                        self.yang_name = "echo-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                        self._segment_path = lambda: "echo-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-briefs/ipv6-multi-hop-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionBriefs.Ipv6MultiHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


    class Ipv6MultiHopSessionDetails(Entity):
        """
        Table of detailed information about all IPv6
        multihop BFD sessions in the System 
        
        .. attribute:: ipv6_multi_hop_session_detail
        
        	Detailed information for a single IPv6 multihop BFD session
        	**type**\: list of    :py:class:`Ipv6MultiHopSessionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6MultiHopSessionDetails, self).__init__()

            self.yang_name = "ipv6-multi-hop-session-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv6-multi-hop-session-detail" : ("ipv6_multi_hop_session_detail", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail)}

            self.ipv6_multi_hop_session_detail = YList(self)
            self._segment_path = lambda: "ipv6-multi-hop-session-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails, [], name, value)


        class Ipv6MultiHopSessionDetail(Entity):
            """
            Detailed information for a single IPv6 multihop
            BFD session
            
            .. attribute:: association_information
            
            	Association session information
            	**type**\: list of    :py:class:`AssociationInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: lsp_ping_info
            
            	LSP Ping Info
            	**type**\:   :py:class:`LspPingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo>`
            
            .. attribute:: mp_download_state
            
            	MP Dowload State
            	**type**\:   :py:class:`MpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState>`
            
            .. attribute:: owner_information
            
            	Client applications owning the session
            	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.OwnerInformation>`
            
            .. attribute:: source_address
            
            	Source Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: status_information
            
            	Session status information
            	**type**\:   :py:class:`StatusInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation>`
            
            .. attribute:: vrf_name
            
            	VRF name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail, self).__init__()

                self.yang_name = "ipv6-multi-hop-session-detail"
                self.yang_parent_name = "ipv6-multi-hop-session-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"lsp-ping-info" : ("lsp_ping_info", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo), "mp-download-state" : ("mp_download_state", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState), "status-information" : ("status_information", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation)}
                self._child_list_classes = {"association-information" : ("association_information", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation), "owner-information" : ("owner_information", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.OwnerInformation)}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.location = YLeaf(YType.str, "location")

                self.source_address = YLeaf(YType.str, "source-address")

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.lsp_ping_info = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo()
                self.lsp_ping_info.parent = self
                self._children_name_map["lsp_ping_info"] = "lsp-ping-info"
                self._children_yang_names.add("lsp-ping-info")

                self.mp_download_state = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState()
                self.mp_download_state.parent = self
                self._children_name_map["mp_download_state"] = "mp-download-state"
                self._children_yang_names.add("mp-download-state")

                self.status_information = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation()
                self.status_information.parent = self
                self._children_name_map["status_information"] = "status-information"
                self._children_yang_names.add("status-information")

                self.association_information = YList(self)
                self.owner_information = YList(self)
                self._segment_path = lambda: "ipv6-multi-hop-session-detail"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail, ['destination_address', 'location', 'source_address', 'vrf_name'], name, value)


            class AssociationInformation(Entity):
                """
                Association session information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: ip_destination_address
                
                	IPv4/v6 dest address
                	**type**\:   :py:class:`IpDestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation.IpDestinationAddress>`
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: owner_information
                
                	Client applications owning the session
                	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation.OwnerInformation>`
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation, self).__init__()

                    self.yang_name = "association-information"
                    self.yang_parent_name = "ipv6-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"ip-destination-address" : ("ip_destination_address", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation.IpDestinationAddress)}
                    self._child_list_classes = {"owner-information" : ("owner_information", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation.OwnerInformation)}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.ip_destination_address = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation.IpDestinationAddress()
                    self.ip_destination_address.parent = self
                    self._children_name_map["ip_destination_address"] = "ip-destination-address"
                    self._children_yang_names.add("ip-destination-address")

                    self.owner_information = YList(self)
                    self._segment_path = lambda: "association-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation, ['interface_name', 'local_discriminator', 'sessiontype'], name, value)


                class IpDestinationAddress(Entity):
                    """
                    IPv4/v6 dest address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation.IpDestinationAddress, self).__init__()

                        self.yang_name = "ip-destination-address"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "ip-destination-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation.IpDestinationAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class OwnerInformation(Entity):
                    """
                    Client applications owning the session
                    
                    .. attribute:: adjusted_detection_multiplier
                    
                    	Adjusted detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: adjusted_interval
                    
                    	Adjusted minimum transmit interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Client specified detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interval
                    
                    	Client specified minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: name
                    
                    	Client process name
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation.OwnerInformation, self).__init__()

                        self.yang_name = "owner-information"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                        self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "owner-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.AssociationInformation.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class LspPingInfo(Entity):
                """
                LSP Ping Info
                
                .. attribute:: lsp_ping_rx_count
                
                	LSP Ping numer of times received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_code
                
                	LSP Ping Rx Last Code
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_discr
                
                	LSP Ping Rx last received discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_output
                
                	LSP Ping Rx Last Output
                	**type**\:  str
                
                .. attribute:: lsp_ping_rx_last_subcode
                
                	LSP Ping Rx Last Subcode
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_time
                
                	LSP Ping last received time
                	**type**\:   :py:class:`LspPingRxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime>`
                
                .. attribute:: lsp_ping_tx_count
                
                	LSP Ping Tx count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_error_count
                
                	LSP Ping Tx error count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_last_error_rc
                
                	LSP Ping Tx last error
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_error_time
                
                	LSP Ping last error time
                	**type**\:   :py:class:`LspPingTxLastErrorTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime>`
                
                .. attribute:: lsp_ping_tx_last_rc
                
                	LSP Ping Tx last result
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_time
                
                	LSP Ping last sent time
                	**type**\:   :py:class:`LspPingTxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo, self).__init__()

                    self.yang_name = "lsp-ping-info"
                    self.yang_parent_name = "ipv6-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"lsp-ping-rx-last-time" : ("lsp_ping_rx_last_time", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime), "lsp-ping-tx-last-error-time" : ("lsp_ping_tx_last_error_time", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime), "lsp-ping-tx-last-time" : ("lsp_ping_tx_last_time", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime)}
                    self._child_list_classes = {}

                    self.lsp_ping_rx_count = YLeaf(YType.uint32, "lsp-ping-rx-count")

                    self.lsp_ping_rx_last_code = YLeaf(YType.uint8, "lsp-ping-rx-last-code")

                    self.lsp_ping_rx_last_discr = YLeaf(YType.uint32, "lsp-ping-rx-last-discr")

                    self.lsp_ping_rx_last_output = YLeaf(YType.str, "lsp-ping-rx-last-output")

                    self.lsp_ping_rx_last_subcode = YLeaf(YType.uint8, "lsp-ping-rx-last-subcode")

                    self.lsp_ping_tx_count = YLeaf(YType.uint32, "lsp-ping-tx-count")

                    self.lsp_ping_tx_error_count = YLeaf(YType.uint32, "lsp-ping-tx-error-count")

                    self.lsp_ping_tx_last_error_rc = YLeaf(YType.str, "lsp-ping-tx-last-error-rc")

                    self.lsp_ping_tx_last_rc = YLeaf(YType.str, "lsp-ping-tx-last-rc")

                    self.lsp_ping_rx_last_time = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime()
                    self.lsp_ping_rx_last_time.parent = self
                    self._children_name_map["lsp_ping_rx_last_time"] = "lsp-ping-rx-last-time"
                    self._children_yang_names.add("lsp-ping-rx-last-time")

                    self.lsp_ping_tx_last_error_time = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime()
                    self.lsp_ping_tx_last_error_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_error_time"] = "lsp-ping-tx-last-error-time"
                    self._children_yang_names.add("lsp-ping-tx-last-error-time")

                    self.lsp_ping_tx_last_time = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime()
                    self.lsp_ping_tx_last_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_time"] = "lsp-ping-tx-last-time"
                    self._children_yang_names.add("lsp-ping-tx-last-time")
                    self._segment_path = lambda: "lsp-ping-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo, ['lsp_ping_rx_count', 'lsp_ping_rx_last_code', 'lsp_ping_rx_last_discr', 'lsp_ping_rx_last_output', 'lsp_ping_rx_last_subcode', 'lsp_ping_tx_count', 'lsp_ping_tx_error_count', 'lsp_ping_tx_last_error_rc', 'lsp_ping_tx_last_rc'], name, value)


                class LspPingRxLastTime(Entity):
                    """
                    LSP Ping last received time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-rx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-rx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingRxLastTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastErrorTime(Entity):
                    """
                    LSP Ping last error time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-error-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-error-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastTime(Entity):
                    """
                    LSP Ping last sent time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.LspPingInfo.LspPingTxLastTime, ['nanoseconds', 'seconds'], name, value)


            class MpDownloadState(Entity):
                """
                MP Dowload State
                
                .. attribute:: change_time
                
                	Change time
                	**type**\:   :py:class:`ChangeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState.ChangeTime>`
                
                .. attribute:: mp_download_state
                
                	MP Download State
                	**type**\:   :py:class:`BfdMpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMpDownloadState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState, self).__init__()

                    self.yang_name = "mp-download-state"
                    self.yang_parent_name = "ipv6-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"change-time" : ("change_time", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState.ChangeTime)}
                    self._child_list_classes = {}

                    self.mp_download_state = YLeaf(YType.enumeration, "mp-download-state")

                    self.change_time = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState.ChangeTime()
                    self.change_time.parent = self
                    self._children_name_map["change_time"] = "change-time"
                    self._children_yang_names.add("change-time")
                    self._segment_path = lambda: "mp-download-state"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState, ['mp_download_state'], name, value)


                class ChangeTime(Entity):
                    """
                    Change time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState.ChangeTime, self).__init__()

                        self.yang_name = "change-time"
                        self.yang_parent_name = "mp-download-state"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "change-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/mp-download-state/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.MpDownloadState.ChangeTime, ['nanoseconds', 'seconds'], name, value)


            class OwnerInformation(Entity):
                """
                Client applications owning the session
                
                .. attribute:: adjusted_detection_multiplier
                
                	Adjusted detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adjusted_interval
                
                	Adjusted minimum transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: detection_multiplier
                
                	Client specified detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interval
                
                	Client specified minimum transmit interval in micro\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: name
                
                	Client process name
                	**type**\:  str
                
                	**length:** 0..257
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.OwnerInformation, self).__init__()

                    self.yang_name = "owner-information"
                    self.yang_parent_name = "ipv6-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                    self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.interval = YLeaf(YType.uint32, "interval")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "owner-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class StatusInformation(Entity):
                """
                Session status information
                
                .. attribute:: async_receive_statistics
                
                	Statistics of Interval between Async Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`AsyncReceiveStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics>`
                
                .. attribute:: async_transmit_statistics
                
                	Statistics of Interval between Async Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`AsyncTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics>`
                
                .. attribute:: desired_minimum_echo_transmit_interval
                
                	Desired minimum echo transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: echo_received_statistics
                
                	Statistics of Interval between Echo Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`EchoReceivedStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics>`
                
                .. attribute:: echo_transmit_statistics
                
                	Statistics of Interval between Echo Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`EchoTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics>`
                
                .. attribute:: internal_label
                
                	Internal Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_state_change
                
                	Time since last state change
                	**type**\:   :py:class:`LastStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.LastStateChange>`
                
                .. attribute:: latency_average
                
                	Average value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_maximum
                
                	Maximum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_minimum
                
                	Minimum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_number
                
                	Number of Latency Samples. Time between Transmit and Receive
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: node_id
                
                	Location where session is housed
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: receive_packet
                
                	Receive Packet
                	**type**\:   :py:class:`ReceivePacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.ReceivePacket>`
                
                .. attribute:: remote_discriminator
                
                	Session's Remote discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_negotiated_interval
                
                	Remote Negotiated Interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: session_subtype
                
                	Session subtype
                	**type**\:  str
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                .. attribute:: source_address
                
                	Source address
                	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.SourceAddress>`
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                .. attribute:: status_brief_information
                
                	Brief Status Information
                	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation>`
                
                .. attribute:: to_up_state_count
                
                	Number of times session state went to UP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmit_packet
                
                	Transmit Packet
                	**type**\:   :py:class:`TransmitPacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.TransmitPacket>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation, self).__init__()

                    self.yang_name = "status-information"
                    self.yang_parent_name = "ipv6-multi-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-receive-statistics" : ("async_receive_statistics", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics), "async-transmit-statistics" : ("async_transmit_statistics", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics), "echo-received-statistics" : ("echo_received_statistics", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics), "echo-transmit-statistics" : ("echo_transmit_statistics", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics), "last-state-change" : ("last_state_change", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.LastStateChange), "receive-packet" : ("receive_packet", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.ReceivePacket), "source-address" : ("source_address", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.SourceAddress), "status-brief-information" : ("status_brief_information", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation), "transmit-packet" : ("transmit_packet", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.TransmitPacket)}
                    self._child_list_classes = {}

                    self.desired_minimum_echo_transmit_interval = YLeaf(YType.uint32, "desired-minimum-echo-transmit-interval")

                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                    self.latency_average = YLeaf(YType.uint32, "latency-average")

                    self.latency_maximum = YLeaf(YType.uint32, "latency-maximum")

                    self.latency_minimum = YLeaf(YType.uint32, "latency-minimum")

                    self.latency_number = YLeaf(YType.uint32, "latency-number")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.remote_discriminator = YLeaf(YType.uint32, "remote-discriminator")

                    self.remote_negotiated_interval = YLeaf(YType.uint32, "remote-negotiated-interval")

                    self.session_subtype = YLeaf(YType.str, "session-subtype")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.to_up_state_count = YLeaf(YType.uint32, "to-up-state-count")

                    self.async_receive_statistics = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics()
                    self.async_receive_statistics.parent = self
                    self._children_name_map["async_receive_statistics"] = "async-receive-statistics"
                    self._children_yang_names.add("async-receive-statistics")

                    self.async_transmit_statistics = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics()
                    self.async_transmit_statistics.parent = self
                    self._children_name_map["async_transmit_statistics"] = "async-transmit-statistics"
                    self._children_yang_names.add("async-transmit-statistics")

                    self.echo_received_statistics = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics()
                    self.echo_received_statistics.parent = self
                    self._children_name_map["echo_received_statistics"] = "echo-received-statistics"
                    self._children_yang_names.add("echo-received-statistics")

                    self.echo_transmit_statistics = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics()
                    self.echo_transmit_statistics.parent = self
                    self._children_name_map["echo_transmit_statistics"] = "echo-transmit-statistics"
                    self._children_yang_names.add("echo-transmit-statistics")

                    self.last_state_change = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.LastStateChange()
                    self.last_state_change.parent = self
                    self._children_name_map["last_state_change"] = "last-state-change"
                    self._children_yang_names.add("last-state-change")

                    self.receive_packet = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.ReceivePacket()
                    self.receive_packet.parent = self
                    self._children_name_map["receive_packet"] = "receive-packet"
                    self._children_yang_names.add("receive-packet")

                    self.source_address = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.SourceAddress()
                    self.source_address.parent = self
                    self._children_name_map["source_address"] = "source-address"
                    self._children_yang_names.add("source-address")

                    self.status_brief_information = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation()
                    self.status_brief_information.parent = self
                    self._children_name_map["status_brief_information"] = "status-brief-information"
                    self._children_yang_names.add("status-brief-information")

                    self.transmit_packet = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.TransmitPacket()
                    self.transmit_packet.parent = self
                    self._children_name_map["transmit_packet"] = "transmit-packet"
                    self._children_yang_names.add("transmit-packet")
                    self._segment_path = lambda: "status-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation, ['desired_minimum_echo_transmit_interval', 'internal_label', 'latency_average', 'latency_maximum', 'latency_minimum', 'latency_number', 'local_discriminator', 'node_id', 'remote_discriminator', 'remote_negotiated_interval', 'session_subtype', 'sessiontype', 'state', 'to_up_state_count'], name, value)


                class AsyncReceiveStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics, self).__init__()

                        self.yang_name = "async-receive-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-receive-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncReceiveStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class AsyncTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics, self).__init__()

                        self.yang_name = "async-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.AsyncTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoReceivedStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics, self).__init__()

                        self.yang_name = "echo-received-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-received-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoReceivedStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics, self).__init__()

                        self.yang_name = "echo-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.EchoTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class LastStateChange(Entity):
                    """
                    Time since last state change
                    
                    .. attribute:: days
                    
                    	Number of days since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: day
                    
                    .. attribute:: hours
                    
                    	Number of hours since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: hour
                    
                    .. attribute:: minutes
                    
                    	Number of mins since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: minute
                    
                    .. attribute:: seconds
                    
                    	Number of seconds since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.LastStateChange, self).__init__()

                        self.yang_name = "last-state-change"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.days = YLeaf(YType.uint32, "days")

                        self.hours = YLeaf(YType.uint8, "hours")

                        self.minutes = YLeaf(YType.uint8, "minutes")

                        self.seconds = YLeaf(YType.uint8, "seconds")
                        self._segment_path = lambda: "last-state-change"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.LastStateChange, ['days', 'hours', 'minutes', 'seconds'], name, value)


                class ReceivePacket(Entity):
                    """
                    Receive Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.ReceivePacket, self).__init__()

                        self.yang_name = "receive-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "receive-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.ReceivePacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


                class SourceAddress(Entity):
                    """
                    Source address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.SourceAddress, self).__init__()

                        self.yang_name = "source-address"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "source-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.SourceAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class StatusBriefInformation(Entity):
                    """
                    Brief Status Information
                    
                    .. attribute:: async_interval_multiplier
                    
                    	Async Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier>`
                    
                    .. attribute:: echo_interval_multiplier
                    
                    	Echo Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier>`
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation, self).__init__()

                        self.yang_name = "status-brief-information"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier)}
                        self._child_list_classes = {}

                        self.async_interval_multiplier = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier()
                        self.async_interval_multiplier.parent = self
                        self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                        self._children_yang_names.add("async-interval-multiplier")

                        self.echo_interval_multiplier = Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier()
                        self.echo_interval_multiplier.parent = self
                        self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                        self._children_yang_names.add("echo-interval-multiplier")
                        self._segment_path = lambda: "status-brief-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/%s" % self._segment_path()


                    class AsyncIntervalMultiplier(Entity):
                        """
                        Async Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_local_transmit_interval
                        
                        	Negotiated local transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_remote_transmit_interval
                        
                        	Negotiated remote transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                            self.yang_name = "async-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                            self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                            self._segment_path = lambda: "async-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                    class EchoIntervalMultiplier(Entity):
                        """
                        Echo Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_transmit_interval
                        
                        	Negotiated transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                            self.yang_name = "echo-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                            self._segment_path = lambda: "echo-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


                class TransmitPacket(Entity):
                    """
                    Transmit Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.TransmitPacket, self).__init__()

                        self.yang_name = "transmit-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "transmit-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-session-details/ipv6-multi-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6MultiHopSessionDetails.Ipv6MultiHopSessionDetail.StatusInformation.TransmitPacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


    class Ipv6MultiHopSummary(Entity):
        """
        Summary information of BFD IPv6 multihop
        sessions
        
        .. attribute:: session_state
        
        	Statistics of states for sessions
        	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6MultiHopSummary.SessionState>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6MultiHopSummary, self).__init__()

            self.yang_name = "ipv6-multi-hop-summary"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv6MultiHopSummary.SessionState)}
            self._child_list_classes = {}

            self.session_state = Bfd.Ipv6MultiHopSummary.SessionState()
            self.session_state.parent = self
            self._children_name_map["session_state"] = "session-state"
            self._children_yang_names.add("session-state")
            self._segment_path = lambda: "ipv6-multi-hop-summary"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class SessionState(Entity):
            """
            Statistics of states for sessions
            
            .. attribute:: down_count
            
            	Number of sessions in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_count
            
            	Number of sessions in database
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_count
            
            	Number of sessions in unknown state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of sessions in up state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6MultiHopSummary.SessionState, self).__init__()

                self.yang_name = "session-state"
                self.yang_parent_name = "ipv6-multi-hop-summary"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.down_count = YLeaf(YType.uint32, "down-count")

                self.total_count = YLeaf(YType.uint32, "total-count")

                self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                self.up_count = YLeaf(YType.uint32, "up-count")
                self._segment_path = lambda: "session-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-multi-hop-summary/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6MultiHopSummary.SessionState, ['down_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv6SingleHopCounters(Entity):
        """
        IPv6 single hop Counters
        
        .. attribute:: ipv6_single_hop_packet_counters
        
        	Table of IPv6 single hop Packet counters
        	**type**\:   :py:class:`Ipv6SingleHopPacketCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopCounters.Ipv6SingleHopPacketCounters>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6SingleHopCounters, self).__init__()

            self.yang_name = "ipv6-single-hop-counters"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"ipv6-single-hop-packet-counters" : ("ipv6_single_hop_packet_counters", Bfd.Ipv6SingleHopCounters.Ipv6SingleHopPacketCounters)}
            self._child_list_classes = {}

            self.ipv6_single_hop_packet_counters = Bfd.Ipv6SingleHopCounters.Ipv6SingleHopPacketCounters()
            self.ipv6_single_hop_packet_counters.parent = self
            self._children_name_map["ipv6_single_hop_packet_counters"] = "ipv6-single-hop-packet-counters"
            self._children_yang_names.add("ipv6-single-hop-packet-counters")
            self._segment_path = lambda: "ipv6-single-hop-counters"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class Ipv6SingleHopPacketCounters(Entity):
            """
            Table of IPv6 single hop Packet counters
            
            .. attribute:: ipv6_single_hop_packet_counter
            
            	Interface IPv6 single hop Packet counters
            	**type**\: list of    :py:class:`Ipv6SingleHopPacketCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopCounters.Ipv6SingleHopPacketCounters.Ipv6SingleHopPacketCounter>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6SingleHopCounters.Ipv6SingleHopPacketCounters, self).__init__()

                self.yang_name = "ipv6-single-hop-packet-counters"
                self.yang_parent_name = "ipv6-single-hop-counters"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"ipv6-single-hop-packet-counter" : ("ipv6_single_hop_packet_counter", Bfd.Ipv6SingleHopCounters.Ipv6SingleHopPacketCounters.Ipv6SingleHopPacketCounter)}

                self.ipv6_single_hop_packet_counter = YList(self)
                self._segment_path = lambda: "ipv6-single-hop-packet-counters"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-counters/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6SingleHopCounters.Ipv6SingleHopPacketCounters, [], name, value)


            class Ipv6SingleHopPacketCounter(Entity):
                """
                Interface IPv6 single hop Packet counters
                
                .. attribute:: interface_name  <key>
                
                	Interface Name
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: display_type
                
                	Packet Display Type
                	**type**\:   :py:class:`BfdMgmtPktDisplay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtPktDisplay>`
                
                .. attribute:: echo_receive_count
                
                	Number of echo packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: echo_transmit_count
                
                	Number of echo packets transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_receive_count
                
                	Number of Hellos received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_transmit_count
                
                	Number of Hellos transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6SingleHopCounters.Ipv6SingleHopPacketCounters.Ipv6SingleHopPacketCounter, self).__init__()

                    self.yang_name = "ipv6-single-hop-packet-counter"
                    self.yang_parent_name = "ipv6-single-hop-packet-counters"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.display_type = YLeaf(YType.enumeration, "display-type")

                    self.echo_receive_count = YLeaf(YType.uint32, "echo-receive-count")

                    self.echo_transmit_count = YLeaf(YType.uint32, "echo-transmit-count")

                    self.hello_receive_count = YLeaf(YType.uint32, "hello-receive-count")

                    self.hello_transmit_count = YLeaf(YType.uint32, "hello-transmit-count")
                    self._segment_path = lambda: "ipv6-single-hop-packet-counter" + "[interface-name='" + self.interface_name.get() + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-counters/ipv6-single-hop-packet-counters/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6SingleHopCounters.Ipv6SingleHopPacketCounters.Ipv6SingleHopPacketCounter, ['interface_name', 'display_type', 'echo_receive_count', 'echo_transmit_count', 'hello_receive_count', 'hello_transmit_count'], name, value)


    class Ipv6SingleHopLocationSummaries(Entity):
        """
        Table of summary information about BFD IPv6
        singlehop sessions per location
        
        .. attribute:: ipv6_single_hop_location_summary
        
        	Summary information for BFD IPv6 singlehop sessions for location
        	**type**\: list of    :py:class:`Ipv6SingleHopLocationSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopLocationSummaries.Ipv6SingleHopLocationSummary>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6SingleHopLocationSummaries, self).__init__()

            self.yang_name = "ipv6-single-hop-location-summaries"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv6-single-hop-location-summary" : ("ipv6_single_hop_location_summary", Bfd.Ipv6SingleHopLocationSummaries.Ipv6SingleHopLocationSummary)}

            self.ipv6_single_hop_location_summary = YList(self)
            self._segment_path = lambda: "ipv6-single-hop-location-summaries"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv6SingleHopLocationSummaries, [], name, value)


        class Ipv6SingleHopLocationSummary(Entity):
            """
            Summary information for BFD IPv6 singlehop
            sessions for location
            
            .. attribute:: location_name  <key>
            
            	Location Name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: session_state
            
            	Statistics of states for sessions
            	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopLocationSummaries.Ipv6SingleHopLocationSummary.SessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6SingleHopLocationSummaries.Ipv6SingleHopLocationSummary, self).__init__()

                self.yang_name = "ipv6-single-hop-location-summary"
                self.yang_parent_name = "ipv6-single-hop-location-summaries"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv6SingleHopLocationSummaries.Ipv6SingleHopLocationSummary.SessionState)}
                self._child_list_classes = {}

                self.location_name = YLeaf(YType.str, "location-name")

                self.session_state = Bfd.Ipv6SingleHopLocationSummaries.Ipv6SingleHopLocationSummary.SessionState()
                self.session_state.parent = self
                self._children_name_map["session_state"] = "session-state"
                self._children_yang_names.add("session-state")
                self._segment_path = lambda: "ipv6-single-hop-location-summary" + "[location-name='" + self.location_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-location-summaries/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6SingleHopLocationSummaries.Ipv6SingleHopLocationSummary, ['location_name'], name, value)


            class SessionState(Entity):
                """
                Statistics of states for sessions
                
                .. attribute:: down_count
                
                	Number of sessions in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retry_count
                
                	Number of sessions in retry state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_count
                
                	Number of sessions in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_count
                
                	Number of sessions in database
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_count
                
                	Number of sessions in unknown state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of sessions in up state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6SingleHopLocationSummaries.Ipv6SingleHopLocationSummary.SessionState, self).__init__()

                    self.yang_name = "session-state"
                    self.yang_parent_name = "ipv6-single-hop-location-summary"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.down_count = YLeaf(YType.uint32, "down-count")

                    self.retry_count = YLeaf(YType.uint32, "retry-count")

                    self.standby_count = YLeaf(YType.uint32, "standby-count")

                    self.total_count = YLeaf(YType.uint32, "total-count")

                    self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                    self.up_count = YLeaf(YType.uint32, "up-count")
                    self._segment_path = lambda: "session-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6SingleHopLocationSummaries.Ipv6SingleHopLocationSummary.SessionState, ['down_count', 'retry_count', 'standby_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv6SingleHopMultiPaths(Entity):
        """
        IPv6 single hop multipath
        
        .. attribute:: ipv6_single_hop_multi_path
        
        	IPv6 single hop multipath table
        	**type**\: list of    :py:class:`Ipv6SingleHopMultiPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopMultiPaths.Ipv6SingleHopMultiPath>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6SingleHopMultiPaths, self).__init__()

            self.yang_name = "ipv6-single-hop-multi-paths"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv6-single-hop-multi-path" : ("ipv6_single_hop_multi_path", Bfd.Ipv6SingleHopMultiPaths.Ipv6SingleHopMultiPath)}

            self.ipv6_single_hop_multi_path = YList(self)
            self._segment_path = lambda: "ipv6-single-hop-multi-paths"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv6SingleHopMultiPaths, [], name, value)


        class Ipv6SingleHopMultiPath(Entity):
            """
            IPv6 single hop multipath table
            
            .. attribute:: destination_address
            
            	Destination address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: incoming_label_xr
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interface_name
            
            	Interface name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: local_discriminator
            
            	Session's Local discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_interface_name
            
            	Interface name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6SingleHopMultiPaths.Ipv6SingleHopMultiPath, self).__init__()

                self.yang_name = "ipv6-single-hop-multi-path"
                self.yang_parent_name = "ipv6-single-hop-multi-paths"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.incoming_label_xr = YLeaf(YType.uint32, "incoming-label-xr")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_interface_name = YLeaf(YType.str, "session-interface-name")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.state = YLeaf(YType.enumeration, "state")
                self._segment_path = lambda: "ipv6-single-hop-multi-path"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-multi-paths/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6SingleHopMultiPaths.Ipv6SingleHopMultiPath, ['destination_address', 'incoming_label_xr', 'interface_name', 'local_discriminator', 'location', 'node_id', 'session_interface_name', 'session_subtype', 'state'], name, value)


    class Ipv6SingleHopNodeLocationSummaries(Entity):
        """
        Table of summary information about BFD IPv6
        singlehop sessions per location
        
        .. attribute:: ipv6_single_hop_node_location_summary
        
        	Summary information for BFD IPv6 singlehop sessions for location
        	**type**\: list of    :py:class:`Ipv6SingleHopNodeLocationSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopNodeLocationSummaries.Ipv6SingleHopNodeLocationSummary>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6SingleHopNodeLocationSummaries, self).__init__()

            self.yang_name = "ipv6-single-hop-node-location-summaries"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv6-single-hop-node-location-summary" : ("ipv6_single_hop_node_location_summary", Bfd.Ipv6SingleHopNodeLocationSummaries.Ipv6SingleHopNodeLocationSummary)}

            self.ipv6_single_hop_node_location_summary = YList(self)
            self._segment_path = lambda: "ipv6-single-hop-node-location-summaries"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv6SingleHopNodeLocationSummaries, [], name, value)


        class Ipv6SingleHopNodeLocationSummary(Entity):
            """
            Summary information for BFD IPv6 singlehop
            sessions for location
            
            .. attribute:: location  <key>
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_state
            
            	Statistics of states for sessions
            	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopNodeLocationSummaries.Ipv6SingleHopNodeLocationSummary.SessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6SingleHopNodeLocationSummaries.Ipv6SingleHopNodeLocationSummary, self).__init__()

                self.yang_name = "ipv6-single-hop-node-location-summary"
                self.yang_parent_name = "ipv6-single-hop-node-location-summaries"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv6SingleHopNodeLocationSummaries.Ipv6SingleHopNodeLocationSummary.SessionState)}
                self._child_list_classes = {}

                self.location = YLeaf(YType.str, "location")

                self.session_state = Bfd.Ipv6SingleHopNodeLocationSummaries.Ipv6SingleHopNodeLocationSummary.SessionState()
                self.session_state.parent = self
                self._children_name_map["session_state"] = "session-state"
                self._children_yang_names.add("session-state")
                self._segment_path = lambda: "ipv6-single-hop-node-location-summary" + "[location='" + self.location.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-node-location-summaries/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6SingleHopNodeLocationSummaries.Ipv6SingleHopNodeLocationSummary, ['location'], name, value)


            class SessionState(Entity):
                """
                Statistics of states for sessions
                
                .. attribute:: down_count
                
                	Number of sessions in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retry_count
                
                	Number of sessions in retry state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_count
                
                	Number of sessions in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_count
                
                	Number of sessions in database
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_count
                
                	Number of sessions in unknown state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of sessions in up state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6SingleHopNodeLocationSummaries.Ipv6SingleHopNodeLocationSummary.SessionState, self).__init__()

                    self.yang_name = "session-state"
                    self.yang_parent_name = "ipv6-single-hop-node-location-summary"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.down_count = YLeaf(YType.uint32, "down-count")

                    self.retry_count = YLeaf(YType.uint32, "retry-count")

                    self.standby_count = YLeaf(YType.uint32, "standby-count")

                    self.total_count = YLeaf(YType.uint32, "total-count")

                    self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                    self.up_count = YLeaf(YType.uint32, "up-count")
                    self._segment_path = lambda: "session-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6SingleHopNodeLocationSummaries.Ipv6SingleHopNodeLocationSummary.SessionState, ['down_count', 'retry_count', 'standby_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class Ipv6SingleHopSessionBriefs(Entity):
        """
        Table of brief information about all IPv6
        singlehop BFD sessions in the System
        
        .. attribute:: ipv6_single_hop_session_brief
        
        	Brief information for a single IPv6 singlehop BFD session
        	**type**\: list of    :py:class:`Ipv6SingleHopSessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6SingleHopSessionBriefs, self).__init__()

            self.yang_name = "ipv6-single-hop-session-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv6-single-hop-session-brief" : ("ipv6_single_hop_session_brief", Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief)}

            self.ipv6_single_hop_session_brief = YList(self)
            self._segment_path = lambda: "ipv6-single-hop-session-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv6SingleHopSessionBriefs, [], name, value)


        class Ipv6SingleHopSessionBrief(Entity):
            """
            Brief information for a single IPv6 singlehop
            BFD session
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_flags
            
            	Session Flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: session_type
            
            	Session type
            	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: status_brief_information
            
            	Brief Status Information
            	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief, self).__init__()

                self.yang_name = "ipv6-single-hop-session-brief"
                self.yang_parent_name = "ipv6-single-hop-session-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"status-brief-information" : ("status_brief_information", Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation)}
                self._child_list_classes = {}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_flags = YLeaf(YType.uint32, "session-flags")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.state = YLeaf(YType.enumeration, "state")

                self.status_brief_information = Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation()
                self.status_brief_information.parent = self
                self._children_name_map["status_brief_information"] = "status-brief-information"
                self._children_yang_names.add("status-brief-information")
                self._segment_path = lambda: "ipv6-single-hop-session-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief, ['destination_address', 'interface_name', 'location', 'node_id', 'session_flags', 'session_subtype', 'session_type', 'state'], name, value)


            class StatusBriefInformation(Entity):
                """
                Brief Status Information
                
                .. attribute:: async_interval_multiplier
                
                	Async Interval and Detect Multiplier Information
                	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier>`
                
                .. attribute:: echo_interval_multiplier
                
                	Echo Interval and Detect Multiplier Information
                	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation, self).__init__()

                    self.yang_name = "status-brief-information"
                    self.yang_parent_name = "ipv6-single-hop-session-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier)}
                    self._child_list_classes = {}

                    self.async_interval_multiplier = Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier()
                    self.async_interval_multiplier.parent = self
                    self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                    self._children_yang_names.add("async-interval-multiplier")

                    self.echo_interval_multiplier = Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier()
                    self.echo_interval_multiplier.parent = self
                    self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                    self._children_yang_names.add("echo-interval-multiplier")
                    self._segment_path = lambda: "status-brief-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-briefs/ipv6-single-hop-session-brief/%s" % self._segment_path()


                class AsyncIntervalMultiplier(Entity):
                    """
                    Async Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_local_transmit_interval
                    
                    	Negotiated local transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_remote_transmit_interval
                    
                    	Negotiated remote transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                        self.yang_name = "async-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                        self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                        self._segment_path = lambda: "async-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-briefs/ipv6-single-hop-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                class EchoIntervalMultiplier(Entity):
                    """
                    Echo Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_transmit_interval
                    
                    	Negotiated transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                        self.yang_name = "echo-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                        self._segment_path = lambda: "echo-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-briefs/ipv6-single-hop-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionBriefs.Ipv6SingleHopSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


    class Ipv6SingleHopSessionDetails(Entity):
        """
        Table of detailed information about all IPv6
        singlehop BFD sessions in the System 
        
        .. attribute:: ipv6_single_hop_session_detail
        
        	Detailed information for a single IPv6 singlehop BFD session
        	**type**\: list of    :py:class:`Ipv6SingleHopSessionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6SingleHopSessionDetails, self).__init__()

            self.yang_name = "ipv6-single-hop-session-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"ipv6-single-hop-session-detail" : ("ipv6_single_hop_session_detail", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail)}

            self.ipv6_single_hop_session_detail = YList(self)
            self._segment_path = lambda: "ipv6-single-hop-session-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails, [], name, value)


        class Ipv6SingleHopSessionDetail(Entity):
            """
            Detailed information for a single IPv6
            singlehop BFD session
            
            .. attribute:: association_information
            
            	Association session information
            	**type**\: list of    :py:class:`AssociationInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: lsp_ping_info
            
            	LSP Ping Info
            	**type**\:   :py:class:`LspPingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo>`
            
            .. attribute:: mp_download_state
            
            	MP Dowload State
            	**type**\:   :py:class:`MpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState>`
            
            .. attribute:: owner_information
            
            	Client applications owning the session
            	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.OwnerInformation>`
            
            .. attribute:: status_information
            
            	Session status information
            	**type**\:   :py:class:`StatusInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail, self).__init__()

                self.yang_name = "ipv6-single-hop-session-detail"
                self.yang_parent_name = "ipv6-single-hop-session-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"lsp-ping-info" : ("lsp_ping_info", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo), "mp-download-state" : ("mp_download_state", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState), "status-information" : ("status_information", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation)}
                self._child_list_classes = {"association-information" : ("association_information", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation), "owner-information" : ("owner_information", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.OwnerInformation)}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.lsp_ping_info = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo()
                self.lsp_ping_info.parent = self
                self._children_name_map["lsp_ping_info"] = "lsp-ping-info"
                self._children_yang_names.add("lsp-ping-info")

                self.mp_download_state = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState()
                self.mp_download_state.parent = self
                self._children_name_map["mp_download_state"] = "mp-download-state"
                self._children_yang_names.add("mp-download-state")

                self.status_information = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation()
                self.status_information.parent = self
                self._children_name_map["status_information"] = "status-information"
                self._children_yang_names.add("status-information")

                self.association_information = YList(self)
                self.owner_information = YList(self)
                self._segment_path = lambda: "ipv6-single-hop-session-detail"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail, ['destination_address', 'interface_name', 'location'], name, value)


            class AssociationInformation(Entity):
                """
                Association session information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: ip_destination_address
                
                	IPv4/v6 dest address
                	**type**\:   :py:class:`IpDestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation.IpDestinationAddress>`
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: owner_information
                
                	Client applications owning the session
                	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation.OwnerInformation>`
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation, self).__init__()

                    self.yang_name = "association-information"
                    self.yang_parent_name = "ipv6-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"ip-destination-address" : ("ip_destination_address", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation.IpDestinationAddress)}
                    self._child_list_classes = {"owner-information" : ("owner_information", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation.OwnerInformation)}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.ip_destination_address = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation.IpDestinationAddress()
                    self.ip_destination_address.parent = self
                    self._children_name_map["ip_destination_address"] = "ip-destination-address"
                    self._children_yang_names.add("ip-destination-address")

                    self.owner_information = YList(self)
                    self._segment_path = lambda: "association-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation, ['interface_name', 'local_discriminator', 'sessiontype'], name, value)


                class IpDestinationAddress(Entity):
                    """
                    IPv4/v6 dest address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation.IpDestinationAddress, self).__init__()

                        self.yang_name = "ip-destination-address"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "ip-destination-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation.IpDestinationAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class OwnerInformation(Entity):
                    """
                    Client applications owning the session
                    
                    .. attribute:: adjusted_detection_multiplier
                    
                    	Adjusted detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: adjusted_interval
                    
                    	Adjusted minimum transmit interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Client specified detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interval
                    
                    	Client specified minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: name
                    
                    	Client process name
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation.OwnerInformation, self).__init__()

                        self.yang_name = "owner-information"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                        self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "owner-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.AssociationInformation.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class LspPingInfo(Entity):
                """
                LSP Ping Info
                
                .. attribute:: lsp_ping_rx_count
                
                	LSP Ping numer of times received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_code
                
                	LSP Ping Rx Last Code
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_discr
                
                	LSP Ping Rx last received discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_output
                
                	LSP Ping Rx Last Output
                	**type**\:  str
                
                .. attribute:: lsp_ping_rx_last_subcode
                
                	LSP Ping Rx Last Subcode
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_time
                
                	LSP Ping last received time
                	**type**\:   :py:class:`LspPingRxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime>`
                
                .. attribute:: lsp_ping_tx_count
                
                	LSP Ping Tx count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_error_count
                
                	LSP Ping Tx error count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_last_error_rc
                
                	LSP Ping Tx last error
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_error_time
                
                	LSP Ping last error time
                	**type**\:   :py:class:`LspPingTxLastErrorTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime>`
                
                .. attribute:: lsp_ping_tx_last_rc
                
                	LSP Ping Tx last result
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_time
                
                	LSP Ping last sent time
                	**type**\:   :py:class:`LspPingTxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo, self).__init__()

                    self.yang_name = "lsp-ping-info"
                    self.yang_parent_name = "ipv6-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"lsp-ping-rx-last-time" : ("lsp_ping_rx_last_time", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime), "lsp-ping-tx-last-error-time" : ("lsp_ping_tx_last_error_time", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime), "lsp-ping-tx-last-time" : ("lsp_ping_tx_last_time", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime)}
                    self._child_list_classes = {}

                    self.lsp_ping_rx_count = YLeaf(YType.uint32, "lsp-ping-rx-count")

                    self.lsp_ping_rx_last_code = YLeaf(YType.uint8, "lsp-ping-rx-last-code")

                    self.lsp_ping_rx_last_discr = YLeaf(YType.uint32, "lsp-ping-rx-last-discr")

                    self.lsp_ping_rx_last_output = YLeaf(YType.str, "lsp-ping-rx-last-output")

                    self.lsp_ping_rx_last_subcode = YLeaf(YType.uint8, "lsp-ping-rx-last-subcode")

                    self.lsp_ping_tx_count = YLeaf(YType.uint32, "lsp-ping-tx-count")

                    self.lsp_ping_tx_error_count = YLeaf(YType.uint32, "lsp-ping-tx-error-count")

                    self.lsp_ping_tx_last_error_rc = YLeaf(YType.str, "lsp-ping-tx-last-error-rc")

                    self.lsp_ping_tx_last_rc = YLeaf(YType.str, "lsp-ping-tx-last-rc")

                    self.lsp_ping_rx_last_time = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime()
                    self.lsp_ping_rx_last_time.parent = self
                    self._children_name_map["lsp_ping_rx_last_time"] = "lsp-ping-rx-last-time"
                    self._children_yang_names.add("lsp-ping-rx-last-time")

                    self.lsp_ping_tx_last_error_time = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime()
                    self.lsp_ping_tx_last_error_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_error_time"] = "lsp-ping-tx-last-error-time"
                    self._children_yang_names.add("lsp-ping-tx-last-error-time")

                    self.lsp_ping_tx_last_time = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime()
                    self.lsp_ping_tx_last_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_time"] = "lsp-ping-tx-last-time"
                    self._children_yang_names.add("lsp-ping-tx-last-time")
                    self._segment_path = lambda: "lsp-ping-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo, ['lsp_ping_rx_count', 'lsp_ping_rx_last_code', 'lsp_ping_rx_last_discr', 'lsp_ping_rx_last_output', 'lsp_ping_rx_last_subcode', 'lsp_ping_tx_count', 'lsp_ping_tx_error_count', 'lsp_ping_tx_last_error_rc', 'lsp_ping_tx_last_rc'], name, value)


                class LspPingRxLastTime(Entity):
                    """
                    LSP Ping last received time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-rx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-rx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingRxLastTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastErrorTime(Entity):
                    """
                    LSP Ping last error time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-error-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-error-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastErrorTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastTime(Entity):
                    """
                    LSP Ping last sent time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.LspPingInfo.LspPingTxLastTime, ['nanoseconds', 'seconds'], name, value)


            class MpDownloadState(Entity):
                """
                MP Dowload State
                
                .. attribute:: change_time
                
                	Change time
                	**type**\:   :py:class:`ChangeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState.ChangeTime>`
                
                .. attribute:: mp_download_state
                
                	MP Download State
                	**type**\:   :py:class:`BfdMpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMpDownloadState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState, self).__init__()

                    self.yang_name = "mp-download-state"
                    self.yang_parent_name = "ipv6-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"change-time" : ("change_time", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState.ChangeTime)}
                    self._child_list_classes = {}

                    self.mp_download_state = YLeaf(YType.enumeration, "mp-download-state")

                    self.change_time = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState.ChangeTime()
                    self.change_time.parent = self
                    self._children_name_map["change_time"] = "change-time"
                    self._children_yang_names.add("change-time")
                    self._segment_path = lambda: "mp-download-state"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState, ['mp_download_state'], name, value)


                class ChangeTime(Entity):
                    """
                    Change time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState.ChangeTime, self).__init__()

                        self.yang_name = "change-time"
                        self.yang_parent_name = "mp-download-state"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "change-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/mp-download-state/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.MpDownloadState.ChangeTime, ['nanoseconds', 'seconds'], name, value)


            class OwnerInformation(Entity):
                """
                Client applications owning the session
                
                .. attribute:: adjusted_detection_multiplier
                
                	Adjusted detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adjusted_interval
                
                	Adjusted minimum transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: detection_multiplier
                
                	Client specified detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interval
                
                	Client specified minimum transmit interval in micro\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: name
                
                	Client process name
                	**type**\:  str
                
                	**length:** 0..257
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.OwnerInformation, self).__init__()

                    self.yang_name = "owner-information"
                    self.yang_parent_name = "ipv6-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                    self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.interval = YLeaf(YType.uint32, "interval")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "owner-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class StatusInformation(Entity):
                """
                Session status information
                
                .. attribute:: async_receive_statistics
                
                	Statistics of Interval between Async Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`AsyncReceiveStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics>`
                
                .. attribute:: async_transmit_statistics
                
                	Statistics of Interval between Async Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`AsyncTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics>`
                
                .. attribute:: desired_minimum_echo_transmit_interval
                
                	Desired minimum echo transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: echo_received_statistics
                
                	Statistics of Interval between Echo Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`EchoReceivedStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics>`
                
                .. attribute:: echo_transmit_statistics
                
                	Statistics of Interval between Echo Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`EchoTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics>`
                
                .. attribute:: internal_label
                
                	Internal Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_state_change
                
                	Time since last state change
                	**type**\:   :py:class:`LastStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.LastStateChange>`
                
                .. attribute:: latency_average
                
                	Average value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_maximum
                
                	Maximum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_minimum
                
                	Minimum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_number
                
                	Number of Latency Samples. Time between Transmit and Receive
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: node_id
                
                	Location where session is housed
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: receive_packet
                
                	Receive Packet
                	**type**\:   :py:class:`ReceivePacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.ReceivePacket>`
                
                .. attribute:: remote_discriminator
                
                	Session's Remote discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_negotiated_interval
                
                	Remote Negotiated Interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: session_subtype
                
                	Session subtype
                	**type**\:  str
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                .. attribute:: source_address
                
                	Source address
                	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.SourceAddress>`
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                .. attribute:: status_brief_information
                
                	Brief Status Information
                	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation>`
                
                .. attribute:: to_up_state_count
                
                	Number of times session state went to UP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmit_packet
                
                	Transmit Packet
                	**type**\:   :py:class:`TransmitPacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.TransmitPacket>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation, self).__init__()

                    self.yang_name = "status-information"
                    self.yang_parent_name = "ipv6-single-hop-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-receive-statistics" : ("async_receive_statistics", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics), "async-transmit-statistics" : ("async_transmit_statistics", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics), "echo-received-statistics" : ("echo_received_statistics", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics), "echo-transmit-statistics" : ("echo_transmit_statistics", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics), "last-state-change" : ("last_state_change", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.LastStateChange), "receive-packet" : ("receive_packet", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.ReceivePacket), "source-address" : ("source_address", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.SourceAddress), "status-brief-information" : ("status_brief_information", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation), "transmit-packet" : ("transmit_packet", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.TransmitPacket)}
                    self._child_list_classes = {}

                    self.desired_minimum_echo_transmit_interval = YLeaf(YType.uint32, "desired-minimum-echo-transmit-interval")

                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                    self.latency_average = YLeaf(YType.uint32, "latency-average")

                    self.latency_maximum = YLeaf(YType.uint32, "latency-maximum")

                    self.latency_minimum = YLeaf(YType.uint32, "latency-minimum")

                    self.latency_number = YLeaf(YType.uint32, "latency-number")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.remote_discriminator = YLeaf(YType.uint32, "remote-discriminator")

                    self.remote_negotiated_interval = YLeaf(YType.uint32, "remote-negotiated-interval")

                    self.session_subtype = YLeaf(YType.str, "session-subtype")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.to_up_state_count = YLeaf(YType.uint32, "to-up-state-count")

                    self.async_receive_statistics = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics()
                    self.async_receive_statistics.parent = self
                    self._children_name_map["async_receive_statistics"] = "async-receive-statistics"
                    self._children_yang_names.add("async-receive-statistics")

                    self.async_transmit_statistics = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics()
                    self.async_transmit_statistics.parent = self
                    self._children_name_map["async_transmit_statistics"] = "async-transmit-statistics"
                    self._children_yang_names.add("async-transmit-statistics")

                    self.echo_received_statistics = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics()
                    self.echo_received_statistics.parent = self
                    self._children_name_map["echo_received_statistics"] = "echo-received-statistics"
                    self._children_yang_names.add("echo-received-statistics")

                    self.echo_transmit_statistics = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics()
                    self.echo_transmit_statistics.parent = self
                    self._children_name_map["echo_transmit_statistics"] = "echo-transmit-statistics"
                    self._children_yang_names.add("echo-transmit-statistics")

                    self.last_state_change = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.LastStateChange()
                    self.last_state_change.parent = self
                    self._children_name_map["last_state_change"] = "last-state-change"
                    self._children_yang_names.add("last-state-change")

                    self.receive_packet = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.ReceivePacket()
                    self.receive_packet.parent = self
                    self._children_name_map["receive_packet"] = "receive-packet"
                    self._children_yang_names.add("receive-packet")

                    self.source_address = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.SourceAddress()
                    self.source_address.parent = self
                    self._children_name_map["source_address"] = "source-address"
                    self._children_yang_names.add("source-address")

                    self.status_brief_information = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation()
                    self.status_brief_information.parent = self
                    self._children_name_map["status_brief_information"] = "status-brief-information"
                    self._children_yang_names.add("status-brief-information")

                    self.transmit_packet = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.TransmitPacket()
                    self.transmit_packet.parent = self
                    self._children_name_map["transmit_packet"] = "transmit-packet"
                    self._children_yang_names.add("transmit-packet")
                    self._segment_path = lambda: "status-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation, ['desired_minimum_echo_transmit_interval', 'internal_label', 'latency_average', 'latency_maximum', 'latency_minimum', 'latency_number', 'local_discriminator', 'node_id', 'remote_discriminator', 'remote_negotiated_interval', 'session_subtype', 'sessiontype', 'state', 'to_up_state_count'], name, value)


                class AsyncReceiveStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics, self).__init__()

                        self.yang_name = "async-receive-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-receive-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncReceiveStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class AsyncTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics, self).__init__()

                        self.yang_name = "async-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.AsyncTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoReceivedStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics, self).__init__()

                        self.yang_name = "echo-received-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-received-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoReceivedStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics, self).__init__()

                        self.yang_name = "echo-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.EchoTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class LastStateChange(Entity):
                    """
                    Time since last state change
                    
                    .. attribute:: days
                    
                    	Number of days since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: day
                    
                    .. attribute:: hours
                    
                    	Number of hours since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: hour
                    
                    .. attribute:: minutes
                    
                    	Number of mins since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: minute
                    
                    .. attribute:: seconds
                    
                    	Number of seconds since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.LastStateChange, self).__init__()

                        self.yang_name = "last-state-change"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.days = YLeaf(YType.uint32, "days")

                        self.hours = YLeaf(YType.uint8, "hours")

                        self.minutes = YLeaf(YType.uint8, "minutes")

                        self.seconds = YLeaf(YType.uint8, "seconds")
                        self._segment_path = lambda: "last-state-change"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.LastStateChange, ['days', 'hours', 'minutes', 'seconds'], name, value)


                class ReceivePacket(Entity):
                    """
                    Receive Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.ReceivePacket, self).__init__()

                        self.yang_name = "receive-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "receive-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.ReceivePacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


                class SourceAddress(Entity):
                    """
                    Source address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.SourceAddress, self).__init__()

                        self.yang_name = "source-address"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "source-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.SourceAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class StatusBriefInformation(Entity):
                    """
                    Brief Status Information
                    
                    .. attribute:: async_interval_multiplier
                    
                    	Async Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier>`
                    
                    .. attribute:: echo_interval_multiplier
                    
                    	Echo Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier>`
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation, self).__init__()

                        self.yang_name = "status-brief-information"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier)}
                        self._child_list_classes = {}

                        self.async_interval_multiplier = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier()
                        self.async_interval_multiplier.parent = self
                        self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                        self._children_yang_names.add("async-interval-multiplier")

                        self.echo_interval_multiplier = Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier()
                        self.echo_interval_multiplier.parent = self
                        self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                        self._children_yang_names.add("echo-interval-multiplier")
                        self._segment_path = lambda: "status-brief-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/%s" % self._segment_path()


                    class AsyncIntervalMultiplier(Entity):
                        """
                        Async Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_local_transmit_interval
                        
                        	Negotiated local transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_remote_transmit_interval
                        
                        	Negotiated remote transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                            self.yang_name = "async-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                            self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                            self._segment_path = lambda: "async-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                    class EchoIntervalMultiplier(Entity):
                        """
                        Echo Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_transmit_interval
                        
                        	Negotiated transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                            self.yang_name = "echo-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                            self._segment_path = lambda: "echo-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


                class TransmitPacket(Entity):
                    """
                    Transmit Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.TransmitPacket, self).__init__()

                        self.yang_name = "transmit-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "transmit-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-session-details/ipv6-single-hop-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.Ipv6SingleHopSessionDetails.Ipv6SingleHopSessionDetail.StatusInformation.TransmitPacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


    class Ipv6SingleHopSummary(Entity):
        """
        Summary information of BFD IPv6 singlehop
        sessions
        
        .. attribute:: session_state
        
        	Statistics of states for sessions
        	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Ipv6SingleHopSummary.SessionState>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Ipv6SingleHopSummary, self).__init__()

            self.yang_name = "ipv6-single-hop-summary"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"session-state" : ("session_state", Bfd.Ipv6SingleHopSummary.SessionState)}
            self._child_list_classes = {}

            self.session_state = Bfd.Ipv6SingleHopSummary.SessionState()
            self.session_state.parent = self
            self._children_name_map["session_state"] = "session-state"
            self._children_yang_names.add("session-state")
            self._segment_path = lambda: "ipv6-single-hop-summary"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class SessionState(Entity):
            """
            Statistics of states for sessions
            
            .. attribute:: down_count
            
            	Number of sessions in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_count
            
            	Number of sessions in database
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_count
            
            	Number of sessions in unknown state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of sessions in up state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Ipv6SingleHopSummary.SessionState, self).__init__()

                self.yang_name = "session-state"
                self.yang_parent_name = "ipv6-single-hop-summary"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.down_count = YLeaf(YType.uint32, "down-count")

                self.total_count = YLeaf(YType.uint32, "total-count")

                self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                self.up_count = YLeaf(YType.uint32, "up-count")
                self._segment_path = lambda: "session-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/ipv6-single-hop-summary/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Ipv6SingleHopSummary.SessionState, ['down_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class LabelCounters(Entity):
        """
        Label Counters
        
        .. attribute:: label_packet_counters
        
        	Table of Label Packet counters
        	**type**\:   :py:class:`LabelPacketCounters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelCounters.LabelPacketCounters>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.LabelCounters, self).__init__()

            self.yang_name = "label-counters"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"label-packet-counters" : ("label_packet_counters", Bfd.LabelCounters.LabelPacketCounters)}
            self._child_list_classes = {}

            self.label_packet_counters = Bfd.LabelCounters.LabelPacketCounters()
            self.label_packet_counters.parent = self
            self._children_name_map["label_packet_counters"] = "label-packet-counters"
            self._children_yang_names.add("label-packet-counters")
            self._segment_path = lambda: "label-counters"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class LabelPacketCounters(Entity):
            """
            Table of Label Packet counters
            
            .. attribute:: label_packet_counter
            
            	Interface Label Packet counters
            	**type**\: list of    :py:class:`LabelPacketCounter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelCounters.LabelPacketCounters.LabelPacketCounter>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.LabelCounters.LabelPacketCounters, self).__init__()

                self.yang_name = "label-packet-counters"
                self.yang_parent_name = "label-counters"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"label-packet-counter" : ("label_packet_counter", Bfd.LabelCounters.LabelPacketCounters.LabelPacketCounter)}

                self.label_packet_counter = YList(self)
                self._segment_path = lambda: "label-packet-counters"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-counters/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.LabelCounters.LabelPacketCounters, [], name, value)


            class LabelPacketCounter(Entity):
                """
                Interface Label Packet counters
                
                .. attribute:: display_type
                
                	Packet Display Type
                	**type**\:   :py:class:`BfdMgmtPktDisplay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtPktDisplay>`
                
                .. attribute:: echo_receive_count
                
                	Number of echo packets received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: echo_transmit_count
                
                	Number of echo packets transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_receive_count
                
                	Number of Hellos received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: hello_transmit_count
                
                	Number of Hellos transmitted
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface_name
                
                	Interface Name
                	**type**\:  str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: location
                
                	Location
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.LabelCounters.LabelPacketCounters.LabelPacketCounter, self).__init__()

                    self.yang_name = "label-packet-counter"
                    self.yang_parent_name = "label-packet-counters"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.display_type = YLeaf(YType.enumeration, "display-type")

                    self.echo_receive_count = YLeaf(YType.uint32, "echo-receive-count")

                    self.echo_transmit_count = YLeaf(YType.uint32, "echo-transmit-count")

                    self.hello_receive_count = YLeaf(YType.uint32, "hello-receive-count")

                    self.hello_transmit_count = YLeaf(YType.uint32, "hello-transmit-count")

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.location = YLeaf(YType.str, "location")
                    self._segment_path = lambda: "label-packet-counter"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-counters/label-packet-counters/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.LabelCounters.LabelPacketCounters.LabelPacketCounter, ['display_type', 'echo_receive_count', 'echo_transmit_count', 'hello_receive_count', 'hello_transmit_count', 'interface_name', 'location'], name, value)


    class LabelMultiPaths(Entity):
        """
        Label multipath
        
        .. attribute:: label_multi_path
        
        	Label multipath table
        	**type**\: list of    :py:class:`LabelMultiPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelMultiPaths.LabelMultiPath>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.LabelMultiPaths, self).__init__()

            self.yang_name = "label-multi-paths"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"label-multi-path" : ("label_multi_path", Bfd.LabelMultiPaths.LabelMultiPath)}

            self.label_multi_path = YList(self)
            self._segment_path = lambda: "label-multi-paths"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.LabelMultiPaths, [], name, value)


        class LabelMultiPath(Entity):
            """
            Label multipath table
            
            .. attribute:: incoming_label
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: incoming_label_xr
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: local_discriminator
            
            	Session's Local discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_interface_name
            
            	Interface name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.LabelMultiPaths.LabelMultiPath, self).__init__()

                self.yang_name = "label-multi-path"
                self.yang_parent_name = "label-multi-paths"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.incoming_label = YLeaf(YType.int32, "incoming-label")

                self.incoming_label_xr = YLeaf(YType.uint32, "incoming-label-xr")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_interface_name = YLeaf(YType.str, "session-interface-name")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.state = YLeaf(YType.enumeration, "state")
                self._segment_path = lambda: "label-multi-path"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-multi-paths/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.LabelMultiPaths.LabelMultiPath, ['incoming_label', 'incoming_label_xr', 'interface_name', 'local_discriminator', 'location', 'node_id', 'session_interface_name', 'session_subtype', 'state'], name, value)


    class LabelSessionBriefs(Entity):
        """
        Table of brief information about all Label BFD
        sessions in the System
        
        .. attribute:: label_session_brief
        
        	Brief information for a single Label BFD session
        	**type**\: list of    :py:class:`LabelSessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionBriefs.LabelSessionBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.LabelSessionBriefs, self).__init__()

            self.yang_name = "label-session-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"label-session-brief" : ("label_session_brief", Bfd.LabelSessionBriefs.LabelSessionBrief)}

            self.label_session_brief = YList(self)
            self._segment_path = lambda: "label-session-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.LabelSessionBriefs, [], name, value)


        class LabelSessionBrief(Entity):
            """
            Brief information for a single Label BFD
            session
            
            .. attribute:: incoming_label
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_flags
            
            	Session Flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: session_type
            
            	Session type
            	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: status_brief_information
            
            	Brief Status Information
            	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.LabelSessionBriefs.LabelSessionBrief, self).__init__()

                self.yang_name = "label-session-brief"
                self.yang_parent_name = "label-session-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"status-brief-information" : ("status_brief_information", Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation)}
                self._child_list_classes = {}

                self.incoming_label = YLeaf(YType.int32, "incoming-label")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_flags = YLeaf(YType.uint32, "session-flags")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.state = YLeaf(YType.enumeration, "state")

                self.status_brief_information = Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation()
                self.status_brief_information.parent = self
                self._children_name_map["status_brief_information"] = "status-brief-information"
                self._children_yang_names.add("status-brief-information")
                self._segment_path = lambda: "label-session-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.LabelSessionBriefs.LabelSessionBrief, ['incoming_label', 'interface_name', 'location', 'node_id', 'session_flags', 'session_subtype', 'session_type', 'state'], name, value)


            class StatusBriefInformation(Entity):
                """
                Brief Status Information
                
                .. attribute:: async_interval_multiplier
                
                	Async Interval and Detect Multiplier Information
                	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier>`
                
                .. attribute:: echo_interval_multiplier
                
                	Echo Interval and Detect Multiplier Information
                	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.EchoIntervalMultiplier>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation, self).__init__()

                    self.yang_name = "status-brief-information"
                    self.yang_parent_name = "label-session-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.EchoIntervalMultiplier)}
                    self._child_list_classes = {}

                    self.async_interval_multiplier = Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier()
                    self.async_interval_multiplier.parent = self
                    self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                    self._children_yang_names.add("async-interval-multiplier")

                    self.echo_interval_multiplier = Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.EchoIntervalMultiplier()
                    self.echo_interval_multiplier.parent = self
                    self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                    self._children_yang_names.add("echo-interval-multiplier")
                    self._segment_path = lambda: "status-brief-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-briefs/label-session-brief/%s" % self._segment_path()


                class AsyncIntervalMultiplier(Entity):
                    """
                    Async Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_local_transmit_interval
                    
                    	Negotiated local transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_remote_transmit_interval
                    
                    	Negotiated remote transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                        self.yang_name = "async-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                        self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                        self._segment_path = lambda: "async-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-briefs/label-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                class EchoIntervalMultiplier(Entity):
                    """
                    Echo Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_transmit_interval
                    
                    	Negotiated transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                        self.yang_name = "echo-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                        self._segment_path = lambda: "echo-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-briefs/label-session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionBriefs.LabelSessionBrief.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


    class LabelSessionDetails(Entity):
        """
        Table of detailed information about all Label
        BFD sessions in the System 
        
        .. attribute:: label_session_detail
        
        	Detailed information for a single BFD session
        	**type**\: list of    :py:class:`LabelSessionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.LabelSessionDetails, self).__init__()

            self.yang_name = "label-session-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"label-session-detail" : ("label_session_detail", Bfd.LabelSessionDetails.LabelSessionDetail)}

            self.label_session_detail = YList(self)
            self._segment_path = lambda: "label-session-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.LabelSessionDetails, [], name, value)


        class LabelSessionDetail(Entity):
            """
            Detailed information for a single BFD session
            
            .. attribute:: association_information
            
            	Association session information
            	**type**\: list of    :py:class:`AssociationInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation>`
            
            .. attribute:: incoming_label
            
            	Incoming Label
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: lsp_ping_info
            
            	LSP Ping Info
            	**type**\:   :py:class:`LspPingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo>`
            
            .. attribute:: mp_download_state
            
            	MP Dowload State
            	**type**\:   :py:class:`MpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState>`
            
            .. attribute:: owner_information
            
            	Client applications owning the session
            	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.OwnerInformation>`
            
            .. attribute:: status_information
            
            	Session status information
            	**type**\:   :py:class:`StatusInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.LabelSessionDetails.LabelSessionDetail, self).__init__()

                self.yang_name = "label-session-detail"
                self.yang_parent_name = "label-session-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"lsp-ping-info" : ("lsp_ping_info", Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo), "mp-download-state" : ("mp_download_state", Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState), "status-information" : ("status_information", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation)}
                self._child_list_classes = {"association-information" : ("association_information", Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation), "owner-information" : ("owner_information", Bfd.LabelSessionDetails.LabelSessionDetail.OwnerInformation)}

                self.incoming_label = YLeaf(YType.int32, "incoming-label")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.lsp_ping_info = Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo()
                self.lsp_ping_info.parent = self
                self._children_name_map["lsp_ping_info"] = "lsp-ping-info"
                self._children_yang_names.add("lsp-ping-info")

                self.mp_download_state = Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState()
                self.mp_download_state.parent = self
                self._children_name_map["mp_download_state"] = "mp-download-state"
                self._children_yang_names.add("mp-download-state")

                self.status_information = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation()
                self.status_information.parent = self
                self._children_name_map["status_information"] = "status-information"
                self._children_yang_names.add("status-information")

                self.association_information = YList(self)
                self.owner_information = YList(self)
                self._segment_path = lambda: "label-session-detail"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail, ['incoming_label', 'interface_name', 'location'], name, value)


            class AssociationInformation(Entity):
                """
                Association session information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: ip_destination_address
                
                	IPv4/v6 dest address
                	**type**\:   :py:class:`IpDestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation.IpDestinationAddress>`
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: owner_information
                
                	Client applications owning the session
                	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation.OwnerInformation>`
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation, self).__init__()

                    self.yang_name = "association-information"
                    self.yang_parent_name = "label-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"ip-destination-address" : ("ip_destination_address", Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation.IpDestinationAddress)}
                    self._child_list_classes = {"owner-information" : ("owner_information", Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation.OwnerInformation)}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.ip_destination_address = Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation.IpDestinationAddress()
                    self.ip_destination_address.parent = self
                    self._children_name_map["ip_destination_address"] = "ip-destination-address"
                    self._children_yang_names.add("ip-destination-address")

                    self.owner_information = YList(self)
                    self._segment_path = lambda: "association-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation, ['interface_name', 'local_discriminator', 'sessiontype'], name, value)


                class IpDestinationAddress(Entity):
                    """
                    IPv4/v6 dest address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation.IpDestinationAddress, self).__init__()

                        self.yang_name = "ip-destination-address"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "ip-destination-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation.IpDestinationAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class OwnerInformation(Entity):
                    """
                    Client applications owning the session
                    
                    .. attribute:: adjusted_detection_multiplier
                    
                    	Adjusted detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: adjusted_interval
                    
                    	Adjusted minimum transmit interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Client specified detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interval
                    
                    	Client specified minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: name
                    
                    	Client process name
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation.OwnerInformation, self).__init__()

                        self.yang_name = "owner-information"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                        self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "owner-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.AssociationInformation.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class LspPingInfo(Entity):
                """
                LSP Ping Info
                
                .. attribute:: lsp_ping_rx_count
                
                	LSP Ping numer of times received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_code
                
                	LSP Ping Rx Last Code
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_discr
                
                	LSP Ping Rx last received discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_output
                
                	LSP Ping Rx Last Output
                	**type**\:  str
                
                .. attribute:: lsp_ping_rx_last_subcode
                
                	LSP Ping Rx Last Subcode
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_time
                
                	LSP Ping last received time
                	**type**\:   :py:class:`LspPingRxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingRxLastTime>`
                
                .. attribute:: lsp_ping_tx_count
                
                	LSP Ping Tx count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_error_count
                
                	LSP Ping Tx error count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_last_error_rc
                
                	LSP Ping Tx last error
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_error_time
                
                	LSP Ping last error time
                	**type**\:   :py:class:`LspPingTxLastErrorTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastErrorTime>`
                
                .. attribute:: lsp_ping_tx_last_rc
                
                	LSP Ping Tx last result
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_time
                
                	LSP Ping last sent time
                	**type**\:   :py:class:`LspPingTxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastTime>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo, self).__init__()

                    self.yang_name = "lsp-ping-info"
                    self.yang_parent_name = "label-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"lsp-ping-rx-last-time" : ("lsp_ping_rx_last_time", Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingRxLastTime), "lsp-ping-tx-last-error-time" : ("lsp_ping_tx_last_error_time", Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastErrorTime), "lsp-ping-tx-last-time" : ("lsp_ping_tx_last_time", Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastTime)}
                    self._child_list_classes = {}

                    self.lsp_ping_rx_count = YLeaf(YType.uint32, "lsp-ping-rx-count")

                    self.lsp_ping_rx_last_code = YLeaf(YType.uint8, "lsp-ping-rx-last-code")

                    self.lsp_ping_rx_last_discr = YLeaf(YType.uint32, "lsp-ping-rx-last-discr")

                    self.lsp_ping_rx_last_output = YLeaf(YType.str, "lsp-ping-rx-last-output")

                    self.lsp_ping_rx_last_subcode = YLeaf(YType.uint8, "lsp-ping-rx-last-subcode")

                    self.lsp_ping_tx_count = YLeaf(YType.uint32, "lsp-ping-tx-count")

                    self.lsp_ping_tx_error_count = YLeaf(YType.uint32, "lsp-ping-tx-error-count")

                    self.lsp_ping_tx_last_error_rc = YLeaf(YType.str, "lsp-ping-tx-last-error-rc")

                    self.lsp_ping_tx_last_rc = YLeaf(YType.str, "lsp-ping-tx-last-rc")

                    self.lsp_ping_rx_last_time = Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingRxLastTime()
                    self.lsp_ping_rx_last_time.parent = self
                    self._children_name_map["lsp_ping_rx_last_time"] = "lsp-ping-rx-last-time"
                    self._children_yang_names.add("lsp-ping-rx-last-time")

                    self.lsp_ping_tx_last_error_time = Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastErrorTime()
                    self.lsp_ping_tx_last_error_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_error_time"] = "lsp-ping-tx-last-error-time"
                    self._children_yang_names.add("lsp-ping-tx-last-error-time")

                    self.lsp_ping_tx_last_time = Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastTime()
                    self.lsp_ping_tx_last_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_time"] = "lsp-ping-tx-last-time"
                    self._children_yang_names.add("lsp-ping-tx-last-time")
                    self._segment_path = lambda: "lsp-ping-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo, ['lsp_ping_rx_count', 'lsp_ping_rx_last_code', 'lsp_ping_rx_last_discr', 'lsp_ping_rx_last_output', 'lsp_ping_rx_last_subcode', 'lsp_ping_tx_count', 'lsp_ping_tx_error_count', 'lsp_ping_tx_last_error_rc', 'lsp_ping_tx_last_rc'], name, value)


                class LspPingRxLastTime(Entity):
                    """
                    LSP Ping last received time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingRxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-rx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-rx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingRxLastTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastErrorTime(Entity):
                    """
                    LSP Ping last error time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastErrorTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-error-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-error-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastErrorTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastTime(Entity):
                    """
                    LSP Ping last sent time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.LspPingInfo.LspPingTxLastTime, ['nanoseconds', 'seconds'], name, value)


            class MpDownloadState(Entity):
                """
                MP Dowload State
                
                .. attribute:: change_time
                
                	Change time
                	**type**\:   :py:class:`ChangeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState.ChangeTime>`
                
                .. attribute:: mp_download_state
                
                	MP Download State
                	**type**\:   :py:class:`BfdMpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMpDownloadState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState, self).__init__()

                    self.yang_name = "mp-download-state"
                    self.yang_parent_name = "label-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"change-time" : ("change_time", Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState.ChangeTime)}
                    self._child_list_classes = {}

                    self.mp_download_state = YLeaf(YType.enumeration, "mp-download-state")

                    self.change_time = Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState.ChangeTime()
                    self.change_time.parent = self
                    self._children_name_map["change_time"] = "change-time"
                    self._children_yang_names.add("change-time")
                    self._segment_path = lambda: "mp-download-state"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState, ['mp_download_state'], name, value)


                class ChangeTime(Entity):
                    """
                    Change time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState.ChangeTime, self).__init__()

                        self.yang_name = "change-time"
                        self.yang_parent_name = "mp-download-state"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "change-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/mp-download-state/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.MpDownloadState.ChangeTime, ['nanoseconds', 'seconds'], name, value)


            class OwnerInformation(Entity):
                """
                Client applications owning the session
                
                .. attribute:: adjusted_detection_multiplier
                
                	Adjusted detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adjusted_interval
                
                	Adjusted minimum transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: detection_multiplier
                
                	Client specified detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interval
                
                	Client specified minimum transmit interval in micro\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: name
                
                	Client process name
                	**type**\:  str
                
                	**length:** 0..257
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.LabelSessionDetails.LabelSessionDetail.OwnerInformation, self).__init__()

                    self.yang_name = "owner-information"
                    self.yang_parent_name = "label-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                    self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.interval = YLeaf(YType.uint32, "interval")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "owner-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class StatusInformation(Entity):
                """
                Session status information
                
                .. attribute:: async_receive_statistics
                
                	Statistics of Interval between Async Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`AsyncReceiveStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncReceiveStatistics>`
                
                .. attribute:: async_transmit_statistics
                
                	Statistics of Interval between Async Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`AsyncTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncTransmitStatistics>`
                
                .. attribute:: desired_minimum_echo_transmit_interval
                
                	Desired minimum echo transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: echo_received_statistics
                
                	Statistics of Interval between Echo Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`EchoReceivedStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoReceivedStatistics>`
                
                .. attribute:: echo_transmit_statistics
                
                	Statistics of Interval between Echo Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`EchoTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoTransmitStatistics>`
                
                .. attribute:: internal_label
                
                	Internal Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_state_change
                
                	Time since last state change
                	**type**\:   :py:class:`LastStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.LastStateChange>`
                
                .. attribute:: latency_average
                
                	Average value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_maximum
                
                	Maximum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_minimum
                
                	Minimum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_number
                
                	Number of Latency Samples. Time between Transmit and Receive
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: node_id
                
                	Location where session is housed
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: receive_packet
                
                	Receive Packet
                	**type**\:   :py:class:`ReceivePacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.ReceivePacket>`
                
                .. attribute:: remote_discriminator
                
                	Session's Remote discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_negotiated_interval
                
                	Remote Negotiated Interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: session_subtype
                
                	Session subtype
                	**type**\:  str
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                .. attribute:: source_address
                
                	Source address
                	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.SourceAddress>`
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                .. attribute:: status_brief_information
                
                	Brief Status Information
                	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation>`
                
                .. attribute:: to_up_state_count
                
                	Number of times session state went to UP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmit_packet
                
                	Transmit Packet
                	**type**\:   :py:class:`TransmitPacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.TransmitPacket>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation, self).__init__()

                    self.yang_name = "status-information"
                    self.yang_parent_name = "label-session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-receive-statistics" : ("async_receive_statistics", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncReceiveStatistics), "async-transmit-statistics" : ("async_transmit_statistics", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncTransmitStatistics), "echo-received-statistics" : ("echo_received_statistics", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoReceivedStatistics), "echo-transmit-statistics" : ("echo_transmit_statistics", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoTransmitStatistics), "last-state-change" : ("last_state_change", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.LastStateChange), "receive-packet" : ("receive_packet", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.ReceivePacket), "source-address" : ("source_address", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.SourceAddress), "status-brief-information" : ("status_brief_information", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation), "transmit-packet" : ("transmit_packet", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.TransmitPacket)}
                    self._child_list_classes = {}

                    self.desired_minimum_echo_transmit_interval = YLeaf(YType.uint32, "desired-minimum-echo-transmit-interval")

                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                    self.latency_average = YLeaf(YType.uint32, "latency-average")

                    self.latency_maximum = YLeaf(YType.uint32, "latency-maximum")

                    self.latency_minimum = YLeaf(YType.uint32, "latency-minimum")

                    self.latency_number = YLeaf(YType.uint32, "latency-number")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.remote_discriminator = YLeaf(YType.uint32, "remote-discriminator")

                    self.remote_negotiated_interval = YLeaf(YType.uint32, "remote-negotiated-interval")

                    self.session_subtype = YLeaf(YType.str, "session-subtype")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.to_up_state_count = YLeaf(YType.uint32, "to-up-state-count")

                    self.async_receive_statistics = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncReceiveStatistics()
                    self.async_receive_statistics.parent = self
                    self._children_name_map["async_receive_statistics"] = "async-receive-statistics"
                    self._children_yang_names.add("async-receive-statistics")

                    self.async_transmit_statistics = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncTransmitStatistics()
                    self.async_transmit_statistics.parent = self
                    self._children_name_map["async_transmit_statistics"] = "async-transmit-statistics"
                    self._children_yang_names.add("async-transmit-statistics")

                    self.echo_received_statistics = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoReceivedStatistics()
                    self.echo_received_statistics.parent = self
                    self._children_name_map["echo_received_statistics"] = "echo-received-statistics"
                    self._children_yang_names.add("echo-received-statistics")

                    self.echo_transmit_statistics = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoTransmitStatistics()
                    self.echo_transmit_statistics.parent = self
                    self._children_name_map["echo_transmit_statistics"] = "echo-transmit-statistics"
                    self._children_yang_names.add("echo-transmit-statistics")

                    self.last_state_change = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.LastStateChange()
                    self.last_state_change.parent = self
                    self._children_name_map["last_state_change"] = "last-state-change"
                    self._children_yang_names.add("last-state-change")

                    self.receive_packet = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.ReceivePacket()
                    self.receive_packet.parent = self
                    self._children_name_map["receive_packet"] = "receive-packet"
                    self._children_yang_names.add("receive-packet")

                    self.source_address = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.SourceAddress()
                    self.source_address.parent = self
                    self._children_name_map["source_address"] = "source-address"
                    self._children_yang_names.add("source-address")

                    self.status_brief_information = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation()
                    self.status_brief_information.parent = self
                    self._children_name_map["status_brief_information"] = "status-brief-information"
                    self._children_yang_names.add("status-brief-information")

                    self.transmit_packet = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.TransmitPacket()
                    self.transmit_packet.parent = self
                    self._children_name_map["transmit_packet"] = "transmit-packet"
                    self._children_yang_names.add("transmit-packet")
                    self._segment_path = lambda: "status-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation, ['desired_minimum_echo_transmit_interval', 'internal_label', 'latency_average', 'latency_maximum', 'latency_minimum', 'latency_number', 'local_discriminator', 'node_id', 'remote_discriminator', 'remote_negotiated_interval', 'session_subtype', 'sessiontype', 'state', 'to_up_state_count'], name, value)


                class AsyncReceiveStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncReceiveStatistics, self).__init__()

                        self.yang_name = "async-receive-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-receive-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncReceiveStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class AsyncTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncTransmitStatistics, self).__init__()

                        self.yang_name = "async-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.AsyncTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoReceivedStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoReceivedStatistics, self).__init__()

                        self.yang_name = "echo-received-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-received-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoReceivedStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoTransmitStatistics, self).__init__()

                        self.yang_name = "echo-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.EchoTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class LastStateChange(Entity):
                    """
                    Time since last state change
                    
                    .. attribute:: days
                    
                    	Number of days since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: day
                    
                    .. attribute:: hours
                    
                    	Number of hours since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: hour
                    
                    .. attribute:: minutes
                    
                    	Number of mins since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: minute
                    
                    .. attribute:: seconds
                    
                    	Number of seconds since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.LastStateChange, self).__init__()

                        self.yang_name = "last-state-change"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.days = YLeaf(YType.uint32, "days")

                        self.hours = YLeaf(YType.uint8, "hours")

                        self.minutes = YLeaf(YType.uint8, "minutes")

                        self.seconds = YLeaf(YType.uint8, "seconds")
                        self._segment_path = lambda: "last-state-change"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.LastStateChange, ['days', 'hours', 'minutes', 'seconds'], name, value)


                class ReceivePacket(Entity):
                    """
                    Receive Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.ReceivePacket, self).__init__()

                        self.yang_name = "receive-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "receive-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.ReceivePacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


                class SourceAddress(Entity):
                    """
                    Source address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.SourceAddress, self).__init__()

                        self.yang_name = "source-address"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "source-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.SourceAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class StatusBriefInformation(Entity):
                    """
                    Brief Status Information
                    
                    .. attribute:: async_interval_multiplier
                    
                    	Async Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier>`
                    
                    .. attribute:: echo_interval_multiplier
                    
                    	Echo Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier>`
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation, self).__init__()

                        self.yang_name = "status-brief-information"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier)}
                        self._child_list_classes = {}

                        self.async_interval_multiplier = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier()
                        self.async_interval_multiplier.parent = self
                        self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                        self._children_yang_names.add("async-interval-multiplier")

                        self.echo_interval_multiplier = Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier()
                        self.echo_interval_multiplier.parent = self
                        self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                        self._children_yang_names.add("echo-interval-multiplier")
                        self._segment_path = lambda: "status-brief-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/%s" % self._segment_path()


                    class AsyncIntervalMultiplier(Entity):
                        """
                        Async Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_local_transmit_interval
                        
                        	Negotiated local transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_remote_transmit_interval
                        
                        	Negotiated remote transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                            self.yang_name = "async-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                            self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                            self._segment_path = lambda: "async-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                    class EchoIntervalMultiplier(Entity):
                        """
                        Echo Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_transmit_interval
                        
                        	Negotiated transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                            self.yang_name = "echo-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                            self._segment_path = lambda: "echo-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


                class TransmitPacket(Entity):
                    """
                    Transmit Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.TransmitPacket, self).__init__()

                        self.yang_name = "transmit-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "transmit-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-session-details/label-session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.LabelSessionDetails.LabelSessionDetail.StatusInformation.TransmitPacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


    class LabelSummary(Entity):
        """
        Summary information of Label BFD
        
        .. attribute:: session_state
        
        	Statistics of states for sessions
        	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSummary.SessionState>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.LabelSummary, self).__init__()

            self.yang_name = "label-summary"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"session-state" : ("session_state", Bfd.LabelSummary.SessionState)}
            self._child_list_classes = {}

            self.session_state = Bfd.LabelSummary.SessionState()
            self.session_state.parent = self
            self._children_name_map["session_state"] = "session-state"
            self._children_yang_names.add("session-state")
            self._segment_path = lambda: "label-summary"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class SessionState(Entity):
            """
            Statistics of states for sessions
            
            .. attribute:: down_count
            
            	Number of sessions in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_count
            
            	Number of sessions in database
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_count
            
            	Number of sessions in unknown state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of sessions in up state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.LabelSummary.SessionState, self).__init__()

                self.yang_name = "session-state"
                self.yang_parent_name = "label-summary"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.down_count = YLeaf(YType.uint32, "down-count")

                self.total_count = YLeaf(YType.uint32, "total-count")

                self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                self.up_count = YLeaf(YType.uint32, "up-count")
                self._segment_path = lambda: "session-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-summary/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.LabelSummary.SessionState, ['down_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class LabelSummaryNodes(Entity):
        """
        Table of summary about Label BFD sessions for
        location
        
        .. attribute:: label_summary_node
        
        	Summary of Label BFD 
        	**type**\: list of    :py:class:`LabelSummaryNode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSummaryNodes.LabelSummaryNode>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.LabelSummaryNodes, self).__init__()

            self.yang_name = "label-summary-nodes"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"label-summary-node" : ("label_summary_node", Bfd.LabelSummaryNodes.LabelSummaryNode)}

            self.label_summary_node = YList(self)
            self._segment_path = lambda: "label-summary-nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.LabelSummaryNodes, [], name, value)


        class LabelSummaryNode(Entity):
            """
            Summary of Label BFD 
            
            .. attribute:: location_name  <key>
            
            	Location name
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: session_state
            
            	Statistics of states for sessions
            	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.LabelSummaryNodes.LabelSummaryNode.SessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.LabelSummaryNodes.LabelSummaryNode, self).__init__()

                self.yang_name = "label-summary-node"
                self.yang_parent_name = "label-summary-nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"session-state" : ("session_state", Bfd.LabelSummaryNodes.LabelSummaryNode.SessionState)}
                self._child_list_classes = {}

                self.location_name = YLeaf(YType.str, "location-name")

                self.session_state = Bfd.LabelSummaryNodes.LabelSummaryNode.SessionState()
                self.session_state.parent = self
                self._children_name_map["session_state"] = "session-state"
                self._children_yang_names.add("session-state")
                self._segment_path = lambda: "label-summary-node" + "[location-name='" + self.location_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/label-summary-nodes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.LabelSummaryNodes.LabelSummaryNode, ['location_name'], name, value)


            class SessionState(Entity):
                """
                Statistics of states for sessions
                
                .. attribute:: down_count
                
                	Number of sessions in down state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: retry_count
                
                	Number of sessions in retry state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_count
                
                	Number of sessions in standby state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: total_count
                
                	Number of sessions in database
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_count
                
                	Number of sessions in unknown state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: up_count
                
                	Number of sessions in up state
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.LabelSummaryNodes.LabelSummaryNode.SessionState, self).__init__()

                    self.yang_name = "session-state"
                    self.yang_parent_name = "label-summary-node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.down_count = YLeaf(YType.uint32, "down-count")

                    self.retry_count = YLeaf(YType.uint32, "retry-count")

                    self.standby_count = YLeaf(YType.uint32, "standby-count")

                    self.total_count = YLeaf(YType.uint32, "total-count")

                    self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                    self.up_count = YLeaf(YType.uint32, "up-count")
                    self._segment_path = lambda: "session-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.LabelSummaryNodes.LabelSummaryNode.SessionState, ['down_count', 'retry_count', 'standby_count', 'total_count', 'unknown_count', 'up_count'], name, value)


    class RelationBriefs(Entity):
        """
        Table of brief information about all BFD
        relations in the System
        
        .. attribute:: relation_brief
        
        	Brief information for relation of a single BFD session
        	**type**\: list of    :py:class:`RelationBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.RelationBriefs.RelationBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.RelationBriefs, self).__init__()

            self.yang_name = "relation-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"relation-brief" : ("relation_brief", Bfd.RelationBriefs.RelationBrief)}

            self.relation_brief = YList(self)
            self._segment_path = lambda: "relation-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.RelationBriefs, [], name, value)


        class RelationBrief(Entity):
            """
            Brief information for relation of a single BFD
            session
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: link_information
            
            	Brief Member Link Information
            	**type**\: list of    :py:class:`LinkInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.RelationBriefs.RelationBrief.LinkInformation>`
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.RelationBriefs.RelationBrief, self).__init__()

                self.yang_name = "relation-brief"
                self.yang_parent_name = "relation-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"link-information" : ("link_information", Bfd.RelationBriefs.RelationBrief.LinkInformation)}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.state = YLeaf(YType.enumeration, "state")

                self.link_information = YList(self)
                self._segment_path = lambda: "relation-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/relation-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.RelationBriefs.RelationBrief, ['destination_address', 'interface_name', 'state'], name, value)


            class LinkInformation(Entity):
                """
                Brief Member Link Information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.RelationBriefs.RelationBrief.LinkInformation, self).__init__()

                    self.yang_name = "link-information"
                    self.yang_parent_name = "relation-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.state = YLeaf(YType.enumeration, "state")
                    self._segment_path = lambda: "link-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/relation-briefs/relation-brief/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.RelationBriefs.RelationBrief.LinkInformation, ['interface_name', 'state'], name, value)


    class RelationDetails(Entity):
        """
        Table of detail information about all BFD
        relations in the System
        
        .. attribute:: relation_detail
        
        	Detail information for relation of a single BFD session
        	**type**\: list of    :py:class:`RelationDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.RelationDetails.RelationDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.RelationDetails, self).__init__()

            self.yang_name = "relation-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"relation-detail" : ("relation_detail", Bfd.RelationDetails.RelationDetail)}

            self.relation_detail = YList(self)
            self._segment_path = lambda: "relation-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.RelationDetails, [], name, value)


        class RelationDetail(Entity):
            """
            Detail information for relation of a single BFD
            session
            
            .. attribute:: association_information
            
            	Association session information
            	**type**\: list of    :py:class:`AssociationInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.RelationDetails.RelationDetail.AssociationInformation>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\: one of the below types:
            
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            
            ----
            	**type**\:  str
            
            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
            
            
            ----
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: link_information
            
            	Detail Member Link Information
            	**type**\: list of    :py:class:`LinkInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.RelationDetails.RelationDetail.LinkInformation>`
            
            .. attribute:: local_discriminator
            
            	Session's Local discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.RelationDetails.RelationDetail, self).__init__()

                self.yang_name = "relation-detail"
                self.yang_parent_name = "relation-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {"association-information" : ("association_information", Bfd.RelationDetails.RelationDetail.AssociationInformation), "link-information" : ("link_information", Bfd.RelationDetails.RelationDetail.LinkInformation)}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                self.state = YLeaf(YType.enumeration, "state")

                self.association_information = YList(self)
                self.link_information = YList(self)
                self._segment_path = lambda: "relation-detail"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/relation-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.RelationDetails.RelationDetail, ['destination_address', 'interface_name', 'local_discriminator', 'state'], name, value)


            class AssociationInformation(Entity):
                """
                Association session information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: ip_destination_address
                
                	IPv4/v6 dest address
                	**type**\:   :py:class:`IpDestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.RelationDetails.RelationDetail.AssociationInformation.IpDestinationAddress>`
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: owner_information
                
                	Client applications owning the session
                	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.RelationDetails.RelationDetail.AssociationInformation.OwnerInformation>`
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.RelationDetails.RelationDetail.AssociationInformation, self).__init__()

                    self.yang_name = "association-information"
                    self.yang_parent_name = "relation-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"ip-destination-address" : ("ip_destination_address", Bfd.RelationDetails.RelationDetail.AssociationInformation.IpDestinationAddress)}
                    self._child_list_classes = {"owner-information" : ("owner_information", Bfd.RelationDetails.RelationDetail.AssociationInformation.OwnerInformation)}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.ip_destination_address = Bfd.RelationDetails.RelationDetail.AssociationInformation.IpDestinationAddress()
                    self.ip_destination_address.parent = self
                    self._children_name_map["ip_destination_address"] = "ip-destination-address"
                    self._children_yang_names.add("ip-destination-address")

                    self.owner_information = YList(self)
                    self._segment_path = lambda: "association-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/relation-details/relation-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.RelationDetails.RelationDetail.AssociationInformation, ['interface_name', 'local_discriminator', 'sessiontype'], name, value)


                class IpDestinationAddress(Entity):
                    """
                    IPv4/v6 dest address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.RelationDetails.RelationDetail.AssociationInformation.IpDestinationAddress, self).__init__()

                        self.yang_name = "ip-destination-address"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "ip-destination-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/relation-details/relation-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.RelationDetails.RelationDetail.AssociationInformation.IpDestinationAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class OwnerInformation(Entity):
                    """
                    Client applications owning the session
                    
                    .. attribute:: adjusted_detection_multiplier
                    
                    	Adjusted detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: adjusted_interval
                    
                    	Adjusted minimum transmit interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Client specified detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interval
                    
                    	Client specified minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: name
                    
                    	Client process name
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.RelationDetails.RelationDetail.AssociationInformation.OwnerInformation, self).__init__()

                        self.yang_name = "owner-information"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                        self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "owner-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/relation-details/relation-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.RelationDetails.RelationDetail.AssociationInformation.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class LinkInformation(Entity):
                """
                Detail Member Link Information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.RelationDetails.RelationDetail.LinkInformation, self).__init__()

                    self.yang_name = "link-information"
                    self.yang_parent_name = "relation-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.state = YLeaf(YType.enumeration, "state")
                    self._segment_path = lambda: "link-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/relation-details/relation-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.RelationDetails.RelationDetail.LinkInformation, ['interface_name', 'local_discriminator', 'state'], name, value)


    class SessionBriefs(Entity):
        """
        Table of brief information about singlehop IPv4
        BFD sessions in the System
        
        .. attribute:: session_brief
        
        	Brief information for a single IPv4 singlehop BFD session
        	**type**\: list of    :py:class:`SessionBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionBriefs.SessionBrief>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.SessionBriefs, self).__init__()

            self.yang_name = "session-briefs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"session-brief" : ("session_brief", Bfd.SessionBriefs.SessionBrief)}

            self.session_brief = YList(self)
            self._segment_path = lambda: "session-briefs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.SessionBriefs, [], name, value)


        class SessionBrief(Entity):
            """
            Brief information for a single IPv4 singlehop
            BFD session
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: node_id
            
            	Location where session is housed
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: session_flags
            
            	Session Flags
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_subtype
            
            	Session subtype
            	**type**\:  str
            
            .. attribute:: session_type
            
            	Session type
            	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
            
            .. attribute:: state
            
            	State
            	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
            
            .. attribute:: status_brief_information
            
            	Brief Status Information
            	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionBriefs.SessionBrief.StatusBriefInformation>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.SessionBriefs.SessionBrief, self).__init__()

                self.yang_name = "session-brief"
                self.yang_parent_name = "session-briefs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"status-brief-information" : ("status_brief_information", Bfd.SessionBriefs.SessionBrief.StatusBriefInformation)}
                self._child_list_classes = {}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.node_id = YLeaf(YType.str, "node-id")

                self.session_flags = YLeaf(YType.uint32, "session-flags")

                self.session_subtype = YLeaf(YType.str, "session-subtype")

                self.session_type = YLeaf(YType.enumeration, "session-type")

                self.state = YLeaf(YType.enumeration, "state")

                self.status_brief_information = Bfd.SessionBriefs.SessionBrief.StatusBriefInformation()
                self.status_brief_information.parent = self
                self._children_name_map["status_brief_information"] = "status-brief-information"
                self._children_yang_names.add("status-brief-information")
                self._segment_path = lambda: "session-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-briefs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.SessionBriefs.SessionBrief, ['destination_address', 'interface_name', 'location', 'node_id', 'session_flags', 'session_subtype', 'session_type', 'state'], name, value)


            class StatusBriefInformation(Entity):
                """
                Brief Status Information
                
                .. attribute:: async_interval_multiplier
                
                	Async Interval and Detect Multiplier Information
                	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.AsyncIntervalMultiplier>`
                
                .. attribute:: echo_interval_multiplier
                
                	Echo Interval and Detect Multiplier Information
                	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.EchoIntervalMultiplier>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.SessionBriefs.SessionBrief.StatusBriefInformation, self).__init__()

                    self.yang_name = "status-brief-information"
                    self.yang_parent_name = "session-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.EchoIntervalMultiplier)}
                    self._child_list_classes = {}

                    self.async_interval_multiplier = Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.AsyncIntervalMultiplier()
                    self.async_interval_multiplier.parent = self
                    self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                    self._children_yang_names.add("async-interval-multiplier")

                    self.echo_interval_multiplier = Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.EchoIntervalMultiplier()
                    self.echo_interval_multiplier.parent = self
                    self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                    self._children_yang_names.add("echo-interval-multiplier")
                    self._segment_path = lambda: "status-brief-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-briefs/session-brief/%s" % self._segment_path()


                class AsyncIntervalMultiplier(Entity):
                    """
                    Async Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_local_transmit_interval
                    
                    	Negotiated local transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_remote_transmit_interval
                    
                    	Negotiated remote transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                        self.yang_name = "async-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                        self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                        self._segment_path = lambda: "async-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-briefs/session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                class EchoIntervalMultiplier(Entity):
                    """
                    Echo Interval and Detect Multiplier Information
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: detection_time
                    
                    	Detection time in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: negotiated_transmit_interval
                    
                    	Negotiated transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                        self.yang_name = "echo-interval-multiplier"
                        self.yang_parent_name = "status-brief-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.detection_time = YLeaf(YType.uint32, "detection-time")

                        self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                        self._segment_path = lambda: "echo-interval-multiplier"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-briefs/session-brief/status-brief-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionBriefs.SessionBrief.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


    class SessionDetails(Entity):
        """
        Table of detailed information about IPv4
        singlehop BFD sessions in the System 
        
        .. attribute:: session_detail
        
        	Detailed information for a single IPv4 singlehop BFD session
        	**type**\: list of    :py:class:`SessionDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.SessionDetails, self).__init__()

            self.yang_name = "session-details"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"session-detail" : ("session_detail", Bfd.SessionDetails.SessionDetail)}

            self.session_detail = YList(self)
            self._segment_path = lambda: "session-details"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.SessionDetails, [], name, value)


        class SessionDetail(Entity):
            """
            Detailed information for a single IPv4
            singlehop BFD session
            
            .. attribute:: association_information
            
            	Association session information
            	**type**\: list of    :py:class:`AssociationInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.AssociationInformation>`
            
            .. attribute:: destination_address
            
            	Destination Address
            	**type**\:  str
            
            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
            
            .. attribute:: interface_name
            
            	Interface Name
            	**type**\:  str
            
            	**pattern:** [a\-zA\-Z0\-9./\-]+
            
            .. attribute:: location
            
            	Location
            	**type**\:  str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: lsp_ping_info
            
            	LSP Ping Info
            	**type**\:   :py:class:`LspPingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.LspPingInfo>`
            
            .. attribute:: mp_download_state
            
            	MP Dowload State
            	**type**\:   :py:class:`MpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.MpDownloadState>`
            
            .. attribute:: owner_information
            
            	Client applications owning the session
            	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.OwnerInformation>`
            
            .. attribute:: status_information
            
            	Session status information
            	**type**\:   :py:class:`StatusInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation>`
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.SessionDetails.SessionDetail, self).__init__()

                self.yang_name = "session-detail"
                self.yang_parent_name = "session-details"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"lsp-ping-info" : ("lsp_ping_info", Bfd.SessionDetails.SessionDetail.LspPingInfo), "mp-download-state" : ("mp_download_state", Bfd.SessionDetails.SessionDetail.MpDownloadState), "status-information" : ("status_information", Bfd.SessionDetails.SessionDetail.StatusInformation)}
                self._child_list_classes = {"association-information" : ("association_information", Bfd.SessionDetails.SessionDetail.AssociationInformation), "owner-information" : ("owner_information", Bfd.SessionDetails.SessionDetail.OwnerInformation)}

                self.destination_address = YLeaf(YType.str, "destination-address")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.location = YLeaf(YType.str, "location")

                self.lsp_ping_info = Bfd.SessionDetails.SessionDetail.LspPingInfo()
                self.lsp_ping_info.parent = self
                self._children_name_map["lsp_ping_info"] = "lsp-ping-info"
                self._children_yang_names.add("lsp-ping-info")

                self.mp_download_state = Bfd.SessionDetails.SessionDetail.MpDownloadState()
                self.mp_download_state.parent = self
                self._children_name_map["mp_download_state"] = "mp-download-state"
                self._children_yang_names.add("mp-download-state")

                self.status_information = Bfd.SessionDetails.SessionDetail.StatusInformation()
                self.status_information.parent = self
                self._children_name_map["status_information"] = "status-information"
                self._children_yang_names.add("status-information")

                self.association_information = YList(self)
                self.owner_information = YList(self)
                self._segment_path = lambda: "session-detail"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.SessionDetails.SessionDetail, ['destination_address', 'interface_name', 'location'], name, value)


            class AssociationInformation(Entity):
                """
                Association session information
                
                .. attribute:: interface_name
                
                	Session Interface Name
                	**type**\:  str
                
                	**length:** 0..64
                
                .. attribute:: ip_destination_address
                
                	IPv4/v6 dest address
                	**type**\:   :py:class:`IpDestinationAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.AssociationInformation.IpDestinationAddress>`
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: owner_information
                
                	Client applications owning the session
                	**type**\: list of    :py:class:`OwnerInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.AssociationInformation.OwnerInformation>`
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.SessionDetails.SessionDetail.AssociationInformation, self).__init__()

                    self.yang_name = "association-information"
                    self.yang_parent_name = "session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"ip-destination-address" : ("ip_destination_address", Bfd.SessionDetails.SessionDetail.AssociationInformation.IpDestinationAddress)}
                    self._child_list_classes = {"owner-information" : ("owner_information", Bfd.SessionDetails.SessionDetail.AssociationInformation.OwnerInformation)}

                    self.interface_name = YLeaf(YType.str, "interface-name")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.ip_destination_address = Bfd.SessionDetails.SessionDetail.AssociationInformation.IpDestinationAddress()
                    self.ip_destination_address.parent = self
                    self._children_name_map["ip_destination_address"] = "ip-destination-address"
                    self._children_yang_names.add("ip-destination-address")

                    self.owner_information = YList(self)
                    self._segment_path = lambda: "association-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.SessionDetails.SessionDetail.AssociationInformation, ['interface_name', 'local_discriminator', 'sessiontype'], name, value)


                class IpDestinationAddress(Entity):
                    """
                    IPv4/v6 dest address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.AssociationInformation.IpDestinationAddress, self).__init__()

                        self.yang_name = "ip-destination-address"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "ip-destination-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.AssociationInformation.IpDestinationAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class OwnerInformation(Entity):
                    """
                    Client applications owning the session
                    
                    .. attribute:: adjusted_detection_multiplier
                    
                    	Adjusted detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: adjusted_interval
                    
                    	Adjusted minimum transmit interval in milli\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Client specified detection multiplier to compute detection time
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interval
                    
                    	Client specified minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: name
                    
                    	Client process name
                    	**type**\:  str
                    
                    	**length:** 0..257
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.AssociationInformation.OwnerInformation, self).__init__()

                        self.yang_name = "owner-information"
                        self.yang_parent_name = "association-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                        self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.interval = YLeaf(YType.uint32, "interval")

                        self.name = YLeaf(YType.str, "name")
                        self._segment_path = lambda: "owner-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/association-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.AssociationInformation.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class LspPingInfo(Entity):
                """
                LSP Ping Info
                
                .. attribute:: lsp_ping_rx_count
                
                	LSP Ping numer of times received
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_code
                
                	LSP Ping Rx Last Code
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_discr
                
                	LSP Ping Rx last received discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_rx_last_output
                
                	LSP Ping Rx Last Output
                	**type**\:  str
                
                .. attribute:: lsp_ping_rx_last_subcode
                
                	LSP Ping Rx Last Subcode
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: lsp_ping_rx_last_time
                
                	LSP Ping last received time
                	**type**\:   :py:class:`LspPingRxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingRxLastTime>`
                
                .. attribute:: lsp_ping_tx_count
                
                	LSP Ping Tx count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_error_count
                
                	LSP Ping Tx error count
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: lsp_ping_tx_last_error_rc
                
                	LSP Ping Tx last error
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_error_time
                
                	LSP Ping last error time
                	**type**\:   :py:class:`LspPingTxLastErrorTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastErrorTime>`
                
                .. attribute:: lsp_ping_tx_last_rc
                
                	LSP Ping Tx last result
                	**type**\:  str
                
                .. attribute:: lsp_ping_tx_last_time
                
                	LSP Ping last sent time
                	**type**\:   :py:class:`LspPingTxLastTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastTime>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.SessionDetails.SessionDetail.LspPingInfo, self).__init__()

                    self.yang_name = "lsp-ping-info"
                    self.yang_parent_name = "session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"lsp-ping-rx-last-time" : ("lsp_ping_rx_last_time", Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingRxLastTime), "lsp-ping-tx-last-error-time" : ("lsp_ping_tx_last_error_time", Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastErrorTime), "lsp-ping-tx-last-time" : ("lsp_ping_tx_last_time", Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastTime)}
                    self._child_list_classes = {}

                    self.lsp_ping_rx_count = YLeaf(YType.uint32, "lsp-ping-rx-count")

                    self.lsp_ping_rx_last_code = YLeaf(YType.uint8, "lsp-ping-rx-last-code")

                    self.lsp_ping_rx_last_discr = YLeaf(YType.uint32, "lsp-ping-rx-last-discr")

                    self.lsp_ping_rx_last_output = YLeaf(YType.str, "lsp-ping-rx-last-output")

                    self.lsp_ping_rx_last_subcode = YLeaf(YType.uint8, "lsp-ping-rx-last-subcode")

                    self.lsp_ping_tx_count = YLeaf(YType.uint32, "lsp-ping-tx-count")

                    self.lsp_ping_tx_error_count = YLeaf(YType.uint32, "lsp-ping-tx-error-count")

                    self.lsp_ping_tx_last_error_rc = YLeaf(YType.str, "lsp-ping-tx-last-error-rc")

                    self.lsp_ping_tx_last_rc = YLeaf(YType.str, "lsp-ping-tx-last-rc")

                    self.lsp_ping_rx_last_time = Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingRxLastTime()
                    self.lsp_ping_rx_last_time.parent = self
                    self._children_name_map["lsp_ping_rx_last_time"] = "lsp-ping-rx-last-time"
                    self._children_yang_names.add("lsp-ping-rx-last-time")

                    self.lsp_ping_tx_last_error_time = Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastErrorTime()
                    self.lsp_ping_tx_last_error_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_error_time"] = "lsp-ping-tx-last-error-time"
                    self._children_yang_names.add("lsp-ping-tx-last-error-time")

                    self.lsp_ping_tx_last_time = Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastTime()
                    self.lsp_ping_tx_last_time.parent = self
                    self._children_name_map["lsp_ping_tx_last_time"] = "lsp-ping-tx-last-time"
                    self._children_yang_names.add("lsp-ping-tx-last-time")
                    self._segment_path = lambda: "lsp-ping-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.SessionDetails.SessionDetail.LspPingInfo, ['lsp_ping_rx_count', 'lsp_ping_rx_last_code', 'lsp_ping_rx_last_discr', 'lsp_ping_rx_last_output', 'lsp_ping_rx_last_subcode', 'lsp_ping_tx_count', 'lsp_ping_tx_error_count', 'lsp_ping_tx_last_error_rc', 'lsp_ping_tx_last_rc'], name, value)


                class LspPingRxLastTime(Entity):
                    """
                    LSP Ping last received time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingRxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-rx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-rx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingRxLastTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastErrorTime(Entity):
                    """
                    LSP Ping last error time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastErrorTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-error-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-error-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastErrorTime, ['nanoseconds', 'seconds'], name, value)


                class LspPingTxLastTime(Entity):
                    """
                    LSP Ping last sent time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastTime, self).__init__()

                        self.yang_name = "lsp-ping-tx-last-time"
                        self.yang_parent_name = "lsp-ping-info"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "lsp-ping-tx-last-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/lsp-ping-info/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.LspPingInfo.LspPingTxLastTime, ['nanoseconds', 'seconds'], name, value)


            class MpDownloadState(Entity):
                """
                MP Dowload State
                
                .. attribute:: change_time
                
                	Change time
                	**type**\:   :py:class:`ChangeTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.MpDownloadState.ChangeTime>`
                
                .. attribute:: mp_download_state
                
                	MP Download State
                	**type**\:   :py:class:`BfdMpDownloadState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMpDownloadState>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.SessionDetails.SessionDetail.MpDownloadState, self).__init__()

                    self.yang_name = "mp-download-state"
                    self.yang_parent_name = "session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"change-time" : ("change_time", Bfd.SessionDetails.SessionDetail.MpDownloadState.ChangeTime)}
                    self._child_list_classes = {}

                    self.mp_download_state = YLeaf(YType.enumeration, "mp-download-state")

                    self.change_time = Bfd.SessionDetails.SessionDetail.MpDownloadState.ChangeTime()
                    self.change_time.parent = self
                    self._children_name_map["change_time"] = "change-time"
                    self._children_yang_names.add("change-time")
                    self._segment_path = lambda: "mp-download-state"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.SessionDetails.SessionDetail.MpDownloadState, ['mp_download_state'], name, value)


                class ChangeTime(Entity):
                    """
                    Change time
                    
                    .. attribute:: nanoseconds
                    
                    	nanoseconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: nanosecond
                    
                    .. attribute:: seconds
                    
                    	seconds
                    	**type**\:  int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.MpDownloadState.ChangeTime, self).__init__()

                        self.yang_name = "change-time"
                        self.yang_parent_name = "mp-download-state"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.nanoseconds = YLeaf(YType.uint32, "nanoseconds")

                        self.seconds = YLeaf(YType.uint64, "seconds")
                        self._segment_path = lambda: "change-time"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/mp-download-state/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.MpDownloadState.ChangeTime, ['nanoseconds', 'seconds'], name, value)


            class OwnerInformation(Entity):
                """
                Client applications owning the session
                
                .. attribute:: adjusted_detection_multiplier
                
                	Adjusted detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: adjusted_interval
                
                	Adjusted minimum transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: detection_multiplier
                
                	Client specified detection multiplier to compute detection time
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: interval
                
                	Client specified minimum transmit interval in micro\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: name
                
                	Client process name
                	**type**\:  str
                
                	**length:** 0..257
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.SessionDetails.SessionDetail.OwnerInformation, self).__init__()

                    self.yang_name = "owner-information"
                    self.yang_parent_name = "session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.adjusted_detection_multiplier = YLeaf(YType.uint32, "adjusted-detection-multiplier")

                    self.adjusted_interval = YLeaf(YType.uint32, "adjusted-interval")

                    self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                    self.interval = YLeaf(YType.uint32, "interval")

                    self.name = YLeaf(YType.str, "name")
                    self._segment_path = lambda: "owner-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.SessionDetails.SessionDetail.OwnerInformation, ['adjusted_detection_multiplier', 'adjusted_interval', 'detection_multiplier', 'interval', 'name'], name, value)


            class StatusInformation(Entity):
                """
                Session status information
                
                .. attribute:: async_receive_statistics
                
                	Statistics of Interval between Async Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`AsyncReceiveStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncReceiveStatistics>`
                
                .. attribute:: async_transmit_statistics
                
                	Statistics of Interval between Async Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`AsyncTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncTransmitStatistics>`
                
                .. attribute:: desired_minimum_echo_transmit_interval
                
                	Desired minimum echo transmit interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: echo_received_statistics
                
                	Statistics of Interval between Echo Packets Received (in milli\-seconds)
                	**type**\:   :py:class:`EchoReceivedStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.EchoReceivedStatistics>`
                
                .. attribute:: echo_transmit_statistics
                
                	Statistics of Interval between Echo Packets Transmitted (in milli\-seconds)
                	**type**\:   :py:class:`EchoTransmitStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.EchoTransmitStatistics>`
                
                .. attribute:: internal_label
                
                	Internal Label
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: last_state_change
                
                	Time since last state change
                	**type**\:   :py:class:`LastStateChange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.LastStateChange>`
                
                .. attribute:: latency_average
                
                	Average value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_maximum
                
                	Maximum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_minimum
                
                	Minimum value of Latency (in micro\-seconds)
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: microsecond
                
                .. attribute:: latency_number
                
                	Number of Latency Samples. Time between Transmit and Receive
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: local_discriminator
                
                	Session's Local discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: node_id
                
                	Location where session is housed
                	**type**\:  str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                .. attribute:: receive_packet
                
                	Receive Packet
                	**type**\:   :py:class:`ReceivePacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.ReceivePacket>`
                
                .. attribute:: remote_discriminator
                
                	Session's Remote discriminator
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: remote_negotiated_interval
                
                	Remote Negotiated Interval in milli\-seconds
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                	**units**\: millisecond
                
                .. attribute:: session_subtype
                
                	Session subtype
                	**type**\:  str
                
                .. attribute:: sessiontype
                
                	Session type
                	**type**\:   :py:class:`BfdSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdSession>`
                
                .. attribute:: source_address
                
                	Source address
                	**type**\:   :py:class:`SourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.SourceAddress>`
                
                .. attribute:: state
                
                	State
                	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                
                .. attribute:: status_brief_information
                
                	Brief Status Information
                	**type**\:   :py:class:`StatusBriefInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation>`
                
                .. attribute:: to_up_state_count
                
                	Number of times session state went to UP
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: transmit_packet
                
                	Transmit Packet
                	**type**\:   :py:class:`TransmitPacket <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.TransmitPacket>`
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.SessionDetails.SessionDetail.StatusInformation, self).__init__()

                    self.yang_name = "status-information"
                    self.yang_parent_name = "session-detail"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self._child_container_classes = {"async-receive-statistics" : ("async_receive_statistics", Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncReceiveStatistics), "async-transmit-statistics" : ("async_transmit_statistics", Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncTransmitStatistics), "echo-received-statistics" : ("echo_received_statistics", Bfd.SessionDetails.SessionDetail.StatusInformation.EchoReceivedStatistics), "echo-transmit-statistics" : ("echo_transmit_statistics", Bfd.SessionDetails.SessionDetail.StatusInformation.EchoTransmitStatistics), "last-state-change" : ("last_state_change", Bfd.SessionDetails.SessionDetail.StatusInformation.LastStateChange), "receive-packet" : ("receive_packet", Bfd.SessionDetails.SessionDetail.StatusInformation.ReceivePacket), "source-address" : ("source_address", Bfd.SessionDetails.SessionDetail.StatusInformation.SourceAddress), "status-brief-information" : ("status_brief_information", Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation), "transmit-packet" : ("transmit_packet", Bfd.SessionDetails.SessionDetail.StatusInformation.TransmitPacket)}
                    self._child_list_classes = {}

                    self.desired_minimum_echo_transmit_interval = YLeaf(YType.uint32, "desired-minimum-echo-transmit-interval")

                    self.internal_label = YLeaf(YType.uint32, "internal-label")

                    self.latency_average = YLeaf(YType.uint32, "latency-average")

                    self.latency_maximum = YLeaf(YType.uint32, "latency-maximum")

                    self.latency_minimum = YLeaf(YType.uint32, "latency-minimum")

                    self.latency_number = YLeaf(YType.uint32, "latency-number")

                    self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                    self.node_id = YLeaf(YType.str, "node-id")

                    self.remote_discriminator = YLeaf(YType.uint32, "remote-discriminator")

                    self.remote_negotiated_interval = YLeaf(YType.uint32, "remote-negotiated-interval")

                    self.session_subtype = YLeaf(YType.str, "session-subtype")

                    self.sessiontype = YLeaf(YType.enumeration, "sessiontype")

                    self.state = YLeaf(YType.enumeration, "state")

                    self.to_up_state_count = YLeaf(YType.uint32, "to-up-state-count")

                    self.async_receive_statistics = Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncReceiveStatistics()
                    self.async_receive_statistics.parent = self
                    self._children_name_map["async_receive_statistics"] = "async-receive-statistics"
                    self._children_yang_names.add("async-receive-statistics")

                    self.async_transmit_statistics = Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncTransmitStatistics()
                    self.async_transmit_statistics.parent = self
                    self._children_name_map["async_transmit_statistics"] = "async-transmit-statistics"
                    self._children_yang_names.add("async-transmit-statistics")

                    self.echo_received_statistics = Bfd.SessionDetails.SessionDetail.StatusInformation.EchoReceivedStatistics()
                    self.echo_received_statistics.parent = self
                    self._children_name_map["echo_received_statistics"] = "echo-received-statistics"
                    self._children_yang_names.add("echo-received-statistics")

                    self.echo_transmit_statistics = Bfd.SessionDetails.SessionDetail.StatusInformation.EchoTransmitStatistics()
                    self.echo_transmit_statistics.parent = self
                    self._children_name_map["echo_transmit_statistics"] = "echo-transmit-statistics"
                    self._children_yang_names.add("echo-transmit-statistics")

                    self.last_state_change = Bfd.SessionDetails.SessionDetail.StatusInformation.LastStateChange()
                    self.last_state_change.parent = self
                    self._children_name_map["last_state_change"] = "last-state-change"
                    self._children_yang_names.add("last-state-change")

                    self.receive_packet = Bfd.SessionDetails.SessionDetail.StatusInformation.ReceivePacket()
                    self.receive_packet.parent = self
                    self._children_name_map["receive_packet"] = "receive-packet"
                    self._children_yang_names.add("receive-packet")

                    self.source_address = Bfd.SessionDetails.SessionDetail.StatusInformation.SourceAddress()
                    self.source_address.parent = self
                    self._children_name_map["source_address"] = "source-address"
                    self._children_yang_names.add("source-address")

                    self.status_brief_information = Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation()
                    self.status_brief_information.parent = self
                    self._children_name_map["status_brief_information"] = "status-brief-information"
                    self._children_yang_names.add("status-brief-information")

                    self.transmit_packet = Bfd.SessionDetails.SessionDetail.StatusInformation.TransmitPacket()
                    self.transmit_packet.parent = self
                    self._children_name_map["transmit_packet"] = "transmit-packet"
                    self._children_yang_names.add("transmit-packet")
                    self._segment_path = lambda: "status-information"
                    self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation, ['desired_minimum_echo_transmit_interval', 'internal_label', 'latency_average', 'latency_maximum', 'latency_minimum', 'latency_number', 'local_discriminator', 'node_id', 'remote_discriminator', 'remote_negotiated_interval', 'session_subtype', 'sessiontype', 'state', 'to_up_state_count'], name, value)


                class AsyncReceiveStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncReceiveStatistics, self).__init__()

                        self.yang_name = "async-receive-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-receive-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncReceiveStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class AsyncTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Async Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncTransmitStatistics, self).__init__()

                        self.yang_name = "async-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "async-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.AsyncTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoReceivedStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Received (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.StatusInformation.EchoReceivedStatistics, self).__init__()

                        self.yang_name = "echo-received-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-received-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.EchoReceivedStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class EchoTransmitStatistics(Entity):
                    """
                    Statistics of Interval between Echo Packets
                    Transmitted (in milli\-seconds)
                    
                    .. attribute:: average
                    
                    	Average of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: last
                    
                    	Time since last Transmit/Receive (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: maximum
                    
                    	Maximum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: minimum
                    
                    	Minimum of Transmit/Receive Interval (in milli\-seconds)
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: millisecond
                    
                    .. attribute:: number
                    
                    	Number of Interval Samples between Packets sent/received
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.StatusInformation.EchoTransmitStatistics, self).__init__()

                        self.yang_name = "echo-transmit-statistics"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.average = YLeaf(YType.uint32, "average")

                        self.last = YLeaf(YType.uint32, "last")

                        self.maximum = YLeaf(YType.uint32, "maximum")

                        self.minimum = YLeaf(YType.uint32, "minimum")

                        self.number = YLeaf(YType.uint32, "number")
                        self._segment_path = lambda: "echo-transmit-statistics"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.EchoTransmitStatistics, ['average', 'last', 'maximum', 'minimum', 'number'], name, value)


                class LastStateChange(Entity):
                    """
                    Time since last state change
                    
                    .. attribute:: days
                    
                    	Number of days since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: day
                    
                    .. attribute:: hours
                    
                    	Number of hours since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: hour
                    
                    .. attribute:: minutes
                    
                    	Number of mins since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: minute
                    
                    .. attribute:: seconds
                    
                    	Number of seconds since last session state transition
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.StatusInformation.LastStateChange, self).__init__()

                        self.yang_name = "last-state-change"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.days = YLeaf(YType.uint32, "days")

                        self.hours = YLeaf(YType.uint8, "hours")

                        self.minutes = YLeaf(YType.uint8, "minutes")

                        self.seconds = YLeaf(YType.uint8, "seconds")
                        self._segment_path = lambda: "last-state-change"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.LastStateChange, ['days', 'hours', 'minutes', 'seconds'], name, value)


                class ReceivePacket(Entity):
                    """
                    Receive Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.StatusInformation.ReceivePacket, self).__init__()

                        self.yang_name = "receive-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "receive-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.ReceivePacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


                class SourceAddress(Entity):
                    """
                    Source address
                    
                    .. attribute:: afi
                    
                    	AFI
                    	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                    
                    .. attribute:: dummy
                    
                    	No Address
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: ipv4
                    
                    	IPv4 address type
                    	**type**\:  str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: ipv6
                    
                    	IPv6 address type
                    	**type**\:  str
                    
                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.StatusInformation.SourceAddress, self).__init__()

                        self.yang_name = "source-address"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.afi = YLeaf(YType.enumeration, "afi")

                        self.dummy = YLeaf(YType.uint8, "dummy")

                        self.ipv4 = YLeaf(YType.str, "ipv4")

                        self.ipv6 = YLeaf(YType.str, "ipv6")
                        self._segment_path = lambda: "source-address"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.SourceAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


                class StatusBriefInformation(Entity):
                    """
                    Brief Status Information
                    
                    .. attribute:: async_interval_multiplier
                    
                    	Async Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`AsyncIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier>`
                    
                    .. attribute:: echo_interval_multiplier
                    
                    	Echo Interval and Detect Multiplier Information
                    	**type**\:   :py:class:`EchoIntervalMultiplier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier>`
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation, self).__init__()

                        self.yang_name = "status-brief-information"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {"async-interval-multiplier" : ("async_interval_multiplier", Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier), "echo-interval-multiplier" : ("echo_interval_multiplier", Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier)}
                        self._child_list_classes = {}

                        self.async_interval_multiplier = Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier()
                        self.async_interval_multiplier.parent = self
                        self._children_name_map["async_interval_multiplier"] = "async-interval-multiplier"
                        self._children_yang_names.add("async-interval-multiplier")

                        self.echo_interval_multiplier = Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier()
                        self.echo_interval_multiplier.parent = self
                        self._children_name_map["echo_interval_multiplier"] = "echo-interval-multiplier"
                        self._children_yang_names.add("echo-interval-multiplier")
                        self._segment_path = lambda: "status-brief-information"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/%s" % self._segment_path()


                    class AsyncIntervalMultiplier(Entity):
                        """
                        Async Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_local_transmit_interval
                        
                        	Negotiated local transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_remote_transmit_interval
                        
                        	Negotiated remote transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, self).__init__()

                            self.yang_name = "async-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_local_transmit_interval = YLeaf(YType.uint32, "negotiated-local-transmit-interval")

                            self.negotiated_remote_transmit_interval = YLeaf(YType.uint32, "negotiated-remote-transmit-interval")
                            self._segment_path = lambda: "async-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.AsyncIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_local_transmit_interval', 'negotiated_remote_transmit_interval'], name, value)


                    class EchoIntervalMultiplier(Entity):
                        """
                        Echo Interval and Detect Multiplier Information
                        
                        .. attribute:: detection_multiplier
                        
                        	Detection Multiplier
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: detection_time
                        
                        	Detection time in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        .. attribute:: negotiated_transmit_interval
                        
                        	Negotiated transmit interval in micro\-seconds
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: microsecond
                        
                        

                        """

                        _prefix = 'ip-bfd-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, self).__init__()

                            self.yang_name = "echo-interval-multiplier"
                            self.yang_parent_name = "status-brief-information"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                            self.detection_time = YLeaf(YType.uint32, "detection-time")

                            self.negotiated_transmit_interval = YLeaf(YType.uint32, "negotiated-transmit-interval")
                            self._segment_path = lambda: "echo-interval-multiplier"
                            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/status-brief-information/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.StatusBriefInformation.EchoIntervalMultiplier, ['detection_multiplier', 'detection_time', 'negotiated_transmit_interval'], name, value)


                class TransmitPacket(Entity):
                    """
                    Transmit Packet
                    
                    .. attribute:: authentication_present
                    
                    	Requesting authentication for the session
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: control_plane_independent
                    
                    	BFD implementation does not share fate with its control plane
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: demand
                    
                    	Demand mode
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: desired_minimum_transmit_interval
                    
                    	Desired minimum transmit interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: detection_multiplier
                    
                    	Detection Multiplier
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: diagnostic
                    
                    	Diagnostic
                    	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
                    
                    .. attribute:: final
                    
                    	Final bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: ihear_you
                    
                    	I Hear You (v0)
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: length
                    
                    	Length
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: my_discriminator
                    
                    	My Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: poll
                    
                    	Poll bit
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: required_minimum_echo_receive_interval
                    
                    	Required echo receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: required_minimum_receive_interval
                    
                    	Required receive interval in micro\-seconds
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: microsecond
                    
                    .. attribute:: state
                    
                    	State (v1)
                    	**type**\:   :py:class:`BfdMgmtSessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionState>`
                    
                    .. attribute:: version
                    
                    	Version
                    	**type**\:  int
                    
                    	**range:** 0..255
                    
                    .. attribute:: your_discriminator
                    
                    	Your Discriminator
                    	**type**\:  int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'ip-bfd-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Bfd.SessionDetails.SessionDetail.StatusInformation.TransmitPacket, self).__init__()

                        self.yang_name = "transmit-packet"
                        self.yang_parent_name = "status-information"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self._child_container_classes = {}
                        self._child_list_classes = {}

                        self.authentication_present = YLeaf(YType.int32, "authentication-present")

                        self.control_plane_independent = YLeaf(YType.int32, "control-plane-independent")

                        self.demand = YLeaf(YType.int32, "demand")

                        self.desired_minimum_transmit_interval = YLeaf(YType.uint32, "desired-minimum-transmit-interval")

                        self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                        self.diagnostic = YLeaf(YType.enumeration, "diagnostic")

                        self.final = YLeaf(YType.int32, "final")

                        self.ihear_you = YLeaf(YType.int32, "ihear-you")

                        self.length = YLeaf(YType.uint32, "length")

                        self.my_discriminator = YLeaf(YType.uint32, "my-discriminator")

                        self.poll = YLeaf(YType.int32, "poll")

                        self.required_minimum_echo_receive_interval = YLeaf(YType.uint32, "required-minimum-echo-receive-interval")

                        self.required_minimum_receive_interval = YLeaf(YType.uint32, "required-minimum-receive-interval")

                        self.state = YLeaf(YType.enumeration, "state")

                        self.version = YLeaf(YType.uint8, "version")

                        self.your_discriminator = YLeaf(YType.uint32, "your-discriminator")
                        self._segment_path = lambda: "transmit-packet"
                        self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-details/session-detail/status-information/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(Bfd.SessionDetails.SessionDetail.StatusInformation.TransmitPacket, ['authentication_present', 'control_plane_independent', 'demand', 'desired_minimum_transmit_interval', 'detection_multiplier', 'diagnostic', 'final', 'ihear_you', 'length', 'my_discriminator', 'poll', 'required_minimum_echo_receive_interval', 'required_minimum_receive_interval', 'state', 'version', 'your_discriminator'], name, value)


    class SessionMibs(Entity):
        """
        BFD session MIB database
        
        .. attribute:: session_mib
        
        	Brief information for BFD session MIB
        	**type**\: list of    :py:class:`SessionMib <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionMibs.SessionMib>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.SessionMibs, self).__init__()

            self.yang_name = "session-mibs"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"session-mib" : ("session_mib", Bfd.SessionMibs.SessionMib)}

            self.session_mib = YList(self)
            self._segment_path = lambda: "session-mibs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Bfd.SessionMibs, [], name, value)


        class SessionMib(Entity):
            """
            Brief information for BFD session MIB
            
            .. attribute:: discriminator  <key>
            
            	Sesison Discr 
            	**type**\:  int
            
            	**range:** \-2147483648..2147483647
            
            .. attribute:: desired_min_tx_interval
            
            	Desired Min TX Interval
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: dest_address
            
            	Session Destination address
            	**type**\:   :py:class:`DestAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.SessionMibs.SessionMib.DestAddress>`
            
            .. attribute:: detection_multiplier
            
            	Detection Multiplier
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: int_handle
            
            	Session Interface Handle
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: interface_name
            
            	Session Interface Name
            	**type**\:  str
            
            	**length:** 0..64
            
            .. attribute:: last_down_diag
            
            	Last Session Down Diag
            	**type**\:   :py:class:`BfdMgmtSessionDiag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdMgmtSessionDiag>`
            
            .. attribute:: last_down_time_nsec
            
            	Last Session Down Time (nanoseconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: nanosecond
            
            .. attribute:: last_down_time_sec
            
            	Last Session Down Time (seconds)
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            	**units**\: second
            
            .. attribute:: last_time_cached
            
            	Last Time Session Info Queried
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: last_up_time_nsec
            
            	Last Session Up Time (nanoseconds)
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            	**units**\: nanosecond
            
            .. attribute:: last_up_time_sec
            
            	Last Session Up Time (seconds)
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            	**units**\: second
            
            .. attribute:: local_discriminator
            
            	Sessions' Local Discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: pkt_in
            
            	Packet In Counter
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: pkt_out
            
            	Packet Out Counter
            	**type**\:  int
            
            	**range:** 0..18446744073709551615
            
            .. attribute:: remote_discriminator
            
            	Sessions' Remote Discriminator
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: required_min_rx_echo_interval
            
            	Required Min RX Echo Interval
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: required_min_rx_interval
            
            	Required Min RX Interval
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: session_state
            
            	Session State
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: sessionversion
            
            	Session BFD Version
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: trap_bitmap
            
            	Trap Generator Bitmap
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_counter
            
            	Up Count
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.SessionMibs.SessionMib, self).__init__()

                self.yang_name = "session-mib"
                self.yang_parent_name = "session-mibs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"dest-address" : ("dest_address", Bfd.SessionMibs.SessionMib.DestAddress)}
                self._child_list_classes = {}

                self.discriminator = YLeaf(YType.int32, "discriminator")

                self.desired_min_tx_interval = YLeaf(YType.uint32, "desired-min-tx-interval")

                self.detection_multiplier = YLeaf(YType.uint32, "detection-multiplier")

                self.int_handle = YLeaf(YType.uint32, "int-handle")

                self.interface_name = YLeaf(YType.str, "interface-name")

                self.last_down_diag = YLeaf(YType.enumeration, "last-down-diag")

                self.last_down_time_nsec = YLeaf(YType.uint32, "last-down-time-nsec")

                self.last_down_time_sec = YLeaf(YType.uint64, "last-down-time-sec")

                self.last_time_cached = YLeaf(YType.uint64, "last-time-cached")

                self.last_up_time_nsec = YLeaf(YType.uint32, "last-up-time-nsec")

                self.last_up_time_sec = YLeaf(YType.uint64, "last-up-time-sec")

                self.local_discriminator = YLeaf(YType.uint32, "local-discriminator")

                self.pkt_in = YLeaf(YType.uint64, "pkt-in")

                self.pkt_out = YLeaf(YType.uint64, "pkt-out")

                self.remote_discriminator = YLeaf(YType.uint32, "remote-discriminator")

                self.required_min_rx_echo_interval = YLeaf(YType.uint32, "required-min-rx-echo-interval")

                self.required_min_rx_interval = YLeaf(YType.uint32, "required-min-rx-interval")

                self.session_state = YLeaf(YType.uint32, "session-state")

                self.sessionversion = YLeaf(YType.uint32, "sessionversion")

                self.trap_bitmap = YLeaf(YType.uint32, "trap-bitmap")

                self.up_counter = YLeaf(YType.uint32, "up-counter")

                self.dest_address = Bfd.SessionMibs.SessionMib.DestAddress()
                self.dest_address.parent = self
                self._children_name_map["dest_address"] = "dest-address"
                self._children_yang_names.add("dest-address")
                self._segment_path = lambda: "session-mib" + "[discriminator='" + self.discriminator.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/session-mibs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.SessionMibs.SessionMib, ['discriminator', 'desired_min_tx_interval', 'detection_multiplier', 'int_handle', 'interface_name', 'last_down_diag', 'last_down_time_nsec', 'last_down_time_sec', 'last_time_cached', 'last_up_time_nsec', 'last_up_time_sec', 'local_discriminator', 'pkt_in', 'pkt_out', 'remote_discriminator', 'required_min_rx_echo_interval', 'required_min_rx_interval', 'session_state', 'sessionversion', 'trap_bitmap', 'up_counter'], name, value)


            class DestAddress(Entity):
                """
                Session Destination address
                
                .. attribute:: afi
                
                	AFI
                	**type**\:   :py:class:`BfdAfId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.BfdAfId>`
                
                .. attribute:: dummy
                
                	No Address
                	**type**\:  int
                
                	**range:** 0..255
                
                .. attribute:: ipv4
                
                	IPv4 address type
                	**type**\:  str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: ipv6
                
                	IPv6 address type
                	**type**\:  str
                
                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                
                

                """

                _prefix = 'ip-bfd-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Bfd.SessionMibs.SessionMib.DestAddress, self).__init__()

                    self.yang_name = "dest-address"
                    self.yang_parent_name = "session-mib"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.afi = YLeaf(YType.enumeration, "afi")

                    self.dummy = YLeaf(YType.uint8, "dummy")

                    self.ipv4 = YLeaf(YType.str, "ipv4")

                    self.ipv6 = YLeaf(YType.str, "ipv6")
                    self._segment_path = lambda: "dest-address"

                def __setattr__(self, name, value):
                    self._perform_setattr(Bfd.SessionMibs.SessionMib.DestAddress, ['afi', 'dummy', 'ipv4', 'ipv6'], name, value)


    class Summary(Entity):
        """
        Summary information of BFD IPv4 singlehop
        sessions
        
        .. attribute:: session_state
        
        	Statistics of states for sessions
        	**type**\:   :py:class:`SessionState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_bfd_oper.Bfd.Summary.SessionState>`
        
        

        """

        _prefix = 'ip-bfd-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Bfd.Summary, self).__init__()

            self.yang_name = "summary"
            self.yang_parent_name = "bfd"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {"session-state" : ("session_state", Bfd.Summary.SessionState)}
            self._child_list_classes = {}

            self.session_state = Bfd.Summary.SessionState()
            self.session_state.parent = self
            self._children_name_map["session_state"] = "session-state"
            self._children_yang_names.add("session-state")
            self._segment_path = lambda: "summary"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/%s" % self._segment_path()


        class SessionState(Entity):
            """
            Statistics of states for sessions
            
            .. attribute:: down_count
            
            	Number of sessions in down state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: total_count
            
            	Number of sessions in database
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: unknown_count
            
            	Number of sessions in unknown state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            .. attribute:: up_count
            
            	Number of sessions in up state
            	**type**\:  int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'ip-bfd-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Bfd.Summary.SessionState, self).__init__()

                self.yang_name = "session-state"
                self.yang_parent_name = "summary"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {}
                self._child_list_classes = {}

                self.down_count = YLeaf(YType.uint32, "down-count")

                self.total_count = YLeaf(YType.uint32, "total-count")

                self.unknown_count = YLeaf(YType.uint32, "unknown-count")

                self.up_count = YLeaf(YType.uint32, "up-count")
                self._segment_path = lambda: "session-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-bfd-oper:bfd/summary/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Bfd.Summary.SessionState, ['down_count', 'total_count', 'unknown_count', 'up_count'], name, value)

    def clone_ptr(self):
        self._top_entity = Bfd()
        return self._top_entity

