""" Cisco_IOS_XR_ip_rib_ipv4_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR ip\-rib\-ipv4 package operational data.

This module contains definitions
for the following management objects\:
  rib\-stdby\: RIB standby node operational data
  rib\: rib

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YPYError, YPYModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error



class Rib(Entity):
    """
    rib
    
    .. attribute:: rib_table_ids
    
    	RIB table
    	**type**\:   :py:class:`RibTableIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds>`
    
    .. attribute:: vrfs
    
    	VRF table
    	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs>`
    
    

    """

    _prefix = 'ip-rib-ipv4-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(Rib, self).__init__()
        self._top_entity = None

        self.yang_name = "rib"
        self.yang_parent_name = "Cisco-IOS-XR-ip-rib-ipv4-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"rib-table-ids" : ("rib_table_ids", Rib.RibTableIds), "vrfs" : ("vrfs", Rib.Vrfs)}
        self._child_list_classes = {}

        self.rib_table_ids = Rib.RibTableIds()
        self.rib_table_ids.parent = self
        self._children_name_map["rib_table_ids"] = "rib-table-ids"
        self._children_yang_names.add("rib-table-ids")

        self.vrfs = Rib.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"
        self._children_yang_names.add("vrfs")
        self._segment_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib"


    class RibTableIds(Entity):
        """
        RIB table
        
        .. attribute:: rib_table_id
        
        	Specific Table
        	**type**\: list of    :py:class:`RibTableId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId>`
        
        

        """

        _prefix = 'ip-rib-ipv4-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rib.RibTableIds, self).__init__()

            self.yang_name = "rib-table-ids"
            self.yang_parent_name = "rib"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"rib-table-id" : ("rib_table_id", Rib.RibTableIds.RibTableId)}

            self.rib_table_id = YList(self)
            self._segment_path = lambda: "rib-table-ids"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Rib.RibTableIds, [], name, value)


        class RibTableId(Entity):
            """
            Specific Table
            
            .. attribute:: tableid  <key>
            
            	Table ID
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: information
            
            	Table related Information
            	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.Information>`
            
            .. attribute:: rib_table_itf_hndls
            
            	RIB table interface
            	**type**\:   :py:class:`RibTableItfHndls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.RibTableItfHndls>`
            
            .. attribute:: summary_protos
            
            	RIB table summary
            	**type**\:   :py:class:`SummaryProtos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos>`
            
            

            """

            _prefix = 'ip-rib-ipv4-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rib.RibTableIds.RibTableId, self).__init__()

                self.yang_name = "rib-table-id"
                self.yang_parent_name = "rib-table-ids"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"information" : ("information", Rib.RibTableIds.RibTableId.Information), "rib-table-itf-hndls" : ("rib_table_itf_hndls", Rib.RibTableIds.RibTableId.RibTableItfHndls), "summary-protos" : ("summary_protos", Rib.RibTableIds.RibTableId.SummaryProtos)}
                self._child_list_classes = {}

                self.tableid = YLeaf(YType.str, "tableid")

                self.information = Rib.RibTableIds.RibTableId.Information()
                self.information.parent = self
                self._children_name_map["information"] = "information"
                self._children_yang_names.add("information")

                self.rib_table_itf_hndls = Rib.RibTableIds.RibTableId.RibTableItfHndls()
                self.rib_table_itf_hndls.parent = self
                self._children_name_map["rib_table_itf_hndls"] = "rib-table-itf-hndls"
                self._children_yang_names.add("rib-table-itf-hndls")

                self.summary_protos = Rib.RibTableIds.RibTableId.SummaryProtos()
                self.summary_protos.parent = self
                self._children_name_map["summary_protos"] = "summary-protos"
                self._children_yang_names.add("summary-protos")
                self._segment_path = lambda: "rib-table-id" + "[tableid='" + self.tableid.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib/rib-table-ids/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Rib.RibTableIds.RibTableId, ['tableid'], name, value)


            class Information(Entity):
                """
                Table related Information
                
                .. attribute:: afi
                
                	Address Family
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: conf_prefix_limit
                
                	Configured prefix limit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: current_prefix_count
                
                	Num prefixes in table
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: deleted
                
                	Table deleted?
                	**type**\:  bool
                
                .. attribute:: fwd_referenced
                
                	Table in fwd reference state?
                	**type**\:  bool
                
                .. attribute:: initial_converge
                
                	Table has reached convergence
                	**type**\:  bool
                
                .. attribute:: num_svdlcl_prefix
                
                	Num SVD local prefixes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_svdrem_prefix
                
                	Num SVD remote prefixes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_limit_notified
                
                	Prefix limit state indicator
                	**type**\:  bool
                
                .. attribute:: safi
                
                	sub Address Family
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_name
                
                	Name of the table
                	**type**\:  str
                
                .. attribute:: table_version
                
                	Version no. of the table
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: tableid
                
                	Table id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: version
                
                	Table version
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: vrf_name
                
                	VRF Name of the table
                	**type**\:  str
                
                

                """

                _prefix = 'ip-rib-ipv4-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rib.RibTableIds.RibTableId.Information, self).__init__()

                    self.yang_name = "information"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.afi = YLeaf(YType.uint32, "afi")

                    self.conf_prefix_limit = YLeaf(YType.uint32, "conf-prefix-limit")

                    self.current_prefix_count = YLeaf(YType.uint32, "current-prefix-count")

                    self.deleted = YLeaf(YType.boolean, "deleted")

                    self.fwd_referenced = YLeaf(YType.boolean, "fwd-referenced")

                    self.initial_converge = YLeaf(YType.boolean, "initial-converge")

                    self.num_svdlcl_prefix = YLeaf(YType.uint32, "num-svdlcl-prefix")

                    self.num_svdrem_prefix = YLeaf(YType.uint32, "num-svdrem-prefix")

                    self.prefix_limit_notified = YLeaf(YType.boolean, "prefix-limit-notified")

                    self.safi = YLeaf(YType.uint32, "safi")

                    self.table_name = YLeaf(YType.str, "table-name")

                    self.table_version = YLeaf(YType.uint64, "table-version")

                    self.tableid = YLeaf(YType.uint32, "tableid")

                    self.version = YLeaf(YType.uint64, "version")

                    self.vrf_name = YLeaf(YType.str, "vrf-name")
                    self._segment_path = lambda: "information"

                def __setattr__(self, name, value):
                    self._perform_setattr(Rib.RibTableIds.RibTableId.Information, ['afi', 'conf_prefix_limit', 'current_prefix_count', 'deleted', 'fwd_referenced', 'initial_converge', 'num_svdlcl_prefix', 'num_svdrem_prefix', 'prefix_limit_notified', 'safi', 'table_name', 'table_version', 'tableid', 'version', 'vrf_name'], name, value)


            class RibTableItfHndls(Entity):
                """
                RIB table interface
                
                .. attribute:: rib_table_itf_hndl
                
                	Interface handle
                	**type**\: list of    :py:class:`RibTableItfHndl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl>`
                
                

                """

                _prefix = 'ip-rib-ipv4-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rib.RibTableIds.RibTableId.RibTableItfHndls, self).__init__()

                    self.yang_name = "rib-table-itf-hndls"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"rib-table-itf-hndl" : ("rib_table_itf_hndl", Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl)}

                    self.rib_table_itf_hndl = YList(self)
                    self._segment_path = lambda: "rib-table-itf-hndls"

                def __setattr__(self, name, value):
                    self._perform_setattr(Rib.RibTableIds.RibTableId.RibTableItfHndls, [], name, value)


                class RibTableItfHndl(Entity):
                    """
                    Interface handle
                    
                    .. attribute:: handle  <key>
                    
                    	Itf Handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: itf_route
                    
                    	Route information for a specific table/interface 
                    	**type**\: list of    :py:class:`ItfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv4-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__init__()

                        self.yang_name = "rib-table-itf-hndl"
                        self.yang_parent_name = "rib-table-itf-hndls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"itf-route" : ("itf_route", Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute)}

                        self.handle = YLeaf(YType.int32, "handle")

                        self.itf_route = YList(self)
                        self._segment_path = lambda: "rib-table-itf-hndl" + "[handle='" + self.handle.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, ['handle'], name, value)


                    class ItfRoute(Entity):
                        """
                        Route information for a specific
                        table/interface 
                        
                        .. attribute:: address  <key>
                        
                        	Network Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: active
                        
                        	Is the route active or backup
                        	**type**\:  bool
                        
                        .. attribute:: attribute_identity
                        
                        	BGP Attribute ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client_id
                        
                        	Client adding the route to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distance
                        
                        	Distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion
                        
                        	Route has a diversion path
                        	**type**\:  bool
                        
                        .. attribute:: diversion_distance
                        
                        	Diversion distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion_proto_name
                        
                        	Diversion route protocol name
                        	**type**\:  str
                        
                        .. attribute:: extended_flags
                        
                        	Extended Route flags
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: flags
                        
                        	Route flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_tag
                        
                        	Flow tag
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: fwd_class
                        
                        	Forward Class
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: instance
                        
                        	Instance name
                        	**type**\:  str
                        
                        .. attribute:: metric
                        
                        	Route metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_count
                        
                        	Number of paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pic_count
                        
                        	Number of pic paths in this route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length_xr
                        
                        	Length of prefix
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: priority
                        
                        	Route priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: protocol_id
                        
                        	Protocol advertising the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_name
                        
                        	 Name of Protocol
                        	**type**\:  str
                        
                        .. attribute:: qos_group
                        
                        	Route qos group
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_age
                        
                        	Age of route (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: route_label
                        
                        	Local label of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_modify_time
                        
                        	Route modification time(nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: route_path
                        
                        	Path(s) of the route
                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath>`
                        
                        .. attribute:: route_precedence
                        
                        	Route ip precedence
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_type
                        
                        	Route type
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: route_version
                        
                        	Route version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: svd_type
                        
                        	SVD Type of route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tag
                        
                        	Opaque proto specific info
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tbl_version
                        
                        	Table Version
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: traffic_index
                        
                        	BGP Traffic Index
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: version
                        
                        	Route Version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__init__()

                            self.yang_name = "itf-route"
                            self.yang_parent_name = "rib-table-itf-hndl"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"route-path" : ("route_path", Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath)}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.active = YLeaf(YType.boolean, "active")

                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                            self.client_id = YLeaf(YType.uint32, "client-id")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.diversion = YLeaf(YType.boolean, "diversion")

                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                            self.flags = YLeaf(YType.uint32, "flags")

                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                            self.instance = YLeaf(YType.str, "instance")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.priority = YLeaf(YType.uint8, "priority")

                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                            self.route_age = YLeaf(YType.uint32, "route-age")

                            self.route_label = YLeaf(YType.uint32, "route-label")

                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                            self.route_type = YLeaf(YType.uint16, "route-type")

                            self.route_version = YLeaf(YType.uint32, "route-version")

                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                            self.tag = YLeaf(YType.uint32, "tag")

                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                            self.version = YLeaf(YType.uint32, "version")

                            self.route_path = Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                            self.route_path.parent = self
                            self._children_name_map["route_path"] = "route-path"
                            self._children_yang_names.add("route-path")
                            self._segment_path = lambda: "itf-route" + "[address='" + self.address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, ['address', 'active', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                        class RoutePath(Entity):
                            """
                            Path(s) of the route
                            
                            .. attribute:: ipv4_rib_edm_path
                            
                            	ipv4 rib edm path
                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv4-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "itf-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath)}

                                self.ipv4_rib_edm_path = YList(self)
                                self._segment_path = lambda: "route-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, [], name, value)


                            class Ipv4RibEdmPath(Entity):
                                """
                                ipv4 rib edm path
                                
                                .. attribute:: address
                                
                                	Nexthop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pathid
                                
                                	Path id of this path's backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_label
                                
                                	binding Label for this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags
                                
                                	Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: flags64
                                
                                	Flags extended to 64 bits
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: has_labelstk
                                
                                	Path has a label stack
                                	**type**\:  bool
                                
                                .. attribute:: information_source
                                
                                	Infosource
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_name
                                
                                	Interface Name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: labelstk
                                
                                	Outgoing label stack for this path
                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                
                                .. attribute:: load_metric
                                
                                	Load Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: looped
                                
                                	Looping path
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_feid
                                
                                	Fib mpls encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: mvpn_present
                                
                                	MVPN attribute present
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_afi
                                
                                	NH afi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id
                                
                                	NHID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id_refcount
                                
                                	NHID references
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_safi
                                
                                	NH safi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_id
                                
                                	Nexthop tableid
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_name
                                
                                	NH table name
                                	**type**\:  str
                                
                                .. attribute:: next_hop_vrf_name
                                
                                	VRF Name of the nh table
                                	**type**\:  str
                                
                                .. attribute:: nhid_feid
                                
                                	Fib nhid encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: num_labels
                                
                                	Number of labels in stack
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: number_of_extended_communities
                                
                                	Number of extended communities
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_area_id
                                
                                	OSPF area associated with the path
                                	**type**\:  str
                                
                                .. attribute:: path_rt_present
                                
                                	Path RT present
                                	**type**\:  bool
                                
                                .. attribute:: pathid
                                
                                	Path id of this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: private_flags
                                
                                	Private Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ref_cnt_of_backup
                                
                                	Refcnt of backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_backup_addr
                                
                                	Remote backup node address
                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                
                                .. attribute:: route_label
                                
                                	Label associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: segmented_nexthop_present
                                
                                	SegmentedNexthopPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_asrt_present
                                
                                	SOURCEASRTPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_rd_present
                                
                                	SOURCERDPresent
                                	**type**\:  bool
                                
                                .. attribute:: tunnel_id
                                
                                	Tunnel ID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: v6_information_source
                                
                                	V6 Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_nexthop
                                
                                	V6 nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vrf_import_rt_present
                                
                                	VRFIMPORTRTPresent
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rib-ipv4-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                    self.yang_name = "ipv4-rib-edm-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                    self.address = YLeaf(YType.str, "address")

                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                    self.flags = YLeaf(YType.uint16, "flags")

                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                    self.information_source = YLeaf(YType.str, "information-source")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                    self.looped = YLeaf(YType.boolean, "looped")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                    self.labelstk = YList(self)
                                    self.remote_backup_addr = YList(self)
                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                class Labelstk(Entity):
                                    """
                                    Outgoing label stack for this path
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv4-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                        self.yang_name = "labelstk"
                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "labelstk"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                class RemoteBackupAddr(Entity):
                                    """
                                    Remote backup node address
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv4-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                        self.yang_name = "remote-backup-addr"
                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.str, "entry")
                                        self._segment_path = lambda: "remote-backup-addr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Rib.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


            class SummaryProtos(Entity):
                """
                RIB table summary
                
                .. attribute:: summary_proto
                
                	Route summary information for a specific table/protocol 
                	**type**\: list of    :py:class:`SummaryProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto>`
                
                

                """

                _prefix = 'ip-rib-ipv4-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rib.RibTableIds.RibTableId.SummaryProtos, self).__init__()

                    self.yang_name = "summary-protos"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"summary-proto" : ("summary_proto", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto)}

                    self.summary_proto = YList(self)
                    self._segment_path = lambda: "summary-protos"

                def __setattr__(self, name, value):
                    self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos, [], name, value)


                class SummaryProto(Entity):
                    """
                    Route summary information for a specific
                    table/protocol 
                    
                    .. attribute:: protoid  <key>
                    
                    	Proto ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: instance
                    
                    	Instance
                    	**type**\:  str
                    
                    .. attribute:: name
                    
                    	Proto name
                    	**type**\:  str
                    
                    .. attribute:: proto_route_count
                    
                    	Count for proto. instance
                    	**type**\:   :py:class:`ProtoRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount>`
                    
                    .. attribute:: rtype_bgp_ext
                    
                    	eBGP route
                    	**type**\:   :py:class:`RtypeBgpExt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt>`
                    
                    .. attribute:: rtype_bgp_int
                    
                    	iBGP route
                    	**type**\:   :py:class:`RtypeBgpInt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt>`
                    
                    .. attribute:: rtype_bgp_loc
                    
                    	BGP local route
                    	**type**\:   :py:class:`RtypeBgpLoc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc>`
                    
                    .. attribute:: rtype_igrp2_ext
                    
                    	EIGRP external route
                    	**type**\:   :py:class:`RtypeIgrp2Ext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext>`
                    
                    .. attribute:: rtype_igrp2_int
                    
                    	EIGRP internal route
                    	**type**\:   :py:class:`RtypeIgrp2Int <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int>`
                    
                    .. attribute:: rtype_isis_l1
                    
                    	IS\-IS level 1 route
                    	**type**\:   :py:class:`RtypeIsisL1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1>`
                    
                    .. attribute:: rtype_isis_l1_ia
                    
                    	IS\-IS level1 inter\-area route
                    	**type**\:   :py:class:`RtypeIsisL1Ia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia>`
                    
                    .. attribute:: rtype_isis_l2
                    
                    	IS\-IS level 2 route
                    	**type**\:   :py:class:`RtypeIsisL2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2>`
                    
                    .. attribute:: rtype_isis_sum
                    
                    	IS\-IS summary route
                    	**type**\:   :py:class:`RtypeIsisSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum>`
                    
                    .. attribute:: rtype_none
                    
                    	No route type
                    	**type**\:   :py:class:`RtypeNone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone>`
                    
                    .. attribute:: rtype_ospf_extern1
                    
                    	OSPF external route of type 1
                    	**type**\:   :py:class:`RtypeOspfExtern1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1>`
                    
                    .. attribute:: rtype_ospf_extern2
                    
                    	OSPF external route of type 2
                    	**type**\:   :py:class:`RtypeOspfExtern2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2>`
                    
                    .. attribute:: rtype_ospf_inter
                    
                    	OSPF route across diff. areas
                    	**type**\:   :py:class:`RtypeOspfInter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter>`
                    
                    .. attribute:: rtype_ospf_intra
                    
                    	OSPF route within an area
                    	**type**\:   :py:class:`RtypeOspfIntra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra>`
                    
                    .. attribute:: rtype_ospf_nssa1
                    
                    	OSPF NSSA ext. route type 1
                    	**type**\:   :py:class:`RtypeOspfNssa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1>`
                    
                    .. attribute:: rtype_ospf_nssa2
                    
                    	OSPF NSSA ext. route type 2
                    	**type**\:   :py:class:`RtypeOspfNssa2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2>`
                    
                    .. attribute:: rtype_other
                    
                    	Unknown route type
                    	**type**\:   :py:class:`RtypeOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv4-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__init__()

                        self.yang_name = "summary-proto"
                        self.yang_parent_name = "summary-protos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"proto-route-count" : ("proto_route_count", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount), "rtype-bgp-ext" : ("rtype_bgp_ext", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt), "rtype-bgp-int" : ("rtype_bgp_int", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt), "rtype-bgp-loc" : ("rtype_bgp_loc", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc), "rtype-igrp2-ext" : ("rtype_igrp2_ext", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext), "rtype-igrp2-int" : ("rtype_igrp2_int", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int), "rtype-isis-l1" : ("rtype_isis_l1", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1), "rtype-isis-l1-ia" : ("rtype_isis_l1_ia", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia), "rtype-isis-l2" : ("rtype_isis_l2", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2), "rtype-isis-sum" : ("rtype_isis_sum", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum), "rtype-none" : ("rtype_none", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone), "rtype-ospf-extern1" : ("rtype_ospf_extern1", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1), "rtype-ospf-extern2" : ("rtype_ospf_extern2", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2), "rtype-ospf-inter" : ("rtype_ospf_inter", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter), "rtype-ospf-intra" : ("rtype_ospf_intra", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra), "rtype-ospf-nssa1" : ("rtype_ospf_nssa1", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1), "rtype-ospf-nssa2" : ("rtype_ospf_nssa2", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2), "rtype-other" : ("rtype_other", Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther)}
                        self._child_list_classes = {}

                        self.protoid = YLeaf(YType.int32, "protoid")

                        self.instance = YLeaf(YType.str, "instance")

                        self.name = YLeaf(YType.str, "name")

                        self.proto_route_count = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                        self.proto_route_count.parent = self
                        self._children_name_map["proto_route_count"] = "proto-route-count"
                        self._children_yang_names.add("proto-route-count")

                        self.rtype_bgp_ext = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                        self.rtype_bgp_ext.parent = self
                        self._children_name_map["rtype_bgp_ext"] = "rtype-bgp-ext"
                        self._children_yang_names.add("rtype-bgp-ext")

                        self.rtype_bgp_int = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                        self.rtype_bgp_int.parent = self
                        self._children_name_map["rtype_bgp_int"] = "rtype-bgp-int"
                        self._children_yang_names.add("rtype-bgp-int")

                        self.rtype_bgp_loc = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                        self.rtype_bgp_loc.parent = self
                        self._children_name_map["rtype_bgp_loc"] = "rtype-bgp-loc"
                        self._children_yang_names.add("rtype-bgp-loc")

                        self.rtype_igrp2_ext = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                        self.rtype_igrp2_ext.parent = self
                        self._children_name_map["rtype_igrp2_ext"] = "rtype-igrp2-ext"
                        self._children_yang_names.add("rtype-igrp2-ext")

                        self.rtype_igrp2_int = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                        self.rtype_igrp2_int.parent = self
                        self._children_name_map["rtype_igrp2_int"] = "rtype-igrp2-int"
                        self._children_yang_names.add("rtype-igrp2-int")

                        self.rtype_isis_l1 = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                        self.rtype_isis_l1.parent = self
                        self._children_name_map["rtype_isis_l1"] = "rtype-isis-l1"
                        self._children_yang_names.add("rtype-isis-l1")

                        self.rtype_isis_l1_ia = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                        self.rtype_isis_l1_ia.parent = self
                        self._children_name_map["rtype_isis_l1_ia"] = "rtype-isis-l1-ia"
                        self._children_yang_names.add("rtype-isis-l1-ia")

                        self.rtype_isis_l2 = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                        self.rtype_isis_l2.parent = self
                        self._children_name_map["rtype_isis_l2"] = "rtype-isis-l2"
                        self._children_yang_names.add("rtype-isis-l2")

                        self.rtype_isis_sum = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                        self.rtype_isis_sum.parent = self
                        self._children_name_map["rtype_isis_sum"] = "rtype-isis-sum"
                        self._children_yang_names.add("rtype-isis-sum")

                        self.rtype_none = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                        self.rtype_none.parent = self
                        self._children_name_map["rtype_none"] = "rtype-none"
                        self._children_yang_names.add("rtype-none")

                        self.rtype_ospf_extern1 = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                        self.rtype_ospf_extern1.parent = self
                        self._children_name_map["rtype_ospf_extern1"] = "rtype-ospf-extern1"
                        self._children_yang_names.add("rtype-ospf-extern1")

                        self.rtype_ospf_extern2 = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                        self.rtype_ospf_extern2.parent = self
                        self._children_name_map["rtype_ospf_extern2"] = "rtype-ospf-extern2"
                        self._children_yang_names.add("rtype-ospf-extern2")

                        self.rtype_ospf_inter = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                        self.rtype_ospf_inter.parent = self
                        self._children_name_map["rtype_ospf_inter"] = "rtype-ospf-inter"
                        self._children_yang_names.add("rtype-ospf-inter")

                        self.rtype_ospf_intra = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                        self.rtype_ospf_intra.parent = self
                        self._children_name_map["rtype_ospf_intra"] = "rtype-ospf-intra"
                        self._children_yang_names.add("rtype-ospf-intra")

                        self.rtype_ospf_nssa1 = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                        self.rtype_ospf_nssa1.parent = self
                        self._children_name_map["rtype_ospf_nssa1"] = "rtype-ospf-nssa1"
                        self._children_yang_names.add("rtype-ospf-nssa1")

                        self.rtype_ospf_nssa2 = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                        self.rtype_ospf_nssa2.parent = self
                        self._children_name_map["rtype_ospf_nssa2"] = "rtype-ospf-nssa2"
                        self._children_yang_names.add("rtype-ospf-nssa2")

                        self.rtype_other = Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                        self.rtype_other.parent = self
                        self._children_name_map["rtype_other"] = "rtype-other"
                        self._children_yang_names.add("rtype-other")
                        self._segment_path = lambda: "summary-proto" + "[protoid='" + self.protoid.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto, ['protoid', 'instance', 'name'], name, value)


                    class ProtoRouteCount(Entity):
                        """
                        Count for proto. instance
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__init__()

                            self.yang_name = "proto-route-count"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "proto-route-count"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeBgpExt(Entity):
                        """
                        eBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__init__()

                            self.yang_name = "rtype-bgp-ext"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-bgp-ext"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeBgpInt(Entity):
                        """
                        iBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__init__()

                            self.yang_name = "rtype-bgp-int"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-bgp-int"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeBgpLoc(Entity):
                        """
                        BGP local route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__init__()

                            self.yang_name = "rtype-bgp-loc"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-bgp-loc"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIgrp2Ext(Entity):
                        """
                        EIGRP external route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__init__()

                            self.yang_name = "rtype-igrp2-ext"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-igrp2-ext"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIgrp2Int(Entity):
                        """
                        EIGRP internal route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__init__()

                            self.yang_name = "rtype-igrp2-int"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-igrp2-int"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIsisL1(Entity):
                        """
                        IS\-IS level 1 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__init__()

                            self.yang_name = "rtype-isis-l1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-isis-l1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIsisL1Ia(Entity):
                        """
                        IS\-IS level1 inter\-area route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__init__()

                            self.yang_name = "rtype-isis-l1-ia"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-isis-l1-ia"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIsisL2(Entity):
                        """
                        IS\-IS level 2 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__init__()

                            self.yang_name = "rtype-isis-l2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-isis-l2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIsisSum(Entity):
                        """
                        IS\-IS summary route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__init__()

                            self.yang_name = "rtype-isis-sum"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-isis-sum"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeNone(Entity):
                        """
                        No route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__init__()

                            self.yang_name = "rtype-none"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-none"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfExtern1(Entity):
                        """
                        OSPF external route of type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__init__()

                            self.yang_name = "rtype-ospf-extern1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-extern1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfExtern2(Entity):
                        """
                        OSPF external route of type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__init__()

                            self.yang_name = "rtype-ospf-extern2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-extern2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfInter(Entity):
                        """
                        OSPF route across diff. areas
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__init__()

                            self.yang_name = "rtype-ospf-inter"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-inter"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfIntra(Entity):
                        """
                        OSPF route within an area
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__init__()

                            self.yang_name = "rtype-ospf-intra"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-intra"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfNssa1(Entity):
                        """
                        OSPF NSSA ext. route type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__init__()

                            self.yang_name = "rtype-ospf-nssa1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-nssa1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfNssa2(Entity):
                        """
                        OSPF NSSA ext. route type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__init__()

                            self.yang_name = "rtype-ospf-nssa2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-nssa2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOther(Entity):
                        """
                        Unknown route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__init__()

                            self.yang_name = "rtype-other"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-other"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


    class Vrfs(Entity):
        """
        VRF table
        
        .. attribute:: vrf
        
        	Specific VRF
        	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-rib-ipv4-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(Rib.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "rib"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"vrf" : ("vrf", Rib.Vrfs.Vrf)}

            self.vrf = YList(self)
            self._segment_path = lambda: "vrfs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(Rib.Vrfs, [], name, value)


        class Vrf(Entity):
            """
            Specific VRF
            
            .. attribute:: vrf_name  <key>
            
            	Name of the VRF
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: afs
            
            	Address Family (AF) table
            	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs>`
            
            

            """

            _prefix = 'ip-rib-ipv4-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(Rib.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"afs" : ("afs", Rib.Vrfs.Vrf.Afs)}
                self._child_list_classes = {}

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.afs = Rib.Vrfs.Vrf.Afs()
                self.afs.parent = self
                self._children_name_map["afs"] = "afs"
                self._children_yang_names.add("afs")
                self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib/vrfs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(Rib.Vrfs.Vrf, ['vrf_name'], name, value)


            class Afs(Entity):
                """
                Address Family (AF) table
                
                .. attribute:: af
                
                	Specific AF information
                	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af>`
                
                

                """

                _prefix = 'ip-rib-ipv4-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(Rib.Vrfs.Vrf.Afs, self).__init__()

                    self.yang_name = "afs"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"af" : ("af", Rib.Vrfs.Vrf.Afs.Af)}

                    self.af = YList(self)
                    self._segment_path = lambda: "afs"

                def __setattr__(self, name, value):
                    self._perform_setattr(Rib.Vrfs.Vrf.Afs, [], name, value)


                class Af(Entity):
                    """
                    Specific AF information
                    
                    .. attribute:: af_name  <key>
                    
                    	Name of the AF
                    	**type**\:  str
                    
                    	**pattern:** (IPv4)\|(IPv6)
                    
                    .. attribute:: safs
                    
                    	Subsequent Address Family (SAF) table
                    	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv4-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(Rib.Vrfs.Vrf.Afs.Af, self).__init__()

                        self.yang_name = "af"
                        self.yang_parent_name = "afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"safs" : ("safs", Rib.Vrfs.Vrf.Afs.Af.Safs)}
                        self._child_list_classes = {}

                        self.af_name = YLeaf(YType.str, "af-name")

                        self.safs = Rib.Vrfs.Vrf.Afs.Af.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                        self._children_yang_names.add("safs")
                        self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                    class Safs(Entity):
                        """
                        Subsequent Address Family (SAF) table
                        
                        .. attribute:: saf
                        
                        	Specific SAF information
                        	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf>`
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(Rib.Vrfs.Vrf.Afs.Af.Safs, self).__init__()

                            self.yang_name = "safs"
                            self.yang_parent_name = "af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"saf" : ("saf", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf)}

                            self.saf = YList(self)
                            self._segment_path = lambda: "safs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs, [], name, value)


                        class Saf(Entity):
                            """
                            Specific SAF information
                            
                            .. attribute:: saf_name  <key>
                            
                            	Name of the SAF
                            	**type**\:  str
                            
                            	**pattern:** (Unicast)\|(Multicast)
                            
                            .. attribute:: ip_rib_route_table_names
                            
                            	Global container of routes
                            	**type**\:   :py:class:`IpRibRouteTableNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv4-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__init__()

                                self.yang_name = "saf"
                                self.yang_parent_name = "safs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ip-rib-route-table-names" : ("ip_rib_route_table_names", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames)}
                                self._child_list_classes = {}

                                self.saf_name = YLeaf(YType.str, "saf-name")

                                self.ip_rib_route_table_names = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                self.ip_rib_route_table_names.parent = self
                                self._children_name_map["ip_rib_route_table_names"] = "ip-rib-route-table-names"
                                self._children_yang_names.add("ip-rib-route-table-names")
                                self._segment_path = lambda: "saf" + "[saf-name='" + self.saf_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf, ['saf_name'], name, value)


                            class IpRibRouteTableNames(Entity):
                                """
                                Global container of routes
                                
                                .. attribute:: ip_rib_route_table_name
                                
                                	IP RIB Route table name for a topology
                                	**type**\: list of    :py:class:`IpRibRouteTableName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv4-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__init__()

                                    self.yang_name = "ip-rib-route-table-names"
                                    self.yang_parent_name = "saf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ip-rib-route-table-name" : ("ip_rib_route_table_name", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName)}

                                    self.ip_rib_route_table_name = YList(self)
                                    self._segment_path = lambda: "ip-rib-route-table-names"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, [], name, value)


                                class IpRibRouteTableName(Entity):
                                    """
                                    IP RIB Route table name for a topology
                                    
                                    .. attribute:: route_table_name  <key>
                                    
                                    	Name of the route table
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: adverts
                                    
                                    	Route advertiser information 
                                    	**type**\:   :py:class:`Adverts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts>`
                                    
                                    .. attribute:: backup_routes
                                    
                                    	Backup route information for the given table
                                    	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes>`
                                    
                                    .. attribute:: deleted_routes
                                    
                                    	Deleted
                                    	**type**\:   :py:class:`DeletedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes>`
                                    
                                    .. attribute:: destination_kw
                                    
                                    	Destination KW
                                    	**type**\:   :py:class:`DestinationKw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw>`
                                    
                                    .. attribute:: opaques
                                    
                                    	Opaque information 
                                    	**type**\:   :py:class:`Opaques <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Contains the classification of routes by protocol
                                    	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol>`
                                    
                                    .. attribute:: q_routes
                                    
                                    	Quarantine
                                    	**type**\:   :py:class:`QRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes>`
                                    
                                    .. attribute:: routes
                                    
                                    	Route information 
                                    	**type**\:   :py:class:`Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes>`
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv4-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__init__()

                                        self.yang_name = "ip-rib-route-table-name"
                                        self.yang_parent_name = "ip-rib-route-table-names"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"adverts" : ("adverts", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts), "backup-routes" : ("backup_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes), "deleted-routes" : ("deleted_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes), "destination-kw" : ("destination_kw", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw), "opaques" : ("opaques", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques), "protocol" : ("protocol", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol), "q-routes" : ("q_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes), "routes" : ("routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes)}
                                        self._child_list_classes = {}

                                        self.route_table_name = YLeaf(YType.str, "route-table-name")

                                        self.adverts = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                        self.adverts.parent = self
                                        self._children_name_map["adverts"] = "adverts"
                                        self._children_yang_names.add("adverts")

                                        self.backup_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                        self.backup_routes.parent = self
                                        self._children_name_map["backup_routes"] = "backup-routes"
                                        self._children_yang_names.add("backup-routes")

                                        self.deleted_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                        self.deleted_routes.parent = self
                                        self._children_name_map["deleted_routes"] = "deleted-routes"
                                        self._children_yang_names.add("deleted-routes")

                                        self.destination_kw = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                        self.destination_kw.parent = self
                                        self._children_name_map["destination_kw"] = "destination-kw"
                                        self._children_yang_names.add("destination-kw")

                                        self.opaques = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques()
                                        self.opaques.parent = self
                                        self._children_name_map["opaques"] = "opaques"
                                        self._children_yang_names.add("opaques")

                                        self.protocol = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                        self.protocol.parent = self
                                        self._children_name_map["protocol"] = "protocol"
                                        self._children_yang_names.add("protocol")

                                        self.q_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                        self.q_routes.parent = self
                                        self._children_name_map["q_routes"] = "q-routes"
                                        self._children_yang_names.add("q-routes")

                                        self.routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                        self.routes.parent = self
                                        self._children_name_map["routes"] = "routes"
                                        self._children_yang_names.add("routes")
                                        self._segment_path = lambda: "ip-rib-route-table-name" + "[route-table-name='" + self.route_table_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, ['route_table_name'], name, value)


                                    class Adverts(Entity):
                                        """
                                        Route advertiser information 
                                        
                                        .. attribute:: advert
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Advert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__init__()

                                            self.yang_name = "adverts"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"advert" : ("advert", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert)}

                                            self.advert = YList(self)
                                            self._segment_path = lambda: "adverts"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, [], name, value)


                                        class Advert(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_rib_edm_advert
                                            
                                            	ipv4 rib edm advert
                                            	**type**\: list of    :py:class:`Ipv4RibEdmAdvert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv4RibEdmAdvert>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__init__()

                                                self.yang_name = "advert"
                                                self.yang_parent_name = "adverts"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"ipv4-rib-edm-advert" : ("ipv4_rib_edm_advert", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv4RibEdmAdvert)}

                                                self.address = YLeaf(YType.str, "address")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.ipv4_rib_edm_advert = YList(self)
                                                self._segment_path = lambda: "advert"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, ['address', 'prefix_length'], name, value)


                                            class Ipv4RibEdmAdvert(Entity):
                                                """
                                                ipv4 rib edm advert
                                                
                                                .. attribute:: client_id
                                                
                                                	  Client advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: code
                                                
                                                	Protocol code
                                                	**type**\:  int
                                                
                                                	**range:** \-128..127
                                                
                                                .. attribute:: extended_communities
                                                
                                                	Extended communities
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: instance_name
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                	**length:** 0..41
                                                
                                                .. attribute:: number_of_extended_communities
                                                
                                                	Number of extended communities
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque
                                                
                                                	OSPF area\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque_flags
                                                
                                                	OSPF area\-id flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv4RibEdmAdvert, self).__init__()

                                                    self.yang_name = "ipv4-rib-edm-advert"
                                                    self.yang_parent_name = "advert"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.code = YLeaf(YType.int8, "code")

                                                    self.extended_communities = YLeaf(YType.str, "extended-communities")

                                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_opaque = YLeaf(YType.uint32, "protocol-opaque")

                                                    self.protocol_opaque_flags = YLeaf(YType.uint8, "protocol-opaque-flags")
                                                    self._segment_path = lambda: "ipv4-rib-edm-advert"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv4RibEdmAdvert, ['client_id', 'code', 'extended_communities', 'instance_name', 'number_of_extended_communities', 'protocol_id', 'protocol_opaque', 'protocol_opaque_flags'], name, value)


                                    class BackupRoutes(Entity):
                                        """
                                        Backup route information for the given
                                        table
                                        
                                        .. attribute:: backup_route
                                        
                                        	Route information for a specific backup address 
                                        	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__init__()

                                            self.yang_name = "backup-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"backup-route" : ("backup_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute)}

                                            self.backup_route = YList(self)
                                            self._segment_path = lambda: "backup-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, [], name, value)


                                        class BackupRoute(Entity):
                                            """
                                            Route information for a specific backup
                                            address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: protoid
                                            
                                            	Proto ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__init__()

                                                self.yang_name = "backup-route"
                                                self.yang_parent_name = "backup-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath)}
                                                self._child_list_classes = {}

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.protoid = YLeaf(YType.int32, "protoid")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")
                                                self._segment_path = lambda: "backup-route"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'protoid', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv4_rib_edm_path
                                                
                                                	ipv4 rib edm path
                                                	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "backup-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath)}

                                                    self.ipv4_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, [], name, value)


                                                class Ipv4RibEdmPath(Entity):
                                                    """
                                                    ipv4 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv4-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        self.labelstk = YList(self)
                                                        self.remote_backup_addr = YList(self)
                                                        self._segment_path = lambda: "ipv4-rib-edm-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "labelstk"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.str, "entry")
                                                            self._segment_path = lambda: "remote-backup-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class DeletedRoutes(Entity):
                                        """
                                        Deleted
                                        
                                        .. attribute:: deleted_route
                                        
                                        	Route information for a specific deleted address 
                                        	**type**\: list of    :py:class:`DeletedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__init__()

                                            self.yang_name = "deleted-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"deleted-route" : ("deleted_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute)}

                                            self.deleted_route = YList(self)
                                            self._segment_path = lambda: "deleted-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, [], name, value)


                                        class DeletedRoute(Entity):
                                            """
                                            Route information for a specific
                                            deleted address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__init__()

                                                self.yang_name = "deleted-route"
                                                self.yang_parent_name = "deleted-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath)}
                                                self._child_list_classes = {}

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")
                                                self._segment_path = lambda: "deleted-route"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv4_rib_edm_path
                                                
                                                	ipv4 rib edm path
                                                	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "deleted-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath)}

                                                    self.ipv4_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, [], name, value)


                                                class Ipv4RibEdmPath(Entity):
                                                    """
                                                    ipv4 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv4-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        self.labelstk = YList(self)
                                                        self.remote_backup_addr = YList(self)
                                                        self._segment_path = lambda: "ipv4-rib-edm-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "labelstk"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.str, "entry")
                                                            self._segment_path = lambda: "remote-backup-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class DestinationKw(Entity):
                                        """
                                        Destination KW
                                        
                                        .. attribute:: dest_backup_routes
                                        
                                        	Backup
                                        	**type**\:   :py:class:`DestBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes>`
                                        
                                        .. attribute:: dest_best_routes
                                        
                                        	Best Local
                                        	**type**\:   :py:class:`DestBestRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes>`
                                        
                                        .. attribute:: dest_next_hop_routes
                                        
                                        	Resolving next hop
                                        	**type**\:   :py:class:`DestNextHopRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes>`
                                        
                                        .. attribute:: dest_q_routes
                                        
                                        	Quarantine
                                        	**type**\:   :py:class:`DestQRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw, self).__init__()

                                            self.yang_name = "destination-kw"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"dest-backup-routes" : ("dest_backup_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes), "dest-best-routes" : ("dest_best_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes), "dest-next-hop-routes" : ("dest_next_hop_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes), "dest-q-routes" : ("dest_q_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes)}
                                            self._child_list_classes = {}

                                            self.dest_backup_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                            self.dest_backup_routes.parent = self
                                            self._children_name_map["dest_backup_routes"] = "dest-backup-routes"
                                            self._children_yang_names.add("dest-backup-routes")

                                            self.dest_best_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                            self.dest_best_routes.parent = self
                                            self._children_name_map["dest_best_routes"] = "dest-best-routes"
                                            self._children_yang_names.add("dest-best-routes")

                                            self.dest_next_hop_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                            self.dest_next_hop_routes.parent = self
                                            self._children_name_map["dest_next_hop_routes"] = "dest-next-hop-routes"
                                            self._children_yang_names.add("dest-next-hop-routes")

                                            self.dest_q_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                            self.dest_q_routes.parent = self
                                            self._children_name_map["dest_q_routes"] = "dest-q-routes"
                                            self._children_yang_names.add("dest-q-routes")
                                            self._segment_path = lambda: "destination-kw"


                                        class DestBackupRoutes(Entity):
                                            """
                                            Backup
                                            
                                            .. attribute:: dest_backup_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__init__()

                                                self.yang_name = "dest-backup-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"dest-backup-route" : ("dest_backup_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute)}

                                                self.dest_backup_route = YList(self)
                                                self._segment_path = lambda: "dest-backup-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, [], name, value)


                                            class DestBackupRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..32
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__init__()

                                                    self.yang_name = "dest-backup-route"
                                                    self.yang_parent_name = "dest-backup-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath)}
                                                    self._child_list_classes = {}

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")
                                                    self._segment_path = lambda: "dest-backup-route"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv4_rib_edm_path
                                                    
                                                    	ipv4 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-backup-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath)}

                                                        self.ipv4_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, [], name, value)


                                                    class Ipv4RibEdmPath(Entity):
                                                        """
                                                        ipv4 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv4-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                            self.labelstk = YList(self)
                                                            self.remote_backup_addr = YList(self)
                                                            self._segment_path = lambda: "ipv4-rib-edm-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "labelstk"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.str, "entry")
                                                                self._segment_path = lambda: "remote-backup-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class DestBestRoutes(Entity):
                                            """
                                            Best Local
                                            
                                            .. attribute:: dest_best_route
                                            
                                            	Best local route information for a specific Address 
                                            	**type**\: list of    :py:class:`DestBestRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__init__()

                                                self.yang_name = "dest-best-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"dest-best-route" : ("dest_best_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute)}

                                                self.dest_best_route = YList(self)
                                                self._segment_path = lambda: "dest-best-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, [], name, value)


                                            class DestBestRoute(Entity):
                                                """
                                                Best local route information for a
                                                specific Address 
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__init__()

                                                    self.yang_name = "dest-best-route"
                                                    self.yang_parent_name = "dest-best-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath)}
                                                    self._child_list_classes = {}

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")
                                                    self._segment_path = lambda: "dest-best-route" + "[address='" + self.address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, ['address', 'active', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv4_rib_edm_path
                                                    
                                                    	ipv4 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-best-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath)}

                                                        self.ipv4_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, [], name, value)


                                                    class Ipv4RibEdmPath(Entity):
                                                        """
                                                        ipv4 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv4-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                            self.labelstk = YList(self)
                                                            self.remote_backup_addr = YList(self)
                                                            self._segment_path = lambda: "ipv4-rib-edm-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "labelstk"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.str, "entry")
                                                                self._segment_path = lambda: "remote-backup-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class DestNextHopRoutes(Entity):
                                            """
                                            Resolving next hop
                                            
                                            .. attribute:: dest_next_hop_route
                                            
                                            	Nexthop information for a specific address
                                            	**type**\: list of    :py:class:`DestNextHopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__init__()

                                                self.yang_name = "dest-next-hop-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"dest-next-hop-route" : ("dest_next_hop_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute)}

                                                self.dest_next_hop_route = YList(self)
                                                self._segment_path = lambda: "dest-next-hop-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, [], name, value)


                                            class DestNextHopRoute(Entity):
                                                """
                                                Nexthop information for a specific
                                                address
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__init__()

                                                    self.yang_name = "dest-next-hop-route"
                                                    self.yang_parent_name = "dest-next-hop-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath)}
                                                    self._child_list_classes = {}

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")
                                                    self._segment_path = lambda: "dest-next-hop-route" + "[address='" + self.address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, ['address', 'active', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv4_rib_edm_path
                                                    
                                                    	ipv4 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-next-hop-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath)}

                                                        self.ipv4_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, [], name, value)


                                                    class Ipv4RibEdmPath(Entity):
                                                        """
                                                        ipv4 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv4-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                            self.labelstk = YList(self)
                                                            self.remote_backup_addr = YList(self)
                                                            self._segment_path = lambda: "ipv4-rib-edm-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "labelstk"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.str, "entry")
                                                                self._segment_path = lambda: "remote-backup-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class DestQRoutes(Entity):
                                            """
                                            Quarantine
                                            
                                            .. attribute:: dest_q_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestQRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__init__()

                                                self.yang_name = "dest-q-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"dest-q-route" : ("dest_q_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute)}

                                                self.dest_q_route = YList(self)
                                                self._segment_path = lambda: "dest-q-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, [], name, value)


                                            class DestQRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..32
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__init__()

                                                    self.yang_name = "dest-q-route"
                                                    self.yang_parent_name = "dest-q-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath)}
                                                    self._child_list_classes = {}

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")
                                                    self._segment_path = lambda: "dest-q-route"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv4_rib_edm_path
                                                    
                                                    	ipv4 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-q-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath)}

                                                        self.ipv4_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, [], name, value)


                                                    class Ipv4RibEdmPath(Entity):
                                                        """
                                                        ipv4 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv4-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                            self.labelstk = YList(self)
                                                            self.remote_backup_addr = YList(self)
                                                            self._segment_path = lambda: "ipv4-rib-edm-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "labelstk"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.str, "entry")
                                                                self._segment_path = lambda: "remote-backup-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class Opaques(Entity):
                                        """
                                        Opaque information 
                                        
                                        .. attribute:: opaque
                                        
                                        	Opaque item 
                                        	**type**\: list of    :py:class:`Opaque <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques.Opaque>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques, self).__init__()

                                            self.yang_name = "opaques"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"opaque" : ("opaque", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques.Opaque)}

                                            self.opaque = YList(self)
                                            self._segment_path = lambda: "opaques"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques, [], name, value)


                                        class Opaque(Entity):
                                            """
                                            Opaque item 
                                            
                                            .. attribute:: data
                                            
                                            	data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: key
                                            
                                            	key
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: opaque_clientid
                                            
                                            	Opaque Client ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_data_size
                                            
                                            	Opaque data size
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_key_size
                                            
                                            	Opaque key size
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_key_type
                                            
                                            	Opaque key type
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_protoid
                                            
                                            	Opaque Proto ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_string
                                            
                                            	Opaque string
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques.Opaque, self).__init__()

                                                self.yang_name = "opaque"
                                                self.yang_parent_name = "opaques"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.data = YLeaf(YType.str, "data")

                                                self.key = YLeaf(YType.str, "key")

                                                self.opaque_clientid = YLeaf(YType.int32, "opaque-clientid")

                                                self.opaque_data_size = YLeaf(YType.int32, "opaque-data-size")

                                                self.opaque_key_size = YLeaf(YType.int32, "opaque-key-size")

                                                self.opaque_key_type = YLeaf(YType.int32, "opaque-key-type")

                                                self.opaque_protoid = YLeaf(YType.int32, "opaque-protoid")

                                                self.opaque_string = YLeaf(YType.str, "opaque-string")
                                                self._segment_path = lambda: "opaque"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques.Opaque, ['data', 'key', 'opaque_clientid', 'opaque_data_size', 'opaque_key_size', 'opaque_key_type', 'opaque_protoid', 'opaque_string'], name, value)


                                    class Protocol(Entity):
                                        """
                                        Contains the classification of routes by
                                        protocol
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:   :py:class:`Application <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP Protocol
                                        	**type**\:   :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected Protocol
                                        	**type**\:   :py:class:`Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected>`
                                        
                                        .. attribute:: dagr
                                        
                                        	DAGR Protocol(Direct\-Attached Gateway Redundancy) Protocol
                                        	**type**\:   :py:class:`Dagr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	EIGRP Protocol
                                        	**type**\:   :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISIS Protocol
                                        	**type**\:   :py:class:`Isis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis>`
                                        
                                        .. attribute:: local
                                        
                                        	Local Protocol
                                        	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile Protocol
                                        	**type**\:   :py:class:`Mobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile>`
                                        
                                        .. attribute:: ospf
                                        
                                        	OSPF Protocol
                                        	**type**\:   :py:class:`Ospf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf>`
                                        
                                        .. attribute:: rip
                                        
                                        	RIP Protocol
                                        	**type**\:   :py:class:`Rip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip>`
                                        
                                        .. attribute:: rpl
                                        
                                        	RPL Protocol
                                        	**type**\:   :py:class:`Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl>`
                                        
                                        .. attribute:: static
                                        
                                        	Static Protocol
                                        	**type**\:   :py:class:`Static <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static>`
                                        
                                        .. attribute:: subscriber
                                        
                                        	Subscriber Protocol
                                        	**type**\:   :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber>`
                                        
                                        .. attribute:: te_client
                                        
                                        	TEClient Protocol
                                        	**type**\:   :py:class:`TeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol, self).__init__()

                                            self.yang_name = "protocol"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"application" : ("application", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application), "bgp" : ("bgp", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp), "connected" : ("connected", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected), "dagr" : ("dagr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr), "eigrp" : ("eigrp", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp), "isis" : ("isis", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis), "local" : ("local", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local), "mobile" : ("mobile", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile), "ospf" : ("ospf", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf), "rip" : ("rip", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip), "rpl" : ("rpl", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl), "static" : ("static", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static), "subscriber" : ("subscriber", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber), "te-client" : ("te_client", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient)}
                                            self._child_list_classes = {}

                                            self.application = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"
                                            self._children_yang_names.add("application")

                                            self.bgp = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"
                                            self._children_yang_names.add("bgp")

                                            self.connected = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"
                                            self._children_yang_names.add("connected")

                                            self.dagr = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr()
                                            self.dagr.parent = self
                                            self._children_name_map["dagr"] = "dagr"
                                            self._children_yang_names.add("dagr")

                                            self.eigrp = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"
                                            self._children_yang_names.add("eigrp")

                                            self.isis = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"
                                            self._children_yang_names.add("isis")

                                            self.local = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                            self.local.parent = self
                                            self._children_name_map["local"] = "local"
                                            self._children_yang_names.add("local")

                                            self.mobile = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                            self.mobile.parent = self
                                            self._children_name_map["mobile"] = "mobile"
                                            self._children_yang_names.add("mobile")

                                            self.ospf = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                            self.ospf.parent = self
                                            self._children_name_map["ospf"] = "ospf"
                                            self._children_yang_names.add("ospf")

                                            self.rip = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"
                                            self._children_yang_names.add("rip")

                                            self.rpl = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                            self.rpl.parent = self
                                            self._children_name_map["rpl"] = "rpl"
                                            self._children_yang_names.add("rpl")

                                            self.static = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"
                                            self._children_yang_names.add("static")

                                            self.subscriber = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                            self.subscriber.parent = self
                                            self._children_name_map["subscriber"] = "subscriber"
                                            self._children_yang_names.add("subscriber")

                                            self.te_client = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                            self.te_client.parent = self
                                            self._children_name_map["te_client"] = "te-client"
                                            self._children_yang_names.add("te-client")
                                            self._segment_path = lambda: "protocol"


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "application"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Bgp(Entity):
                                            """
                                            BGP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "bgp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "connected"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Dagr(Entity):
                                            """
                                            DAGR Protocol(Direct\-Attached Gateway
                                            Redundancy) Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr, self).__init__()

                                                self.yang_name = "dagr"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "dagr"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "dagr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            EIGRP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "eigrp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISIS Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "isis"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Local(Entity):
                                            """
                                            Local Protocol
                                            
                                            .. attribute:: lspv
                                            
                                            	LSPV(Label Switched Path Verification) Protocol
                                            	**type**\:   :py:class:`Lspv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs>`
                                            
                                            .. attribute:: smiap
                                            
                                            	SMIAP
                                            	**type**\:   :py:class:`Smiap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local, self).__init__()

                                                self.yang_name = "local"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lspv" : ("lspv", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv), "non-as" : ("non_as", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs), "smiap" : ("smiap", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap)}
                                                self._child_list_classes = {}

                                                self.lspv = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                self.lspv.parent = self
                                                self._children_name_map["lspv"] = "lspv"
                                                self._children_yang_names.add("lspv")

                                                self.non_as = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")

                                                self.smiap = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap()
                                                self.smiap.parent = self
                                                self._children_name_map["smiap"] = "smiap"
                                                self._children_yang_names.add("smiap")
                                                self._segment_path = lambda: "local"


                                            class Lspv(Entity):
                                                """
                                                LSPV(Label Switched Path Verification)
                                                Protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv, self).__init__()

                                                    self.yang_name = "lspv"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "lspv"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "lspv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "lspv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                            class Smiap(Entity):
                                                """
                                                SMIAP
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap, self).__init__()

                                                    self.yang_name = "smiap"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "smiap"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "smiap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "smiap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Mobile(Entity):
                                            """
                                            Mobile Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "mobile"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "mobile"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Ospf(Entity):
                                            """
                                            OSPF Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "ospf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Rip(Entity):
                                            """
                                            RIP Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "rip"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Rpl(Entity):
                                            """
                                            RPL Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__init__()

                                                self.yang_name = "rpl"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "rpl"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "rpl"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Static(Entity):
                                            """
                                            Static Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "static"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Subscriber(Entity):
                                            """
                                            Subscriber Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber, self).__init__()

                                                self.yang_name = "subscriber"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "subscriber"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "subscriber"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class TeClient(Entity):
                                            """
                                            TEClient Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient, self).__init__()

                                                self.yang_name = "te-client"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "te-client"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "te-client"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information), "protocol-routes" : ("protocol_routes", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class QRoutes(Entity):
                                        """
                                        Quarantine
                                        
                                        .. attribute:: q_route
                                        
                                        	Route information for a specific quarantined address 
                                        	**type**\: list of    :py:class:`QRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__init__()

                                            self.yang_name = "q-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"q-route" : ("q_route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute)}

                                            self.q_route = YList(self)
                                            self._segment_path = lambda: "q-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, [], name, value)


                                        class QRoute(Entity):
                                            """
                                            Route information for a specific
                                            quarantined address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__init__()

                                                self.yang_name = "q-route"
                                                self.yang_parent_name = "q-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath)}
                                                self._child_list_classes = {}

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")
                                                self._segment_path = lambda: "q-route"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv4_rib_edm_path
                                                
                                                	ipv4 rib edm path
                                                	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "q-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath)}

                                                    self.ipv4_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, [], name, value)


                                                class Ipv4RibEdmPath(Entity):
                                                    """
                                                    ipv4 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv4-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        self.labelstk = YList(self)
                                                        self.remote_backup_addr = YList(self)
                                                        self._segment_path = lambda: "ipv4-rib-edm-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "labelstk"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.str, "entry")
                                                            self._segment_path = lambda: "remote-backup-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class Routes(Entity):
                                        """
                                        Route information 
                                        
                                        .. attribute:: route
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__init__()

                                            self.yang_name = "routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"route" : ("route", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route)}

                                            self.route = YList(self)
                                            self._segment_path = lambda: "routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, [], name, value)


                                        class Route(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: interface_name
                                            
                                            	Outgoing Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	NextHop Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__init__()

                                                self.yang_name = "route"
                                                self.yang_parent_name = "routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-path" : ("route_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath)}
                                                self._child_list_classes = {}

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")
                                                self._segment_path = lambda: "route"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'interface_name', 'metric', 'next_hop_address', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv4_rib_edm_path
                                                
                                                	ipv4 rib edm path
                                                	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath)}

                                                    self.ipv4_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, [], name, value)


                                                class Ipv4RibEdmPath(Entity):
                                                    """
                                                    ipv4 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv4-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"labelstk" : ("labelstk", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        self.labelstk = YList(self)
                                                        self.remote_backup_addr = YList(self)
                                                        self._segment_path = lambda: "ipv4-rib-edm-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "labelstk"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.str, "entry")
                                                            self._segment_path = lambda: "remote-backup-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(Rib.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)

    def clone_ptr(self):
        self._top_entity = Rib()
        return self._top_entity

class RibStdby(Entity):
    """
    RIB standby node operational data
    
    .. attribute:: rib_table_ids
    
    	RIB table
    	**type**\:   :py:class:`RibTableIds <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds>`
    
    .. attribute:: vrfs
    
    	VRF table
    	**type**\:   :py:class:`Vrfs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs>`
    
    

    """

    _prefix = 'ip-rib-ipv4-oper'
    _revision = '2015-11-09'

    def __init__(self):
        super(RibStdby, self).__init__()
        self._top_entity = None

        self.yang_name = "rib-stdby"
        self.yang_parent_name = "Cisco-IOS-XR-ip-rib-ipv4-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self._child_container_classes = {"rib-table-ids" : ("rib_table_ids", RibStdby.RibTableIds), "vrfs" : ("vrfs", RibStdby.Vrfs)}
        self._child_list_classes = {}

        self.rib_table_ids = RibStdby.RibTableIds()
        self.rib_table_ids.parent = self
        self._children_name_map["rib_table_ids"] = "rib-table-ids"
        self._children_yang_names.add("rib-table-ids")

        self.vrfs = RibStdby.Vrfs()
        self.vrfs.parent = self
        self._children_name_map["vrfs"] = "vrfs"
        self._children_yang_names.add("vrfs")
        self._segment_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib-stdby"


    class RibTableIds(Entity):
        """
        RIB table
        
        .. attribute:: rib_table_id
        
        	Specific Table
        	**type**\: list of    :py:class:`RibTableId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId>`
        
        

        """

        _prefix = 'ip-rib-ipv4-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RibStdby.RibTableIds, self).__init__()

            self.yang_name = "rib-table-ids"
            self.yang_parent_name = "rib-stdby"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"rib-table-id" : ("rib_table_id", RibStdby.RibTableIds.RibTableId)}

            self.rib_table_id = YList(self)
            self._segment_path = lambda: "rib-table-ids"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib-stdby/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(RibStdby.RibTableIds, [], name, value)


        class RibTableId(Entity):
            """
            Specific Table
            
            .. attribute:: tableid  <key>
            
            	Table ID
            	**type**\:  str
            
            	**pattern:** [0\-9a\-fA\-F]{1,8}
            
            .. attribute:: information
            
            	Table related Information
            	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.Information>`
            
            .. attribute:: rib_table_itf_hndls
            
            	RIB table interface
            	**type**\:   :py:class:`RibTableItfHndls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.RibTableItfHndls>`
            
            .. attribute:: summary_protos
            
            	RIB table summary
            	**type**\:   :py:class:`SummaryProtos <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos>`
            
            

            """

            _prefix = 'ip-rib-ipv4-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RibStdby.RibTableIds.RibTableId, self).__init__()

                self.yang_name = "rib-table-id"
                self.yang_parent_name = "rib-table-ids"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"information" : ("information", RibStdby.RibTableIds.RibTableId.Information), "rib-table-itf-hndls" : ("rib_table_itf_hndls", RibStdby.RibTableIds.RibTableId.RibTableItfHndls), "summary-protos" : ("summary_protos", RibStdby.RibTableIds.RibTableId.SummaryProtos)}
                self._child_list_classes = {}

                self.tableid = YLeaf(YType.str, "tableid")

                self.information = RibStdby.RibTableIds.RibTableId.Information()
                self.information.parent = self
                self._children_name_map["information"] = "information"
                self._children_yang_names.add("information")

                self.rib_table_itf_hndls = RibStdby.RibTableIds.RibTableId.RibTableItfHndls()
                self.rib_table_itf_hndls.parent = self
                self._children_name_map["rib_table_itf_hndls"] = "rib-table-itf-hndls"
                self._children_yang_names.add("rib-table-itf-hndls")

                self.summary_protos = RibStdby.RibTableIds.RibTableId.SummaryProtos()
                self.summary_protos.parent = self
                self._children_name_map["summary_protos"] = "summary-protos"
                self._children_yang_names.add("summary-protos")
                self._segment_path = lambda: "rib-table-id" + "[tableid='" + self.tableid.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib-stdby/rib-table-ids/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(RibStdby.RibTableIds.RibTableId, ['tableid'], name, value)


            class Information(Entity):
                """
                Table related Information
                
                .. attribute:: afi
                
                	Address Family
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: conf_prefix_limit
                
                	Configured prefix limit
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: current_prefix_count
                
                	Num prefixes in table
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: deleted
                
                	Table deleted?
                	**type**\:  bool
                
                .. attribute:: fwd_referenced
                
                	Table in fwd reference state?
                	**type**\:  bool
                
                .. attribute:: initial_converge
                
                	Table has reached convergence
                	**type**\:  bool
                
                .. attribute:: num_svdlcl_prefix
                
                	Num SVD local prefixes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_svdrem_prefix
                
                	Num SVD remote prefixes
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: prefix_limit_notified
                
                	Prefix limit state indicator
                	**type**\:  bool
                
                .. attribute:: safi
                
                	sub Address Family
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: table_name
                
                	Name of the table
                	**type**\:  str
                
                .. attribute:: table_version
                
                	Version no. of the table
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: tableid
                
                	Table id
                	**type**\:  int
                
                	**range:** 0..4294967295
                
                .. attribute:: version
                
                	Table version
                	**type**\:  int
                
                	**range:** 0..18446744073709551615
                
                .. attribute:: vrf_name
                
                	VRF Name of the table
                	**type**\:  str
                
                

                """

                _prefix = 'ip-rib-ipv4-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RibStdby.RibTableIds.RibTableId.Information, self).__init__()

                    self.yang_name = "information"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {}

                    self.afi = YLeaf(YType.uint32, "afi")

                    self.conf_prefix_limit = YLeaf(YType.uint32, "conf-prefix-limit")

                    self.current_prefix_count = YLeaf(YType.uint32, "current-prefix-count")

                    self.deleted = YLeaf(YType.boolean, "deleted")

                    self.fwd_referenced = YLeaf(YType.boolean, "fwd-referenced")

                    self.initial_converge = YLeaf(YType.boolean, "initial-converge")

                    self.num_svdlcl_prefix = YLeaf(YType.uint32, "num-svdlcl-prefix")

                    self.num_svdrem_prefix = YLeaf(YType.uint32, "num-svdrem-prefix")

                    self.prefix_limit_notified = YLeaf(YType.boolean, "prefix-limit-notified")

                    self.safi = YLeaf(YType.uint32, "safi")

                    self.table_name = YLeaf(YType.str, "table-name")

                    self.table_version = YLeaf(YType.uint64, "table-version")

                    self.tableid = YLeaf(YType.uint32, "tableid")

                    self.version = YLeaf(YType.uint64, "version")

                    self.vrf_name = YLeaf(YType.str, "vrf-name")
                    self._segment_path = lambda: "information"

                def __setattr__(self, name, value):
                    self._perform_setattr(RibStdby.RibTableIds.RibTableId.Information, ['afi', 'conf_prefix_limit', 'current_prefix_count', 'deleted', 'fwd_referenced', 'initial_converge', 'num_svdlcl_prefix', 'num_svdrem_prefix', 'prefix_limit_notified', 'safi', 'table_name', 'table_version', 'tableid', 'version', 'vrf_name'], name, value)


            class RibTableItfHndls(Entity):
                """
                RIB table interface
                
                .. attribute:: rib_table_itf_hndl
                
                	Interface handle
                	**type**\: list of    :py:class:`RibTableItfHndl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl>`
                
                

                """

                _prefix = 'ip-rib-ipv4-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RibStdby.RibTableIds.RibTableId.RibTableItfHndls, self).__init__()

                    self.yang_name = "rib-table-itf-hndls"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"rib-table-itf-hndl" : ("rib_table_itf_hndl", RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl)}

                    self.rib_table_itf_hndl = YList(self)
                    self._segment_path = lambda: "rib-table-itf-hndls"

                def __setattr__(self, name, value):
                    self._perform_setattr(RibStdby.RibTableIds.RibTableId.RibTableItfHndls, [], name, value)


                class RibTableItfHndl(Entity):
                    """
                    Interface handle
                    
                    .. attribute:: handle  <key>
                    
                    	Itf Handle
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: itf_route
                    
                    	Route information for a specific table/interface 
                    	**type**\: list of    :py:class:`ItfRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv4-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, self).__init__()

                        self.yang_name = "rib-table-itf-hndl"
                        self.yang_parent_name = "rib-table-itf-hndls"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {}
                        self._child_list_classes = {"itf-route" : ("itf_route", RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute)}

                        self.handle = YLeaf(YType.int32, "handle")

                        self.itf_route = YList(self)
                        self._segment_path = lambda: "rib-table-itf-hndl" + "[handle='" + self.handle.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl, ['handle'], name, value)


                    class ItfRoute(Entity):
                        """
                        Route information for a specific
                        table/interface 
                        
                        .. attribute:: address  <key>
                        
                        	Network Address
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: active
                        
                        	Is the route active or backup
                        	**type**\:  bool
                        
                        .. attribute:: attribute_identity
                        
                        	BGP Attribute ID
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: client_id
                        
                        	Client adding the route to RIB
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: distance
                        
                        	Distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion
                        
                        	Route has a diversion path
                        	**type**\:  bool
                        
                        .. attribute:: diversion_distance
                        
                        	Diversion distance of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: diversion_proto_name
                        
                        	Diversion route protocol name
                        	**type**\:  str
                        
                        .. attribute:: extended_flags
                        
                        	Extended Route flags
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: flags
                        
                        	Route flags
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flow_tag
                        
                        	Flow tag
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: fwd_class
                        
                        	Forward Class
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: instance
                        
                        	Instance name
                        	**type**\:  str
                        
                        .. attribute:: metric
                        
                        	Route metric
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: paths_count
                        
                        	Number of paths
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pic_count
                        
                        	Number of pic paths in this route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix
                        
                        	Route prefix
                        	**type**\:  str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: prefix_length_xr
                        
                        	Length of prefix
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: priority
                        
                        	Route priority
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: protocol_id
                        
                        	Protocol advertising the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: protocol_name
                        
                        	 Name of Protocol
                        	**type**\:  str
                        
                        .. attribute:: qos_group
                        
                        	Route qos group
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_age
                        
                        	Age of route (seconds)
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: route_label
                        
                        	Local label of the route
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: route_modify_time
                        
                        	Route modification time(nanoseconds)
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: nanosecond
                        
                        .. attribute:: route_path
                        
                        	Path(s) of the route
                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath>`
                        
                        .. attribute:: route_precedence
                        
                        	Route ip precedence
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: route_type
                        
                        	Route type
                        	**type**\:  int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: route_version
                        
                        	Route version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: svd_type
                        
                        	SVD Type of route
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: tag
                        
                        	Opaque proto specific info
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tbl_version
                        
                        	Table Version
                        	**type**\:  int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: traffic_index
                        
                        	BGP Traffic Index
                        	**type**\:  int
                        
                        	**range:** 0..255
                        
                        .. attribute:: version
                        
                        	Route Version
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, self).__init__()

                            self.yang_name = "itf-route"
                            self.yang_parent_name = "rib-table-itf-hndl"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath)}
                            self._child_list_classes = {}

                            self.address = YLeaf(YType.str, "address")

                            self.active = YLeaf(YType.boolean, "active")

                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                            self.client_id = YLeaf(YType.uint32, "client-id")

                            self.distance = YLeaf(YType.uint32, "distance")

                            self.diversion = YLeaf(YType.boolean, "diversion")

                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                            self.flags = YLeaf(YType.uint32, "flags")

                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                            self.instance = YLeaf(YType.str, "instance")

                            self.metric = YLeaf(YType.uint32, "metric")

                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                            self.prefix = YLeaf(YType.str, "prefix")

                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                            self.priority = YLeaf(YType.uint8, "priority")

                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                            self.route_age = YLeaf(YType.uint32, "route-age")

                            self.route_label = YLeaf(YType.uint32, "route-label")

                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                            self.route_type = YLeaf(YType.uint16, "route-type")

                            self.route_version = YLeaf(YType.uint32, "route-version")

                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                            self.tag = YLeaf(YType.uint32, "tag")

                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                            self.version = YLeaf(YType.uint32, "version")

                            self.route_path = RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath()
                            self.route_path.parent = self
                            self._children_name_map["route_path"] = "route-path"
                            self._children_yang_names.add("route-path")
                            self._segment_path = lambda: "itf-route" + "[address='" + self.address.get() + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute, ['address', 'active', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                        class RoutePath(Entity):
                            """
                            Path(s) of the route
                            
                            .. attribute:: ipv4_rib_edm_path
                            
                            	ipv4 rib edm path
                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv4-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, self).__init__()

                                self.yang_name = "route-path"
                                self.yang_parent_name = "itf-route"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {}
                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath)}

                                self.ipv4_rib_edm_path = YList(self)
                                self._segment_path = lambda: "route-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath, [], name, value)


                            class Ipv4RibEdmPath(Entity):
                                """
                                ipv4 rib edm path
                                
                                .. attribute:: address
                                
                                	Nexthop
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pathid
                                
                                	Path id of this path's backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: binding_label
                                
                                	binding Label for this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flags
                                
                                	Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: flags64
                                
                                	Flags extended to 64 bits
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: has_labelstk
                                
                                	Path has a label stack
                                	**type**\:  bool
                                
                                .. attribute:: information_source
                                
                                	Infosource
                                	**type**\:  str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: interface_name
                                
                                	Interface Name
                                	**type**\:  str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: labelstk
                                
                                	Outgoing label stack for this path
                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                
                                .. attribute:: load_metric
                                
                                	Load Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: looped
                                
                                	Looping path
                                	**type**\:  bool
                                
                                .. attribute:: metric
                                
                                	Metrics
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mpls_feid
                                
                                	Fib mpls encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: mvpn_present
                                
                                	MVPN attribute present
                                	**type**\:  bool
                                
                                .. attribute:: next_hop_afi
                                
                                	NH afi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id
                                
                                	NHID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_id_refcount
                                
                                	NHID references
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_safi
                                
                                	NH safi
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_id
                                
                                	Nexthop tableid
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop_table_name
                                
                                	NH table name
                                	**type**\:  str
                                
                                .. attribute:: next_hop_vrf_name
                                
                                	VRF Name of the nh table
                                	**type**\:  str
                                
                                .. attribute:: nhid_feid
                                
                                	Fib nhid encap id
                                	**type**\:  int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: num_labels
                                
                                	Number of labels in stack
                                	**type**\:  int
                                
                                	**range:** 0..255
                                
                                .. attribute:: number_of_extended_communities
                                
                                	Number of extended communities
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ospf_area_id
                                
                                	OSPF area associated with the path
                                	**type**\:  str
                                
                                .. attribute:: path_rt_present
                                
                                	Path RT present
                                	**type**\:  bool
                                
                                .. attribute:: pathid
                                
                                	Path id of this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: private_flags
                                
                                	Private Flags
                                	**type**\:  int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: ref_cnt_of_backup
                                
                                	Refcnt of backup
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_backup_addr
                                
                                	Remote backup node address
                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                
                                .. attribute:: route_label
                                
                                	Label associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: segmented_nexthop_present
                                
                                	SegmentedNexthopPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_asrt_present
                                
                                	SOURCEASRTPresent
                                	**type**\:  bool
                                
                                .. attribute:: source_rd_present
                                
                                	SOURCERDPresent
                                	**type**\:  bool
                                
                                .. attribute:: tunnel_id
                                
                                	Tunnel ID associated with this path
                                	**type**\:  int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: v6_information_source
                                
                                	V6 Infosource
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: v6_nexthop
                                
                                	V6 nexthop
                                	**type**\:  str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vrf_import_rt_present
                                
                                	VRFIMPORTRTPresent
                                	**type**\:  bool
                                
                                

                                """

                                _prefix = 'ip-rib-ipv4-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                    self.yang_name = "ipv4-rib-edm-path"
                                    self.yang_parent_name = "route-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                    self.address = YLeaf(YType.str, "address")

                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                    self.flags = YLeaf(YType.uint16, "flags")

                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                    self.information_source = YLeaf(YType.str, "information-source")

                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                    self.looped = YLeaf(YType.boolean, "looped")

                                    self.metric = YLeaf(YType.uint32, "metric")

                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                    self.labelstk = YList(self)
                                    self.remote_backup_addr = YList(self)
                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                class Labelstk(Entity):
                                    """
                                    Outgoing label stack for this path
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv4-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                        self.yang_name = "labelstk"
                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.uint32, "entry")
                                        self._segment_path = lambda: "labelstk"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                class RemoteBackupAddr(Entity):
                                    """
                                    Remote backup node address
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\:  str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv4-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                        self.yang_name = "remote-backup-addr"
                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {}
                                        self._child_list_classes = {}

                                        self.entry = YLeaf(YType.str, "entry")
                                        self._segment_path = lambda: "remote-backup-addr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RibStdby.RibTableIds.RibTableId.RibTableItfHndls.RibTableItfHndl.ItfRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


            class SummaryProtos(Entity):
                """
                RIB table summary
                
                .. attribute:: summary_proto
                
                	Route summary information for a specific table/protocol 
                	**type**\: list of    :py:class:`SummaryProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto>`
                
                

                """

                _prefix = 'ip-rib-ipv4-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RibStdby.RibTableIds.RibTableId.SummaryProtos, self).__init__()

                    self.yang_name = "summary-protos"
                    self.yang_parent_name = "rib-table-id"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"summary-proto" : ("summary_proto", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto)}

                    self.summary_proto = YList(self)
                    self._segment_path = lambda: "summary-protos"

                def __setattr__(self, name, value):
                    self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos, [], name, value)


                class SummaryProto(Entity):
                    """
                    Route summary information for a specific
                    table/protocol 
                    
                    .. attribute:: protoid  <key>
                    
                    	Proto ID
                    	**type**\:  int
                    
                    	**range:** \-2147483648..2147483647
                    
                    .. attribute:: instance
                    
                    	Instance
                    	**type**\:  str
                    
                    .. attribute:: name
                    
                    	Proto name
                    	**type**\:  str
                    
                    .. attribute:: proto_route_count
                    
                    	Count for proto. instance
                    	**type**\:   :py:class:`ProtoRouteCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount>`
                    
                    .. attribute:: rtype_bgp_ext
                    
                    	eBGP route
                    	**type**\:   :py:class:`RtypeBgpExt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt>`
                    
                    .. attribute:: rtype_bgp_int
                    
                    	iBGP route
                    	**type**\:   :py:class:`RtypeBgpInt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt>`
                    
                    .. attribute:: rtype_bgp_loc
                    
                    	BGP local route
                    	**type**\:   :py:class:`RtypeBgpLoc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc>`
                    
                    .. attribute:: rtype_igrp2_ext
                    
                    	EIGRP external route
                    	**type**\:   :py:class:`RtypeIgrp2Ext <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext>`
                    
                    .. attribute:: rtype_igrp2_int
                    
                    	EIGRP internal route
                    	**type**\:   :py:class:`RtypeIgrp2Int <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int>`
                    
                    .. attribute:: rtype_isis_l1
                    
                    	IS\-IS level 1 route
                    	**type**\:   :py:class:`RtypeIsisL1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1>`
                    
                    .. attribute:: rtype_isis_l1_ia
                    
                    	IS\-IS level1 inter\-area route
                    	**type**\:   :py:class:`RtypeIsisL1Ia <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia>`
                    
                    .. attribute:: rtype_isis_l2
                    
                    	IS\-IS level 2 route
                    	**type**\:   :py:class:`RtypeIsisL2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2>`
                    
                    .. attribute:: rtype_isis_sum
                    
                    	IS\-IS summary route
                    	**type**\:   :py:class:`RtypeIsisSum <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum>`
                    
                    .. attribute:: rtype_none
                    
                    	No route type
                    	**type**\:   :py:class:`RtypeNone <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone>`
                    
                    .. attribute:: rtype_ospf_extern1
                    
                    	OSPF external route of type 1
                    	**type**\:   :py:class:`RtypeOspfExtern1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1>`
                    
                    .. attribute:: rtype_ospf_extern2
                    
                    	OSPF external route of type 2
                    	**type**\:   :py:class:`RtypeOspfExtern2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2>`
                    
                    .. attribute:: rtype_ospf_inter
                    
                    	OSPF route across diff. areas
                    	**type**\:   :py:class:`RtypeOspfInter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter>`
                    
                    .. attribute:: rtype_ospf_intra
                    
                    	OSPF route within an area
                    	**type**\:   :py:class:`RtypeOspfIntra <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra>`
                    
                    .. attribute:: rtype_ospf_nssa1
                    
                    	OSPF NSSA ext. route type 1
                    	**type**\:   :py:class:`RtypeOspfNssa1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1>`
                    
                    .. attribute:: rtype_ospf_nssa2
                    
                    	OSPF NSSA ext. route type 2
                    	**type**\:   :py:class:`RtypeOspfNssa2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2>`
                    
                    .. attribute:: rtype_other
                    
                    	Unknown route type
                    	**type**\:   :py:class:`RtypeOther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv4-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto, self).__init__()

                        self.yang_name = "summary-proto"
                        self.yang_parent_name = "summary-protos"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"proto-route-count" : ("proto_route_count", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount), "rtype-bgp-ext" : ("rtype_bgp_ext", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt), "rtype-bgp-int" : ("rtype_bgp_int", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt), "rtype-bgp-loc" : ("rtype_bgp_loc", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc), "rtype-igrp2-ext" : ("rtype_igrp2_ext", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext), "rtype-igrp2-int" : ("rtype_igrp2_int", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int), "rtype-isis-l1" : ("rtype_isis_l1", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1), "rtype-isis-l1-ia" : ("rtype_isis_l1_ia", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia), "rtype-isis-l2" : ("rtype_isis_l2", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2), "rtype-isis-sum" : ("rtype_isis_sum", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum), "rtype-none" : ("rtype_none", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone), "rtype-ospf-extern1" : ("rtype_ospf_extern1", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1), "rtype-ospf-extern2" : ("rtype_ospf_extern2", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2), "rtype-ospf-inter" : ("rtype_ospf_inter", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter), "rtype-ospf-intra" : ("rtype_ospf_intra", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra), "rtype-ospf-nssa1" : ("rtype_ospf_nssa1", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1), "rtype-ospf-nssa2" : ("rtype_ospf_nssa2", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2), "rtype-other" : ("rtype_other", RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther)}
                        self._child_list_classes = {}

                        self.protoid = YLeaf(YType.int32, "protoid")

                        self.instance = YLeaf(YType.str, "instance")

                        self.name = YLeaf(YType.str, "name")

                        self.proto_route_count = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount()
                        self.proto_route_count.parent = self
                        self._children_name_map["proto_route_count"] = "proto-route-count"
                        self._children_yang_names.add("proto-route-count")

                        self.rtype_bgp_ext = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt()
                        self.rtype_bgp_ext.parent = self
                        self._children_name_map["rtype_bgp_ext"] = "rtype-bgp-ext"
                        self._children_yang_names.add("rtype-bgp-ext")

                        self.rtype_bgp_int = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt()
                        self.rtype_bgp_int.parent = self
                        self._children_name_map["rtype_bgp_int"] = "rtype-bgp-int"
                        self._children_yang_names.add("rtype-bgp-int")

                        self.rtype_bgp_loc = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc()
                        self.rtype_bgp_loc.parent = self
                        self._children_name_map["rtype_bgp_loc"] = "rtype-bgp-loc"
                        self._children_yang_names.add("rtype-bgp-loc")

                        self.rtype_igrp2_ext = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext()
                        self.rtype_igrp2_ext.parent = self
                        self._children_name_map["rtype_igrp2_ext"] = "rtype-igrp2-ext"
                        self._children_yang_names.add("rtype-igrp2-ext")

                        self.rtype_igrp2_int = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int()
                        self.rtype_igrp2_int.parent = self
                        self._children_name_map["rtype_igrp2_int"] = "rtype-igrp2-int"
                        self._children_yang_names.add("rtype-igrp2-int")

                        self.rtype_isis_l1 = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1()
                        self.rtype_isis_l1.parent = self
                        self._children_name_map["rtype_isis_l1"] = "rtype-isis-l1"
                        self._children_yang_names.add("rtype-isis-l1")

                        self.rtype_isis_l1_ia = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia()
                        self.rtype_isis_l1_ia.parent = self
                        self._children_name_map["rtype_isis_l1_ia"] = "rtype-isis-l1-ia"
                        self._children_yang_names.add("rtype-isis-l1-ia")

                        self.rtype_isis_l2 = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2()
                        self.rtype_isis_l2.parent = self
                        self._children_name_map["rtype_isis_l2"] = "rtype-isis-l2"
                        self._children_yang_names.add("rtype-isis-l2")

                        self.rtype_isis_sum = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum()
                        self.rtype_isis_sum.parent = self
                        self._children_name_map["rtype_isis_sum"] = "rtype-isis-sum"
                        self._children_yang_names.add("rtype-isis-sum")

                        self.rtype_none = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone()
                        self.rtype_none.parent = self
                        self._children_name_map["rtype_none"] = "rtype-none"
                        self._children_yang_names.add("rtype-none")

                        self.rtype_ospf_extern1 = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1()
                        self.rtype_ospf_extern1.parent = self
                        self._children_name_map["rtype_ospf_extern1"] = "rtype-ospf-extern1"
                        self._children_yang_names.add("rtype-ospf-extern1")

                        self.rtype_ospf_extern2 = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2()
                        self.rtype_ospf_extern2.parent = self
                        self._children_name_map["rtype_ospf_extern2"] = "rtype-ospf-extern2"
                        self._children_yang_names.add("rtype-ospf-extern2")

                        self.rtype_ospf_inter = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter()
                        self.rtype_ospf_inter.parent = self
                        self._children_name_map["rtype_ospf_inter"] = "rtype-ospf-inter"
                        self._children_yang_names.add("rtype-ospf-inter")

                        self.rtype_ospf_intra = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra()
                        self.rtype_ospf_intra.parent = self
                        self._children_name_map["rtype_ospf_intra"] = "rtype-ospf-intra"
                        self._children_yang_names.add("rtype-ospf-intra")

                        self.rtype_ospf_nssa1 = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1()
                        self.rtype_ospf_nssa1.parent = self
                        self._children_name_map["rtype_ospf_nssa1"] = "rtype-ospf-nssa1"
                        self._children_yang_names.add("rtype-ospf-nssa1")

                        self.rtype_ospf_nssa2 = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2()
                        self.rtype_ospf_nssa2.parent = self
                        self._children_name_map["rtype_ospf_nssa2"] = "rtype-ospf-nssa2"
                        self._children_yang_names.add("rtype-ospf-nssa2")

                        self.rtype_other = RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther()
                        self.rtype_other.parent = self
                        self._children_name_map["rtype_other"] = "rtype-other"
                        self._children_yang_names.add("rtype-other")
                        self._segment_path = lambda: "summary-proto" + "[protoid='" + self.protoid.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto, ['protoid', 'instance', 'name'], name, value)


                    class ProtoRouteCount(Entity):
                        """
                        Count for proto. instance
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, self).__init__()

                            self.yang_name = "proto-route-count"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "proto-route-count"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.ProtoRouteCount, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeBgpExt(Entity):
                        """
                        eBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, self).__init__()

                            self.yang_name = "rtype-bgp-ext"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-bgp-ext"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpExt, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeBgpInt(Entity):
                        """
                        iBGP route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, self).__init__()

                            self.yang_name = "rtype-bgp-int"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-bgp-int"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpInt, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeBgpLoc(Entity):
                        """
                        BGP local route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, self).__init__()

                            self.yang_name = "rtype-bgp-loc"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-bgp-loc"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeBgpLoc, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIgrp2Ext(Entity):
                        """
                        EIGRP external route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, self).__init__()

                            self.yang_name = "rtype-igrp2-ext"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-igrp2-ext"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Ext, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIgrp2Int(Entity):
                        """
                        EIGRP internal route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, self).__init__()

                            self.yang_name = "rtype-igrp2-int"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-igrp2-int"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIgrp2Int, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIsisL1(Entity):
                        """
                        IS\-IS level 1 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, self).__init__()

                            self.yang_name = "rtype-isis-l1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-isis-l1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIsisL1Ia(Entity):
                        """
                        IS\-IS level1 inter\-area route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, self).__init__()

                            self.yang_name = "rtype-isis-l1-ia"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-isis-l1-ia"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL1Ia, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIsisL2(Entity):
                        """
                        IS\-IS level 2 route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, self).__init__()

                            self.yang_name = "rtype-isis-l2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-isis-l2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisL2, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeIsisSum(Entity):
                        """
                        IS\-IS summary route
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, self).__init__()

                            self.yang_name = "rtype-isis-sum"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-isis-sum"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeIsisSum, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeNone(Entity):
                        """
                        No route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, self).__init__()

                            self.yang_name = "rtype-none"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-none"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeNone, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfExtern1(Entity):
                        """
                        OSPF external route of type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, self).__init__()

                            self.yang_name = "rtype-ospf-extern1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-extern1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern1, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfExtern2(Entity):
                        """
                        OSPF external route of type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, self).__init__()

                            self.yang_name = "rtype-ospf-extern2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-extern2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfExtern2, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfInter(Entity):
                        """
                        OSPF route across diff. areas
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, self).__init__()

                            self.yang_name = "rtype-ospf-inter"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-inter"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfInter, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfIntra(Entity):
                        """
                        OSPF route within an area
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, self).__init__()

                            self.yang_name = "rtype-ospf-intra"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-intra"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfIntra, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfNssa1(Entity):
                        """
                        OSPF NSSA ext. route type 1
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, self).__init__()

                            self.yang_name = "rtype-ospf-nssa1"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-nssa1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa1, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOspfNssa2(Entity):
                        """
                        OSPF NSSA ext. route type 2
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, self).__init__()

                            self.yang_name = "rtype-ospf-nssa2"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-ospf-nssa2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOspfNssa2, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


                    class RtypeOther(Entity):
                        """
                        Unknown route type
                        
                        .. attribute:: active_routes_count
                        
                        	Number of active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_active_paths
                        
                        	Number of paths to active routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_paths
                        
                        	Number of paths to backup routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_backup_routes
                        
                        	Number of backup (inactive) routes
                        	**type**\:  int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, self).__init__()

                            self.yang_name = "rtype-other"
                            self.yang_parent_name = "summary-proto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {}

                            self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                            self.num_active_paths = YLeaf(YType.uint32, "num-active-paths")

                            self.num_backup_paths = YLeaf(YType.uint32, "num-backup-paths")

                            self.num_backup_routes = YLeaf(YType.uint32, "num-backup-routes")
                            self._segment_path = lambda: "rtype-other"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.RibTableIds.RibTableId.SummaryProtos.SummaryProto.RtypeOther, ['active_routes_count', 'num_active_paths', 'num_backup_paths', 'num_backup_routes'], name, value)


    class Vrfs(Entity):
        """
        VRF table
        
        .. attribute:: vrf
        
        	Specific VRF
        	**type**\: list of    :py:class:`Vrf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf>`
        
        

        """

        _prefix = 'ip-rib-ipv4-oper'
        _revision = '2015-11-09'

        def __init__(self):
            super(RibStdby.Vrfs, self).__init__()

            self.yang_name = "vrfs"
            self.yang_parent_name = "rib-stdby"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self._child_container_classes = {}
            self._child_list_classes = {"vrf" : ("vrf", RibStdby.Vrfs.Vrf)}

            self.vrf = YList(self)
            self._segment_path = lambda: "vrfs"
            self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib-stdby/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(RibStdby.Vrfs, [], name, value)


        class Vrf(Entity):
            """
            Specific VRF
            
            .. attribute:: vrf_name  <key>
            
            	Name of the VRF
            	**type**\:  str
            
            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
            
            .. attribute:: afs
            
            	Address Family (AF) table
            	**type**\:   :py:class:`Afs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs>`
            
            

            """

            _prefix = 'ip-rib-ipv4-oper'
            _revision = '2015-11-09'

            def __init__(self):
                super(RibStdby.Vrfs.Vrf, self).__init__()

                self.yang_name = "vrf"
                self.yang_parent_name = "vrfs"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self._child_container_classes = {"afs" : ("afs", RibStdby.Vrfs.Vrf.Afs)}
                self._child_list_classes = {}

                self.vrf_name = YLeaf(YType.str, "vrf-name")

                self.afs = RibStdby.Vrfs.Vrf.Afs()
                self.afs.parent = self
                self._children_name_map["afs"] = "afs"
                self._children_yang_names.add("afs")
                self._segment_path = lambda: "vrf" + "[vrf-name='" + self.vrf_name.get() + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-ip-rib-ipv4-oper:rib-stdby/vrfs/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(RibStdby.Vrfs.Vrf, ['vrf_name'], name, value)


            class Afs(Entity):
                """
                Address Family (AF) table
                
                .. attribute:: af
                
                	Specific AF information
                	**type**\: list of    :py:class:`Af <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af>`
                
                

                """

                _prefix = 'ip-rib-ipv4-oper'
                _revision = '2015-11-09'

                def __init__(self):
                    super(RibStdby.Vrfs.Vrf.Afs, self).__init__()

                    self.yang_name = "afs"
                    self.yang_parent_name = "vrf"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self._child_container_classes = {}
                    self._child_list_classes = {"af" : ("af", RibStdby.Vrfs.Vrf.Afs.Af)}

                    self.af = YList(self)
                    self._segment_path = lambda: "afs"

                def __setattr__(self, name, value):
                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs, [], name, value)


                class Af(Entity):
                    """
                    Specific AF information
                    
                    .. attribute:: af_name  <key>
                    
                    	Name of the AF
                    	**type**\:  str
                    
                    	**pattern:** (IPv4)\|(IPv6)
                    
                    .. attribute:: safs
                    
                    	Subsequent Address Family (SAF) table
                    	**type**\:   :py:class:`Safs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs>`
                    
                    

                    """

                    _prefix = 'ip-rib-ipv4-oper'
                    _revision = '2015-11-09'

                    def __init__(self):
                        super(RibStdby.Vrfs.Vrf.Afs.Af, self).__init__()

                        self.yang_name = "af"
                        self.yang_parent_name = "afs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self._child_container_classes = {"safs" : ("safs", RibStdby.Vrfs.Vrf.Afs.Af.Safs)}
                        self._child_list_classes = {}

                        self.af_name = YLeaf(YType.str, "af-name")

                        self.safs = RibStdby.Vrfs.Vrf.Afs.Af.Safs()
                        self.safs.parent = self
                        self._children_name_map["safs"] = "safs"
                        self._children_yang_names.add("safs")
                        self._segment_path = lambda: "af" + "[af-name='" + self.af_name.get() + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af, ['af_name'], name, value)


                    class Safs(Entity):
                        """
                        Subsequent Address Family (SAF) table
                        
                        .. attribute:: saf
                        
                        	Specific SAF information
                        	**type**\: list of    :py:class:`Saf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf>`
                        
                        

                        """

                        _prefix = 'ip-rib-ipv4-oper'
                        _revision = '2015-11-09'

                        def __init__(self):
                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs, self).__init__()

                            self.yang_name = "safs"
                            self.yang_parent_name = "af"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self._child_container_classes = {}
                            self._child_list_classes = {"saf" : ("saf", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf)}

                            self.saf = YList(self)
                            self._segment_path = lambda: "safs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs, [], name, value)


                        class Saf(Entity):
                            """
                            Specific SAF information
                            
                            .. attribute:: saf_name  <key>
                            
                            	Name of the SAF
                            	**type**\:  str
                            
                            	**pattern:** (Unicast)\|(Multicast)
                            
                            .. attribute:: ip_rib_route_table_names
                            
                            	Global container of routes
                            	**type**\:   :py:class:`IpRibRouteTableNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames>`
                            
                            

                            """

                            _prefix = 'ip-rib-ipv4-oper'
                            _revision = '2015-11-09'

                            def __init__(self):
                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf, self).__init__()

                                self.yang_name = "saf"
                                self.yang_parent_name = "safs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self._child_container_classes = {"ip-rib-route-table-names" : ("ip_rib_route_table_names", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames)}
                                self._child_list_classes = {}

                                self.saf_name = YLeaf(YType.str, "saf-name")

                                self.ip_rib_route_table_names = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames()
                                self.ip_rib_route_table_names.parent = self
                                self._children_name_map["ip_rib_route_table_names"] = "ip-rib-route-table-names"
                                self._children_yang_names.add("ip-rib-route-table-names")
                                self._segment_path = lambda: "saf" + "[saf-name='" + self.saf_name.get() + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf, ['saf_name'], name, value)


                            class IpRibRouteTableNames(Entity):
                                """
                                Global container of routes
                                
                                .. attribute:: ip_rib_route_table_name
                                
                                	IP RIB Route table name for a topology
                                	**type**\: list of    :py:class:`IpRibRouteTableName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName>`
                                
                                

                                """

                                _prefix = 'ip-rib-ipv4-oper'
                                _revision = '2015-11-09'

                                def __init__(self):
                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, self).__init__()

                                    self.yang_name = "ip-rib-route-table-names"
                                    self.yang_parent_name = "saf"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self._child_container_classes = {}
                                    self._child_list_classes = {"ip-rib-route-table-name" : ("ip_rib_route_table_name", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName)}

                                    self.ip_rib_route_table_name = YList(self)
                                    self._segment_path = lambda: "ip-rib-route-table-names"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames, [], name, value)


                                class IpRibRouteTableName(Entity):
                                    """
                                    IP RIB Route table name for a topology
                                    
                                    .. attribute:: route_table_name  <key>
                                    
                                    	Name of the route table
                                    	**type**\:  str
                                    
                                    	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                    
                                    .. attribute:: adverts
                                    
                                    	Route advertiser information 
                                    	**type**\:   :py:class:`Adverts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts>`
                                    
                                    .. attribute:: backup_routes
                                    
                                    	Backup route information for the given table
                                    	**type**\:   :py:class:`BackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes>`
                                    
                                    .. attribute:: deleted_routes
                                    
                                    	Deleted
                                    	**type**\:   :py:class:`DeletedRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes>`
                                    
                                    .. attribute:: destination_kw
                                    
                                    	Destination KW
                                    	**type**\:   :py:class:`DestinationKw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw>`
                                    
                                    .. attribute:: opaques
                                    
                                    	Opaque information 
                                    	**type**\:   :py:class:`Opaques <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Contains the classification of routes by protocol
                                    	**type**\:   :py:class:`Protocol <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol>`
                                    
                                    .. attribute:: q_routes
                                    
                                    	Quarantine
                                    	**type**\:   :py:class:`QRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes>`
                                    
                                    .. attribute:: routes
                                    
                                    	Route information 
                                    	**type**\:   :py:class:`Routes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes>`
                                    
                                    

                                    """

                                    _prefix = 'ip-rib-ipv4-oper'
                                    _revision = '2015-11-09'

                                    def __init__(self):
                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, self).__init__()

                                        self.yang_name = "ip-rib-route-table-name"
                                        self.yang_parent_name = "ip-rib-route-table-names"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self._child_container_classes = {"adverts" : ("adverts", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts), "backup-routes" : ("backup_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes), "deleted-routes" : ("deleted_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes), "destination-kw" : ("destination_kw", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw), "opaques" : ("opaques", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques), "protocol" : ("protocol", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol), "q-routes" : ("q_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes), "routes" : ("routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes)}
                                        self._child_list_classes = {}

                                        self.route_table_name = YLeaf(YType.str, "route-table-name")

                                        self.adverts = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts()
                                        self.adverts.parent = self
                                        self._children_name_map["adverts"] = "adverts"
                                        self._children_yang_names.add("adverts")

                                        self.backup_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes()
                                        self.backup_routes.parent = self
                                        self._children_name_map["backup_routes"] = "backup-routes"
                                        self._children_yang_names.add("backup-routes")

                                        self.deleted_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes()
                                        self.deleted_routes.parent = self
                                        self._children_name_map["deleted_routes"] = "deleted-routes"
                                        self._children_yang_names.add("deleted-routes")

                                        self.destination_kw = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw()
                                        self.destination_kw.parent = self
                                        self._children_name_map["destination_kw"] = "destination-kw"
                                        self._children_yang_names.add("destination-kw")

                                        self.opaques = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques()
                                        self.opaques.parent = self
                                        self._children_name_map["opaques"] = "opaques"
                                        self._children_yang_names.add("opaques")

                                        self.protocol = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol()
                                        self.protocol.parent = self
                                        self._children_name_map["protocol"] = "protocol"
                                        self._children_yang_names.add("protocol")

                                        self.q_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes()
                                        self.q_routes.parent = self
                                        self._children_name_map["q_routes"] = "q-routes"
                                        self._children_yang_names.add("q-routes")

                                        self.routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes()
                                        self.routes.parent = self
                                        self._children_name_map["routes"] = "routes"
                                        self._children_yang_names.add("routes")
                                        self._segment_path = lambda: "ip-rib-route-table-name" + "[route-table-name='" + self.route_table_name.get() + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName, ['route_table_name'], name, value)


                                    class Adverts(Entity):
                                        """
                                        Route advertiser information 
                                        
                                        .. attribute:: advert
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Advert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, self).__init__()

                                            self.yang_name = "adverts"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"advert" : ("advert", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert)}

                                            self.advert = YList(self)
                                            self._segment_path = lambda: "adverts"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts, [], name, value)


                                        class Advert(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv4_rib_edm_advert
                                            
                                            	ipv4 rib edm advert
                                            	**type**\: list of    :py:class:`Ipv4RibEdmAdvert <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv4RibEdmAdvert>`
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, self).__init__()

                                                self.yang_name = "advert"
                                                self.yang_parent_name = "adverts"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"ipv4-rib-edm-advert" : ("ipv4_rib_edm_advert", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv4RibEdmAdvert)}

                                                self.address = YLeaf(YType.str, "address")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.ipv4_rib_edm_advert = YList(self)
                                                self._segment_path = lambda: "advert"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert, ['address', 'prefix_length'], name, value)


                                            class Ipv4RibEdmAdvert(Entity):
                                                """
                                                ipv4 rib edm advert
                                                
                                                .. attribute:: client_id
                                                
                                                	  Client advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: code
                                                
                                                	Protocol code
                                                	**type**\:  int
                                                
                                                	**range:** \-128..127
                                                
                                                .. attribute:: extended_communities
                                                
                                                	Extended communities
                                                	**type**\:  str
                                                
                                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                                
                                                .. attribute:: instance_name
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                	**length:** 0..41
                                                
                                                .. attribute:: number_of_extended_communities
                                                
                                                	Number of extended communities
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque
                                                
                                                	OSPF area\-id
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_opaque_flags
                                                
                                                	OSPF area\-id flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv4RibEdmAdvert, self).__init__()

                                                    self.yang_name = "ipv4-rib-edm-advert"
                                                    self.yang_parent_name = "advert"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {}

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.code = YLeaf(YType.int8, "code")

                                                    self.extended_communities = YLeaf(YType.str, "extended-communities")

                                                    self.instance_name = YLeaf(YType.str, "instance-name")

                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_opaque = YLeaf(YType.uint32, "protocol-opaque")

                                                    self.protocol_opaque_flags = YLeaf(YType.uint8, "protocol-opaque-flags")
                                                    self._segment_path = lambda: "ipv4-rib-edm-advert"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Adverts.Advert.Ipv4RibEdmAdvert, ['client_id', 'code', 'extended_communities', 'instance_name', 'number_of_extended_communities', 'protocol_id', 'protocol_opaque', 'protocol_opaque_flags'], name, value)


                                    class BackupRoutes(Entity):
                                        """
                                        Backup route information for the given
                                        table
                                        
                                        .. attribute:: backup_route
                                        
                                        	Route information for a specific backup address 
                                        	**type**\: list of    :py:class:`BackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, self).__init__()

                                            self.yang_name = "backup-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"backup-route" : ("backup_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute)}

                                            self.backup_route = YList(self)
                                            self._segment_path = lambda: "backup-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes, [], name, value)


                                        class BackupRoute(Entity):
                                            """
                                            Route information for a specific backup
                                            address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: protoid
                                            
                                            	Proto ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, self).__init__()

                                                self.yang_name = "backup-route"
                                                self.yang_parent_name = "backup-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath)}
                                                self._child_list_classes = {}

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.protoid = YLeaf(YType.int32, "protoid")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")
                                                self._segment_path = lambda: "backup-route"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'protoid', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv4_rib_edm_path
                                                
                                                	ipv4 rib edm path
                                                	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "backup-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath)}

                                                    self.ipv4_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath, [], name, value)


                                                class Ipv4RibEdmPath(Entity):
                                                    """
                                                    ipv4 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv4-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        self.labelstk = YList(self)
                                                        self.remote_backup_addr = YList(self)
                                                        self._segment_path = lambda: "ipv4-rib-edm-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "labelstk"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.str, "entry")
                                                            self._segment_path = lambda: "remote-backup-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.BackupRoutes.BackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class DeletedRoutes(Entity):
                                        """
                                        Deleted
                                        
                                        .. attribute:: deleted_route
                                        
                                        	Route information for a specific deleted address 
                                        	**type**\: list of    :py:class:`DeletedRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, self).__init__()

                                            self.yang_name = "deleted-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"deleted-route" : ("deleted_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute)}

                                            self.deleted_route = YList(self)
                                            self._segment_path = lambda: "deleted-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes, [], name, value)


                                        class DeletedRoute(Entity):
                                            """
                                            Route information for a specific
                                            deleted address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, self).__init__()

                                                self.yang_name = "deleted-route"
                                                self.yang_parent_name = "deleted-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath)}
                                                self._child_list_classes = {}

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")
                                                self._segment_path = lambda: "deleted-route"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv4_rib_edm_path
                                                
                                                	ipv4 rib edm path
                                                	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "deleted-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath)}

                                                    self.ipv4_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath, [], name, value)


                                                class Ipv4RibEdmPath(Entity):
                                                    """
                                                    ipv4 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv4-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        self.labelstk = YList(self)
                                                        self.remote_backup_addr = YList(self)
                                                        self._segment_path = lambda: "ipv4-rib-edm-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "labelstk"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.str, "entry")
                                                            self._segment_path = lambda: "remote-backup-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DeletedRoutes.DeletedRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class DestinationKw(Entity):
                                        """
                                        Destination KW
                                        
                                        .. attribute:: dest_backup_routes
                                        
                                        	Backup
                                        	**type**\:   :py:class:`DestBackupRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes>`
                                        
                                        .. attribute:: dest_best_routes
                                        
                                        	Best Local
                                        	**type**\:   :py:class:`DestBestRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes>`
                                        
                                        .. attribute:: dest_next_hop_routes
                                        
                                        	Resolving next hop
                                        	**type**\:   :py:class:`DestNextHopRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes>`
                                        
                                        .. attribute:: dest_q_routes
                                        
                                        	Quarantine
                                        	**type**\:   :py:class:`DestQRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw, self).__init__()

                                            self.yang_name = "destination-kw"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"dest-backup-routes" : ("dest_backup_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes), "dest-best-routes" : ("dest_best_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes), "dest-next-hop-routes" : ("dest_next_hop_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes), "dest-q-routes" : ("dest_q_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes)}
                                            self._child_list_classes = {}

                                            self.dest_backup_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes()
                                            self.dest_backup_routes.parent = self
                                            self._children_name_map["dest_backup_routes"] = "dest-backup-routes"
                                            self._children_yang_names.add("dest-backup-routes")

                                            self.dest_best_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes()
                                            self.dest_best_routes.parent = self
                                            self._children_name_map["dest_best_routes"] = "dest-best-routes"
                                            self._children_yang_names.add("dest-best-routes")

                                            self.dest_next_hop_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes()
                                            self.dest_next_hop_routes.parent = self
                                            self._children_name_map["dest_next_hop_routes"] = "dest-next-hop-routes"
                                            self._children_yang_names.add("dest-next-hop-routes")

                                            self.dest_q_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes()
                                            self.dest_q_routes.parent = self
                                            self._children_name_map["dest_q_routes"] = "dest-q-routes"
                                            self._children_yang_names.add("dest-q-routes")
                                            self._segment_path = lambda: "destination-kw"


                                        class DestBackupRoutes(Entity):
                                            """
                                            Backup
                                            
                                            .. attribute:: dest_backup_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestBackupRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, self).__init__()

                                                self.yang_name = "dest-backup-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"dest-backup-route" : ("dest_backup_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute)}

                                                self.dest_backup_route = YList(self)
                                                self._segment_path = lambda: "dest-backup-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes, [], name, value)


                                            class DestBackupRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..32
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, self).__init__()

                                                    self.yang_name = "dest-backup-route"
                                                    self.yang_parent_name = "dest-backup-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath)}
                                                    self._child_list_classes = {}

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")
                                                    self._segment_path = lambda: "dest-backup-route"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv4_rib_edm_path
                                                    
                                                    	ipv4 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-backup-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath)}

                                                        self.ipv4_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath, [], name, value)


                                                    class Ipv4RibEdmPath(Entity):
                                                        """
                                                        ipv4 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv4-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                            self.labelstk = YList(self)
                                                            self.remote_backup_addr = YList(self)
                                                            self._segment_path = lambda: "ipv4-rib-edm-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "labelstk"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.str, "entry")
                                                                self._segment_path = lambda: "remote-backup-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBackupRoutes.DestBackupRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class DestBestRoutes(Entity):
                                            """
                                            Best Local
                                            
                                            .. attribute:: dest_best_route
                                            
                                            	Best local route information for a specific Address 
                                            	**type**\: list of    :py:class:`DestBestRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, self).__init__()

                                                self.yang_name = "dest-best-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"dest-best-route" : ("dest_best_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute)}

                                                self.dest_best_route = YList(self)
                                                self._segment_path = lambda: "dest-best-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes, [], name, value)


                                            class DestBestRoute(Entity):
                                                """
                                                Best local route information for a
                                                specific Address 
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, self).__init__()

                                                    self.yang_name = "dest-best-route"
                                                    self.yang_parent_name = "dest-best-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath)}
                                                    self._child_list_classes = {}

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")
                                                    self._segment_path = lambda: "dest-best-route" + "[address='" + self.address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute, ['address', 'active', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv4_rib_edm_path
                                                    
                                                    	ipv4 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-best-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath)}

                                                        self.ipv4_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath, [], name, value)


                                                    class Ipv4RibEdmPath(Entity):
                                                        """
                                                        ipv4 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv4-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                            self.labelstk = YList(self)
                                                            self.remote_backup_addr = YList(self)
                                                            self._segment_path = lambda: "ipv4-rib-edm-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "labelstk"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.str, "entry")
                                                                self._segment_path = lambda: "remote-backup-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestBestRoutes.DestBestRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class DestNextHopRoutes(Entity):
                                            """
                                            Resolving next hop
                                            
                                            .. attribute:: dest_next_hop_route
                                            
                                            	Nexthop information for a specific address
                                            	**type**\: list of    :py:class:`DestNextHopRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, self).__init__()

                                                self.yang_name = "dest-next-hop-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"dest-next-hop-route" : ("dest_next_hop_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute)}

                                                self.dest_next_hop_route = YList(self)
                                                self._segment_path = lambda: "dest-next-hop-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes, [], name, value)


                                            class DestNextHopRoute(Entity):
                                                """
                                                Nexthop information for a specific
                                                address
                                                
                                                .. attribute:: address  <key>
                                                
                                                	Network Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, self).__init__()

                                                    self.yang_name = "dest-next-hop-route"
                                                    self.yang_parent_name = "dest-next-hop-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath)}
                                                    self._child_list_classes = {}

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")
                                                    self._segment_path = lambda: "dest-next-hop-route" + "[address='" + self.address.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute, ['address', 'active', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv4_rib_edm_path
                                                    
                                                    	ipv4 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-next-hop-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath)}

                                                        self.ipv4_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath, [], name, value)


                                                    class Ipv4RibEdmPath(Entity):
                                                        """
                                                        ipv4 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv4-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                            self.labelstk = YList(self)
                                                            self.remote_backup_addr = YList(self)
                                                            self._segment_path = lambda: "ipv4-rib-edm-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "labelstk"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.str, "entry")
                                                                self._segment_path = lambda: "remote-backup-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestNextHopRoutes.DestNextHopRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class DestQRoutes(Entity):
                                            """
                                            Quarantine
                                            
                                            .. attribute:: dest_q_route
                                            
                                            	Route information of a specific Backup Address 
                                            	**type**\: list of    :py:class:`DestQRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, self).__init__()

                                                self.yang_name = "dest-q-routes"
                                                self.yang_parent_name = "destination-kw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"dest-q-route" : ("dest_q_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute)}

                                                self.dest_q_route = YList(self)
                                                self._segment_path = lambda: "dest-q-routes"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes, [], name, value)


                                            class DestQRoute(Entity):
                                                """
                                                Route information of a specific Backup
                                                Address 
                                                
                                                .. attribute:: active
                                                
                                                	Is the route active or backup
                                                	**type**\:  bool
                                                
                                                .. attribute:: address
                                                
                                                	Network Address
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: attribute_identity
                                                
                                                	BGP Attribute ID
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: client_id
                                                
                                                	Client adding the route to RIB
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: distance
                                                
                                                	Distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion
                                                
                                                	Route has a diversion path
                                                	**type**\:  bool
                                                
                                                .. attribute:: diversion_distance
                                                
                                                	Diversion distance of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: diversion_proto_name
                                                
                                                	Diversion route protocol name
                                                	**type**\:  str
                                                
                                                .. attribute:: extended_flags
                                                
                                                	Extended Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: flags
                                                
                                                	Route flags
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: flow_tag
                                                
                                                	Flow tag
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: fwd_class
                                                
                                                	Forward Class
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: instance
                                                
                                                	Instance name
                                                	**type**\:  str
                                                
                                                .. attribute:: metric
                                                
                                                	Route metric
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: paths_count
                                                
                                                	Number of paths
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: pic_count
                                                
                                                	Number of pic paths in this route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: prefix
                                                
                                                	Route prefix
                                                	**type**\:  str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: prefix_length
                                                
                                                	Prefix Length
                                                	**type**\:  int
                                                
                                                	**range:** 0..32
                                                
                                                .. attribute:: prefix_length_xr
                                                
                                                	Length of prefix
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: priority
                                                
                                                	Route priority
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: protocol_id
                                                
                                                	Protocol advertising the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: protocol_name
                                                
                                                	 Name of Protocol
                                                	**type**\:  str
                                                
                                                .. attribute:: qos_group
                                                
                                                	Route qos group
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_age
                                                
                                                	Age of route (seconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: second
                                                
                                                .. attribute:: route_label
                                                
                                                	Local label of the route
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: route_modify_time
                                                
                                                	Route modification time(nanoseconds)
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: nanosecond
                                                
                                                .. attribute:: route_path
                                                
                                                	Path(s) of the route
                                                	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath>`
                                                
                                                .. attribute:: route_precedence
                                                
                                                	Route ip precedence
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: route_type
                                                
                                                	Route type
                                                	**type**\:  int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: route_version
                                                
                                                	Route version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: svd_type
                                                
                                                	SVD Type of route
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: tag
                                                
                                                	Opaque proto specific info
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: tbl_version
                                                
                                                	Table Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: traffic_index
                                                
                                                	BGP Traffic Index
                                                	**type**\:  int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: version
                                                
                                                	Route Version
                                                	**type**\:  int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, self).__init__()

                                                    self.yang_name = "dest-q-route"
                                                    self.yang_parent_name = "dest-q-routes"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath)}
                                                    self._child_list_classes = {}

                                                    self.active = YLeaf(YType.boolean, "active")

                                                    self.address = YLeaf(YType.str, "address")

                                                    self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                    self.client_id = YLeaf(YType.uint32, "client-id")

                                                    self.distance = YLeaf(YType.uint32, "distance")

                                                    self.diversion = YLeaf(YType.boolean, "diversion")

                                                    self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                    self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                    self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                    self.flags = YLeaf(YType.uint32, "flags")

                                                    self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                    self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                    self.instance = YLeaf(YType.str, "instance")

                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                    self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                    self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                    self.prefix = YLeaf(YType.str, "prefix")

                                                    self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                    self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                    self.priority = YLeaf(YType.uint8, "priority")

                                                    self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                    self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                    self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                    self.route_age = YLeaf(YType.uint32, "route-age")

                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                    self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                    self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                    self.route_type = YLeaf(YType.uint16, "route-type")

                                                    self.route_version = YLeaf(YType.uint32, "route-version")

                                                    self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                    self.tag = YLeaf(YType.uint32, "tag")

                                                    self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                    self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                    self.version = YLeaf(YType.uint32, "version")

                                                    self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath()
                                                    self.route_path.parent = self
                                                    self._children_name_map["route_path"] = "route-path"
                                                    self._children_yang_names.add("route-path")
                                                    self._segment_path = lambda: "dest-q-route"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                class RoutePath(Entity):
                                                    """
                                                    Path(s) of the route
                                                    
                                                    .. attribute:: ipv4_rib_edm_path
                                                    
                                                    	ipv4 rib edm path
                                                    	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, self).__init__()

                                                        self.yang_name = "route-path"
                                                        self.yang_parent_name = "dest-q-route"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath)}

                                                        self.ipv4_rib_edm_path = YList(self)
                                                        self._segment_path = lambda: "route-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath, [], name, value)


                                                    class Ipv4RibEdmPath(Entity):
                                                        """
                                                        ipv4 rib edm path
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: backup_pathid
                                                        
                                                        	Path id of this path's backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: binding_label
                                                        
                                                        	binding Label for this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: flags64
                                                        
                                                        	Flags extended to 64 bits
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: has_labelstk
                                                        
                                                        	Path has a label stack
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: information_source
                                                        
                                                        	Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface Name
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                        
                                                        .. attribute:: labelstk
                                                        
                                                        	Outgoing label stack for this path
                                                        	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                        
                                                        .. attribute:: load_metric
                                                        
                                                        	Load Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: looped
                                                        
                                                        	Looping path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Metrics
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: mpls_feid
                                                        
                                                        	Fib mpls encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: mvpn_present
                                                        
                                                        	MVPN attribute present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: next_hop_afi
                                                        
                                                        	NH afi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id
                                                        
                                                        	NHID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_id_refcount
                                                        
                                                        	NHID references
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_safi
                                                        
                                                        	NH safi
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_id
                                                        
                                                        	Nexthop tableid
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: next_hop_table_name
                                                        
                                                        	NH table name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: next_hop_vrf_name
                                                        
                                                        	VRF Name of the nh table
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: nhid_feid
                                                        
                                                        	Fib nhid encap id
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: num_labels
                                                        
                                                        	Number of labels in stack
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: number_of_extended_communities
                                                        
                                                        	Number of extended communities
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: ospf_area_id
                                                        
                                                        	OSPF area associated with the path
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: path_rt_present
                                                        
                                                        	Path RT present
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: pathid
                                                        
                                                        	Path id of this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: private_flags
                                                        
                                                        	Private Flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: ref_cnt_of_backup
                                                        
                                                        	Refcnt of backup
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: remote_backup_addr
                                                        
                                                        	Remote backup node address
                                                        	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Label associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: segmented_nexthop_present
                                                        
                                                        	SegmentedNexthopPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_asrt_present
                                                        
                                                        	SOURCEASRTPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: source_rd_present
                                                        
                                                        	SOURCERDPresent
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: tunnel_id
                                                        
                                                        	Tunnel ID associated with this path
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: v6_information_source
                                                        
                                                        	V6 Infosource
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: v6_nexthop
                                                        
                                                        	V6 nexthop
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: vrf_import_rt_present
                                                        
                                                        	VRFIMPORTRTPresent
                                                        	**type**\:  bool
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                            self.yang_name = "ipv4-rib-edm-path"
                                                            self.yang_parent_name = "route-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                            self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                            self.flags = YLeaf(YType.uint16, "flags")

                                                            self.flags64 = YLeaf(YType.uint64, "flags64")

                                                            self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                            self.information_source = YLeaf(YType.str, "information-source")

                                                            self.interface_name = YLeaf(YType.str, "interface-name")

                                                            self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                            self.looped = YLeaf(YType.boolean, "looped")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                            self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                            self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                            self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                            self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                            self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                            self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                            self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                            self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                            self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                            self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                            self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                            self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                            self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                            self.pathid = YLeaf(YType.uint32, "pathid")

                                                            self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                            self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                            self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                            self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                            self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                            self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                            self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                            self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                            self.labelstk = YList(self)
                                                            self.remote_backup_addr = YList(self)
                                                            self._segment_path = lambda: "ipv4-rib-edm-path"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                        class Labelstk(Entity):
                                                            """
                                                            Outgoing label stack for this path
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  int
                                                            
                                                            	**range:** 0..4294967295
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                self.yang_name = "labelstk"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.uint32, "entry")
                                                                self._segment_path = lambda: "labelstk"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                        class RemoteBackupAddr(Entity):
                                                            """
                                                            Remote backup node address
                                                            
                                                            .. attribute:: entry
                                                            
                                                            	
                                                            	**type**\:  str
                                                            
                                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                self.yang_name = "remote-backup-addr"
                                                                self.yang_parent_name = "ipv4-rib-edm-path"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {}

                                                                self.entry = YLeaf(YType.str, "entry")
                                                                self._segment_path = lambda: "remote-backup-addr"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.DestinationKw.DestQRoutes.DestQRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class Opaques(Entity):
                                        """
                                        Opaque information 
                                        
                                        .. attribute:: opaque
                                        
                                        	Opaque item 
                                        	**type**\: list of    :py:class:`Opaque <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques.Opaque>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques, self).__init__()

                                            self.yang_name = "opaques"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"opaque" : ("opaque", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques.Opaque)}

                                            self.opaque = YList(self)
                                            self._segment_path = lambda: "opaques"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques, [], name, value)


                                        class Opaque(Entity):
                                            """
                                            Opaque item 
                                            
                                            .. attribute:: data
                                            
                                            	data
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: key
                                            
                                            	key
                                            	**type**\:  str
                                            
                                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                            
                                            .. attribute:: opaque_clientid
                                            
                                            	Opaque Client ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_data_size
                                            
                                            	Opaque data size
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_key_size
                                            
                                            	Opaque key size
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_key_type
                                            
                                            	Opaque key type
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_protoid
                                            
                                            	Opaque Proto ID
                                            	**type**\:  int
                                            
                                            	**range:** \-2147483648..2147483647
                                            
                                            .. attribute:: opaque_string
                                            
                                            	Opaque string
                                            	**type**\:  str
                                            
                                            	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques.Opaque, self).__init__()

                                                self.yang_name = "opaque"
                                                self.yang_parent_name = "opaques"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {}

                                                self.data = YLeaf(YType.str, "data")

                                                self.key = YLeaf(YType.str, "key")

                                                self.opaque_clientid = YLeaf(YType.int32, "opaque-clientid")

                                                self.opaque_data_size = YLeaf(YType.int32, "opaque-data-size")

                                                self.opaque_key_size = YLeaf(YType.int32, "opaque-key-size")

                                                self.opaque_key_type = YLeaf(YType.int32, "opaque-key-type")

                                                self.opaque_protoid = YLeaf(YType.int32, "opaque-protoid")

                                                self.opaque_string = YLeaf(YType.str, "opaque-string")
                                                self._segment_path = lambda: "opaque"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Opaques.Opaque, ['data', 'key', 'opaque_clientid', 'opaque_data_size', 'opaque_key_size', 'opaque_key_type', 'opaque_protoid', 'opaque_string'], name, value)


                                    class Protocol(Entity):
                                        """
                                        Contains the classification of routes by
                                        protocol
                                        
                                        .. attribute:: application
                                        
                                        	Application Protocol
                                        	**type**\:   :py:class:`Application <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application>`
                                        
                                        .. attribute:: bgp
                                        
                                        	BGP Protocol
                                        	**type**\:   :py:class:`Bgp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp>`
                                        
                                        .. attribute:: connected
                                        
                                        	Connected Protocol
                                        	**type**\:   :py:class:`Connected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected>`
                                        
                                        .. attribute:: dagr
                                        
                                        	DAGR Protocol(Direct\-Attached Gateway Redundancy) Protocol
                                        	**type**\:   :py:class:`Dagr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr>`
                                        
                                        .. attribute:: eigrp
                                        
                                        	EIGRP Protocol
                                        	**type**\:   :py:class:`Eigrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp>`
                                        
                                        .. attribute:: isis
                                        
                                        	ISIS Protocol
                                        	**type**\:   :py:class:`Isis <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis>`
                                        
                                        .. attribute:: local
                                        
                                        	Local Protocol
                                        	**type**\:   :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local>`
                                        
                                        .. attribute:: mobile
                                        
                                        	Mobile Protocol
                                        	**type**\:   :py:class:`Mobile <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile>`
                                        
                                        .. attribute:: ospf
                                        
                                        	OSPF Protocol
                                        	**type**\:   :py:class:`Ospf <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf>`
                                        
                                        .. attribute:: rip
                                        
                                        	RIP Protocol
                                        	**type**\:   :py:class:`Rip <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip>`
                                        
                                        .. attribute:: rpl
                                        
                                        	RPL Protocol
                                        	**type**\:   :py:class:`Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl>`
                                        
                                        .. attribute:: static
                                        
                                        	Static Protocol
                                        	**type**\:   :py:class:`Static <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static>`
                                        
                                        .. attribute:: subscriber
                                        
                                        	Subscriber Protocol
                                        	**type**\:   :py:class:`Subscriber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber>`
                                        
                                        .. attribute:: te_client
                                        
                                        	TEClient Protocol
                                        	**type**\:   :py:class:`TeClient <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol, self).__init__()

                                            self.yang_name = "protocol"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {"application" : ("application", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application), "bgp" : ("bgp", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp), "connected" : ("connected", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected), "dagr" : ("dagr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr), "eigrp" : ("eigrp", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp), "isis" : ("isis", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis), "local" : ("local", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local), "mobile" : ("mobile", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile), "ospf" : ("ospf", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf), "rip" : ("rip", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip), "rpl" : ("rpl", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl), "static" : ("static", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static), "subscriber" : ("subscriber", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber), "te-client" : ("te_client", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient)}
                                            self._child_list_classes = {}

                                            self.application = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application()
                                            self.application.parent = self
                                            self._children_name_map["application"] = "application"
                                            self._children_yang_names.add("application")

                                            self.bgp = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp()
                                            self.bgp.parent = self
                                            self._children_name_map["bgp"] = "bgp"
                                            self._children_yang_names.add("bgp")

                                            self.connected = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected()
                                            self.connected.parent = self
                                            self._children_name_map["connected"] = "connected"
                                            self._children_yang_names.add("connected")

                                            self.dagr = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr()
                                            self.dagr.parent = self
                                            self._children_name_map["dagr"] = "dagr"
                                            self._children_yang_names.add("dagr")

                                            self.eigrp = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp()
                                            self.eigrp.parent = self
                                            self._children_name_map["eigrp"] = "eigrp"
                                            self._children_yang_names.add("eigrp")

                                            self.isis = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis()
                                            self.isis.parent = self
                                            self._children_name_map["isis"] = "isis"
                                            self._children_yang_names.add("isis")

                                            self.local = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local()
                                            self.local.parent = self
                                            self._children_name_map["local"] = "local"
                                            self._children_yang_names.add("local")

                                            self.mobile = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile()
                                            self.mobile.parent = self
                                            self._children_name_map["mobile"] = "mobile"
                                            self._children_yang_names.add("mobile")

                                            self.ospf = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf()
                                            self.ospf.parent = self
                                            self._children_name_map["ospf"] = "ospf"
                                            self._children_yang_names.add("ospf")

                                            self.rip = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip()
                                            self.rip.parent = self
                                            self._children_name_map["rip"] = "rip"
                                            self._children_yang_names.add("rip")

                                            self.rpl = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl()
                                            self.rpl.parent = self
                                            self._children_name_map["rpl"] = "rpl"
                                            self._children_yang_names.add("rpl")

                                            self.static = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static()
                                            self.static.parent = self
                                            self._children_name_map["static"] = "static"
                                            self._children_yang_names.add("static")

                                            self.subscriber = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber()
                                            self.subscriber.parent = self
                                            self._children_name_map["subscriber"] = "subscriber"
                                            self._children_yang_names.add("subscriber")

                                            self.te_client = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient()
                                            self.te_client.parent = self
                                            self._children_name_map["te_client"] = "te-client"
                                            self._children_yang_names.add("te-client")
                                            self._segment_path = lambda: "protocol"


                                        class Application(Entity):
                                            """
                                            Application Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application, self).__init__()

                                                self.yang_name = "application"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "application"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "application"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Application.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Bgp(Entity):
                                            """
                                            BGP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, self).__init__()

                                                self.yang_name = "bgp"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "bgp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "bgp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Bgp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Connected(Entity):
                                            """
                                            Connected Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected, self).__init__()

                                                self.yang_name = "connected"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "connected"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "connected"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Connected.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Dagr(Entity):
                                            """
                                            DAGR Protocol(Direct\-Attached Gateway
                                            Redundancy) Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr, self).__init__()

                                                self.yang_name = "dagr"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "dagr"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "dagr"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Dagr.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Eigrp(Entity):
                                            """
                                            EIGRP Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, self).__init__()

                                                self.yang_name = "eigrp"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "eigrp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "eigrp"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Eigrp.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Isis(Entity):
                                            """
                                            ISIS Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, self).__init__()

                                                self.yang_name = "isis"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "isis"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "isis"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Isis.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Local(Entity):
                                            """
                                            Local Protocol
                                            
                                            .. attribute:: lspv
                                            
                                            	LSPV(Label Switched Path Verification) Protocol
                                            	**type**\:   :py:class:`Lspv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv>`
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs>`
                                            
                                            .. attribute:: smiap
                                            
                                            	SMIAP
                                            	**type**\:   :py:class:`Smiap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local, self).__init__()

                                                self.yang_name = "local"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"lspv" : ("lspv", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv), "non-as" : ("non_as", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs), "smiap" : ("smiap", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap)}
                                                self._child_list_classes = {}

                                                self.lspv = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv()
                                                self.lspv.parent = self
                                                self._children_name_map["lspv"] = "lspv"
                                                self._children_yang_names.add("lspv")

                                                self.non_as = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")

                                                self.smiap = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap()
                                                self.smiap.parent = self
                                                self._children_name_map["smiap"] = "smiap"
                                                self._children_yang_names.add("smiap")
                                                self._segment_path = lambda: "local"


                                            class Lspv(Entity):
                                                """
                                                LSPV(Label Switched Path Verification)
                                                Protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv, self).__init__()

                                                    self.yang_name = "lspv"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "lspv"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "lspv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "lspv"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Lspv.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                            class Smiap(Entity):
                                                """
                                                SMIAP
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap, self).__init__()

                                                    self.yang_name = "smiap"
                                                    self.yang_parent_name = "local"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "smiap"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "smiap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "smiap"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Local.Smiap.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Mobile(Entity):
                                            """
                                            Mobile Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile, self).__init__()

                                                self.yang_name = "mobile"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "mobile"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "mobile"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Mobile.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Ospf(Entity):
                                            """
                                            OSPF Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, self).__init__()

                                                self.yang_name = "ospf"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "ospf"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "ospf"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Ospf.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Rip(Entity):
                                            """
                                            RIP Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip, self).__init__()

                                                self.yang_name = "rip"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "rip"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "rip"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rip.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Rpl(Entity):
                                            """
                                            RPL Protocol
                                            
                                            .. attribute:: as_
                                            
                                            	Autonomous System of protocol
                                            	**type**\: list of    :py:class:`As_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, self).__init__()

                                                self.yang_name = "rpl"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {}
                                                self._child_list_classes = {"as" : ("as_", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_)}

                                                self.as_ = YList(self)
                                                self._segment_path = lambda: "rpl"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl, [], name, value)


                                            class As_(Entity):
                                                """
                                                Autonomous System of protocol
                                                
                                                .. attribute:: as_  <key>
                                                
                                                	Autonomous system
                                                	**type**\:  str
                                                
                                                	**pattern:** [\\w\\\-\\.\:,\_@#%$\\+=\\\|;]+
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, self).__init__()

                                                    self.yang_name = "as"
                                                    self.yang_parent_name = "rpl"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.as_ = YLeaf(YType.str, "as")

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "as" + "[as='" + self.as_.get() + "']"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_, ['as_'], name, value)


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Rpl.As_.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Static(Entity):
                                            """
                                            Static Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static, self).__init__()

                                                self.yang_name = "static"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "static"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "static"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Static.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class Subscriber(Entity):
                                            """
                                            Subscriber Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber, self).__init__()

                                                self.yang_name = "subscriber"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "subscriber"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "subscriber"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.Subscriber.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                        class TeClient(Entity):
                                            """
                                            TEClient Protocol
                                            
                                            .. attribute:: non_as
                                            
                                            	Non Autonomous System of protocol
                                            	**type**\:   :py:class:`NonAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs>`
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient, self).__init__()

                                                self.yang_name = "te-client"
                                                self.yang_parent_name = "protocol"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"non-as" : ("non_as", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs)}
                                                self._child_list_classes = {}

                                                self.non_as = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs()
                                                self.non_as.parent = self
                                                self._children_name_map["non_as"] = "non-as"
                                                self._children_yang_names.add("non-as")
                                                self._segment_path = lambda: "te-client"


                                            class NonAs(Entity):
                                                """
                                                Non Autonomous System of protocol
                                                
                                                .. attribute:: information
                                                
                                                	Protocol related Information
                                                	**type**\:   :py:class:`Information <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information>`
                                                
                                                .. attribute:: protocol_routes
                                                
                                                	Protocol specific Route
                                                	**type**\:   :py:class:`ProtocolRoutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs, self).__init__()

                                                    self.yang_name = "non-as"
                                                    self.yang_parent_name = "te-client"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {"information" : ("information", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information), "protocol-routes" : ("protocol_routes", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes)}
                                                    self._child_list_classes = {}

                                                    self.information = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information()
                                                    self.information.parent = self
                                                    self._children_name_map["information"] = "information"
                                                    self._children_yang_names.add("information")

                                                    self.protocol_routes = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes()
                                                    self.protocol_routes.parent = self
                                                    self._children_name_map["protocol_routes"] = "protocol-routes"
                                                    self._children_yang_names.add("protocol-routes")
                                                    self._segment_path = lambda: "non-as"


                                                class Information(Entity):
                                                    """
                                                    Protocol related Information
                                                    
                                                    .. attribute:: active_routes_count
                                                    
                                                    	Number of active routes (not deleted)
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: backup_routes_count
                                                    
                                                    	Number of backup routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: deleted_routes_count
                                                    
                                                    	Number of deleted routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: instance
                                                    
                                                    	Instance
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: paths_count
                                                    
                                                    	Number of paths for all routes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_clients_count
                                                    
                                                    	Number of proto clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: protocol_names
                                                    
                                                    	Name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: protocol_route_memory
                                                    
                                                    	Memory for proto's routes and paths in bytes
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: redistribution_client_count
                                                    
                                                    	Number of redist clients
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: routes_counts
                                                    
                                                    	Number of routes (including active, backup and deleted), where, number of backup routes = RoutesCounts \- ActiveRoutesCount \- DeletedRoutesCount 
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: version
                                                    
                                                    	Proto version
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, self).__init__()

                                                        self.yang_name = "information"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {}

                                                        self.active_routes_count = YLeaf(YType.uint32, "active-routes-count")

                                                        self.backup_routes_count = YLeaf(YType.uint32, "backup-routes-count")

                                                        self.deleted_routes_count = YLeaf(YType.uint32, "deleted-routes-count")

                                                        self.instance = YLeaf(YType.str, "instance")

                                                        self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                        self.protocol_clients_count = YLeaf(YType.uint32, "protocol-clients-count")

                                                        self.protocol_names = YLeaf(YType.str, "protocol-names")

                                                        self.protocol_route_memory = YLeaf(YType.uint32, "protocol-route-memory")

                                                        self.redistribution_client_count = YLeaf(YType.uint32, "redistribution-client-count")

                                                        self.routes_counts = YLeaf(YType.uint32, "routes-counts")

                                                        self.version = YLeaf(YType.uint32, "version")
                                                        self._segment_path = lambda: "information"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.Information, ['active_routes_count', 'backup_routes_count', 'deleted_routes_count', 'instance', 'paths_count', 'protocol_clients_count', 'protocol_names', 'protocol_route_memory', 'redistribution_client_count', 'routes_counts', 'version'], name, value)


                                                class ProtocolRoutes(Entity):
                                                    """
                                                    Protocol specific Route
                                                    
                                                    .. attribute:: protocol_route
                                                    
                                                    	 Route information of a specific Network Address 
                                                    	**type**\: list of    :py:class:`ProtocolRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, self).__init__()

                                                        self.yang_name = "protocol-routes"
                                                        self.yang_parent_name = "non-as"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"protocol-route" : ("protocol_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute)}

                                                        self.protocol_route = YList(self)
                                                        self._segment_path = lambda: "protocol-routes"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes, [], name, value)


                                                    class ProtocolRoute(Entity):
                                                        """
                                                         Route information of a specific Network
                                                        Address 
                                                        
                                                        .. attribute:: active
                                                        
                                                        	Is the route active or backup
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: address
                                                        
                                                        	Network Address
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: attribute_identity
                                                        
                                                        	BGP Attribute ID
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: client_id
                                                        
                                                        	Client adding the route to RIB
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: distance
                                                        
                                                        	Distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion
                                                        
                                                        	Route has a diversion path
                                                        	**type**\:  bool
                                                        
                                                        .. attribute:: diversion_distance
                                                        
                                                        	Diversion distance of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: diversion_proto_name
                                                        
                                                        	Diversion route protocol name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: extended_flags
                                                        
                                                        	Extended Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: flags
                                                        
                                                        	Route flags
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: flow_tag
                                                        
                                                        	Flow tag
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: fwd_class
                                                        
                                                        	Forward Class
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: instance
                                                        
                                                        	Instance name
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: metric
                                                        
                                                        	Route metric
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: paths_count
                                                        
                                                        	Number of paths
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: pic_count
                                                        
                                                        	Number of pic paths in this route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: prefix
                                                        
                                                        	Route prefix
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        .. attribute:: prefix_length
                                                        
                                                        	Prefix Length
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..32
                                                        
                                                        .. attribute:: prefix_length_xr
                                                        
                                                        	Length of prefix
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: priority
                                                        
                                                        	Route priority
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: protocol_id
                                                        
                                                        	Protocol advertising the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: protocol_name
                                                        
                                                        	 Name of Protocol
                                                        	**type**\:  str
                                                        
                                                        .. attribute:: qos_group
                                                        
                                                        	Route qos group
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_age
                                                        
                                                        	Age of route (seconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        	**units**\: second
                                                        
                                                        .. attribute:: route_label
                                                        
                                                        	Local label of the route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: route_modify_time
                                                        
                                                        	Route modification time(nanoseconds)
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        	**units**\: nanosecond
                                                        
                                                        .. attribute:: route_path
                                                        
                                                        	Path(s) of the route
                                                        	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath>`
                                                        
                                                        .. attribute:: route_precedence
                                                        
                                                        	Route ip precedence
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: route_type
                                                        
                                                        	Route type
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..65535
                                                        
                                                        .. attribute:: route_version
                                                        
                                                        	Route version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: svd_type
                                                        
                                                        	SVD Type of route
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: tag
                                                        
                                                        	Opaque proto specific info
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        .. attribute:: tbl_version
                                                        
                                                        	Table Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..18446744073709551615
                                                        
                                                        .. attribute:: traffic_index
                                                        
                                                        	BGP Traffic Index
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..255
                                                        
                                                        .. attribute:: version
                                                        
                                                        	Route Version
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, self).__init__()

                                                            self.yang_name = "protocol-route"
                                                            self.yang_parent_name = "protocol-routes"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath)}
                                                            self._child_list_classes = {}

                                                            self.active = YLeaf(YType.boolean, "active")

                                                            self.address = YLeaf(YType.str, "address")

                                                            self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                            self.client_id = YLeaf(YType.uint32, "client-id")

                                                            self.distance = YLeaf(YType.uint32, "distance")

                                                            self.diversion = YLeaf(YType.boolean, "diversion")

                                                            self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                            self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                            self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                            self.flags = YLeaf(YType.uint32, "flags")

                                                            self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                            self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                            self.instance = YLeaf(YType.str, "instance")

                                                            self.metric = YLeaf(YType.uint32, "metric")

                                                            self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                            self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                            self.prefix = YLeaf(YType.str, "prefix")

                                                            self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                            self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                            self.priority = YLeaf(YType.uint8, "priority")

                                                            self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                            self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                            self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                            self.route_age = YLeaf(YType.uint32, "route-age")

                                                            self.route_label = YLeaf(YType.uint32, "route-label")

                                                            self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                            self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                            self.route_type = YLeaf(YType.uint16, "route-type")

                                                            self.route_version = YLeaf(YType.uint32, "route-version")

                                                            self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                            self.tag = YLeaf(YType.uint32, "tag")

                                                            self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                            self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                            self.version = YLeaf(YType.uint32, "version")

                                                            self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath()
                                                            self.route_path.parent = self
                                                            self._children_name_map["route_path"] = "route-path"
                                                            self._children_yang_names.add("route-path")
                                                            self._segment_path = lambda: "protocol-route"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                                        class RoutePath(Entity):
                                                            """
                                                            Path(s) of the route
                                                            
                                                            .. attribute:: ipv4_rib_edm_path
                                                            
                                                            	ipv4 rib edm path
                                                            	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath>`
                                                            
                                                            

                                                            """

                                                            _prefix = 'ip-rib-ipv4-oper'
                                                            _revision = '2015-11-09'

                                                            def __init__(self):
                                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, self).__init__()

                                                                self.yang_name = "route-path"
                                                                self.yang_parent_name = "protocol-route"
                                                                self.is_top_level_class = False
                                                                self.has_list_ancestor = True
                                                                self._child_container_classes = {}
                                                                self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath)}

                                                                self.ipv4_rib_edm_path = YList(self)
                                                                self._segment_path = lambda: "route-path"

                                                            def __setattr__(self, name, value):
                                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath, [], name, value)


                                                            class Ipv4RibEdmPath(Entity):
                                                                """
                                                                ipv4 rib edm path
                                                                
                                                                .. attribute:: address
                                                                
                                                                	Nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: backup_pathid
                                                                
                                                                	Path id of this path's backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: binding_label
                                                                
                                                                	binding Label for this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: flags
                                                                
                                                                	Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: flags64
                                                                
                                                                	Flags extended to 64 bits
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: has_labelstk
                                                                
                                                                	Path has a label stack
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: information_source
                                                                
                                                                	Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: interface_name
                                                                
                                                                	Interface Name
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                                
                                                                .. attribute:: labelstk
                                                                
                                                                	Outgoing label stack for this path
                                                                	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                                
                                                                .. attribute:: load_metric
                                                                
                                                                	Load Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: looped
                                                                
                                                                	Looping path
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: metric
                                                                
                                                                	Metrics
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: mpls_feid
                                                                
                                                                	Fib mpls encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: mvpn_present
                                                                
                                                                	MVPN attribute present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: next_hop_afi
                                                                
                                                                	NH afi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id
                                                                
                                                                	NHID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_id_refcount
                                                                
                                                                	NHID references
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_safi
                                                                
                                                                	NH safi
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_id
                                                                
                                                                	Nexthop tableid
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: next_hop_table_name
                                                                
                                                                	NH table name
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: next_hop_vrf_name
                                                                
                                                                	VRF Name of the nh table
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: nhid_feid
                                                                
                                                                	Fib nhid encap id
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..18446744073709551615
                                                                
                                                                .. attribute:: num_labels
                                                                
                                                                	Number of labels in stack
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..255
                                                                
                                                                .. attribute:: number_of_extended_communities
                                                                
                                                                	Number of extended communities
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: ospf_area_id
                                                                
                                                                	OSPF area associated with the path
                                                                	**type**\:  str
                                                                
                                                                .. attribute:: path_rt_present
                                                                
                                                                	Path RT present
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: pathid
                                                                
                                                                	Path id of this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: private_flags
                                                                
                                                                	Private Flags
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..65535
                                                                
                                                                .. attribute:: ref_cnt_of_backup
                                                                
                                                                	Refcnt of backup
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: remote_backup_addr
                                                                
                                                                	Remote backup node address
                                                                	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                                
                                                                .. attribute:: route_label
                                                                
                                                                	Label associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: segmented_nexthop_present
                                                                
                                                                	SegmentedNexthopPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_asrt_present
                                                                
                                                                	SOURCEASRTPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: source_rd_present
                                                                
                                                                	SOURCERDPresent
                                                                	**type**\:  bool
                                                                
                                                                .. attribute:: tunnel_id
                                                                
                                                                	Tunnel ID associated with this path
                                                                	**type**\:  int
                                                                
                                                                	**range:** 0..4294967295
                                                                
                                                                .. attribute:: v6_information_source
                                                                
                                                                	V6 Infosource
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: v6_nexthop
                                                                
                                                                	V6 nexthop
                                                                	**type**\:  str
                                                                
                                                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                                
                                                                .. attribute:: vrf_import_rt_present
                                                                
                                                                	VRFIMPORTRTPresent
                                                                	**type**\:  bool
                                                                
                                                                

                                                                """

                                                                _prefix = 'ip-rib-ipv4-oper'
                                                                _revision = '2015-11-09'

                                                                def __init__(self):
                                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                                    self.yang_name = "ipv4-rib-edm-path"
                                                                    self.yang_parent_name = "route-path"
                                                                    self.is_top_level_class = False
                                                                    self.has_list_ancestor = True
                                                                    self._child_container_classes = {}
                                                                    self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                                    self.address = YLeaf(YType.str, "address")

                                                                    self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                                    self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                                    self.flags = YLeaf(YType.uint16, "flags")

                                                                    self.flags64 = YLeaf(YType.uint64, "flags64")

                                                                    self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                                    self.information_source = YLeaf(YType.str, "information-source")

                                                                    self.interface_name = YLeaf(YType.str, "interface-name")

                                                                    self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                                    self.looped = YLeaf(YType.boolean, "looped")

                                                                    self.metric = YLeaf(YType.uint32, "metric")

                                                                    self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                                    self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                                    self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                                    self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                                    self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                                    self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                                    self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                                    self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                                    self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                                    self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                                    self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                                    self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                                    self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                                    self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                                    self.pathid = YLeaf(YType.uint32, "pathid")

                                                                    self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                                    self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                                    self.route_label = YLeaf(YType.uint32, "route-label")

                                                                    self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                                    self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                                    self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                                    self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                                    self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                                    self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                                    self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                                    self.labelstk = YList(self)
                                                                    self.remote_backup_addr = YList(self)
                                                                    self._segment_path = lambda: "ipv4-rib-edm-path"

                                                                def __setattr__(self, name, value):
                                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                                class Labelstk(Entity):
                                                                    """
                                                                    Outgoing label stack for this path
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  int
                                                                    
                                                                    	**range:** 0..4294967295
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                                        self.yang_name = "labelstk"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.uint32, "entry")
                                                                        self._segment_path = lambda: "labelstk"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                                class RemoteBackupAddr(Entity):
                                                                    """
                                                                    Remote backup node address
                                                                    
                                                                    .. attribute:: entry
                                                                    
                                                                    	
                                                                    	**type**\:  str
                                                                    
                                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                                    
                                                                    

                                                                    """

                                                                    _prefix = 'ip-rib-ipv4-oper'
                                                                    _revision = '2015-11-09'

                                                                    def __init__(self):
                                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                                        self.yang_name = "remote-backup-addr"
                                                                        self.yang_parent_name = "ipv4-rib-edm-path"
                                                                        self.is_top_level_class = False
                                                                        self.has_list_ancestor = True
                                                                        self._child_container_classes = {}
                                                                        self._child_list_classes = {}

                                                                        self.entry = YLeaf(YType.str, "entry")
                                                                        self._segment_path = lambda: "remote-backup-addr"

                                                                    def __setattr__(self, name, value):
                                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Protocol.TeClient.NonAs.ProtocolRoutes.ProtocolRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class QRoutes(Entity):
                                        """
                                        Quarantine
                                        
                                        .. attribute:: q_route
                                        
                                        	Route information for a specific quarantined address 
                                        	**type**\: list of    :py:class:`QRoute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, self).__init__()

                                            self.yang_name = "q-routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"q-route" : ("q_route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute)}

                                            self.q_route = YList(self)
                                            self._segment_path = lambda: "q-routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes, [], name, value)


                                        class QRoute(Entity):
                                            """
                                            Route information for a specific
                                            quarantined address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, self).__init__()

                                                self.yang_name = "q-route"
                                                self.yang_parent_name = "q-routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath)}
                                                self._child_list_classes = {}

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")
                                                self._segment_path = lambda: "q-route"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'metric', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv4_rib_edm_path
                                                
                                                	ipv4 rib edm path
                                                	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "q-route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath)}

                                                    self.ipv4_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath, [], name, value)


                                                class Ipv4RibEdmPath(Entity):
                                                    """
                                                    ipv4 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv4-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        self.labelstk = YList(self)
                                                        self.remote_backup_addr = YList(self)
                                                        self._segment_path = lambda: "ipv4-rib-edm-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "labelstk"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.str, "entry")
                                                            self._segment_path = lambda: "remote-backup-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.QRoutes.QRoute.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)


                                    class Routes(Entity):
                                        """
                                        Route information 
                                        
                                        .. attribute:: route
                                        
                                        	Route information of a specific Network Address 
                                        	**type**\: list of    :py:class:`Route <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route>`
                                        
                                        

                                        """

                                        _prefix = 'ip-rib-ipv4-oper'
                                        _revision = '2015-11-09'

                                        def __init__(self):
                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, self).__init__()

                                            self.yang_name = "routes"
                                            self.yang_parent_name = "ip-rib-route-table-name"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self._child_container_classes = {}
                                            self._child_list_classes = {"route" : ("route", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route)}

                                            self.route = YList(self)
                                            self._segment_path = lambda: "routes"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes, [], name, value)


                                        class Route(Entity):
                                            """
                                            Route information of a specific Network
                                            Address 
                                            
                                            .. attribute:: active
                                            
                                            	Is the route active or backup
                                            	**type**\:  bool
                                            
                                            .. attribute:: address
                                            
                                            	Network Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: attribute_identity
                                            
                                            	BGP Attribute ID
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: client_id
                                            
                                            	Client adding the route to RIB
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: distance
                                            
                                            	Distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion
                                            
                                            	Route has a diversion path
                                            	**type**\:  bool
                                            
                                            .. attribute:: diversion_distance
                                            
                                            	Diversion distance of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: diversion_proto_name
                                            
                                            	Diversion route protocol name
                                            	**type**\:  str
                                            
                                            .. attribute:: extended_flags
                                            
                                            	Extended Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: flags
                                            
                                            	Route flags
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: flow_tag
                                            
                                            	Flow tag
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: fwd_class
                                            
                                            	Forward Class
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: instance
                                            
                                            	Instance name
                                            	**type**\:  str
                                            
                                            .. attribute:: interface_name
                                            
                                            	Outgoing Interface
                                            	**type**\:  str
                                            
                                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                                            
                                            .. attribute:: metric
                                            
                                            	Route metric
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: next_hop_address
                                            
                                            	NextHop Address
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: paths_count
                                            
                                            	Number of paths
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: pic_count
                                            
                                            	Number of pic paths in this route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: prefix
                                            
                                            	Route prefix
                                            	**type**\:  str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: prefix_length
                                            
                                            	Prefix Length
                                            	**type**\:  int
                                            
                                            	**range:** 0..32
                                            
                                            .. attribute:: prefix_length_xr
                                            
                                            	Length of prefix
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: priority
                                            
                                            	Route priority
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: protocol_id
                                            
                                            	Protocol advertising the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: protocol_name
                                            
                                            	 Name of Protocol
                                            	**type**\:  str
                                            
                                            .. attribute:: qos_group
                                            
                                            	Route qos group
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_age
                                            
                                            	Age of route (seconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: route_label
                                            
                                            	Local label of the route
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: route_modify_time
                                            
                                            	Route modification time(nanoseconds)
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: nanosecond
                                            
                                            .. attribute:: route_path
                                            
                                            	Path(s) of the route
                                            	**type**\:   :py:class:`RoutePath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath>`
                                            
                                            .. attribute:: route_precedence
                                            
                                            	Route ip precedence
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: route_type
                                            
                                            	Route type
                                            	**type**\:  int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: route_version
                                            
                                            	Route version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: svd_type
                                            
                                            	SVD Type of route
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: tag
                                            
                                            	Opaque proto specific info
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: tbl_version
                                            
                                            	Table Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: traffic_index
                                            
                                            	BGP Traffic Index
                                            	**type**\:  int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: version
                                            
                                            	Route Version
                                            	**type**\:  int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'ip-rib-ipv4-oper'
                                            _revision = '2015-11-09'

                                            def __init__(self):
                                                super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, self).__init__()

                                                self.yang_name = "route"
                                                self.yang_parent_name = "routes"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self._child_container_classes = {"route-path" : ("route_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath)}
                                                self._child_list_classes = {}

                                                self.active = YLeaf(YType.boolean, "active")

                                                self.address = YLeaf(YType.str, "address")

                                                self.attribute_identity = YLeaf(YType.uint32, "attribute-identity")

                                                self.client_id = YLeaf(YType.uint32, "client-id")

                                                self.distance = YLeaf(YType.uint32, "distance")

                                                self.diversion = YLeaf(YType.boolean, "diversion")

                                                self.diversion_distance = YLeaf(YType.uint32, "diversion-distance")

                                                self.diversion_proto_name = YLeaf(YType.str, "diversion-proto-name")

                                                self.extended_flags = YLeaf(YType.uint64, "extended-flags")

                                                self.flags = YLeaf(YType.uint32, "flags")

                                                self.flow_tag = YLeaf(YType.uint8, "flow-tag")

                                                self.fwd_class = YLeaf(YType.uint8, "fwd-class")

                                                self.instance = YLeaf(YType.str, "instance")

                                                self.interface_name = YLeaf(YType.str, "interface-name")

                                                self.metric = YLeaf(YType.uint32, "metric")

                                                self.next_hop_address = YLeaf(YType.str, "next-hop-address")

                                                self.paths_count = YLeaf(YType.uint32, "paths-count")

                                                self.pic_count = YLeaf(YType.uint8, "pic-count")

                                                self.prefix = YLeaf(YType.str, "prefix")

                                                self.prefix_length = YLeaf(YType.uint8, "prefix-length")

                                                self.prefix_length_xr = YLeaf(YType.uint8, "prefix-length-xr")

                                                self.priority = YLeaf(YType.uint8, "priority")

                                                self.protocol_id = YLeaf(YType.uint32, "protocol-id")

                                                self.protocol_name = YLeaf(YType.str, "protocol-name")

                                                self.qos_group = YLeaf(YType.uint8, "qos-group")

                                                self.route_age = YLeaf(YType.uint32, "route-age")

                                                self.route_label = YLeaf(YType.uint32, "route-label")

                                                self.route_modify_time = YLeaf(YType.uint64, "route-modify-time")

                                                self.route_precedence = YLeaf(YType.uint8, "route-precedence")

                                                self.route_type = YLeaf(YType.uint16, "route-type")

                                                self.route_version = YLeaf(YType.uint32, "route-version")

                                                self.svd_type = YLeaf(YType.uint8, "svd-type")

                                                self.tag = YLeaf(YType.uint32, "tag")

                                                self.tbl_version = YLeaf(YType.uint64, "tbl-version")

                                                self.traffic_index = YLeaf(YType.uint8, "traffic-index")

                                                self.version = YLeaf(YType.uint32, "version")

                                                self.route_path = RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath()
                                                self.route_path.parent = self
                                                self._children_name_map["route_path"] = "route-path"
                                                self._children_yang_names.add("route-path")
                                                self._segment_path = lambda: "route"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route, ['active', 'address', 'attribute_identity', 'client_id', 'distance', 'diversion', 'diversion_distance', 'diversion_proto_name', 'extended_flags', 'flags', 'flow_tag', 'fwd_class', 'instance', 'interface_name', 'metric', 'next_hop_address', 'paths_count', 'pic_count', 'prefix', 'prefix_length', 'prefix_length_xr', 'priority', 'protocol_id', 'protocol_name', 'qos_group', 'route_age', 'route_label', 'route_modify_time', 'route_precedence', 'route_type', 'route_version', 'svd_type', 'tag', 'tbl_version', 'traffic_index', 'version'], name, value)


                                            class RoutePath(Entity):
                                                """
                                                Path(s) of the route
                                                
                                                .. attribute:: ipv4_rib_edm_path
                                                
                                                	ipv4 rib edm path
                                                	**type**\: list of    :py:class:`Ipv4RibEdmPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath>`
                                                
                                                

                                                """

                                                _prefix = 'ip-rib-ipv4-oper'
                                                _revision = '2015-11-09'

                                                def __init__(self):
                                                    super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, self).__init__()

                                                    self.yang_name = "route-path"
                                                    self.yang_parent_name = "route"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self._child_container_classes = {}
                                                    self._child_list_classes = {"ipv4-rib-edm-path" : ("ipv4_rib_edm_path", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath)}

                                                    self.ipv4_rib_edm_path = YList(self)
                                                    self._segment_path = lambda: "route-path"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath, [], name, value)


                                                class Ipv4RibEdmPath(Entity):
                                                    """
                                                    ipv4 rib edm path
                                                    
                                                    .. attribute:: address
                                                    
                                                    	Nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: backup_pathid
                                                    
                                                    	Path id of this path's backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: binding_label
                                                    
                                                    	binding Label for this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: flags
                                                    
                                                    	Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: flags64
                                                    
                                                    	Flags extended to 64 bits
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: has_labelstk
                                                    
                                                    	Path has a label stack
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: information_source
                                                    
                                                    	Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface Name
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                                    
                                                    .. attribute:: labelstk
                                                    
                                                    	Outgoing label stack for this path
                                                    	**type**\: list of    :py:class:`Labelstk <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.Labelstk>`
                                                    
                                                    .. attribute:: load_metric
                                                    
                                                    	Load Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: looped
                                                    
                                                    	Looping path
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: metric
                                                    
                                                    	Metrics
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: mpls_feid
                                                    
                                                    	Fib mpls encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: mvpn_present
                                                    
                                                    	MVPN attribute present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: next_hop_afi
                                                    
                                                    	NH afi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id
                                                    
                                                    	NHID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_id_refcount
                                                    
                                                    	NHID references
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_safi
                                                    
                                                    	NH safi
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_id
                                                    
                                                    	Nexthop tableid
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: next_hop_table_name
                                                    
                                                    	NH table name
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: next_hop_vrf_name
                                                    
                                                    	VRF Name of the nh table
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: nhid_feid
                                                    
                                                    	Fib nhid encap id
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..18446744073709551615
                                                    
                                                    .. attribute:: num_labels
                                                    
                                                    	Number of labels in stack
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: number_of_extended_communities
                                                    
                                                    	Number of extended communities
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: ospf_area_id
                                                    
                                                    	OSPF area associated with the path
                                                    	**type**\:  str
                                                    
                                                    .. attribute:: path_rt_present
                                                    
                                                    	Path RT present
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: pathid
                                                    
                                                    	Path id of this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: private_flags
                                                    
                                                    	Private Flags
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ref_cnt_of_backup
                                                    
                                                    	Refcnt of backup
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: remote_backup_addr
                                                    
                                                    	Remote backup node address
                                                    	**type**\: list of    :py:class:`RemoteBackupAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_ip_rib_ipv4_oper.RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr>`
                                                    
                                                    .. attribute:: route_label
                                                    
                                                    	Label associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: segmented_nexthop_present
                                                    
                                                    	SegmentedNexthopPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_asrt_present
                                                    
                                                    	SOURCEASRTPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: source_rd_present
                                                    
                                                    	SOURCERDPresent
                                                    	**type**\:  bool
                                                    
                                                    .. attribute:: tunnel_id
                                                    
                                                    	Tunnel ID associated with this path
                                                    	**type**\:  int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: v6_information_source
                                                    
                                                    	V6 Infosource
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: v6_nexthop
                                                    
                                                    	V6 nexthop
                                                    	**type**\:  str
                                                    
                                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: vrf_import_rt_present
                                                    
                                                    	VRFIMPORTRTPresent
                                                    	**type**\:  bool
                                                    
                                                    

                                                    """

                                                    _prefix = 'ip-rib-ipv4-oper'
                                                    _revision = '2015-11-09'

                                                    def __init__(self):
                                                        super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath, self).__init__()

                                                        self.yang_name = "ipv4-rib-edm-path"
                                                        self.yang_parent_name = "route-path"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self._child_container_classes = {}
                                                        self._child_list_classes = {"labelstk" : ("labelstk", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.Labelstk), "remote-backup-addr" : ("remote_backup_addr", RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr)}

                                                        self.address = YLeaf(YType.str, "address")

                                                        self.backup_pathid = YLeaf(YType.uint32, "backup-pathid")

                                                        self.binding_label = YLeaf(YType.uint32, "binding-label")

                                                        self.flags = YLeaf(YType.uint16, "flags")

                                                        self.flags64 = YLeaf(YType.uint64, "flags64")

                                                        self.has_labelstk = YLeaf(YType.boolean, "has-labelstk")

                                                        self.information_source = YLeaf(YType.str, "information-source")

                                                        self.interface_name = YLeaf(YType.str, "interface-name")

                                                        self.load_metric = YLeaf(YType.uint32, "load-metric")

                                                        self.looped = YLeaf(YType.boolean, "looped")

                                                        self.metric = YLeaf(YType.uint32, "metric")

                                                        self.mpls_feid = YLeaf(YType.uint64, "mpls-feid")

                                                        self.mvpn_present = YLeaf(YType.boolean, "mvpn-present")

                                                        self.next_hop_afi = YLeaf(YType.uint32, "next-hop-afi")

                                                        self.next_hop_id = YLeaf(YType.uint32, "next-hop-id")

                                                        self.next_hop_id_refcount = YLeaf(YType.uint32, "next-hop-id-refcount")

                                                        self.next_hop_safi = YLeaf(YType.uint32, "next-hop-safi")

                                                        self.next_hop_table_id = YLeaf(YType.uint32, "next-hop-table-id")

                                                        self.next_hop_table_name = YLeaf(YType.str, "next-hop-table-name")

                                                        self.next_hop_vrf_name = YLeaf(YType.str, "next-hop-vrf-name")

                                                        self.nhid_feid = YLeaf(YType.uint64, "nhid-feid")

                                                        self.num_labels = YLeaf(YType.uint8, "num-labels")

                                                        self.number_of_extended_communities = YLeaf(YType.uint32, "number-of-extended-communities")

                                                        self.ospf_area_id = YLeaf(YType.str, "ospf-area-id")

                                                        self.path_rt_present = YLeaf(YType.boolean, "path-rt-present")

                                                        self.pathid = YLeaf(YType.uint32, "pathid")

                                                        self.private_flags = YLeaf(YType.uint16, "private-flags")

                                                        self.ref_cnt_of_backup = YLeaf(YType.uint32, "ref-cnt-of-backup")

                                                        self.route_label = YLeaf(YType.uint32, "route-label")

                                                        self.segmented_nexthop_present = YLeaf(YType.boolean, "segmented-nexthop-present")

                                                        self.source_asrt_present = YLeaf(YType.boolean, "source-asrt-present")

                                                        self.source_rd_present = YLeaf(YType.boolean, "source-rd-present")

                                                        self.tunnel_id = YLeaf(YType.uint32, "tunnel-id")

                                                        self.v6_information_source = YLeaf(YType.str, "v6-information-source")

                                                        self.v6_nexthop = YLeaf(YType.str, "v6-nexthop")

                                                        self.vrf_import_rt_present = YLeaf(YType.boolean, "vrf-import-rt-present")

                                                        self.labelstk = YList(self)
                                                        self.remote_backup_addr = YList(self)
                                                        self._segment_path = lambda: "ipv4-rib-edm-path"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath, ['address', 'backup_pathid', 'binding_label', 'flags', 'flags64', 'has_labelstk', 'information_source', 'interface_name', 'load_metric', 'looped', 'metric', 'mpls_feid', 'mvpn_present', 'next_hop_afi', 'next_hop_id', 'next_hop_id_refcount', 'next_hop_safi', 'next_hop_table_id', 'next_hop_table_name', 'next_hop_vrf_name', 'nhid_feid', 'num_labels', 'number_of_extended_communities', 'ospf_area_id', 'path_rt_present', 'pathid', 'private_flags', 'ref_cnt_of_backup', 'route_label', 'segmented_nexthop_present', 'source_asrt_present', 'source_rd_present', 'tunnel_id', 'v6_information_source', 'v6_nexthop', 'vrf_import_rt_present'], name, value)


                                                    class Labelstk(Entity):
                                                        """
                                                        Outgoing label stack for this path
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  int
                                                        
                                                        	**range:** 0..4294967295
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.Labelstk, self).__init__()

                                                            self.yang_name = "labelstk"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.uint32, "entry")
                                                            self._segment_path = lambda: "labelstk"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.Labelstk, ['entry'], name, value)


                                                    class RemoteBackupAddr(Entity):
                                                        """
                                                        Remote backup node address
                                                        
                                                        .. attribute:: entry
                                                        
                                                        	
                                                        	**type**\:  str
                                                        
                                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                        
                                                        

                                                        """

                                                        _prefix = 'ip-rib-ipv4-oper'
                                                        _revision = '2015-11-09'

                                                        def __init__(self):
                                                            super(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, self).__init__()

                                                            self.yang_name = "remote-backup-addr"
                                                            self.yang_parent_name = "ipv4-rib-edm-path"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self._child_container_classes = {}
                                                            self._child_list_classes = {}

                                                            self.entry = YLeaf(YType.str, "entry")
                                                            self._segment_path = lambda: "remote-backup-addr"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(RibStdby.Vrfs.Vrf.Afs.Af.Safs.Saf.IpRibRouteTableNames.IpRibRouteTableName.Routes.Route.RoutePath.Ipv4RibEdmPath.RemoteBackupAddr, ['entry'], name, value)

    def clone_ptr(self):
        self._top_entity = RibStdby()
        return self._top_entity

